@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1993
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1993
 // 
 // uBoundedBuffer.h -- Generic bounded buffer problem using a monitor and uAccept
 // 
 // Author           : Peter A. Buhr
 // Created On       : Sun Apr  4 10:20:32 1993
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Nov 30 09:00:13 2005
-// Update Count     : 15
+// Last Modified On : Thu Jan 26 22:29:10 2006
+// Update Count     : 16
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -29,48 +29,48 @@
 #define __U_BOUNDEDBUFFER_H__
 
 
-template<class ELEMTYPE> _Monitor uBoundedBuffer {
+template<class ElemType> _Monitor uBoundedBuffer {
   protected:
     const int size;					// number of buffer elements
     int front, back;					// position of front and back of queue
     int count;						// number of used elements in the queue
-    ELEMTYPE *Elements;
+    ElemType *elements;
   public:
     uBoundedBuffer( const int size = 10 ) : size( size ) {
         front = back = count = 0;
-        Elements = new ELEMTYPE[size];
+        elements = new ElemType[size];
     } // uBoundedBuffer::uBoundedBuffer
 
     ~uBoundedBuffer() {
-        delete [] Elements;
+        delete [] elements;
     } // uBoundedBuffer::~uBoundedBuffer
 
     _Nomutex int query() {
         return count;
     } // uBoundedBuffer::query
 
-    void insert( ELEMTYPE elem );
-    ELEMTYPE remove();
+    void insert( ElemType elem );
+    ElemType remove();
 }; // uBoundedBuffer
 
-template<class ELEMTYPE> inline void uBoundedBuffer<ELEMTYPE>::insert( ELEMTYPE elem ) {
+template<class ElemType> inline void uBoundedBuffer<ElemType>::insert( ElemType elem ) {
     if ( count == size ) {				// buffer full ?
         _Accept( remove );				// only allow removals
     } // if
 
-    Elements[back] = elem;
+    elements[back] = elem;
     back = ( back + 1 ) % size;
     count += 1;
 } // uBoundedBuffer::insert
 
-template<class ELEMTYPE> inline ELEMTYPE uBoundedBuffer<ELEMTYPE>::remove() {
-    ELEMTYPE elem;
+template<class ElemType> inline ElemType uBoundedBuffer<ElemType>::remove() {
+    ElemType elem;
 
     if ( count == 0 ) {					// buffer empty ?
         _Accept( insert );				// only allow insertions
     } // if
 
-    elem = Elements[front];
+    elem = elements[front];
     front = ( front + 1 ) % size;
     count -= 1;
 
