@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 2000
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 2000
 // 
 // uHeap.h -- generic heap data structure
 // 
 // Author           : Ashif S. Harji
 // Created On       : Tue Jun 20 11:12:58 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Aug  6 18:15:54 2005
-// Update Count     : 55
+// Last Modified On : Tue Sep 12 08:09:52 2006
+// Update Count     : 56
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -31,7 +31,6 @@
 
 
 #include <uC++.h>
-#include <uAssert.h>
 //#include <uDebug.h>
 
 
@@ -54,20 +53,20 @@ template<int MaxSize> class uStaticHeapArray {
     
 	ArrayType( int size ) {
 #ifdef __U_DEBUG__
-	    uAssert( size <= MaxSize );
+	    assert( size <= MaxSize );
 #endif // __U_DEBUG__
 	} // ArrayType::ArrayType
     
 	const Elt &operator[]( int index ) const {
 #ifdef __U_DEBUG__
-	    uAssert( 0 < index && index <= MaxSize );
+	    assert( 0 < index && index <= MaxSize );
 #endif // __U_DEBUG__
 	    return A[ index ];
 	} // ArrayType::operator[]
     
 	Elt &operator[]( int index ) {
 #ifdef __U_DEBUG__
-	    uAssert( 0 < index && index <= MaxSize );
+	    assert( 0 < index && index <= MaxSize );
 #endif // __U_DEBUG__
 	    return A[ index ];
 	} // ArrayType::operator[]
@@ -182,7 +181,7 @@ template<class KeyType, class DataType, template<class Elt> class Array> class u
     
     void deleteInsert( KeyType new_key, DataType new_data ) { // remove root element
 #ifdef __U_DEBUG__
-	uAssert( heapSize > 0 );
+	assert( heapSize > 0 );
 #endif // __U_DEBUG__
 	
 	A[1].key = new_key;
@@ -195,7 +194,7 @@ template<class KeyType, class DataType, template<class Elt> class Array> class u
 
     void deleteRoot() {					// remove root element
 #ifdef __U_DEBUG__
-	uAssert( heapSize > 0 );
+	assert( heapSize > 0 );
 #endif // __U_DEBUG__
 	
 	exchange( A[1], A[size()] );
