@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter Buhr 1997
+// uC++ Version 5.4.0, Copyright (C) Peter Buhr 1997
 // 
 // uDebuggerProtocolUnit.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Wed Oct 15 13:16:10 1997
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jun 28 16:51:29 2001
-// Update Count     : 10
+// Last Modified On : Tue Sep 12 08:10:44 2006
+// Update Count     : 11
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -127,7 +127,7 @@ void uDebuggerProtocolUnit::re_init( RequestType type ) {
 		size = sizeof(bpMarkConditionPDU);
 		break;
 	default:
-																uAssert(0);
+																assert(0);
 	}
 } // void uDebuggerProtocolUnit::re_init
 
@@ -138,27 +138,27 @@ uDebuggerProtocolUnit::uDebuggerProtocolUnit( RequestType type ) {
 uDebuggerProtocolUnit::~uDebuggerProtocolUnit() {}
 
 int uDebuggerProtocolUnit::total_size() {
-//													uAssert( pdu_data.request_type != NoType );
+//													assert( pdu_data.request_type != NoType );
 	return size + sizeof(RequestType);
 }
 
 InternalAddress uDebuggerProtocolUnit::total_buffer() {
-//													uAssert( pdu_data.request_type != NoType );
+//													assert( pdu_data.request_type != NoType );
 	return (InternalAddress) &pdu_data;
 }
 
 int uDebuggerProtocolUnit::data_size() {
-//													uAssert( pdu_data.request_type != NoType );
+//													assert( pdu_data.request_type != NoType );
 	return size;
 }
 
 InternalAddress uDebuggerProtocolUnit::data_buffer() {
-//													uAssert( pdu_data.request_type != NoType );
+//													assert( pdu_data.request_type != NoType );
 	return (InternalAddress) &pdu_data.data;
 }
 
 void uDebuggerProtocolUnit::createNinitLocalDebugger ( int max_no_of_breakpoints, int path_length ) {
-//									uAssert( pdu_data.request_type == NoType );
+//									assert( pdu_data.request_type == NoType );
 	pdu_data.data.init_local_debugger_data.max_no_of_breakpoints = max_no_of_breakpoints;
 	pdu_data.data.init_local_debugger_data.path_length = path_length;
 	pdu_data.request_type = NinitLocalDebugger;
@@ -166,7 +166,7 @@ void uDebuggerProtocolUnit::createNinitLocalDebugger ( int max_no_of_breakpoints
 }
 
 void uDebuggerProtocolUnit::createNcreateULThread( ULThreadId ul_thread_id, ClusterId cluster_id, MinimalRegisterSet& reg_set, const char* name ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.data.create_ul_thread_data.ul_thread_id = ul_thread_id;
 	pdu_data.data.create_ul_thread_data.cluster_id = cluster_id;
 	pdu_data.data.create_ul_thread_data.reg_set = reg_set;
@@ -178,7 +178,7 @@ void uDebuggerProtocolUnit::createNcreateULThread( ULThreadId ul_thread_id, Clus
 }
 
 void uDebuggerProtocolUnit::createNattachULThread( ULThreadId ul_thread_id, ULThreadId ret_thread_id, ClusterId cluster_id, MinimalRegisterSet& reg_set, const char* name ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.data.attach_ul_thread_data.ul_thread_id = ul_thread_id;
 	pdu_data.data.attach_ul_thread_data.ret_thread_id = ret_thread_id;
 	pdu_data.data.attach_ul_thread_data.cluster_id = cluster_id;
@@ -191,14 +191,14 @@ void uDebuggerProtocolUnit::createNattachULThread( ULThreadId ul_thread_id, ULTh
 }
 
 void uDebuggerProtocolUnit::createNdestroyULThread( ULThreadId ul_thread_id ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.data.ul_thread_id = ul_thread_id;
 	pdu_data.request_type = NdestroyULThread;
 	size = sizeof(ULThreadId);
 }
 
 void uDebuggerProtocolUnit::createNcreateKernelThread( ULThreadId ul_thread_id, ClusterId cluster_id_exec, KernelThreadId kernel_thread_id, ClusterId cluster_id, OSKernelThreadId os_kernel_thread_id, bool copy_from_init ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.data.create_kernel_thread_data.ul_thread_id = ul_thread_id;
 	pdu_data.data.create_kernel_thread_data.kernel_thread_id = kernel_thread_id;
 	pdu_data.data.create_kernel_thread_data.os_kernel_thread_id = os_kernel_thread_id;
@@ -210,7 +210,7 @@ void uDebuggerProtocolUnit::createNcreateKernelThread( ULThreadId ul_thread_id,
 }
 
 void uDebuggerProtocolUnit::createNdestroyKernelThread( ULThreadId ul_thread_id, KernelThreadId kernel_thread_id ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.data.destroy_kernel_thread_data.kernel_thread_id = kernel_thread_id;
 	pdu_data.data.destroy_kernel_thread_data.ul_thread_id = ul_thread_id;
 	pdu_data.request_type = NdestroyKernelThread;
@@ -218,7 +218,7 @@ void uDebuggerProtocolUnit::createNdestroyKernelThread( ULThreadId ul_thread_id,
 }
 
 void uDebuggerProtocolUnit::createNcreateCluster( ClusterId cluster_id, const char* name, bool copy_from_init ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.data.create_cluster_data.cluster_id = cluster_id;
 	memcpy( pdu_data.data.create_cluster_data.name, (char*)name, maxEntityName );
 	// just to be sure
@@ -229,14 +229,14 @@ void uDebuggerProtocolUnit::createNcreateCluster( ClusterId cluster_id, const ch
 }
 
 void uDebuggerProtocolUnit::createNdestroyCluster( ClusterId cluster_id ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.data.cluster_id = cluster_id;
 	pdu_data.request_type = NdestroyCluster;
 	size = sizeof(ClusterId);
 }
 
 void uDebuggerProtocolUnit::createNmigrateULThread( ULThreadId ul_thread_id, ClusterId cluster_id_to ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.data.migrate_ul_thread_data.ul_thread_id = ul_thread_id;
 	pdu_data.data.migrate_ul_thread_data.cluster_id_to = cluster_id_to;
 	pdu_data.request_type = NmigrateULThread;
@@ -244,7 +244,7 @@ void uDebuggerProtocolUnit::createNmigrateULThread( ULThreadId ul_thread_id, Clu
 }
 
 void uDebuggerProtocolUnit::createNmigrateKernelThread( ULThreadId ul_thread_id, KernelThreadId kernel_thread_id, ClusterId cluster_id_to ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.data.migrate_kernel_thread_data.ul_thread_id = ul_thread_id;
 	pdu_data.data.migrate_kernel_thread_data.kernel_thread_id = kernel_thread_id;
 	pdu_data.data.migrate_kernel_thread_data.cluster_id_to = cluster_id_to;
@@ -253,7 +253,7 @@ void uDebuggerProtocolUnit::createNmigrateKernelThread( ULThreadId ul_thread_id,
 }
 
 void uDebuggerProtocolUnit::createNhitBreakpoint( ULThreadId ul_thread_id, int breakpoint_no, MinimalRegisterSet& reg_set ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.data.hit_breakpoint_data.ul_thread_id = ul_thread_id;
 	pdu_data.data.hit_breakpoint_data.breakpoint_no = breakpoint_no;
 	pdu_data.data.hit_breakpoint_data.reg_set = reg_set;
@@ -262,27 +262,27 @@ void uDebuggerProtocolUnit::createNhitBreakpoint( ULThreadId ul_thread_id, int b
 }
 
 void uDebuggerProtocolUnit::createNfinishLocalDebugger( bool deliver ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.request_type = NfinishLocalDebugger;
 	pdu_data.data.deliver = deliver;
 	size = sizeof(bool);
 }
 
 void uDebuggerProtocolUnit::createNabortApplication( int pid ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.request_type = NabortApplication;
 	pdu_data.data.pid = pid;
 	size = sizeof(int);
 }
 
 void uDebuggerProtocolUnit::createNapplicationAttached() {
-//	                                                uAssert( pdu_data.request_type == NoType );
+//	                                                assert( pdu_data.request_type == NoType );
 	pdu_data.request_type = NapplicationAttached;
 	size = 0;
 }
 
 void uDebuggerProtocolUnit::createOcontULThread( ULThreadId ul_thread_id, char* bp_mask, int adjustment ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.data.cont_ul_thread_data.ul_thread_id = ul_thread_id;
 	pdu_data.data.cont_ul_thread_data.adjustment = adjustment;
 	if ( bp_mask ) {
@@ -295,13 +295,13 @@ void uDebuggerProtocolUnit::createOcontULThread( ULThreadId ul_thread_id, char*
 }
 
 void uDebuggerProtocolUnit::createOshutdownConnection() {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.request_type = OshutdownConnection;
 	size = 0;
 }
 
 void uDebuggerProtocolUnit::createOcheckCodeRange( CodeAddress low_pc_app, CodeAddress high_pc_app, CodeAddress low_pc_handler, CodeAddress high_pc_handler, ClusterId cluster_id ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.request_type = OcheckCodeRange;
 	pdu_data.data.check_breakpoint_range_data.low_pc_app = low_pc_app;
 	pdu_data.data.check_breakpoint_range_data.high_pc_app = high_pc_app;
@@ -312,7 +312,7 @@ void uDebuggerProtocolUnit::createOcheckCodeRange( CodeAddress low_pc_app, CodeA
 }
 
 void uDebuggerProtocolUnit::createOignoreClusterMigration( ClusterId cluster_id, bool ignore ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.request_type = OignoreClusterMigration;
 	pdu_data.data.ignore_cluster_migration_data.cluster_id = cluster_id;
 	pdu_data.data.ignore_cluster_migration_data.ignore = ignore;
@@ -320,7 +320,7 @@ void uDebuggerProtocolUnit::createOignoreClusterMigration( ClusterId cluster_id,
 }
 
 void uDebuggerProtocolUnit::createOignoreKernelThreadMigration( KernelThreadId kernel_thread_id, bool ignore ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.request_type = OignoreKernelThreadMigration;
 	pdu_data.data.ignore_kernel_thread_migration_data.kernel_thread_id = kernel_thread_id;
 	pdu_data.data.ignore_kernel_thread_migration_data.ignore = ignore;
@@ -328,52 +328,52 @@ void uDebuggerProtocolUnit::createOignoreKernelThreadMigration( KernelThreadId k
 }
 
 void uDebuggerProtocolUnit::createOstartAtomicOperation() {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.request_type = OstartAtomicOperation;
 	size = 0;
 }
 
 void uDebuggerProtocolUnit::createCconfirmCodeRange( bool ok ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.request_type = CconfirmCodeRange;
 	pdu_data.data.confirm_breakpoint_range_data.ok = ok;
 	size = sizeof(confirmCodeRangePDU);
 }
 
 void uDebuggerProtocolUnit::createCconfirmAtomicOperation ( bool ok ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.request_type = CconfirmAtomicOperation;
 	pdu_data.data.confirm_atomic_operation_data.ok = ok;
 	size = sizeof(confirmAtomicOperationPDU);
 }
 
 void uDebuggerProtocolUnit::createCgeneralConfirmation ( ULThreadId ul_thread_id ) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.data.ul_thread_id = ul_thread_id;
 	pdu_data.request_type = CgeneralConfirmation;
 	size = sizeof(ULThreadId);
 }
 
 void uDebuggerProtocolUnit::createCfinishLocalDebugger () {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.request_type = CfinishLocalDebugger;
 	size = 0;
 }
 
 void uDebuggerProtocolUnit::createCinitLocalDebugger () {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.request_type = CinitLocalDebugger;
 	size = 0;
 }
 
 void uDebuggerProtocolUnit::createCfinishAtomicOperation () {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.request_type = CfinishAtomicOperation;
 	size = 0;
 }
 
 void uDebuggerProtocolUnit::createArequestAddress (ULThreadId ul_thread_id, MinimalRegisterSet& reg_set, int bp_no) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.data.addr_request.ul_thread_id = ul_thread_id;
 	pdu_data.data.addr_request.bp_no = bp_no;
 	pdu_data.request_type = ArequestAddress ;
@@ -385,7 +385,7 @@ void uDebuggerProtocolUnit::createAreplyAddress (ULThreadId ul_thread_id, long f
 														BreakpointCondition::VariableType vtp1, long field_off2, long offset2, 
 														BreakpointCondition::AddressType atp2, BreakpointCondition::VariableType vtp2, 
 														BreakpointCondition::OperationType opt) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.request_type = AreplyAddress;
 	pdu_data.data.addr_reply.ul_thread_id = ul_thread_id;
 	pdu_data.data.addr_reply.bp_condition.var[0].field_off   = field_off1;
@@ -401,7 +401,7 @@ void uDebuggerProtocolUnit::createAreplyAddress (ULThreadId ul_thread_id, long f
 }
 
 void uDebuggerProtocolUnit::createBbpMarkCondition(int bp_no, ULThreadId ul_thread_id) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.data.bp_add.bp_no = bp_no;
 	pdu_data.data.bp_add.ul_thread_id = ul_thread_id;
 	pdu_data.request_type = BbpMarkCondition;
@@ -409,7 +409,7 @@ void uDebuggerProtocolUnit::createBbpMarkCondition(int bp_no, ULThreadId ul_thre
 }
 
 void uDebuggerProtocolUnit::createBbpClearCondition (int bp_no, ULThreadId ul_thread_id) {
-//													uAssert( pdu_data.request_type == NoType );
+//													assert( pdu_data.request_type == NoType );
 	pdu_data.data.bp_clear.bp_no = bp_no;
 	pdu_data.data.bp_clear.ul_thread_id = ul_thread_id;
 	pdu_data.request_type = BbpClearCondition;
@@ -425,13 +425,13 @@ uDebuggerProtocolUnit::RequestType uDebuggerProtocolUnit::getType() {
 //
 
 void	uDebuggerProtocolUnit::readNinitLocalDebugger ( int& max_no_of_breakpoints, int& path_length ) {
-													uAssert( pdu_data.request_type == NinitLocalDebugger );
+													assert( pdu_data.request_type == NinitLocalDebugger );
 	max_no_of_breakpoints = pdu_data.data.init_local_debugger_data.max_no_of_breakpoints;
 	path_length = pdu_data.data.init_local_debugger_data.path_length;
 }
 
 void uDebuggerProtocolUnit::readNcreateULThread( ULThreadId& ul_thread_id, ClusterId& cluster_id, MinimalRegisterSet &reg_set, char*& name ) {
-													uAssert( pdu_data.request_type == NcreateULThread );
+													assert( pdu_data.request_type == NcreateULThread );
 	ul_thread_id = pdu_data.data.create_ul_thread_data.ul_thread_id;
 	cluster_id = pdu_data.data.create_ul_thread_data.cluster_id;
 	reg_set = pdu_data.data.create_ul_thread_data.reg_set;
@@ -439,7 +439,7 @@ void uDebuggerProtocolUnit::readNcreateULThread( ULThreadId& ul_thread_id, Clust
 }
 
 void uDebuggerProtocolUnit::readNattachULThread( ULThreadId& ul_thread_id, ULThreadId& ret_thread_id, ClusterId& cluster_id, MinimalRegisterSet &reg_set, char*& name ) {
-													uAssert( pdu_data.request_type == NattachULThread );
+													assert( pdu_data.request_type == NattachULThread );
 	ul_thread_id = pdu_data.data.attach_ul_thread_data.ul_thread_id;
 	ret_thread_id = pdu_data.data.attach_ul_thread_data.ret_thread_id;
 	cluster_id = pdu_data.data.attach_ul_thread_data.cluster_id;
@@ -448,12 +448,12 @@ void uDebuggerProtocolUnit::readNattachULThread( ULThreadId& ul_thread_id, ULThr
 }
 
 void uDebuggerProtocolUnit::readNdestroyULThread( ULThreadId& ul_thread_id ) {
-													uAssert( pdu_data.request_type == NdestroyULThread );
+													assert( pdu_data.request_type == NdestroyULThread );
 	ul_thread_id = pdu_data.data.ul_thread_id;
 }
 
 void uDebuggerProtocolUnit::readNcreateKernelThread( ULThreadId& ul_thread_id, ClusterId &cluster_id_exec, KernelThreadId& kernel_thread_id, ClusterId& cluster_id, OSKernelThreadId& os_kernel_thread_id, bool& copy_from_init ) {
-													uAssert( pdu_data.request_type == NcreateKernelThread );
+													assert( pdu_data.request_type == NcreateKernelThread );
 	ul_thread_id = pdu_data.data.create_kernel_thread_data.ul_thread_id;
 	kernel_thread_id = pdu_data.data.create_kernel_thread_data.kernel_thread_id;
 	os_kernel_thread_id = pdu_data.data.create_kernel_thread_data.os_kernel_thread_id;
@@ -463,70 +463,70 @@ void uDebuggerProtocolUnit::readNcreateKernelThread( ULThreadId& ul_thread_id, C
 }
 
 void uDebuggerProtocolUnit::readNdestroyKernelThread( ULThreadId& ul_thread_id, KernelThreadId& kernel_thread_id ) {
-													uAssert( pdu_data.request_type == NdestroyKernelThread );
+													assert( pdu_data.request_type == NdestroyKernelThread );
 	kernel_thread_id = pdu_data.data.destroy_kernel_thread_data.kernel_thread_id;
 	ul_thread_id = pdu_data.data.destroy_kernel_thread_data.ul_thread_id;
 }
 
 void uDebuggerProtocolUnit::readNcreateCluster( ClusterId& cluster_id, char*& name, bool& copy_from_init ) {
-													uAssert( pdu_data.request_type == NcreateCluster );
+													assert( pdu_data.request_type == NcreateCluster );
 	cluster_id = pdu_data.data.create_cluster_data.cluster_id;
 	name = pdu_data.data.create_cluster_data.name;
 	copy_from_init = pdu_data.data.create_cluster_data.copy_from_init;
 }
 
 void uDebuggerProtocolUnit::readNdestroyCluster( ClusterId& cluster_id ) {
-													uAssert( pdu_data.request_type == NdestroyCluster );
+													assert( pdu_data.request_type == NdestroyCluster );
 	cluster_id = pdu_data.data.cluster_id;
 }
 
 void uDebuggerProtocolUnit::readNmigrateULThread( ULThreadId& ul_thread_id, ClusterId& cluster_id_to ) {
-													uAssert( pdu_data.request_type == NmigrateULThread );
+													assert( pdu_data.request_type == NmigrateULThread );
 	ul_thread_id = pdu_data.data.migrate_ul_thread_data.ul_thread_id;
 	cluster_id_to = pdu_data.data.migrate_ul_thread_data.cluster_id_to;
 }
 
 void uDebuggerProtocolUnit::readNmigrateKernelThread( ULThreadId& ul_thread_id, KernelThreadId& kernel_thread_id, ClusterId& cluster_id_to ) {
-													uAssert( pdu_data.request_type == NmigrateKernelThread );
+													assert( pdu_data.request_type == NmigrateKernelThread );
 	ul_thread_id = pdu_data.data.migrate_kernel_thread_data.ul_thread_id;
 	kernel_thread_id = pdu_data.data.migrate_kernel_thread_data.kernel_thread_id;
 	cluster_id_to = pdu_data.data.migrate_kernel_thread_data.cluster_id_to;
 }
 
 void uDebuggerProtocolUnit::readNhitBreakpoint( ULThreadId& ul_thread_id, int& breakpoint_no, MinimalRegisterSet& reg_set ) {
-													uAssert( pdu_data.request_type == NhitBreakpoint );
+													assert( pdu_data.request_type == NhitBreakpoint );
 	ul_thread_id = pdu_data.data.hit_breakpoint_data.ul_thread_id;
 	breakpoint_no = pdu_data.data.hit_breakpoint_data.breakpoint_no;
 	reg_set = pdu_data.data.hit_breakpoint_data.reg_set;
 }
 
 void	uDebuggerProtocolUnit::readNfinishLocalDebugger( bool& deliver ) {
-													uAssert( pdu_data.request_type == NfinishLocalDebugger );
+													assert( pdu_data.request_type == NfinishLocalDebugger );
 	deliver = pdu_data.data.deliver;
 }
 
 void	uDebuggerProtocolUnit::readNabortApplication( int &pid ) {
-													uAssert( pdu_data.request_type == NabortApplication );
+													assert( pdu_data.request_type == NabortApplication );
 	pid = pdu_data.data.pid;
 }
 
 void uDebuggerProtocolUnit::readNapplicationAttached() {
-													uAssert( pdu_data.request_type == NapplicationAttached );
+													assert( pdu_data.request_type == NapplicationAttached );
 }
 
 void uDebuggerProtocolUnit::readOcontULThread( ULThreadId& ul_thread_id, char* bp_mask, int &adjustment ) {
-													uAssert( pdu_data.request_type == OcontULThread );
+													assert( pdu_data.request_type == OcontULThread );
 	ul_thread_id = pdu_data.data.cont_ul_thread_data.ul_thread_id;
 	adjustment = pdu_data.data.cont_ul_thread_data.adjustment;
 	memcpy( (char*)bp_mask, (char*)pdu_data.data.cont_ul_thread_data.bp_mask, SIZE_OF_BREAKPOINT_FIELD / NBBY );
 }
 
 void uDebuggerProtocolUnit::readOshutdownConnection() {
-													uAssert( pdu_data.request_type == OshutdownConnection );
+													assert( pdu_data.request_type == OshutdownConnection );
 }
 
 void uDebuggerProtocolUnit::readOcheckCodeRange( CodeAddress& low_pc_app, CodeAddress& high_pc_app, CodeAddress& low_pc_handler, CodeAddress& high_pc_handler, ClusterId& cluster_id ) {
-													uAssert( pdu_data.request_type == OcheckCodeRange );
+													assert( pdu_data.request_type == OcheckCodeRange );
 	low_pc_app = pdu_data.data.check_breakpoint_range_data.low_pc_app;
 	high_pc_app = pdu_data.data.check_breakpoint_range_data.high_pc_app;
 	low_pc_handler = pdu_data.data.check_breakpoint_range_data.low_pc_handler;
@@ -535,33 +535,33 @@ void uDebuggerProtocolUnit::readOcheckCodeRange( CodeAddress& low_pc_app, CodeAd
 }
 
 void uDebuggerProtocolUnit::readOignoreClusterMigration( ClusterId& cluster_id, bool& ignore ) {
-													uAssert( pdu_data.request_type == OignoreClusterMigration );
+													assert( pdu_data.request_type == OignoreClusterMigration );
 	cluster_id = pdu_data.data.ignore_cluster_migration_data.cluster_id;
 	ignore = pdu_data.data.ignore_cluster_migration_data.ignore;
 }
 
 void uDebuggerProtocolUnit::readOignoreKernelThreadMigration( KernelThreadId& kernel_thread_id, bool& ignore ) {
-													uAssert( pdu_data.request_type == OignoreKernelThreadMigration );
+													assert( pdu_data.request_type == OignoreKernelThreadMigration );
 	kernel_thread_id = pdu_data.data.ignore_kernel_thread_migration_data.kernel_thread_id;
 	ignore = pdu_data.data.ignore_kernel_thread_migration_data.ignore;
 }
 
 void uDebuggerProtocolUnit::readOstartAtomicOperation() {
-													uAssert( pdu_data.request_type == OstartAtomicOperation );
+													assert( pdu_data.request_type == OstartAtomicOperation );
 }
 
 void uDebuggerProtocolUnit::readCconfirmCodeRange( bool &ok ) {
-													uAssert( pdu_data.request_type == CconfirmCodeRange );
+													assert( pdu_data.request_type == CconfirmCodeRange );
 	ok = pdu_data.data.confirm_breakpoint_range_data.ok;
 }
 
 void uDebuggerProtocolUnit::readCconfirmAtomicOperation ( bool &ok ) {
-													uAssert( pdu_data.request_type == CconfirmAtomicOperation );
+													assert( pdu_data.request_type == CconfirmAtomicOperation );
 	ok = pdu_data.data.confirm_atomic_operation_data.ok;
 }
 
 ULThreadId uDebuggerProtocolUnit::readCgeneralConfirmation () {
-													uAssert( pdu_data.request_type == CgeneralConfirmation || 
+													assert( pdu_data.request_type == CgeneralConfirmation || 
 															 pdu_data.request_type == OcontULThread ||
 															 pdu_data.request_type == AreplyAddress);
 	if ( pdu_data.request_type == CgeneralConfirmation ) {
@@ -574,37 +574,37 @@ ULThreadId uDebuggerProtocolUnit::readCgeneralConfirmation () {
 }
 
 void uDebuggerProtocolUnit::readCfinishLocalDebugger () {
-													uAssert( pdu_data.request_type == CfinishLocalDebugger );
+													assert( pdu_data.request_type == CfinishLocalDebugger );
 }
 
 void uDebuggerProtocolUnit::readCinitLocalDebugger () {
-													uAssert( pdu_data.request_type == CinitLocalDebugger );
+													assert( pdu_data.request_type == CinitLocalDebugger );
 }
 
 void uDebuggerProtocolUnit::readCfinishAtomicOperation () {
-													uAssert( pdu_data.request_type == CfinishAtomicOperation );
+													assert( pdu_data.request_type == CfinishAtomicOperation );
 }
 
 void uDebuggerProtocolUnit::readArequestAddress (ULThreadId& ul_thread_id, MinimalRegisterSet& reg_set, int& bp_no ) {
-	                                                uAssert( pdu_data.request_type == ArequestAddress );
+	                                                assert( pdu_data.request_type == ArequestAddress );
 	ul_thread_id = pdu_data.data.addr_request.ul_thread_id;
 	bp_no = pdu_data.data.addr_request.bp_no;
 	reg_set = pdu_data.data.addr_request.reg_set;
 }
 
 void uDebuggerProtocolUnit::readAreplyAddress (BreakpointCondition& bp_condition) {
-	                                                uAssert( pdu_data.request_type == AreplyAddress );
+	                                                assert( pdu_data.request_type == AreplyAddress );
     bp_condition = pdu_data.data.addr_reply.bp_condition;													
 }
 
 void uDebuggerProtocolUnit::readBbpMarkCondition(int& bp_no, ULThreadId& ul_thread_id) {
-	                                                uAssert( pdu_data.request_type == BbpMarkCondition );
+	                                                assert( pdu_data.request_type == BbpMarkCondition );
 	bp_no = pdu_data.data.bp_add.bp_no;
 	ul_thread_id = pdu_data.data.bp_add.ul_thread_id;
 }
 
 void uDebuggerProtocolUnit::readBbpClearCondition (int &bp_no, ULThreadId& ul_thread_id) {
-	                                                uAssert( pdu_data.request_type == BbpClearCondition );
+	                                                assert( pdu_data.request_type == BbpClearCondition );
 	bp_no = pdu_data.data.bp_clear.bp_no;
 	ul_thread_id = pdu_data.data.bp_clear.ul_thread_id;
 }
