@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Martin Karsten 1995
+// uC++ Version 5.4.0, Copyright (C) Martin Karsten 1995
 // 
 // uLocalDebugger.cc -- 
 // 
 // Author           : Martin Karsten
 // Created On       : Thu Apr 20 21:34:48 1995
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 11:21:52 2005
-// Update Count     : 684
+// Last Modified On : Tue Sep 12 08:10:26 2006
+// Update Count     : 700
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -60,8 +60,8 @@ bool uLocalDebugger::abort_confirmed = false;
 // KEEP CONSISTENT WITH THE CORRESPONDING FUNCTIONS IN uC++.h
 // REASON : ACHIEVE OPTIMIZATION WITHOUT TURNING ON THE COMPILER'S
 // OPTIMIZATION FLAG (-O) TO MAKE INLINE FUNCTIONS REALLY INLINE
-#define U_THIS_TASK		THREAD_GETMEM( uActiveTask)		// uThisTask()
-#define U_THIS_CLUSTER	THREAD_GETMEM( uActiveCluster)	// uThisCluster()
+#define U_THIS_TASK		THREAD_GETMEM( activeTask)		// uThisTask()
+#define U_THIS_CLUSTER	THREAD_GETMEM( activeCluster)	// uThisCluster()
 
 // include now, so that everything is already declared
 #include <uLocalDebuggerHandler.h>
@@ -79,7 +79,7 @@ void uLocalDebugger::readPDU( uSocketClient &sockClient, uDebuggerProtocolUnit &
 
 	if ( sockClient.read( (char *)&request_type, sizeof(uDebuggerProtocolUnit::RequestType) ) != sizeof(uDebuggerProtocolUnit::RequestType) ) {
 		uLocalDebugger::uGlobalDebuggerActive = false;
-		uExit( -1 );									// TEMPORARY
+		exit( -1 );									// TEMPORARY
 		uAbort( "uLocalDebugger/readPDU : global debugger is gone" );
 	} // if
 
@@ -90,7 +90,7 @@ void uLocalDebugger::readPDU( uSocketClient &sockClient, uDebuggerProtocolUnit &
 	if ( pdu.data_size() ) {
 		if ( sockClient.read( (char *)pdu.data_buffer(), pdu.data_size() ) != pdu.data_size() ) {
 			uLocalDebugger::uGlobalDebuggerActive = false;
-			uExit( -1 );								// TEMPORARY
+			exit( -1 );								// TEMPORARY
 			uAbort( "uLocalDebugger/readPDU : global debugger is gone" );
 		} // if
 	} // if
@@ -158,14 +158,14 @@ void uLocalDebuggerReader::main() {
 #ifdef __U_DEBUG_H__
 #endif // __U_DEBUG_H__
 			uDebugPrt( "%d (uLocalDebuggerReader &)0x%p.main, saw OignoreClusterMigration, cluster:0x%p, ignore:%d\n", __LINE__, this, cluster, ignore );
-			cluster->uDebugIgnore = ignore;
+			cluster->debugIgnore = ignore;
 			break;
 		  case uDebuggerProtocolUnit::OignoreKernelThreadMigration:
 			pdu.readOignoreKernelThreadMigration( processor, ignore );
 #ifdef __U_DEBUG_H__
 #endif // __U_DEBUG_H__
 			uDebugPrt( "%d (uLocalDebuggerReader &)0x%p.main, saw OignoreKernelThreadMigration, processor:0x%p, ignore:%d\n", __LINE__, this, processor, ignore );
-			processor->uDebugIgnore = ignore;
+			processor->debugIgnore = ignore;
 			break;
 		  case uDebuggerProtocolUnit::BbpMarkCondition:
 			{
@@ -316,7 +316,7 @@ void uLocalDebugger::resetConditionMask( int bp_no, void *ul_thread_id ) {
 
 	// A non-existent conditional breakpoint should not be deleted.
 	
-	uAssert( code );
+	assert( code );
 } // uLocalDebugger::resetConditionMask
 
 
@@ -329,15 +329,15 @@ void uLocalDebugger::deregister() {
 
 	uDebuggerProtocolUnit pdu;
 
-	// de-register the uSystemProcessor
-	pdu.createNdestroyKernelThread( U_THIS_TASK, uKernelModule::uSystemProcessor );
+	// de-register the systemProcessor
+	pdu.createNdestroyKernelThread( U_THIS_TASK, uKernelModule::systemProcessor );
 	send( pdu );
 
 	// just consume the confirmation PDU and trust the global debugger
 	receive();
 
-	// de-register the uSystemCluster
-	pdu.createNdestroyCluster( uKernelModule::uSystemCluster );
+	// de-register the systemCluster
+	pdu.createNdestroyCluster( uKernelModule::systemCluster );
 	send( pdu );
 
 	pdu.re_init( uDebuggerProtocolUnit::NoType );
@@ -372,12 +372,12 @@ void uLocalDebugger::uCreateLocalDebugger( int port, char *machine, char *name )
 	// Since stream I/O is done on the system cluster, ignore the migration
 	// or the cost is too high.
 
-	uKernelModule::uSystemCluster->uDebugIgnore = true;
+	uKernelModule::systemCluster->debugIgnore = true;
 #else
     // TEMPORARY: THE GLOBAL DEBUGGER FAILS IF THIS IS NOT SET TO FALSE: SOURCE
     // CODE FOR TASKS CANNOT BE FOUND. IT NEEDS FIXING.
 
-	uKernelModule::uSystemProcessor->uDebugIgnore = false;
+	uKernelModule::systemProcessor->debugIgnore = false;
 #endif // __U_MULTI__
 
 	// now start the dispatcher task
@@ -386,8 +386,8 @@ void uLocalDebugger::uCreateLocalDebugger( int port, char *machine, char *name )
 	// register clusters
 	uSeqIter<uClusterDL> ci;
 	uClusterDL *cr;
-	for ( ci.over( *uKernelModule::uGlobalClusters ); ci >> cr; ) {
-		uCluster &cluster = cr->uGet();
+	for ( ci.over( *uKernelModule::globalClusters ); ci >> cr; ) {
+		uCluster &cluster = cr->cluster();
 #ifdef __U_DEBUG_H__
 		uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, cluster is %s (0x%p)\n", __LINE__, this, cluster.getName(), &cluster );
 #endif // __U_DEBUG_H__
@@ -396,30 +396,30 @@ void uLocalDebugger::uCreateLocalDebugger( int port, char *machine, char *name )
 
 		// register processors associated with this cluster
 		uProcessorDL *pr;
-		for ( uSeqIter<uProcessorDL> iter( cluster.uProcessorsOnCluster ); iter >> pr; ) {
-			uProcessor &processor = pr->uGet();
+		for ( uSeqIter<uProcessorDL> iter( cluster.processorsOnCluster ); iter >> pr; ) {
+			uProcessor &processor = pr->processor();
 #ifdef __U_DEBUG_H__
 			uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, processor is 0x%p\n", __LINE__, this, &processor );
 #endif // __U_DEBUG_H__
-			pdu.createNcreateKernelThread( U_THIS_TASK, U_THIS_CLUSTER, &processor, &cluster, processor.uPid, processor.uDebugIgnore );
+			pdu.createNcreateKernelThread( U_THIS_TASK, U_THIS_CLUSTER, &processor, &cluster, processor.pid, processor.debugIgnore );
 			send( pdu );
 			receive();
 		} // for
 
 		// register tasks on the cluster
 		uBaseTaskDL *bt;
-		for ( uSeqIter<uBaseTaskDL> iter( cluster.uTasksOnCluster ); iter >> bt; ) {
-			uBaseTask &task = bt->uGet();
+		for ( uSeqIter<uBaseTaskDL> iter( cluster.tasksOnCluster ); iter >> bt; ) {
+			uBaseTask &task = bt->task();
 #ifdef __U_DEBUG_H__
 			uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, task %s (0x%p)\n", __LINE__, this, task.getName(), &task );
 #endif // __U_DEBUG_H__
 			// ignore  boot, system, local debugger, dispatcher and processor tasks
 
-			if ( &task != uKernelModule::uTaskBoot && &task != uKernelModule::uTaskSystem &&
-				 &task != uLocalDebuggerInstance && &task != dispatcher && &(task.uBound) == (uProcessor *)0 ) {
+			if ( &task != uKernelModule::bootTask && &task != uKernelModule::systemTask &&
+				 &task != uLocalDebuggerInstance && &task != dispatcher && &(task.bound) == (uProcessor *)0 ) {
 				// retrieve some important registers
 				MinimalRegisterSet regs;
-				int *registers = (int *)task.uTaskDebugMask;
+				int *registers = (int *)task.taskDebugMask;
 				regs.pc = 0;
 				regs.fp = registers[0];
 				regs.sp = registers[1];
@@ -427,11 +427,11 @@ void uLocalDebugger::uCreateLocalDebugger( int port, char *machine, char *name )
 				pdu.createNattachULThread( &task, U_THIS_TASK, &cluster, regs, task.getName() );
 #else
 				// in uni-processor, pretend that every task exist on the system cluster
-				pdu.createNattachULThread( &task, U_THIS_TASK, uKernelModule::uSystemCluster, regs, task.getName() );
+				pdu.createNattachULThread( &task, U_THIS_TASK, uKernelModule::systemCluster, regs, task.getName() );
 #endif
 				send( pdu );
 				receive();
-				memset( task.uTaskDebugMask, 0, 8 );
+				memset( task.taskDebugMask, 0, 8 );
 			} // if
 		} // for
 	} // for
@@ -446,7 +446,7 @@ void uLocalDebugger::uCreateLocalDebugger( int port, char *machine, char *name )
 
 
 uLocalDebugger::uLocalDebugger( char *port, char *machine, char *name ) :
-		uBaseTask ( *uKernelModule::uSystemCluster ), port( atoi(port) ), machine( machine ), name( name ), pdu( *new uDebuggerProtocolUnit ) {
+		uBaseTask ( *uKernelModule::systemCluster ), port( atoi(port) ), machine( machine ), name( name ), pdu( *new uDebuggerProtocolUnit ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.uLocalDebugger( port:%s, machine:%s, name:%s, done\n", __LINE__, this, port, machine, name );
 #endif // __U_DEBUG_H__
@@ -460,7 +460,7 @@ uLocalDebugger::uLocalDebugger( char *port, char *machine, char *name ) :
 } // uLocalDebugger::uLocalDebugger
 
 
-uLocalDebugger::uLocalDebugger( int port ) : uBaseTask ( *uKernelModule::uSystemCluster ), port( port ), pdu( *new uDebuggerProtocolUnit ) {
+uLocalDebugger::uLocalDebugger( int port ) : uBaseTask ( *uKernelModule::systemCluster ), port( port ), pdu( *new uDebuggerProtocolUnit ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.uLocalDebugger( port:%d ), done\n", __LINE__, this, port );
 #endif // __U_DEBUG_H__
@@ -490,7 +490,7 @@ void uLocalDebugger::send( uDebuggerProtocolUnit &pdu ) {
     uDebugPrt( "%d (uLocalDebugger &)0x%p.send, type %d, total_size %d\n", __LINE__, this, pdu.getType(), pdu.total_size() );
 #endif // __U_DEBUG_H__
 
-    uAssert( uLocalDebuggerActive );
+    assert( uLocalDebuggerActive );
     sockClient->write( pdu.total_buffer(), pdu.total_size() );
 
 #ifdef __U_DEBUG_H__
@@ -504,7 +504,7 @@ void uLocalDebugger::receive() {						// only called by the local debugger
     uDebugPrt( "%d (uLocalDebugger &)0x%p.receive, task %s (0x%p) goes to sleep\n", __LINE__, this, (U_THIS_TASK)->getName(), U_THIS_TASK );
 #endif // __U_DEBUG_H__
 
-    uAssert( uLocalDebuggerActive );
+    assert( uLocalDebuggerActive );
     debugger_blocked_tasks += 1;
 	_Accept( unblockTask );
 	debugger_blocked_tasks -= 1;
@@ -520,7 +520,7 @@ bool uLocalDebugger::receive( uDebuggerProtocolUnit &pdu ) {
     uDebugPrt( "%d (uLocalDebugger &)0x%p.receive, task %s (0x%p) goes to sleep / pdu is 0x%p\n", __LINE__, this, (U_THIS_TASK)->getName(), U_THIS_TASK, &pdu );
 #endif // __U_DEBUG_H__
 
-    uAssert( uLocalDebuggerActive );
+    assert( uLocalDebuggerActive );
     debugger_blocked_tasks += 1;
     blockedNode node( U_THIS_TASK, pdu );
 	blockedTasks.add( &node );
@@ -587,11 +587,11 @@ int uLocalDebugger::breakpointHandler( int no ) {
 					   cond->bp_cond.var[1].vtype,cond->getOperator());
 #endif // __U_DEBUG_H__
 
-			// The following uAssert statement is a precaution - the
+			// The following assert statement is a precaution - the
 			// global debugger should not send unsupported breakpoint
 			// information.
-			uAssert( cond->bp_cond.var[0].atype != BreakpointCondition::UNSUPORTED );
-			uAssert( cond->bp_cond.var[1].atype != BreakpointCondition::UNSUPORTED );
+			assert( cond->bp_cond.var[0].atype != BreakpointCondition::UNSUPORTED );
+			assert( cond->bp_cond.var[1].atype != BreakpointCondition::UNSUPORTED );
 		} // if
 	} // if
 
@@ -601,12 +601,12 @@ int uLocalDebugger::breakpointHandler( int no ) {
 	} // if
 
 	if ( ! cond || cond->getOperator() == BreakpointCondition::NONE || cond->evaluate() ) {
-		memset( U_THIS_TASK->uTaskDebugMask, 0, 8 );
+		memset( U_THIS_TASK->taskDebugMask, 0, 8 );
 		pdu.createNhitBreakpoint( U_THIS_TASK, no, regs );
 		send( pdu );
 		if ( receive( pdu ) ) {
 			uBaseTask *task_address;
-			pdu.readOcontULThread( task_address, U_THIS_TASK->uTaskDebugMask, adjustment );
+			pdu.readOcontULThread( task_address, U_THIS_TASK->taskDebugMask, adjustment );
 		} // if
 	} // if
 #ifdef __U_DEBUG_H__
@@ -652,8 +652,8 @@ void uLocalDebugger::performAtomicOperation() {
 #ifndef __U_MULTI__
 		uSeqIter<uClusterDL> ci;
 		uClusterDL *cr;
-		for ( ci.over( *uKernelModule::uGlobalClusters ); ci >> cr; ) {
-			cluster = &cr->uGet();
+		for ( ci.over( *uKernelModule::globalClusters ); ci >> cr; ) {
+			cluster = &cr->cluster();
 #endif // __U_MULTI__
 
 #ifdef __U_DEBUG_H__
@@ -662,15 +662,15 @@ void uLocalDebugger::performAtomicOperation() {
 
 			uSeqIter<uBaseTaskDL> ci;
 			uBaseTaskDL *cr;
-			for ( ci.over( cluster->uTasksOnCluster ); ci >> cr; ) {
+			for ( ci.over( cluster->tasksOnCluster ); ci >> cr; ) {
 
 #ifdef __U_DEBUG_H__
 				uDebugPrt( "%d (uLocalDebugger &)0x%p.performAtomicOperation, task %s (0x%p) at 0x%p\n",
-						   __LINE__, this, cr->uGet().getName(), &cr->uGet(), cr->uGet().DebugPCandSRR );
+						   __LINE__, this, cr->task().getName(), &cr->task(), cr->task().debugPCandSRR );
 #endif // __U_DEBUG_H__
 
-				if ( ( (long *)cr->uGet().DebugPCandSRR >= low1 && (long *)cr->uGet().DebugPCandSRR < high1 )
-					|| ( (long *)cr->uGet().DebugPCandSRR >= low2 && (long *)cr->uGet().DebugPCandSRR < high2 ) ) {
+				if ( ( (long *)cr->task().debugPCandSRR >= low1 && (long *)cr->task().debugPCandSRR < high1 )
+					|| ( (long *)cr->task().debugPCandSRR >= low2 && (long *)cr->task().debugPCandSRR < high2 ) ) {
 					result = false;
 
 #ifdef __U_DEBUG_H__
@@ -723,7 +723,7 @@ void uLocalDebugger::attachULThread( uBaseTask *this_task, uCluster *this_cluste
 
     // retrieve some important registers
 	MinimalRegisterSet regs;
-	int *registers = (int *)this_task->uTaskDebugMask;
+	int *registers = (int *)this_task->taskDebugMask;
 	regs.pc = 0;
 	regs.fp = registers[0];
 	regs.sp = registers[1];
@@ -732,14 +732,14 @@ void uLocalDebugger::attachULThread( uBaseTask *this_task, uCluster *this_cluste
 #else
 	// in uni-processor, pretend that every task exist on the system cluster
 	// WHY IS THIS DONE LIKE THIS?
-	pdu.createNattachULThread( this_task, U_THIS_TASK, uKernelModule::uSystemCluster, regs, this_task->getName() );
+	pdu.createNattachULThread( this_task, U_THIS_TASK, uKernelModule::systemCluster, regs, this_task->getName() );
 #endif
 
 	if ( receive( pdu ) ) {
 #ifdef __U_DEBUG_H__
 		uDebugPrt( "%d (uLocalDebugger &)0x%p.attachULThread, attach confirmation received\n", __LINE__, this );
 #endif // __U_DEBUG_H__
-		memset( this_task->uTaskDebugMask, 0, 8 );
+		memset( this_task->taskDebugMask, 0, 8 );
 	} // if
 
 #ifdef __U_DEBUG_H__
@@ -753,7 +753,7 @@ void uLocalDebugger::checkPoint() {
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.checkPoint, task %s (0x%p) / cluster 0x%p\n", __LINE__, this, U_THIS_TASK->getName(), U_THIS_TASK, U_THIS_CLUSTER );
 #endif // __U_DEBUG_H__
 
-  if ( U_THIS_TASK == uLocalDebuggerInstance || U_THIS_TASK == dispatcher || &U_THIS_TASK->uBound != NULL ) return;
+  if ( U_THIS_TASK == uLocalDebuggerInstance || U_THIS_TASK == dispatcher || &U_THIS_TASK->bound != NULL ) return;
 	checkPointMX();
 } // uLocalDebugger::checkPoint
 
@@ -773,9 +773,9 @@ void uLocalDebugger::createULThread() {
 	MinimalRegisterSet regs;
 	CREATE_MINIMAL_REGISTER_SET( regs );				// save caller information
 
-  if ( U_THIS_TASK == uLocalDebuggerInstance || U_THIS_TASK == dispatcher || &U_THIS_TASK->uBound != NULL ) {
+  if ( U_THIS_TASK == uLocalDebuggerInstance || U_THIS_TASK == dispatcher || &U_THIS_TASK->bound != NULL ) {
 		// save the regs here for attaching later on
-		int *registers = (int *)U_THIS_TASK->uTaskDebugMask;
+		int *registers = (int *)U_THIS_TASK->taskDebugMask;
 		registers[0] = regs.fp;
 		registers[1] = regs.sp;
 		return;
@@ -799,12 +799,12 @@ void uLocalDebugger::createULThreadMX( MinimalRegisterSet &regs ) {
 #else
 	// in uni-processor, pretend that every task exist on the system cluster
 	// WHY IS THIS DONE LIKE THIS?
-	pdu.createNcreateULThread( U_THIS_TASK, uKernelModule::uSystemCluster, regs, U_THIS_TASK->getName() );
+	pdu.createNcreateULThread( U_THIS_TASK, uKernelModule::systemCluster, regs, U_THIS_TASK->getName() );
 #endif
 	if ( receive( pdu ) ) {
 		int dummy;
 		uBaseTask *task_address;
-		pdu.readOcontULThread( task_address, U_THIS_TASK->uTaskDebugMask, dummy );
+		pdu.readOcontULThread( task_address, U_THIS_TASK->taskDebugMask, dummy );
 	} // if
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.createULThreadMX, done\n", __LINE__, this );
@@ -818,7 +818,7 @@ void uLocalDebugger::destroyULThread() {
 			   __LINE__, this, U_THIS_TASK, U_THIS_TASK->getName(), U_THIS_CLUSTER, U_THIS_CLUSTER->getName() );
 #endif // __U_DEBUG_H__
 
-  if ( U_THIS_TASK == uLocalDebuggerInstance || U_THIS_TASK == dispatcher || U_THIS_TASK == uThisProcessor().uProcTask ) return;
+  if ( U_THIS_TASK == uLocalDebuggerInstance || U_THIS_TASK == dispatcher || U_THIS_TASK == uThisProcessor().procTask ) return;
 
 	destroyULThreadMX();								// obtain mutual exclusion
 } // uLocalDebugger::destroyULThread
@@ -848,7 +848,7 @@ void uLocalDebugger::createCluster( uCluster &cluster ) {
 
   if ( ! uLocalDebuggerActive ) return;
 
-	pdu.createNcreateCluster( &cluster, cluster.getName(), cluster.uDebugIgnore );
+	pdu.createNcreateCluster( &cluster, cluster.getName(), cluster.debugIgnore );
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.createCluster, type %d, done\n", __LINE__, this, pdu.getType() );
@@ -874,12 +874,12 @@ void uLocalDebugger::destroyCluster( uCluster &cluster ) {
 void uLocalDebugger::createKernelThread( uProcessor &process, uCluster &cluster ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.createKernelThread, creating task: %s (0x%p), creating cluster:0x%p, process 0x%p / cluster 0x%p / pid %d\n",
-			   __LINE__, this, (U_THIS_TASK)->getName(), U_THIS_TASK, U_THIS_CLUSTER, &process, &cluster, process.uPid );
+			   __LINE__, this, (U_THIS_TASK)->getName(), U_THIS_TASK, U_THIS_CLUSTER, &process, &cluster, process.pid );
 #endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
 
-	pdu.createNcreateKernelThread( U_THIS_TASK, U_THIS_CLUSTER, &process, &cluster, process.uPid, process.uDebugIgnore );
+	pdu.createNcreateKernelThread( U_THIS_TASK, U_THIS_CLUSTER, &process, &cluster, process.pid, process.debugIgnore );
 	receive( pdu );										// receive confirmation
 
 #ifdef __U_DEBUG_H__
@@ -910,7 +910,7 @@ void uLocalDebugger::migrateKernelThread( uProcessor &process, uCluster &to_clus
 #endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
-  if ( U_THIS_CLUSTER->uDebugIgnore || to_cluster.uDebugIgnore || process.uDebugIgnore ) return;
+  if ( U_THIS_CLUSTER->debugIgnore || to_cluster.debugIgnore || process.debugIgnore ) return;
 
 	pdu.createNmigrateKernelThread( U_THIS_TASK, &process, &to_cluster );
 	receive( pdu );										// receive confirmation
@@ -927,7 +927,7 @@ void uLocalDebugger::migrateULThread( uCluster &to_cluster ) {
 			   __LINE__, this, (U_THIS_TASK)->getName(), U_THIS_TASK, &to_cluster );
 #endif // __U_DEBUG_H__
 
-  if ( U_THIS_CLUSTER->uDebugIgnore || to_cluster.uDebugIgnore ) return;
+  if ( U_THIS_CLUSTER->debugIgnore || to_cluster.debugIgnore ) return;
 
 	migrateULThreadMX( to_cluster );					// obtain mutual exclusion
 } // uLocalDebugger::migrateULThread
@@ -975,7 +975,7 @@ void uLocalDebugger::abortApplication() {
   if ( ! uLocalDebuggerActive ) return;
   if ( U_THIS_TASK == uLocalDebuggerInstance ) return;	// prevent recursion
 
-	uSigHandlerModule::uSSignal( SIGCONT, cont_handler ); // install SIGCONT handler
+	uSigHandlerModule::signal( SIGCONT, cont_handler );	// install SIGCONT handler
 	pdu.createNabortApplication( uThisProcessor().getPid() );
 	send( pdu );
 	while ( ! abort_confirmed ) {						// busy wait for a response
