@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr and Richard Bilson 2003
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr and Richard Bilson 2003
 // 
 // AbortExit.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Fri Dec 19 10:33:58 2003
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sun Jul 31 12:51:37 2005
-// Update Count     : 7
+// Last Modified On : Fri Sep  8 15:55:23 2006
+// Update Count     : 10
 // 
 
 #include <uC++.h>
@@ -17,7 +17,7 @@
 using std::cerr;
 using std::endl;
 
-enum Mode { SPIN, EXIT, ABORT, EXPLODE } mode;
+enum Mode { SPIN, EXIT, UABORT, EXPLODE, ABORT, ASSERT } mode;
 
 _Task worker {
     void main() {
@@ -25,12 +25,18 @@ _Task worker {
           case SPIN:
 	    for ( ;; ) {}
 	  case EXIT:
-	    uExit( 3 );
-	  case ABORT:
+	    exit( 3 );
+	  case UABORT:
 	    uAbort( "worker %d %s", 3, "text" );
 	  case EXPLODE:
 	    kill( getpid(), SIGILL );
+	    for ( ;; ) {}				// delay until signal delivered to some kernel thread
+	  case ABORT:
+	    abort();
+	  case ASSERT:
+	    assert( false );
 	} // switch
+ 	// CONTROL NEVER REACHES HERE!
     } // main
   public:
     worker( uCluster &c ) : uBaseTask( c ) {}
