@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Ashif Harji 2000
+// uC++ Version 5.4.0, Copyright (C) Ashif Harji 2000
 // 
 // Disinherit1.cc -- 
 // 
 // Author           : Ashif Harji
 // Created On       : Sat Mar 11 09:56:27 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Dec  3 09:43:57 2005
-// Update Count     : 20
+// Last Modified On : Thu Jan 12 16:23:18 2006
+// Update Count     : 22
 // 
 
 
@@ -24,7 +24,7 @@ using std::setw;
 _Mutex<uPriorityQ, uPriorityQ> class Monitor2 {
   public:
     void call1( int id, uDuration delay ){
-	for (int i = 0; i < 3; i+=1 ){
+	for ( int i = 0; i < 3; i+=1 ){
 	    osacquire( cout ) << setw(3) << id << " blocks in monitor 2 for " << delay << " at priority " <<
 		uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
 	    
@@ -35,20 +35,17 @@ _Mutex<uPriorityQ, uPriorityQ> class Monitor2 {
 	} // for
 
 	osacquire( cout ) << setw(3) << id << " leaves monitor 2 at priority " <<
-	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() <<
-	    endl;
+	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
     } // call1
 
     void call2( int id, uDuration delay ) {
-
 	osacquire( cout ) << setw(3) << id << " blocks in monitor 2 for " << delay << " at priority " <<
 	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
 	
 	_Timeout( delay );
 	
 	osacquire( cout ) << setw(3) << id << " leaves monitor 2 at priority " <<
-	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() <<
-	    endl;
+	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
     } // call2
 }; // Monitor2
 
@@ -56,7 +53,6 @@ _Mutex<uPriorityQ, uPriorityQ> class Monitor2 {
 _Mutex<uPriorityQ, uPriorityQ> class Monitor1 {
   public:
     void call( int id, uDuration delay1, uDuration delay2, Monitor2 &m2 ) {
-
 	osacquire( cout ) << setw(3) << id << " blocks in monitor 1 for " << delay1 << " at priority " <<
 	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
 
@@ -64,21 +60,17 @@ _Mutex<uPriorityQ, uPriorityQ> class Monitor1 {
 
 	// call Monitor2
 	if (id == 1 ) { 
-	osacquire( cout ) << setw(3) << id << " calls monitor 2 at priority " <<
-	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() <<
-	    endl;
+	    osacquire( cout ) << setw(3) << id << " calls monitor 2 at priority " <<
+		uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
 	    m2.call1(id, delay2);
 	} else {
-	osacquire( cout ) << setw(3) << id << " calls monitor 2 at priority " <<
-	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() <<
-	    endl;
+	    osacquire( cout ) << setw(3) << id << " calls monitor 2 at priority " <<
+		uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
 	    m2.call2(id, delay2);
 	} // if
 	    
 	osacquire( cout ) << setw(3) << id << " leaves monitor 1 at priority " <<
-	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() <<
-	    endl;
-
+	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
     } // call
 }; // Monitor1
 
@@ -93,15 +85,14 @@ _Mutex<uPriorityQ, uPriorityQ> _PeriodicTask<uPIHeap> task1 {
     void main() {
 	_Timeout(D1);
 	osacquire( cout ) << setw(3) << id << " calls monitor 1 at priority " <<
-	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() <<
-	    endl;
+	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
 	monitor1.call( id, D1, D2, monitor2 );
     } // Philosopher::main
   public:
     task1( int id, uDuration period, uDuration delay1, uDuration delay2, uCluster &clust ) :
 	    uPeriodicBaseTask( period, uTime(0,0), uThisProcessor().getClock().getTime() + uDuration(90), period, clust ),
 //	    uPeriodicBaseTask( period, uTime(0,0), uTime(0,0), period, clust ),
-	    D1( delay1 ), D2( delay2 ), id( id ) {
+	D1( delay1 ), D2( delay2 ), id( id ) {
     } // task1::task1
 }; // task1
 
@@ -113,15 +104,14 @@ _Mutex<uPriorityQ, uPriorityQ> _PeriodicTask<uPIHeap> task2 {
     void main() {
 	_Timeout( D1 );
 	osacquire( cout ) << setw(3) << id << " calls monitor 2 at priority " <<
-	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() <<
-	    endl;
+	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
 	    monitor2.call1( id, D1 );
     } // Philosopher::main
   public:
     task2( int id, uDuration period, uDuration delay, uCluster &clust ) :
 	    uPeriodicBaseTask( period, uTime(0,0), uThisProcessor().getClock().getTime() + uDuration( 90 ), period, clust ),
 //	    uPeriodicBaseTask( period, uTime(0,0), uTime(0,0), period, clust ),
-	    D1( delay ), id( id ) {
+	D1( delay ), id( id ) {
     } // task2::task2
 }; // task2
 
