@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.4.0, Copyright (C) Ashif S. Harji 2000
 // 
 // Disinherit.cc -- 
 // 
 // Author           : Ashif S. Harji
 // Created On       : Mon Feb 14 14:22:08 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Dec  3 09:44:14 2005
-// Update Count     : 32
+// Last Modified On : Thu Jan 12 16:11:30 2006
+// Update Count     : 33
 // 
 
 
@@ -48,8 +48,7 @@ _Mutex<uStaticPriorityQ, uStaticPriorityQ> class Monitor2 {
 	_Timeout( delay );
 	
 	osacquire( cout ) << setw(3) << id << " leaves monitor 2 at priority " <<
-	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() <<
-	    endl;
+	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
     } // call2
 }; // Monitor2
 
@@ -57,7 +56,6 @@ _Mutex<uStaticPriorityQ, uStaticPriorityQ> class Monitor2 {
 _Mutex<uStaticPriorityQ, uStaticPriorityQ> class Monitor1 {
   public:
     void call( int id, uDuration delay1, uDuration delay2, Monitor2 &m2 ) {
-
 	osacquire( cout ) << setw(3) << id << " blocks in monitor 1 for " << delay1 << " at priority " <<
 	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
 
@@ -65,20 +63,17 @@ _Mutex<uStaticPriorityQ, uStaticPriorityQ> class Monitor1 {
 
 	// call Monitor2
 	if (id == 1 ) { 
-	osacquire( cout ) << setw(3) << id << " calls monitor 2 at priority " <<
-	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() <<
-	    endl;
+	    osacquire( cout ) << setw(3) << id << " calls monitor 2 at priority " <<
+		uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
 	    m2.call1(id, delay2);
 	} else {
-	osacquire( cout ) << setw(3) << id << " calls monitor 2 at priority " <<
-	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() <<
-	    endl;
+	    osacquire( cout ) << setw(3) << id << " calls monitor 2 at priority " <<
+		uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
 	    m2.call2(id, delay2);
 	} // if
 	    
 	osacquire( cout ) << setw(3) << id << " leaves monitor 1 at priority " <<
-	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() <<
-	    endl;
+	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
     } // call
 }; // Monitor1
 
@@ -93,15 +88,14 @@ _Mutex<uStaticPriorityQ, uStaticPriorityQ> _PeriodicTask<uStaticPIQ> task1 {
     void main() {
 	_Timeout(D1);
 	osacquire( cout ) << setw(3) << id << " calls monitor 1 at priority " <<
-	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() <<
-	    endl;
+	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
 	monitor1.call( id, D1, D2, monitor2 );
     } // Philosopher::main
   public:
     task1( int id, uDuration period, uDuration delay1, uDuration delay2, uCluster &clust ) :
 	    uPeriodicBaseTask( period, uTime(0,0), uThisProcessor().getClock().getTime() + uDuration(90), period, clust ),
 //	    uPeriodicBaseTask( period, uTime(0,0), uTime(0,0), period, clust ),
-	    D1( delay1 ), D2( delay2 ), id( id ) {
+	D1( delay1 ), D2( delay2 ), id( id ) {
     } // task1::task1
 }; // task1
 
@@ -113,15 +107,14 @@ _Mutex<uStaticPriorityQ, uStaticPriorityQ> _PeriodicTask<uStaticPIQ> task2 {
     void main() {
 	_Timeout( D1 );
 	osacquire( cout ) << setw(3) << id << " calls monitor 2 at priority " <<
-	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() <<
-	    endl;
+	    uThisTask().getActivePriorityValue() << ", " << uThisTask().getActiveQueueValue() << endl;
 	    monitor2.call2( id, D1 );
     } // Philosopher::main
   public:
     task2( int id, uDuration period, uDuration delay, uCluster &clust ) :
 	    uPeriodicBaseTask( period, uTime(0,0), uThisProcessor().getClock().getTime() + uDuration( 90 ), period, clust ), 
 //	    uPeriodicBaseTask( period, uTime(0,0), uTime(0,0), period, clust ),
-	    D1( delay ), id( id ) {
+	D1( delay ), id( id ) {
     } // task2::task2
 }; // task2
 
