@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1998
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1998
 // 
 // EHM2.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Tue Oct 27 21:24:48 1998
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Aug  5 14:46:10 2005
-// Update Count     : 28
+// Last Modified On : Tue Sep 12 08:08:53 2006
+// Update Count     : 29
 // 
 
 #include <uC++.h>
@@ -40,7 +40,7 @@ _Task fred {
 	    try {
 		r( 5 );
 	    } catch( xxx e ) {
-		uAssert( e.tid == &uThisTask() );
+		assert( e.tid == &uThisTask() );
 		_Throw;
 	    }
 	} else {
@@ -53,7 +53,7 @@ _Task fred {
 	    try {
 		s( 5 );
 	    } catch( xxx e ) {
-		uAssert( e.tid == &uThisTask() );
+		assert( e.tid == &uThisTask() );
 		_Throw yyy( &uThisTask() );
 	    }
 	} else {
@@ -67,7 +67,7 @@ _Task fred {
 	    try {
 		t( 5 );
 	    } catch( yyy e ) {
-		uAssert( e.tid == &uThisTask() );
+		assert( e.tid == &uThisTask() );
 	    } // try
 	} // for
     } // fred::main
