@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Roy Krischer 2002
+// uC++ Version 5.4.0, Copyright (C) Roy Krischer 2002
 // 
 // EHM4.cc -- 
 // 
 // Author           : Roy Krischer
 // Created On       : Tue Mar 26 23:01:30 2002
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Dec 12 09:16:09 2005
-// Update Count     : 138
+// Last Modified On : Tue Sep 12 08:08:45 2006
+// Update Count     : 139
 // 
 
 #include <uC++.h>
@@ -69,7 +69,7 @@ class Arg {
 	void operator()( rev &r ) {
 		handled[id] += 1;								// count exceptions handled by each task
 		//osacquire( cerr ) << "handler, exception id: " << e.ticket << endl;
-		uAssert( r.ticket < NTASK*((NTASK-1)*ROUNDS+1) ); // subscript error ?
+		assert( r.ticket < NTASK*((NTASK-1)*ROUNDS+1) ); // subscript error ?
 		array[r.ticket] += 1;
 		if ( array[r.ticket] > 1 ) uAbort( "error - same exception handled twice");
 		if ( round != 0 ) {								// only a subset of exceptions raise more
