@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 2002
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 2002
 // 
 // EHM7.cc -- 
 // 
 // Author           : Roy Krischer
 // Created On       : Sun Nov 24 12:42:34 2002
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Aug  6 17:49:05 2005
-// Update Count     : 24
+// Last Modified On : Tue Sep 12 08:09:20 2006
+// Update Count     : 25
 // 
 
 #include <uC++.h>
@@ -43,9 +43,9 @@ void mary :: main() {
 			for ( int i = 0; i < 200; i+= 1 ) yield();
 		} // _Enable
     } catch ( j.fred f ) {
-		uAssert( &j == f.getOriginalThrower() );
-		uAssert( &j == &f.source() );
-		uAssert( f.k == 84 ); 
+		assert( &j == f.getOriginalThrower() );
+		assert( &j == &f.source() );
+		assert( f.k == 84 ); 
 		osacquire( cout ) << "mary catches exception from john: " << f.k << endl;
 	    for ( int i = 0; i < 200; i+= 1 )
 			yield();
@@ -59,9 +59,9 @@ void john :: main() {
 			for ( int i = 0; i < 200; i+= 1 ) yield();
 		} // _Enable
     } catch ( m.fred f ) {
-		uAssert( &m == f.getOriginalThrower() );
-		uAssert( &m == &f.source() );
-		uAssert( f.k == 42 ); 
+		assert( &m == f.getOriginalThrower() );
+		assert( &m == &f.source() );
+		assert( f.k == 42 ); 
 		osacquire( cout ) << "john catches exception from mary: " << f.k << endl
 			  << "mary m's address: " << (void *)&m << " exception binding: " << f.getOriginalThrower()
 			  << " exception Src: " << (void *)&f.source() << endl;
