@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 2003
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 2003
 // 
 // EHM8.cc -- 
 // 
 // Author           : Roy Krischer
 // Created On       : Wed Oct  8 22:02:29 2003
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Aug  6 17:49:25 2005
-// Update Count     : 53
+// Last Modified On : Tue Sep 12 08:09:27 2006
+// Update Count     : 55
 // 
 
 #include <uC++.h>
@@ -32,7 +32,7 @@ void two() {
 }
 void three() {
     osacquire( cout ) << "success" << endl;
-    uExit(0);
+    exit( 0 );
 }
 
 _Task fred {
@@ -51,11 +51,11 @@ _Task fred {
 	for ( int i = 0; i < ROUNDS; i += 1 ) {
 	    yield();
 	    if ( id % 2 ) {
-		uAssert( one == std::set_terminate( one ) );
-		uAssert( two == std::set_unexpected( two ) );
+		assert( one == std::set_terminate( one ) );
+		assert( two == std::set_unexpected( two ) );
 	    } else {
-		uAssert( two == std::set_terminate( two ) );
-		uAssert( one == std::set_unexpected( one ) );
+		assert( two == std::set_terminate( two ) );
+		assert( one == std::set_unexpected( one ) );
 	    } // if	    
 	} // for
     } // fred::main    
