@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // ClientINET.cc -- Client for INET/stream socket test. Client reads from
 // standard input, writes the data to the server, reads the data from the
@@ -9,8 +9,8 @@
 // Author           : Peter A. Buhr
 // Created On       : Tue Jan  7 08:42:32 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Nov 30 13:20:45 2005
-// Update Count     : 142
+// Last Modified On : Sat Sep  2 09:19:04 2006
+// Update Count     : 143
 // 
 
 #include <uC++.h>
@@ -81,7 +81,7 @@ void uMain::main() {
 		break;
 	  default:
 		cerr << "Usage: " << argv[0] << " port-number" << endl;
-		uExit( -1 );
+		exit( -1 );
 	} // switch
 
 	uSocketClient client( atoi( argv[1] ) );			// connection to server
