@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1999
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1999
 // 
 // ClientINET2.cc -- Client for INET/datagram socket test. Client reads from
 // standard input, writes the data to the server, reads the data from the
@@ -9,8 +9,8 @@
 // Author           : Peter A. Buhr
 // Created On       : Thu Apr 29 16:04:50 1999
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Nov 30 13:20:52 2005
-// Update Count     : 50
+// Last Modified On : Sat Sep  2 09:19:26 2006
+// Update Count     : 51
 // 
 
 #include <uC++.h>
@@ -94,7 +94,7 @@ void uMain::main() {
 		break;
 	  default:
 		cerr << "Usage: " << argv[0] << " port-number" << endl;
-		uExit( -1 );
+		exit( -1 );
 	} // switch
 
 	uSocketClient client( atoi( argv[1] ), SOCK_DGRAM ); // connection to server
