@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1999
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1999
 // 
 // ClientUNIX2.cc -- Client for UNIX/datagram socket test. Client reads from
 // standard input, writes the data to the server, reads the data from the
@@ -9,8 +9,8 @@
 // Author           : Peter A. Buhr
 // Created On       : Thu Apr 29 16:05:12 1999
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Nov 30 13:19:57 2005
-// Update Count     : 29
+// Last Modified On : Sat Sep  2 09:20:13 2006
+// Update Count     : 30
 // 
 
 #include <uC++.h>
@@ -96,7 +96,7 @@ void uMain::main() {
 		break;
 	  default:
 		cerr << "Usage: " << argv[0] << " socket-name" << endl;
-		uExit( -1 );
+		exit( -1 );
 	} // switch
 
 	uSocketClient client( argv[1], SOCK_DGRAM );		// connection to server
