@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // File.cc -- Print multiple copies of the same file to standard output
 // 
 // Author           : Peter A. Buhr
 // Created On       : Tue Jan  7 08:44:56 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sun Jul 31 18:57:48 2005
-// Update Count     : 41
+// Last Modified On : Sat Sep  2 09:20:34 2006
+// Update Count     : 42
 // 
 
 #include <uC++.h>
@@ -44,7 +44,7 @@ void uMain::main() {
 		break;
 	  default:
 		cerr << "Usage: " << argv[0] << " input-file" << std::endl;
-		uExit( -1 );
+		exit( -1 );
 	} // switch
 
 	uFile input( argv[1] );								// connect with UNIX files
