@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // ServerINET.cc -- Server for INET/stream socket test. Server accepts multiple
 // connections from clients. Each client then communicates with an acceptor.
@@ -9,8 +9,8 @@
 // Author           : Peter A. Buhr
 // Created On       : Tue Jan  7 08:40:22 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Sep 15 17:59:46 2005
-// Update Count     : 174
+// Last Modified On : Sat Sep  2 09:21:07 2006
+// Update Count     : 175
 // 
 
 #include <uC++.h>
@@ -100,7 +100,7 @@ void uMain::main() {
 		break;
 	  default:
 		cerr << "Usage: " << argv[0] << endl;
-		uExit( -1 );
+		exit( -1 );
 	} // switch
 
 	short unsigned int port;
