@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 2003
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 2003
 // 
 // StringIO.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Wed Jan 22 12:32:28 2003
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sun Jul 31 19:04:51 2005
-// Update Count     : 5
+// Last Modified On : Sat Sep  2 09:22:46 2006
+// Update Count     : 6
 // 
 
 #include <uC++.h>
@@ -38,7 +38,7 @@ void uMain::main() {
             outfile = new ofstream( argv[2] );			// open the outfile file
         } catch( uFile::Failure ) {
             cerr << "Could not open output file \"" << argv[2] << "\"" << endl;
-            uExit( -1 );                                // TERMINATE!
+            exit( -1 );                                // TERMINATE!
         } // try
         // fall through to handle input file
       case 2:
@@ -46,12 +46,12 @@ void uMain::main() {
             infile = new ifstream( argv[1] );			// open the first input file
         } catch( uFile::Failure ) {
             cerr << "Could not open input file \"" << argv[1] << "\"" << endl;
-            uExit( -1 );                                // TERMINATE!
+            exit( -1 );                                // TERMINATE!
         } // try
         break;
       default:                                          // must specify an input file
         cerr << "Usage: " << argv[0] << " input-file [output-file]" << endl;
-        uExit( -1 );                                    // TERMINATE!
+        exit( -1 );                                    // TERMINATE!
     } // swtich
 
     *infile >> skipws;									// turn off white space skipping during input
