@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // Paging.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Wed May 11 17:03:26 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sun Jul 31 18:02:30 2005
-// Update Count     : 10
+// Last Modified On : Sat Sep  2 09:17:36 2006
+// Update Count     : 11
 // 
 
 #include <uC++.h>
@@ -219,19 +219,19 @@ void uMain::main() {
 	outfile = new ofstream( argv[2] );
 	if ( outfile->fail() ) {
 	    cerr << "Open error, outfile file: " << argv[2] << endl;
-	    uExit( -1 );
+	    exit( -1 );
 	} // if
       case 2:
 	infile = new ifstream( argv[1] );		// 1st file is input file
 	if ( infile->fail() ) {
 	    cerr << "Open error, infile file: " << argv[1] << endl;
-	    uExit( -1 );
+	    exit( -1 );
 	} // if
       case 1:
 	break;
       default:
 	cerr << "Usage: " << argv[0] << " [infile-file [outfile-file]]" << endl;
-	uExit( -1 );
+	exit( -1 );
     } // switch
 
     int NoValues;
