@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 2000
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 2000
 // 
 // SRC2.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Sun Dec 10 08:44:06 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Nov 30 08:39:52 2005
-// Update Count     : 150
+// Last Modified On : Tue Sep 12 08:08:38 2006
+// Update Count     : 151
 // 
 
 #include <uC++.h>
@@ -71,7 +71,7 @@ void SRC::Deallocate() {
 	if ( Taken <= 0 ) uAbort( "problem 1" );
 	Free += 1;
 	Taken -= 1;
-	uAssert( Free >= 0 && Taken <= MaxItems );
+	assert( Free >= 0 && Taken <= MaxItems );
 	osacquire( cout ) << &uThisTask() << " Deallocate, Free:" << Free << " Taken:" << Taken << " Locked:" << Locked << " Need:" << Need << endl;
 
 	if ( Locked ) uAcceptReturn( Resume, Deallocate );
@@ -92,7 +92,7 @@ void SRC::Allocate( unsigned int N = 1 ) {
 	} // if
 	Free -= N;
 	Taken += N;
-	uAssert( ! Locked && Free >= 0 && Taken <= MaxItems );
+	assert( ! Locked && Free >= 0 && Taken <= MaxItems );
 	osacquire( cout ) << &uThisTask() << " Allocate(" << N << "), exit, Free:" << Free << " Taken:" << Taken << endl;
 	_AcceptReturn( Hold, Deallocate, Allocate );
 } // SRC::Allocate
