@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 2000
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 2000
 // 
 // SRC2.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Sun Dec 10 08:44:06 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Nov 30 08:43:04 2005
-// Update Count     : 259
+// Last Modified On : Tue Sep 12 08:09:00 2006
+// Update Count     : 260
 // 
 
 #include <uC++.h>
@@ -92,7 +92,7 @@ void SRC::Deallocate() {
 	if ( Taken <= 0 ) uAbort( "problem 2" );
 	Free += 1;
 	Taken -= 1;
-	uAssert( Free >= 0 && Taken <= MaxItems );
+	assert( Free >= 0 && Taken <= MaxItems );
 	osacquire( cout ) << &uThisTask() << " Deallocate, Free:" << Free << " Taken:" << Taken << " Locked:" << Locked << " Waiting:" << list.empty() << endl;
 	if ( Locked ) uAcceptReturn( Resume, Deallocate );
 	if ( ! CheckPending() ) uAcceptReturn( Hold, Deallocate, Allocate, ~SRC ); // check for any pending requests
@@ -111,7 +111,7 @@ void SRC::Allocate( unsigned int N = 1 ) {
 	} // if
 	Free -= N;
 	Taken += N;
-	uAssert( ! Locked && Free >= 0 && Taken <= MaxItems );
+	assert( ! Locked && Free >= 0 && Taken <= MaxItems );
 	osacquire( cout ) << &uThisTask() << " Allocate(" << N << "), exit, Free:" << Free << " Taken:" << Taken << endl;
 	uAcceptReturn( Hold, Deallocate, Allocate );		// block until sufficient resources
 } // SRC::Allocate
