@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.4.0, Copyright (C) Ashif S. Harji 2000
 // 
 // SRC3.cc -- 
 // 
 // Author           : Ashif S. Harji
 // Created On       : Fri Dec 22 14:58:38 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Nov 30 08:43:26 2005
-// Update Count     : 26
+// Last Modified On : Tue Sep 12 08:09:06 2006
+// Update Count     : 27
 // 
 
 #include <uC++.h>
@@ -68,7 +68,7 @@ void SRC::Deallocate() {
 	if ( Taken <= 0 ) uAbort( "problem 2" );
 	Free += 1;
 	Taken -= 1;
-	uAssert( Free >= 0 && Taken <= MaxItems );
+	assert( Free >= 0 && Taken <= MaxItems );
 	osacquire( cout ) << &uThisTask() << " Deallocate, Free:" << Free << " Taken:" << Taken << " Locked:" << Locked << " Need:" << Need << endl;
 } // SRC::Deallocate
 
@@ -83,7 +83,7 @@ void SRC::Allocate( unsigned int N = 1 ) {
 	} // while	
 	Free -= N;
 	Taken += N;
-	uAssert( ! Locked && Free >= 0 && Taken <= MaxItems );
+	assert( ! Locked && Free >= 0 && Taken <= MaxItems );
 	osacquire( cout ) << &uThisTask() << " Allocate(" << N << "), exit, Free:" << Free << " Taken:" << Taken << endl;
 } // SRC::Allocate
 
