@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.4.0, Copyright (C) Ashif S. Harji 2000
 // 
 // SRC4.cc -- 
 // 
 // Author           : Ashif S. Harji
 // Created On       : Sun Dec 10 08:44:06 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Nov 30 08:43:39 2005
-// Update Count     : 268
+// Last Modified On : Tue Sep 12 08:09:12 2006
+// Update Count     : 269
 // 
 
 #include <uC++.h>
@@ -95,7 +95,7 @@ void SRC::Deallocate() {
 	if ( Taken <= 0 ) uAbort( "problem 2" );
 	Free += 1;
 	Taken -= 1;
-	uAssert( Free >= 0 && Taken <= MaxItems );
+	assert( Free >= 0 && Taken <= MaxItems );
 	osacquire( cout ) << &uThisTask() << " Deallocate, Free:" << Free << " Taken:" << Taken << " Locked:" << Locked << " Waiting:" << list.empty() << endl;
 	if ( ! Locked ) CheckPending();										// check for any pending requests
 } // SRC::Deallocate
@@ -112,7 +112,7 @@ void SRC::Allocate( unsigned int N = 1 ) {
 	} // if
 	Free -= N;
 	Taken += N;
-	uAssert( ! Locked && Free >= 0 && Taken <= MaxItems );
+	assert( ! Locked && Free >= 0 && Taken <= MaxItems );
 	osacquire( cout ) << &uThisTask() << " Allocate(" << N << "), exit, Free:" << Free << " Taken:" << Taken << endl;
 } // SRC::Allocate
 
