@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
-// uAbort.cc -- 
+// uAbortExit.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Fri Oct 26 11:54:31 1990
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 10:57:09 2005
-// Update Count     : 463
+// Last Modified On : Tue Sep 26 11:07:53 2006
+// Update Count     : 496
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -41,44 +41,78 @@
 #include <unistd.h>					// _exit
 
 
-void uAbortExit() {
+void uKernelModule::abortExit() {
     // Deal with any starting processors spinning to get onto the global
     // processor list.
 
-    uKernelModule::uGlobalProcessorLock->acquire();	// never released again
-    uKernelModule::uGlobalSpinAbort = true;
+    uKernelModule::globalProcessorLock->acquire();	// never released again
+    uKernelModule::globalSpinAbort = true;
 
     // Destory any remaining processors.
 
     uProcessorDL *pr;
-    for ( uSeqIter<uProcessorDL> iter(*uKernelModule::uGlobalProcessors); iter >> pr; ) {
-	if ( &(pr->uGet()) != &uThisProcessor() ) {	// do not kill current processor
+    for ( uSeqIter<uProcessorDL> iter(*uKernelModule::globalProcessors); iter >> pr; ) {
+	if ( &(pr->processor()) != &uThisProcessor() ) { // do not kill current processor
 #ifdef __U_DEBUG_H__
-	    fprintf( stderr, "uAbortExit(), killing process 0x%p %d\n", &(pr->uGet()), pr->uGet().getPid() );
+	    fprintf( stderr, "abortExit(), killing process 0x%p %d\n", &(pr->processor()), pr->processor().getPid() );
 #endif // __U_DEBUG_H__
-	    kill( pr->uGet().getPid(), SIGKILL );
+	    kill( pr->processor().getPid(), SIGKILL );
 	} // if
     } // for
-} // uAbortExit
+} // uKernelModule::abortExit
+
+
+#if defined( __irix__ )
+extern "C" void __do_global_dtors();
+extern "C" void _exithandle();
+extern "C" void _cleanup();
+#endif // __irix__
+
+void exit( int retcode ) __THROW {
+    uKernelModule::inExit = true;
+    uKernelModule::retCode = retcode;
+
+#if defined( __U_MULTI__ ) && ! defined( __solaris__ ) && ! defined( __U_PTHREAD__ ) // all SUN lwps are terminated by exit/abort
+    if ( uKernelModule::afterMain ) ((void (*)(int))uKernelModule::interposeSymbol( "exit" ))( retcode );
+
+    // Only the root processor can return a value to the shell so it is
+    // necessary to migrate to the system processor to exit with a return code.
+    // Also exit is not called in the kernal because it blocks.
+
+    if ( &uThisProcessor() != uKernelModule::systemProcessor ) {
+	uKernelModule::systemProcessor->procExit( retcode );
+	// CONTROL NEVER REACHES HERE!
+#ifdef __U_DEBUG__
+	assert( false );
+#endif // __U_DEBUG__
+    } else {
+	uKernelModule::abortExit();                     // shut down other processors
+#if defined( __irix__ )
+	_exithandle();                                  // atexit functions
+	// This next line causes abnormal termination
+	//_cleanup();                                     // close files
+	__do_global_dtors();                            // global destructors
+	_exit( retcode );
+#else
+	((void (*)(int))uKernelModule::interposeSymbol( "exit" ))( retcode ); // call the real exit
+#endif // __irix__
+	// CONTROL NEVER REACHES HERE!
+#ifdef __U_DEBUG__
+	assert( false );
+#endif // __U_DEBUG__
+    } // if
+#else
+    ((void (*)(int))uKernelModule::interposeSymbol( "exit" ))( retcode ); // call the real exit
+    // CONTROL NEVER REACHES HERE!
+#ifdef __U_DEBUG__
+    assert( false );
+#endif // __U_DEBUG__
+#endif
+} // exit
 
 
 void uExit( int retcode ) {
-    uKernelModule::uGlobalAbort = true;
-
-#if defined( __U_MULTI__ ) && ! defined( __solaris__ ) && ! defined( __U_PTHREAD__ ) // all SUN lwps are terminated by exit/abort
-    // Only the root processor can return a value to the shell so it is
-    // necessary to migrate to the sustem processor to exit with a return code.
-    // Also uExit is not called in the kernal because it blocks.
-
-    uKernelModule::uSystemProcessor->uProcExit( retcode );
-    // CONTROL NEVER REACHES HERE!
-#else
-    // _exit is called instead of exit so the global destructors are not
-    // called.  Trying to execute the global destructors after the processors
-    // have been killed just generates incomprehensible errors.
-
-    _exit( retcode );
-#endif
+    exit( retcode );
 } // uExit
 
 
@@ -87,13 +121,13 @@ void uExit( int retcode ) {
 // up the system and possibly dumps core.
 
 void uAbort( const char *fmt, ... ) {
-    uBaseTask &t = uThisTask();				// optimization
-    uKernelModule::uGlobalAbort = true;
+    uBaseTask &task = uThisTask();			// optimization
+    uKernelModule::globalAbort = true;
 
     // uAbort cannot be recursively entered by the same or different processors
-    // because all signal handlers return when the uGlobalAbort flag is true.
+    // because all signal handlers return when the globalAbort flag is true.
 #if defined( __U_MULTI__ )
-    if ( ! uKernelModule::uGlobalAbortLock->tryacquire() ) { // not the first task to abort ?
+    if ( ! uKernelModule::globalAbortLock->tryacquire() ) { // not the first task to abort ?
 	sigset_t mask;
 	sigemptyset( &mask );
 	sigaddset( &mask, SIGALRM );			// block SIGALRM signals
@@ -105,18 +139,21 @@ void uAbort( const char *fmt, ... ) {
 
     // profiling
 
-    t.uProfileInactivate();				// make sure the profiler is not called from this point on
+    task.profileInactivate();				// make sure the profiler is not called from this point on
 
-    // Display the relevant shut down information.
+    if ( fmt != NULL ) {
+	// Display the relevant shut down information.
 
-    fprintf( stderr, "uC++ Runtime error (UNIX pid:%ld) ", (long int)getpid() ); // use UNIX pid (versus getPid)
-    va_list args;
-    va_start( args, fmt );
-    vfprintf( stderr, fmt, args );
-    va_end( args );
+	fprintf( stderr, "uC++ Runtime error (UNIX pid:%ld) ", (long int)getpid() ); // use UNIX pid (versus getPid)
+	va_list args;
+	va_start( args, fmt );
+	vfprintf( stderr, fmt, args );
+	va_end( args );
+	fprintf( stderr, "\n" );
+    } // if
 
-    fprintf( stderr, "\nError occurred while executing task %.256s (0x%p)", t.getName(), &t );
-    if ( &t != &uThisCoroutine() ) {
+    fprintf( stderr, "Error occurred while executing task %.256s (0x%p)", task.getName(), &task );
+    if ( &task != &uThisCoroutine() ) {
 	fprintf( stderr, " in coroutine %.256s (0x%p).\n", uThisCoroutine().getName(), &uThisCoroutine() );
     } else {
 	fprintf( stderr, ".\n" );
@@ -124,12 +161,12 @@ void uAbort( const char *fmt, ... ) {
 
     // In profiling mode, output information about the current task's call stack.
 
-    t.uPrintCallStack();
+    task.printCallStack();
 
     // In debugger mode, tell the global debugger to stop the application.
 
 #if __U_LOCALDEBUGGER_H__
-    if ( ! THREAD_GETMEM( uDisableInt ) && ! THREAD_GETMEM( uDisableIntSpin ) ) {
+    if ( ! THREAD_GETMEM( disableInt ) && ! THREAD_GETMEM( disableIntSpin ) ) {
 	if ( uLocalDebugger::uLocalDebuggerActive ) uLocalDebugger::uLocalDebuggerInstance->abortApplication();
     } // if
 #endif // __U_LOCALDEBUGGER_H__
@@ -137,20 +174,20 @@ void uAbort( const char *fmt, ... ) {
     // Try to shut down other processors.
 
 #if defined( __U_MULTI__ ) && ! ( defined( __solaris__ ) || defined( __U_PTHREAD__ ) ) // SUN lwps and pthread KT are terminated by exit/abort
-    uAbortExit();					// shut down other processors
+    uKernelModule::abortExit();				// shut down other processors
 #endif
 
     // After having killed off the other processors, dump core if required,
     // otherwise, quietly call "_exit". Cannot call "exit" because of global
     // destructors.
 
-    if ( ! uKernelModule::uCoreDumped ) {		// child process may have failed and dumped core already
-	uKernelModule::uCoreDumped = true;		// prevent other UNIX processes from dumping core
+    if ( ! uKernelModule::coreDumped ) {		// child process may have failed and dumped core already
+	uKernelModule::coreDumped = true;		// prevent other UNIX processes from dumping core
 #if defined( __linux__ ) && ! defined( __U_PTHREAD__ )
 	// Use UNIX getpid (versus processor getPid) to terminate the process group.
 	kill( getpid(), SIGABRT );			// "abort()" may call "raise(SIGABRT)" to NPTL thread
 #else
-	abort();
+	((void (*)())uKernelModule::interposeSymbol( "abort" ))(); // call the real abort
 #endif
     } // if
 
@@ -158,6 +195,11 @@ void uAbort( const char *fmt, ... ) {
 } // uAbort
 
 
+void abort() {
+    uAbort( NULL );
+} // uAbort
+
+
 // Local Variables: //
 // compile-command: "gmake install" //
 // End: //
