@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uAlign.h -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Sat Dec 18 22:08:40 1993
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Jun 28 11:27:19 2005
-// Update Count     : 39
+// Last Modified On : Tue Sep 12 11:20:29 2006
+// Update Count     : 41
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -47,9 +47,7 @@ static inline bool uPow2( unsigned long int value ) {
 // Returns value aligned at the floor of align.
 
 static inline unsigned long int uFloor( unsigned long int value, unsigned long int align ) {
-//    return value - ( value % align );
-
-    uAssert( uPow2( align ) );
+    assert( uPow2( align ) );
     // clears all bits above or equal to align, getting (value % align), the
     // phase of value with regards to align
     return value & -align;
@@ -59,10 +57,7 @@ static inline unsigned long int uFloor( unsigned long int value, unsigned long i
 // Returns value aligned at the ceiling of align.
 
 static inline unsigned long int uCeiling( unsigned long int value, unsigned long int align ) {
-//    value += align - 1;
-//    return uFloor( value, align );
-
-    uAssert( uPow2( align ) );
+    assert( uPow2( align ) );
     // "negate, round down, negate" is the same as round up
     return -uFloor( -value, align );
 } // uCeiling
