@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1997
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1997
 // 
 // uBaseCoroutine.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Sat Sep 27 16:46:37 1997
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Dec 12 09:04:53 2005
-// Update Count     : 402
+// Last Modified On : Sun Sep 24 16:53:26 2006
+// Update Count     : 457
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -37,74 +37,109 @@
 //######################### uBaseCoroutine #########################
 
 
-void uBaseCoroutine::uCreateCoroutine() {
+// This routine must be called manually since our exception throwing interferes with normal deallocation
+namespace __cxxabiv1 {
+    extern "C" void __cxa_free_exception(void *vptr) throw();
+} // namespace
+
+
+uBaseCoroutine::UnwindStack::UnwindStack( bool e ) : exec_dtor( e ) {
+} // uBaseCoroutine::UnwindStack::UnwindStack
+
+uBaseCoroutine::UnwindStack::~UnwindStack() {
+    if ( exec_dtor && ! std::uncaught_exception() ) { 	// if executed as part of an exceptional clean-up do nothing, otherwise terminate is called
+	__cxxabiv1::__cxa_free_exception( this );	// if handler terminates and 'safety' is off, clean up the memory for old exception
+	_Throw UnwindStack( true );			// and throw a new exception to continue unwinding
+    } // if
+} // uBaseCoroutine::UnwindStack::~UnwindStack
+
+
+void uBaseCoroutine::unwindStack() {
+    if ( ! _cancelInProgress ) {			// do not cancel if we're already cancelling
+	_cancelInProgress = true;
+	// NOTE: This throw fails and terminates the application if it occurs
+	// in the middle of a destructor triggered by an exception.  While not
+	// a serious restriction now, it could be one when time-slice polling
+	// is introduced
+	_Throw UnwindStack( true );			// start the cancellation unwinding
+    } // if
+} // uBaseCoroutine::unwindStack
+
+
+void uBaseCoroutine::createCoroutine() {
+    last = NULL;					// see ~uCoroutineDestructor
 #ifdef __U_DEBUG__
-    last = NULL;					// for error checking
-    currSerialOwner = NULL;
+    currSerialOwner = NULL;				// for error checking
     currSerialCount = 0;
 #endif // __U_DEBUG__
     notHalted = true;					// must be a non-zero value so detectable after memory is scrubbed
     state = Inactive;
 
-    // exception handling
+    // exception handling / cancellation
 
-    uHandlerStackTop = uHandlerStackVisualTop = NULL;
-    ResumedObj = NULL;
-    TopResumedType = NULL;
-    uDAEStack = NULL;
-    uUnexpectedRtn = uEHM::uUnexpected;			// initialize default unexpected routine
+    handlerStackTop = handlerStackVisualTop = NULL;
+    resumedObj = NULL;
+    topResumedType = NULL;
+    DEStack = NULL;
+    unexpectedRtn = uEHM::unexpected;			// initialize default unexpected routine
+    unexpected = false;
+
+    _cancelled = false;
+    _cancelInProgress = false;
+    cancelState = CancelEnabled;
+    cancelType = CancelPoll;				// not really used yet, but makes Pthread cancellation easier
 
     // profiling
 
-    uProfileTaskSamplerInstance = NULL;
-} // uBaseCoroutine::uCreateCoroutine
+    profileTaskSamplerInstance = NULL;
+} // uBaseCoroutine::createCoroutine
 
 
 uBaseCoroutine::uBaseCoroutine() : uMachContext( uThisCluster().getStackSize() ) {
-    uCreateCoroutine();
+    createCoroutine();
 } // uBaseCoroutine::uBaseCoroutine
 
 
 uBaseCoroutine::uBaseCoroutine( unsigned int stacksize ) : uMachContext( stacksize ) {
-    uCreateCoroutine();
+    createCoroutine();
 } // uBaseCoroutine::uBaseCoroutine
 
 
-void uBaseCoroutine::uContextSw() {			// switch between a task and the kernel
-    uBaseCoroutine &uCurrCor = uThisCoroutine();	// optimization
+void uBaseCoroutine::contextSw() {			// switch between a task and the kernel
+    uBaseCoroutine &coroutine = uThisCoroutine();	// optimization
     uBaseTask &uCurrTask = uThisTask();
 
-    if ( uCurrTask.uProfileActive && uProfiler::uProfiler_BuiltInRegisterTaskBlock ) { // uninterruptable hooks
-	(*uProfiler::uProfiler_BuiltInRegisterTaskBlock)( uProfiler::uProfilerInstance, uCurrTask );
+    if ( uCurrTask.profileActive && uProfiler::uProfiler_builtinRegisterTaskBlock ) { // uninterruptable hooks
+	(*uProfiler::uProfiler_builtinRegisterTaskBlock)( uProfiler::profilerInstance, uCurrTask );
     } // if
 
-    uCurrCor.setState( Inactive );			// set state of current coroutine to inactive
+    coroutine.setState( Inactive );			// set state of current coroutine to inactive
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uBaseCoroutine &)0x%p.uContextSw, uCurrCor:0x%p, uCurrCor.uSP:0x%p, uCurrCor.uStorage:0x%p, uStorage:0x%p\n",
-	       this, &uCurrCor, uCurrCor.stackPointer(), uCurrCor.uStorage, uStorage );
+    uDebugPrt( "(uBaseCoroutine &)0x%p.contextSw, coroutine:0x%p, coroutine.SP:0x%p, coroutine.storage:0x%p, storage:0x%p\n",
+	       this, &coroutine, coroutine.stackPointer(), coroutine.storage, storage );
 #endif // __U_DEBUG_H__
-    uCurrCor.save();					// save user specified contexts
+    coroutine.save();					// save user specified contexts
 
-    uSwitch( uCurrCor.uStorage, uStorage );		// context switch to kernel
-    uCurrCor.restore();					// restore user specified contexts
-    uCurrCor.setState( Active );			// set state of new coroutine to active
+    uSwitch( coroutine.storage, storage );		// context switch to kernel
+    coroutine.restore();				// restore user specified contexts
+    coroutine.setState( Active );			// set state of new coroutine to active
 
     uCurrTask.setState( uBaseTask::Running );
 
-    if ( uCurrTask.uProfileActive && uProfiler::uProfiler_BuiltInRegisterTaskUnblock ) { // uninterruptable hooks
-	(*uProfiler::uProfiler_BuiltInRegisterTaskUnblock)( uProfiler::uProfilerInstance, uCurrTask );
+    if ( uCurrTask.profileActive && uProfiler::uProfiler_builtinRegisterTaskUnblock ) { // uninterruptable hooks
+	(*uProfiler::uProfiler_builtinRegisterTaskUnblock)( uProfiler::profilerInstance, uCurrTask );
     } // if
-} // uBaseCoroutine::uContextSw
+} // uBaseCoroutine::contextSw
 
 
-void uBaseCoroutine::uContextSw2() {			// switch between two coroutine contexts
-    uBaseCoroutine &uCurrCor = uThisCoroutine();	// optimization
+void uBaseCoroutine::contextSw2() {			// switch between two coroutine contexts
+    uBaseCoroutine &coroutine = uThisCoroutine();	// optimization
     uBaseTask &uCurrTask = uThisTask();
 
 #ifdef __U_DEBUG__
     // reset task in current coroutine?
-    if ( uCurrCor.currSerialCount == uCurrTask.uCurrSerialLevel ) {
-	uCurrCor.currSerialOwner = NULL;
+    if ( coroutine.currSerialCount == uCurrTask.currSerialLevel ) {
+	coroutine.currSerialOwner = NULL;
     } // if
     
     // check and set for new owner
@@ -121,77 +156,89 @@ void uBaseCoroutine::uContextSw2() {			// switch between two coroutine contexts
 	    } // if
 	}  else {
 	    currSerialOwner = &uCurrTask;
-	    currSerialCount = uCurrTask.uCurrSerialLevel;
+	    currSerialCount = uCurrTask.currSerialLevel;
 	} // if
     } // if
 #endif // __U_DEBUG__
 
-    if ( uCurrTask.uProfileActive && uProfiler::uProfiler_RegisterCoroutineBlock ) {
-	(*uProfiler::uProfiler_RegisterCoroutineBlock)( uProfiler::uProfilerInstance, uCurrTask, *this );
+    if ( uCurrTask.profileActive && uProfiler::uProfiler_registerCoroutineBlock ) {
+	(*uProfiler::uProfiler_registerCoroutineBlock)( uProfiler::profilerInstance, uCurrTask, *this );
     } // if
 
-    THREAD_GETMEM( uSelf )->disableInterrupts();
+    THREAD_GETMEM( This )->disableInterrupts();
 
-    uCurrCor.setState( Inactive );			// set state of current coroutine to inactive
+    coroutine.setState( Inactive );			// set state of current coroutine to inactive
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uBaseCoroutine &)0x%p.uContextSw2, uCurrCor:0x%p, uCurrCor.uSP:0x%p\n",
-	       this, &uCurrCor, uCurrCor.stackPointer() );
+    uDebugPrt( "(uBaseCoroutine &)0x%p.contextSw2, coroutine:0x%p, coroutine.SP:0x%p\n",
+	       this, &coroutine, coroutine.stackPointer() );
 #endif // __U_DEBUG_H__
-    uCurrCor.save();					// save user specified contexts
+    coroutine.save();					// save user specified contexts
     uCurrTask.currCoroutine = this;			// set new coroutine that task is executing
 
 #if defined( __U_MULTI__ ) && defined( __U_SWAPCONTEXT__ )
 #if defined( __linux__ ) && defined( __i386__ )
 #if ! defined( __U_PTHREAD__ )
-    ((ucontext_t *)(uStorage))->uc_mcontext.gregs[REG_GS] = THREAD_GETMEM( ldtValue );
+    ((ucontext_t *)(storage))->uc_mcontext.gregs[REG_GS] = THREAD_GETMEM( ldtValue );
 #endif // ! __U_PTHREAD__
 #elif defined( __linux__ ) && defined( __x86_64__ )
 #if ! defined( __U_PTHREAD__ )
     #error uC++ : internal error, unsupported architecture
 #endif // ! __U_PTHREAD__
 #elif defined( __linux__ ) && defined( __ia64__ )
-    ((ucontext_t *)(uStorage))->uc_mcontext.sc_gr[13] = (unsigned long)THREAD_GETMEM( threadPointer );
+    ((ucontext_t *)(storage))->uc_mcontext.sc_gr[13] = (unsigned long)THREAD_GETMEM( threadPointer );
 #elif defined( __solaris__ ) && defined( __sparc__ ) && ! defined( __U_PTHREAD__ )
-    ((ucontext_t *)(uStorage))->uc_mcontext.gregs[REG_G7] = (int)(THREAD_GETMEM( uSelf ) );
+    ((ucontext_t *)(storage))->uc_mcontext.gregs[REG_G7] = (int)(THREAD_GETMEM( This ) );
 #elif defined( __irix__ ) && defined( __mips__ )
     // No thread register => nothing needs to be set in the mcontext
+#elif defined( __freebsd__ ) && defined( __i386__ )
+    ((ucontext_t *)storage)->uc_mcontext.mc_gs = THREAD_GETMEM( ldtValue );
 #else
     #error uC++ : internal error, unsupported architecture
 #endif
 #ifdef __U_ONETIMER__
-    if ( &uThisProcessor() == uKernelModule::uSystemProcessor ) {
-	sigdelset( (sigset_t *)&(((ucontext_t *)(uStorage))->uc_sigmask), SIGALRM );
+    if ( &uThisProcessor() == uKernelModule::systemProcessor ) {
+	sigdelset( (sigset_t *)&(((ucontext_t *)(storage))->uc_sigmask), SIGALRM );
     } else {
-	sigaddset( (sigset_t *)&(((ucontext_t *)(uStorage))->uc_sigmask), SIGALRM );
+	sigaddset( (sigset_t *)&(((ucontext_t *)(storage))->uc_sigmask), SIGALRM );
     } // if
 #endif // __U_ONETIMER__
 #endif // __U_MULTI__ && __U_SWAPCONTEXT__
 #if  defined( __U_MULTI__ ) && defined( __U_ONETIMER__ ) && defined( __ia64__ )
-    if ( &uThisProcessor() == uKernelModule::uSystemProcessor ) {
-	sigdelset( &((uContext_t *)(uStorage))->uSigmask, SIGALRM );
+    if ( &uThisProcessor() == uKernelModule::systemProcessor ) {
+	sigdelset( &((uContext_t *)(storage))->sigMask, SIGALRM );
     } else {
-	sigaddset( &((uContext_t *)(uStorage))->uSigmask, SIGALRM );
+	sigaddset( &((uContext_t *)(storage))->sigMask, SIGALRM );
     } // if
 #endif // __U_MULTI__ && __U_ONETIMER__ && __ia64__
 
-    uSwitch( uCurrCor.uStorage, uStorage );		// context switch to specified coroutine
-    uCurrCor.restore();					// restore user specified contexts
-    uCurrCor.setState( Active );			// set state of new coroutine to active
+    uSwitch( coroutine.storage, storage );		// context switch to specified coroutine
+    coroutine.restore();				// restore user specified contexts
+    coroutine.setState( Active );			// set state of new coroutine to active
 
-    THREAD_GETMEM( uSelf )->enableInterrupts();
+    THREAD_GETMEM( This )->enableInterrupts();
 
     // also appears in uCoroutineMain::uCoroutineMain
-    if ( uCurrTask.uProfileActive && uProfiler::uProfiler_RegisterCoroutineUnblock ) {
-	(*uProfiler::uProfiler_RegisterCoroutineUnblock)( uProfiler::uProfilerInstance, uCurrTask );
+    if ( uCurrTask.profileActive && uProfiler::uProfiler_registerCoroutineUnblock ) {
+	(*uProfiler::uProfiler_registerCoroutineUnblock)( uProfiler::profilerInstance, uCurrTask );
     } // if
-} // uBaseCoroutine::uContextSw2
+} // uBaseCoroutine::contextSw2
 
 
-void uBaseCoroutine::uCoFinish() {			// resumes the coroutine that first resumed this coroutine
+void uBaseCoroutine::corFinish() {			// resumes the coroutine that first resumed this coroutine
     notHalted = false;
-    _starter->uContextSw2();
-    uAbort( "(uBaseCoroutine &)0x%p.uCoFinish() : internal error, CONTROL NEVER REACHES HERE!", this );
-} // uBaseCoroutine::uCoFinish
+#ifdef __U_DEBUG__
+    if ( ! _starter->notHalted ) {			// check if terminated
+	    uAbort( "Attempt by coroutine %.256s (0x%p) to resume back to terminated starter coroutine %.256s (0x%p).\n"
+		    "Possible cause is terminated coroutine's main routine has already returned.",
+		    uThisCoroutine().getName(), &uThisCoroutine(), _starter->getName(), _starter );
+    } // if
+#endif // __U_DEBUG__
+    _starter->contextSw2();
+    // CONTROL NEVER REACHES HERE!
+#ifdef __U_DEBUG__
+    assert( false );
+#endif // __U_DEBUG__
+} // uBaseCoroutine::corFinish
 
 
 void uBaseCoroutine::resume() {				// restarts the coroutine's main where last suspended
@@ -206,7 +253,7 @@ void uBaseCoroutine::resume() {				// restarts the coroutine's main where last s
 	} // if
 #endif // __U_DEBUG__
 	last = &c;
-	uContextSw2();
+	contextSw2();
     } // if
     _Enable <uBaseCoroutine::Failure>;			// implicit poll
 } // uBaseCoroutine::resume
@@ -215,7 +262,7 @@ void uBaseCoroutine::resume() {				// restarts the coroutine's main where last s
 void uBaseCoroutine::suspend() {			// restarts the coroutine that most recently resumed this coroutine
 #ifdef __U_DEBUG__
     if ( last == NULL ) {
-	uAbort( "Attempt to suspend coroutine %.256s (0x%p), which has never been resumed.\n"
+	uAbort( "Attempt to suspend coroutine %.256s (0x%p) that has never been resumed.\n"
 		"Possible cause is a suspend executed in a member called by a coroutine user rather than by the coroutine main.",
 		getName(), this );
     } // if
@@ -225,17 +272,17 @@ void uBaseCoroutine::suspend() {			// restarts the coroutine that most recently
 		    uThisCoroutine().getName(), &uThisCoroutine(), last->getName(), last );
     } // if
 #endif // __U_DEBUG__
-    last->uContextSw2();
+    last->contextSw2();
     _Enable <uBaseCoroutine::Failure>;			// implicit poll
 } // uBaseCoroutine::suspend
 
 
-const char *uBaseCoroutine::setName( const char *n ) {
+const char *uBaseCoroutine::setName( const char *name ) {
     const char *prev = name;
-    name = n;
+    uBaseCoroutine::name = name;
 
-    if ( uThisTask().uProfileActive && uProfiler::uProfiler_RegisterSetName ) { 
-	(*uProfiler::uProfiler_RegisterSetName)( uProfiler::uProfilerInstance, *this, name ); 
+    if ( uThisTask().profileActive && uProfiler::uProfiler_registerSetName ) { 
+	(*uProfiler::uProfiler_registerSetName)( uProfiler::profilerInstance, *this, name ); 
     } // if
     return prev;
 } // uBaseCoroutine::setName
@@ -246,6 +293,29 @@ const char *uBaseCoroutine::getName() const {
 } // uBaseCoroutine::getName
 
 
+void uBaseCoroutine::setCancelState( CancellationState state ) {
+#ifdef __U_DEBUG__
+    if ( this != &uThisTask() ) {
+	uAbort( "Attempt to set the cancellation state of coroutine %.256s (0x%p) by coroutine %.256s (0x%p).\n"
+		"A coroutine/task may only change its own cancellation state.",
+		getName(), this, uThisCoroutine().getName(), &uThisCoroutine() );
+    } // if
+#endif // __U_DEBUG__
+    cancelState = state;
+} // uBaseCoroutine::setCancelState
+
+void uBaseCoroutine::setCancelType( CancellationType type ) {
+#ifdef __U_DEBUG__
+    if ( this != &uThisTask() ) {
+	uAbort( "Attempt to set the cancellation state of coroutine %.256s (0x%p) by coroutine %.256s (0x%p).\n"
+		"A coroutine/task may only change its own cancellation state.",
+		getName(), this, uThisCoroutine().getName(), &uThisCoroutine() );
+    } // if
+#endif // __U_DEBUG__
+    cancelType = type;
+} // uBaseCoroutine::setCancelType
+
+
 uBaseCoroutine::Failure::Failure( const char *const msg ) : uKernelFailure( msg ) {
 } // uBaseCoroutine::Failure::Failure
 
@@ -259,7 +329,7 @@ void uBaseCoroutine::Failure::defaultTerminate() const {
 
 uBaseCoroutine::UnHandledException::UnHandledException( const char *const msg ) : Failure( msg ), origFailedCor( uThisCoroutine() ) {
     multiple = false;
-    uEHM::uStrncpy( origFailedCorName, origFailedCor.getName(), uEHMMaxName );
+    uEHM::strncpy( origFailedCorName, origFailedCor.getName(), uEHMMaxName );
 } // uBaseCoroutine::Failure::Failure
 
 uBaseCoroutine::UnHandledException::~UnHandledException() {
