@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uContext.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Wed Feb 23 17:32:14 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 11:09:32 2005
-// Update Count     : 63
+// Last Modified On : Fri Sep 15 21:10:35 2006
+// Update Count     : 69
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -40,39 +40,39 @@ uContext::uContext( void *key ) : key( key ) {
     // call.  If there is a similar context already active for this state, do
     // not add this context again.
 
-    uBaseCoroutine &c = uThisCoroutine();		// optimization
+    uBaseCoroutine &coroutine = uThisCoroutine();	// optimization
     uContext *context;
-    for ( uSeqIter<uContext> iter(c.uAdditionalContexts); iter >> context; ) {
+    for ( uSeqIter<uContext> iter( coroutine.additionalContexts ); iter >> context; ) {
       if ( context->key == key ) return;
     } // for
 
     // If no similar context is found, add this context to the list of contexts
     // active for this state.
 
-    THREAD_GETMEM( uSelf )->disableInterrupts();
-    c.uAdditionalContexts.addTail( this );
-    c.uExtras.uIs.uContexts = 1;
-    THREAD_GETMEM( uSelf )->enableInterrupts();
+    THREAD_GETMEM( This )->disableInterrupts();
+    coroutine.additionalContexts.addTail( this );
+    coroutine.extras.is.usercxts = 1;
+    THREAD_GETMEM( This )->enableInterrupts();
 } // uContext::uContext
 
 uContext::uContext() : key( this ) {
-    uBaseCoroutine &c = uThisCoroutine();		// optimization
-    THREAD_GETMEM( uSelf )->disableInterrupts();
-    c.uAdditionalContexts.addTail( this );
-    c.uExtras.uIs.uContexts = 1;
-    THREAD_GETMEM( uSelf )->enableInterrupts();
+    uBaseCoroutine &coroutine = uThisCoroutine();	// optimization
+    THREAD_GETMEM( This )->disableInterrupts();
+    coroutine.additionalContexts.addTail( this );
+    coroutine.extras.is.usercxts = 1;
+    THREAD_GETMEM( This )->enableInterrupts();
 } // uContext::uContext
 
 uContext::~uContext() {
-    uBaseCoroutine &c = uThisCoroutine();		// optimization
-    // If the context is present on a list of contexts, remove it.
+    uBaseCoroutine &coroutine = uThisCoroutine();	// optimization
+    // If the usercxts is present on a list of contexts, remove it.
     if ( listed() ) {
-	THREAD_GETMEM( uSelf )->disableInterrupts();
-	c.uAdditionalContexts.remove( this );
-	if ( c.uAdditionalContexts.empty() ) {
-	    c.uExtras.uIs.uContexts = 0;
+	THREAD_GETMEM( This )->disableInterrupts();
+	coroutine.additionalContexts.remove( this );
+	if ( coroutine.additionalContexts.empty() ) {
+	    coroutine.extras.is.usercxts = 0;
 	} // if
-	THREAD_GETMEM( uSelf )->enableInterrupts();
+	THREAD_GETMEM( This )->enableInterrupts();
     } // if
 } // uContext::~uContext
 
