@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uDebug.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Sat Dec 18 13:04:26 1993
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Aug  5 14:44:35 2005
-// Update Count     : 107
+// Last Modified On : Wed Jul 19 22:25:33 2006
+// Update Count     : 108
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -87,7 +87,8 @@ extern "C" void uDebugPrt( const char fmt[], ... ) {
     uDebugLock->acquire();
     sprintf( buffer, "(%ld) ", (long int)
 #if defined( __U_PTHREAD__ )
-	     uRealPthread::pthread_self()
+	     // NULL if called early in boot sequence
+	     uRealPthread::pthread_self == NULL ? 0 : uRealPthread::pthread_self()
 #elif defined( __solaris__ )
 	     _lwp_self()				// always print the UNIX pid
 #else
