@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1997
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1997
 // 
 // uDefault.h -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Thu Mar 20 18:12:31 1997
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Apr 22 18:48:17 2005
-// Update Count     : 13
+// Last Modified On : Sat Aug 26 11:03:58 2006
+// Update Count     : 16
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -63,11 +63,18 @@
 #endif // __ia64__
 
 
-extern unsigned int uDefaultHeapExpansion();		// default heap expansion size (bytes)
-extern unsigned int uDefaultStackSize();		// default cluster coroutine/task stack size (bytes)
-extern unsigned int uMainStackSize();			// default uMain task stack size (bytes)
-extern unsigned int uDefaultSpin();			// default processor spin time for idle task (context switches)
-extern unsigned int uDefaultPreemption();		// default processor scheduling pre-emption durations (milliseconds)
+// Define the default number of processors created on the user cluster. May not
+// be less than 1.
+
+#define __U_DEFAULT_PROCESSORS__ 1
+
+
+extern unsigned int uDefaultHeapExpansion();		// heap expansion size (bytes)
+extern unsigned int uDefaultStackSize();		// cluster coroutine/task stack size (bytes)
+extern unsigned int uMainStackSize();			// uMain task stack size (bytes)
+extern unsigned int uDefaultSpin();			// processor spin time for idle task (context switches)
+extern unsigned int uDefaultPreemption();		// processor scheduling pre-emption durations (milliseconds)
+extern unsigned int uDefaultProcessors();		// number of processors created on the user cluster
 
 
 #endif // __U_DEFAULT_H__
