@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Russell Mok 1997
+// uC++ Version 5.4.0, Copyright (C) Russell Mok 1997
 // 
 // uEHM.cc -- 
 // 
 // Author           : Russell Mok
 // Created On       : Sun Jun 29 00:15:09 1997
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Dec 12 09:00:21 2005
-// Update Count     : 478
+// Last Modified On : Sun Sep 24 19:00:42 2006
+// Update Count     : 524
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -90,7 +90,7 @@ namespace __cxxabiv1 {
 //######################### std::{C++ exception routines} ########################
 
 
-void uEHM::uTerminate() {
+void uEHM::terminate() {
     char ExName[uEHMMaxName + sizeof("...")];		// room for "...\0"
     char ResName[uEHMMaxName + sizeof("...")];
 
@@ -105,85 +105,88 @@ void uEHM::uTerminate() {
 		"Possible cause is a rethrow/reraise not directly or indirectly performed from a catch clause." );
     } // if
     
-    uAbort( "Propagation failed to find a matching handler.\n"
-	    "Possible cause is a missing try block with appropriate catch clause for specified or derived exception type\n"
-	    "or throwing an exception from within a destructor while propagating an exception.\n"
-	    "%s%s%s%s%s",
+    uAbort( "%s%s%s%s%s%s",
+	    ( uThisCoroutine().unexpected ?
+	      "Exception propagated through a function whose exception-specification does not permit exceptions of that type.\n" :
+	      "Propagation failed to find a matching handler.\n"
+	      "Possible cause is a missing try block with appropriate catch clause for specified or derived exception type\n"
+	      "or throwing an exception from within a destructor while propagating an exception.\n" ),
 	    (exception  ? "Type of last active exception: "  : ""), (exception  ? ExName  : ""), (exception && resumption ? "\n" : ""),
 	    (resumption ? "Type of last active resumption: " : ""), (resumption ? ResName : "") ); // uAbort puts a "\n"
-} // uEHM::uTerminate
+} // uEHM::terminate
 
-void uEHM::uTerminateHandler() {
+void uEHM::terminateHandler() {
     try {
-	(*uThisTask().uTerminateRtn)();
-	uEHM::uTerminate();
+	(*uThisTask().terminateRtn)();
+	uEHM::terminate();
     } catch( ... ) {
-	uEHM::uTerminate();
+	uEHM::terminate();
     } // try
-} // uEHM::uTerminateHandler
+} // uEHM::terminateHandler
 
-void uEHM::uUnexpected() {
+void uEHM::unexpected() {
+    uThisCoroutine().unexpected = true;
     std::terminate();
-} // uEHM::uTerminate
+} // uEHM::unexpected
 
-void uEHM::uUnexpectedHandler() {
-    (*uThisCoroutine().uUnexpectedRtn)();
+void uEHM::unexpectedHandler() {
+    (*uThisCoroutine().unexpectedRtn)();
     std::terminate();
-} // uEHM::uUnexpectedHandler
+} // uEHM::unexpectedHandler
 
 std::terminate_handler std::set_terminate( std::terminate_handler func ) throw() {
-    uBaseTask &t = uThisTask();
-    std::terminate_handler prev = t.uTerminateRtn;
-    t.uTerminateRtn = func;
+    uBaseTask &task = uThisTask();
+    std::terminate_handler prev = task.terminateRtn;
+    task.terminateRtn = func;
     return prev;
 } // std::set_terminate
 
 std::unexpected_handler std::set_unexpected( std::unexpected_handler func ) throw() {
-    uBaseCoroutine &c = uThisCoroutine();		// optimization
-    std::unexpected_handler prev = c.uUnexpectedRtn;
-    c.uUnexpectedRtn = func;
+    uBaseCoroutine &coroutine = uThisCoroutine();	// optimization
+    std::unexpected_handler prev = coroutine.unexpectedRtn;
+    coroutine.unexpectedRtn = func;
     return prev;
 } // std::set_unexpected
 
 
-//######################### uEHM::uAsyncAEMsg ########################
+//######################### uEHM::AsyncEMsg ########################
 
 
-uEHM::uAsyncAEMsg::uAsyncAEMsg( const uDualClass &ex, const uFlagT f ) : flag( f ), uHidden( false ) {
-    ae = ex.duplicate();
-} // uEHM::uAsyncAEMsg::uAsyncAEMsg
+uEHM::AsyncEMsg::AsyncEMsg( const uDualClass &ex, const raiseKind f ) : flag( f ), hidden( false ) {
+    asyncEvent = ex.duplicate();
+} // uEHM::AsyncEMsg::AsyncEMsg
 
-uEHM::uAsyncAEMsg::~uAsyncAEMsg() {
-    delete ae;
-} // uEHM::uAsyncAEMsg::~uAsyncAEMsg
+uEHM::AsyncEMsg::~AsyncEMsg() {
+    delete asyncEvent;
+} // uEHM::AsyncEMsg::~AsyncEMsg
 
 
-//######################### uEHM::uAsyncAEMsgBuffer ########################
+//######################### uEHM::AsyncEMsgBuffer ########################
 
 
 // msg queue for nonlocal exceptions in a coroutine
 
-uEHM::uAsyncAEMsgBuffer::uAsyncAEMsgBuffer() {
-} // uAsyncAEMsgBuffer::uAsyncAEMsgBuffer
+uEHM::AsyncEMsgBuffer::AsyncEMsgBuffer() {
+} // AsyncEMsgBuffer::AsyncEMsgBuffer
 
-uEHM::uAsyncAEMsgBuffer::~uAsyncAEMsgBuffer() {
+uEHM::AsyncEMsgBuffer::~AsyncEMsgBuffer() {
     uCSpinLock dummy( lock );
-    for ( uAsyncAEMsg *tmp = drop(); tmp; tmp = drop() ) {
+    for ( AsyncEMsg *tmp = drop(); tmp; tmp = drop() ) {
 	delete tmp;
     } // for
-} // uEHM::uAsyncAEMsgBuffer::~uAsyncAEMsgBuffer
+} // uEHM::AsyncEMsgBuffer::~AsyncEMsgBuffer
 
-void uEHM::uAsyncAEMsgBuffer::uAddMsg( uAsyncAEMsg *msg ) {
+void uEHM::AsyncEMsgBuffer::uAddMsg( AsyncEMsg *msg ) {
     uCSpinLock dummy( lock );
     add( msg );
-} // uEHM::uAsyncAEMsgBuffer::uAddMsg
+} // uEHM::AsyncEMsgBuffer::uAddMsg
 
-uEHM::uAsyncAEMsg *uEHM::uAsyncAEMsgBuffer::uRmMsg() {
+uEHM::AsyncEMsg *uEHM::AsyncEMsgBuffer::uRmMsg() {
     uCSpinLock dummy( lock );
     return drop();
-} // uEHM::uAsyncAEMsgBuffer::uRmMsg
+} // uEHM::AsyncEMsgBuffer::uRmMsg
 
-uEHM::uAsyncAEMsg *uEHM::uAsyncAEMsgBuffer::uRmMsg( uAsyncAEMsg *msg ) {
+uEHM::AsyncEMsg *uEHM::AsyncEMsgBuffer::uRmMsg( AsyncEMsg *msg ) {
     // Only lock at the end or the start of the list as these are the only
     // places where interference can occur.
 
@@ -194,22 +197,22 @@ uEHM::uAsyncAEMsg *uEHM::uAsyncAEMsgBuffer::uRmMsg( uAsyncAEMsg *msg ) {
 	remove( msg );
     } // if
     return msg;
-} // uEHM::uAsyncAEMsgBuffer::uRmMsg
+} // uEHM::AsyncEMsgBuffer::uRmMsg
 
-uEHM::uAsyncAEMsg *uEHM::uAsyncAEMsgBuffer::uNextVisible( uAsyncAEMsg *msg ) {
+uEHM::AsyncEMsg *uEHM::AsyncEMsgBuffer::nextVisible( AsyncEMsg *msg ) {
     // find the next msg node that is visible or null
     do {						// do-while because current node could be visible
 	msg = succ( msg );
-    } while ( msg && msg->uHidden );
+    } while ( msg && msg->hidden );
     return msg;
-} // uEHM::uAsyncAEMsgBuffer::uNextVisible
+} // uEHM::AsyncEMsgBuffer::nextVisible
 
 
 //######################### uDualClass ########################
 
 
 uEHM::uDualClass::uDualClass( const char *const msg ) : src( NULL ) {
-    uStrncpy( uEHM::uDualClass::msg, msg, uEHMMaxMsg );	// copy message
+    strncpy( uEHM::uDualClass::msg, msg, uEHMMaxMsg );	// copy message
 }; // uEHM::uDualClass::uDualClass
 
 uEHM::uDualClass::~uDualClass() {}
@@ -220,26 +223,32 @@ const char *uEHM::uDualClass::sourceName() const { return src != NULL ? srcName
 
 void uEHM::uDualClass::setSrc( uBaseCoroutine &cor ) {
     src = &cor;
-    uStrncpy( srcName, cor.getName(), uEHMMaxName );	// copy source name
+    strncpy( srcName, cor.getName(), uEHMMaxName );	// copy source name
 } // uEHM::uDualClass::setSrc
 
 const uEHM::uDualClass &uEHM::uDualClass::setOriginalThrower( const void * p ) const {
-    // Calls to this routine are generated by the translator at each throw
-    // site. Because the exception object being thrown may be const, this
-    // routine still has to modify the exception object. Hence, the need for
-    // the const cast.
-    const_cast< uEHM::uDualClass * >(this)->uStaticallyBoundObject = p;
+    staticallyBoundObject = p;
     return *this;
 } // uEHM::uDualClass::setOriginalThrower
 
 void uEHM::uDualClass::defaultTerminate() const {
 } // uEHM::uDualClass::defaultTerminate
 
+void uEHM::uDualClass::defaultTerminate() {
+    const_cast<const uDualClass *>(this)->defaultTerminate();
+} // uEHM::uDualClass::defaultTerminate
+
 void uEHM::uDualClass::defaultResume() const {
     stackThrow();
     // CONTROL NEVER REACHES HERE!
+#ifdef __U_DEBUG__
+    assert( false );
+#endif // __U_DEBUG__
 } // uEHM::uDualClass::defaultResume
 
+void uEHM::uDualClass::defaultResume() {
+    const_cast<const uDualClass *>(this)->defaultResume();
+} // uEHM::uDualClass::defaultResume
 
 
 //######################### uEHM::uThrowClass ########################
@@ -252,6 +261,10 @@ uEHM::uThrowClass::~uThrowClass() {}
 void uEHM::uThrowClass::defaultResume() const {
     uAbort( "uThrowClass object cannot be casted to a raise-able object." );
 } // uEHM::uThrowClass::defaultResume
+
+void uEHM::uThrowClass::defaultResume() {
+    const_cast<const uThrowClass *>(this)->defaultResume();
+} // uEHM::uThrowClass::defaultResume
 #endif // __DEBUG__
 
 
@@ -269,10 +282,18 @@ uEHM::uResumeClass::~uResumeClass() {}
 void uEHM::uResumeClass::defaultTerminate() const {
     uAbort( "uResumeClass object cannot be casted to a throw-able object." );
 } // uEHM::uResumeClass::defaultTerminate
+
+void uEHM::uResumeClass::defaultTerminate() {
+    const_cast<const uResumeClass *>(this)->defaultTerminate();
+} // uEHM::uResumeClass::defaultTerminate
 #endif // __DEBUG__
 
 void uEHM::uResumeClass::defaultResume() const {
-    uTerminate();
+    terminate();
+} // uEHM::uResumeClass::defaultResume
+
+void uEHM::uResumeClass::defaultResume() {
+    const_cast<const uResumeClass *>(this)->defaultResume();
 } // uEHM::uResumeClass::defaultResume
 
 
@@ -280,36 +301,36 @@ void uEHM::uResumeClass::defaultResume() const {
 
 
 uEHM::uResumptionHandlers::uResumptionHandlers( uHandlerBase *const table[], const unsigned int size ) : size( size ), table( table ) {
-    uBaseCoroutine &c = uThisCoroutine();		// optimization
-    uNext = c.uHandlerStackTop;
-    uConseqNext = c.uHandlerStackVisualTop;
-    c.uHandlerStackTop = this;
-    c.uHandlerStackVisualTop = this;
+    uBaseCoroutine &coroutine = uThisCoroutine();	// optimization
+    next = coroutine.handlerStackTop;
+    conseqNext = coroutine.handlerStackVisualTop;
+    coroutine.handlerStackTop = this;
+    coroutine.handlerStackVisualTop = this;
 } // uEHM::uResumptionHandlers::uResumptionHandlers
 
 uEHM::uResumptionHandlers::~uResumptionHandlers() {
-    uBaseCoroutine &c = uThisCoroutine();		// optimization
-    c.uHandlerStackTop = uNext;
-    c.uHandlerStackVisualTop = uConseqNext;
+    uBaseCoroutine &coroutine = uThisCoroutine();	// optimization
+    coroutine.handlerStackTop = next;
+    coroutine.handlerStackVisualTop = conseqNext;
 } // uEHM::uResumptionHandlers::~uResumptionHandlers
 
 
-//######################### uEHM::uDeliverAEStack ########################
+//######################### uEHM::uDeliverEStack ########################
 
 
-uEHM::uDeliverAEStack::uDeliverAEStack( bool f, const std::type_info **t, unsigned int msg ) : uDeliverFlag( f ), table_size( msg ), event_table( t ) {
+uEHM::uDeliverEStack::uDeliverEStack( bool f, const std::type_info **t, unsigned int msg ) : deliverFlag( f ), table_size( msg ), event_table( t ) {
     // the current node applies to all exceptions when table_size is 0
-    uBaseCoroutine &c = uThisCoroutine();		// optimization
-    next = c.uDAEStack;
-    c.uDAEStack = this;
-} // uEHM::uDeliverAEStack::uDeliverAEStack
+    uBaseCoroutine &coroutine = uThisCoroutine();	// optimization
+    next = coroutine.DEStack;
+    coroutine.DEStack = this;
+} // uEHM::uDeliverEStack::uDeliverEStack
 
-uEHM::uDeliverAEStack::~uDeliverAEStack() {
-    uThisCoroutine().uDAEStack = next;
-} // uEHM::uDeliverAEStack::~uDeliverAEStack
+uEHM::uDeliverEStack::~uDeliverEStack() {
+    uThisCoroutine().DEStack = next;
+} // uEHM::uDeliverEStack::~uDeliverEStack
 
 
-//######################### uEHM::uResumeWorkHorseInit ########################
+//######################### uEHM::ResumeWorkHorseInit ########################
 
 
 // Initialization and finalization when handling a signalled event after
@@ -317,50 +338,50 @@ uEHM::uDeliverAEStack::~uDeliverAEStack() {
 // hierarchies are properly maintained.  As well, it maintains the currently
 // handled resumption object for reraise.
 
-class uEHM::uResumeWorkHorseInit {
+class uEHM::ResumeWorkHorseInit {
     uResumptionHandlers *prevVisualTop;
     uDualClass *prevResumption;
   public:
-    uResumeWorkHorseInit( uResumptionHandlers *h, uDualClass & newResumption ) {
-	uBaseCoroutine &c = uThisCoroutine();		// optimization
-	prevResumption = c.ResumedObj;
-	c.ResumedObj = &newResumption;
-	c.TopResumedType = &typeid(newResumption);
-	uBaseCoroutine &current = c;
-	prevVisualTop = current.uHandlerStackVisualTop;
-	current.uHandlerStackVisualTop = h;
-    } // uEHM::uResumeWorkHorseInit::uResumeWorkHorse
+    ResumeWorkHorseInit( uResumptionHandlers *h, uDualClass & newResumption ) {
+	uBaseCoroutine &coroutine = uThisCoroutine();	// optimization
+	prevResumption = coroutine.resumedObj;
+	coroutine.resumedObj = &newResumption;
+	coroutine.topResumedType = &typeid(newResumption);
+	uBaseCoroutine &current = coroutine;
+	prevVisualTop = current.handlerStackVisualTop;
+	current.handlerStackVisualTop = h;
+    } // uEHM::ResumeWorkHorseInit::resumeWorkHorse
 
-    ~uResumeWorkHorseInit() {
-	uBaseCoroutine &c = uThisCoroutine();		// optimization
-	c.ResumedObj = prevResumption;
+    ~ResumeWorkHorseInit() {
+	uBaseCoroutine &coroutine = uThisCoroutine();	// optimization
+	coroutine.resumedObj = prevResumption;
 	if ( ! std::uncaught_exception() ) {		// update top, unless it's a forceful unwind
-	    c.TopResumedType = prevResumption ? &typeid(prevResumption) : NULL;
+	    coroutine.topResumedType = prevResumption ? &typeid(prevResumption) : NULL;
 	} // if
-	c.uHandlerStackVisualTop = prevVisualTop;
-    } // uEHM::uResumeWorkHorseInit::~uResumeWorkHorse
-}; // uEHM::uResumeWorkHorseInit
+	coroutine.handlerStackVisualTop = prevVisualTop;
+    } // uEHM::ResumeWorkHorseInit::~resumeWorkHorse
+}; // uEHM::ResumeWorkHorseInit
 
 
-//######################### uEHM::uEHMAutoResourceCleanup ########################
+//######################### uEHM::AutoResourceCleanup ########################
 
-// Used by uPoll to ensure a handled message is removed from the queue and its
+// Used by poll to ensure a handled message is removed from the queue and its
 // memory deallocated. These actions are done in the destructor to ensure the
 // clean-up is performed even when an exception is thrown.  Unwinding the stack
-// causes the uEHMAutoResourceCleanup object to be destroyed and hence the
+// causes the AutoResourceCleanup object to be destroyed and hence the
 // destructor to be called.
 
-class uEHM::uEHMAutoResourceCleanup {
-    uAsyncAEMsg *msg;
-    uAsyncAEMsgBuffer &buf;
+class uEHM::AutoResourceCleanup {
+    AsyncEMsg *msg;
+    AsyncEMsgBuffer &buf;
   public:
-    uEHMAutoResourceCleanup( uAsyncAEMsg *msg, uAsyncAEMsgBuffer &buf ) : msg( msg ), buf( buf ) {}
+    AutoResourceCleanup( AsyncEMsg *msg, AsyncEMsgBuffer &buf ) : msg( msg ), buf( buf ) {}
 
-    ~uEHMAutoResourceCleanup() {
+    ~AutoResourceCleanup() {
 	buf.uRmMsg(msg);
 	delete msg;
-    } // uEHM::uEHMAutoResourceCleanup::~uEHMAutoResourceCleanup
-}; // uEHM::uEHMAutoResourceCleanup
+    } // uEHM::AutoResourceCleanup::~AutoResourceCleanup
+}; // uEHM::AutoResourceCleanup
 
 
 //######################### uEHM ########################
@@ -376,23 +397,23 @@ static void Check( uBaseCoroutine &target, const char *kind ) {
 #endif // __U_DEBUG__
 
 
-void uEHM::asyncToss( const uDualClass &ex, uBaseCoroutine &target, uFlagT f, bool rethrow ) {
+void uEHM::asyncToss( const uDualClass &ex, uBaseCoroutine &target, raiseKind f, bool rethrow ) {
 #ifdef __U_DEBUG__
     Check( target, f == uResumeF ? "resume" : "throw" );
 #endif // __U_DEBUG__
 
     if ( target.getState() != uBaseCoroutine::Halt ) {
-	uAsyncAEMsg *temp = new uAsyncAEMsg( ex, f );
+	AsyncEMsg *temp = new AsyncEMsg( ex, f );
 	uBaseCoroutine &cor = uThisCoroutine();
 	if ( ! rethrow ) {				// reset current raiser ?
-	    temp->ae->setOriginalThrower( (void *)&cor );
-	    temp->ae->setSrc( cor );
+	    temp->asyncEvent->setOriginalThrower( (void *)&cor );
+	    temp->asyncEvent->setSrc( cor );
 	} // if
-	target.uAsyncAEBuf.uAddMsg( temp );
+	target.asyncEBuf.uAddMsg( temp );
     } // if
 } // uEHM::asyncToss
 
-void uEHM::asyncReToss( uBaseCoroutine &target, uFlagT f ) {
+void uEHM::asyncReToss( uBaseCoroutine &target, raiseKind f ) {
     uDualClass *r;
 
     if (f == uResumeF) {
@@ -408,7 +429,7 @@ void uEHM::asyncReToss( uBaseCoroutine &target, uFlagT f ) {
     } // if
     
     if ( r == NULL ) {					// => there is nothing to resume => terminate
-	uTerminateHandler();
+	terminateHandler();
     } else {
 	asyncToss( *r, target, f, true );
     } // if
@@ -421,6 +442,9 @@ void uEHM::Throw( const uDualClass &ex ) {
 #endif // __U_DEBUG_H__
     ex.stackThrow();
     // CONTROL NEVER REACHES HERE!
+#ifdef __U_DEBUG__
+    assert( false );
+#endif // __U_DEBUG__
 } // uEHM::Throw
 
 void uEHM::ReThrow() {
@@ -437,7 +461,7 @@ void uEHM::ReThrow() {
 
 
 void uEHM::Resume( const uDualClass &ex ) {
-    uResumeWorkHorse( ex, true );
+    resumeWorkHorse( ex, true );
 } // uEHM::Resume
 
 void uEHM::ReResume() {
@@ -448,56 +472,69 @@ void uEHM::ReResume() {
     } // if
 
     if ( r == NULL ) {					// => there is nothing to resume => terminate
-	uTerminateHandler();
+	terminateHandler();
     } else {						// => there is something to resume
-	uResumeWorkHorse( *r, true );	
+	resumeWorkHorse( *r, true );	
     } // if
 }; // uEHM::ReResume
 
 
 // Check for and handle pending nonlocal exceptions.
 
-bool uEHM::uPoll() {
-    uAsyncAEMsgBuffer &msgbuf = uThisCoroutine().uAsyncAEBuf;
-    uAsyncAEMsg *ae_msg = msgbuf.head();		// find first node in queue
+bool uEHM::poll() {
+    uBaseCoroutine &cor = uThisCoroutine();
+  if ( cor.cancelInProgress() ) return false;		// skip async handling if cancelling
+    if ( cor.getCancelState() != uBaseCoroutine::CancelDisabled && cor.cancelled() ) { // check for cancellation first, but only if it is enabled	
+	cor.unwindStack();				// not cancelling, so unwind stack
+	// CONTROL NEVER REACHES HERE!
+#ifdef __U_DEBUG__
+	assert( false );
+#endif // __U_DEBUG__
+    } // if
 
-  if ( ae_msg == NULL ) return false;
+    AsyncEMsgBuffer &msgbuf = cor.asyncEBuf;
+    AsyncEMsg *asyncMsg = msgbuf.head();		// find first node in queue
 
-    if ( ae_msg->uHidden ) {
-	ae_msg = msgbuf.uNextVisible( ae_msg );		// from there, find first visible node
+  if ( asyncMsg == NULL ) return false;
+
+    if ( asyncMsg->hidden ) {
+	asyncMsg = msgbuf.nextVisible( asyncMsg );	// from there, find first visible node
     } // if
 
     // For each visible node, check if responsible for its delivery. If yes,
-    // hide it from any recursive uPoll call, handle the event, and remove it
+    // hide it from any recursive poll call, handle the event, and remove it
     // from the queue through the automatic resource clean-up.
 
-    while ( ae_msg != NULL ) {
-    	if ( deliverable_exception( ae_msg->ae->uGetEventType() ) ) {
+    while ( asyncMsg != NULL ) {
+    	if ( deliverable_exception( asyncMsg->asyncEvent->getEventType() ) ) {
 	    // Note, implicit context switches only call uYieldNoPoll(), hence
-	    // uPoll can only be called from uResumeWorkHorse again, which is a
+	    // poll can only be called from resumeWorkHorse again, which is a
 	    // safe recursion.
-	    ae_msg->uHidden = true;                     // hide node from recursive children of uPoll
-	    uDualClass *ae = ae_msg->ae;
+	    asyncMsg->hidden = true;			// hide node from recursive children of poll
+	    uDualClass *asyncEvent = asyncMsg->asyncEvent;
 	    
 	    // Recover memory allocated for async event message. Resuming
 	    // handler should not destroyed raised exception regardless of
 	    // whether the exception is normal or nonlocal.
 
-	    uEHMAutoResourceCleanup dummy_var( ae_msg, msgbuf ); // This ensures removal and deletion of the node at end of block.
-	                                                        // Necessary because of return or throw.
+	    AutoResourceCleanup dummy_var( asyncMsg, msgbuf ); // This ensures removal and deletion of the node at end of block.
+	                                                       // Necessary because of return or throw.
 
-	    if ( ae_msg->flag == uThrowF ) {		// throw the event
-		ae->stackThrow();
+	    if ( asyncMsg->flag == uThrowF ) {		// throw the event
+		asyncEvent->stackThrow();
 		// CONTROL NEVER REACHES HERE!
+#ifdef __U_DEBUG__
+		assert( false );
+#endif // __U_DEBUG__
 	    } // if
-	    uResumeWorkHorse( *ae, false );		// handle event, potential recursion! also potential exception
+	    resumeWorkHorse( *asyncEvent, false );	// handle event, potential recursion! also potential exception
 	    
-	    ae_msg = msgbuf.uNextVisible(ae_msg);	// advance to next visible node
+	    asyncMsg = msgbuf.nextVisible( asyncMsg );	// advance to next visible node
 
 	    return true;
-	    // NOTE: AE_MSG IS DESTROYED HERE !!
+	    // NOTE: E_MSG IS DESTROYED HERE !!
 	} else {
-	    ae_msg = msgbuf.uNextVisible(ae_msg);	// advance to next visible node (without deleting)
+	    asyncMsg = msgbuf.nextVisible( asyncMsg );	// advance to next visible node (without deleting)
 	} // if
     } // while
 
@@ -505,7 +542,7 @@ bool uEHM::uPoll() {
     // value, i.e., the first level turns it off
 
     return false;
-} // uEHM::uPoll
+} // uEHM::poll
 
 
 uEHM::uDualClass *uEHM::getCurrentException() {
@@ -520,15 +557,15 @@ uEHM::uDualClass *uEHM::getCurrentException() {
 } // uEHM::getCurrentException
 
 uEHM::uDualClass *uEHM::getCurrentResumption() {
-    return uThisCoroutine().ResumedObj;			// optimization
+    return uThisCoroutine().resumedObj;			// optimization
 } // uEHM::getCurrentResumption
 
 const std::type_info * uEHM::getTopResumptionType() {
-    return uThisCoroutine().TopResumedType;
+    return uThisCoroutine().topResumedType;
 } // uEHM::getCurrentResumptionType()
 
 
-char *uEHM::getCurrentEventName( uFlagT f, char *s1, size_t n ) {
+char *uEHM::getCurrentEventName( raiseKind f, char *s1, size_t n ) {
     const std::type_info *t;
 
     if ( f == uResumeF ) {
@@ -540,7 +577,7 @@ char *uEHM::getCurrentEventName( uFlagT f, char *s1, size_t n ) {
     if ( t != NULL ) {
 	int status;
 	char *s2 = __cxxabiv1::__cxa_demangle( t->name(), 0, 0, &status );
-	uStrncpy( s1, s2, n );
+	strncpy( s1, s2 ? s2 : "*unknown*", n );	// TEMPORARY: older g++ may generate a NULL name for elementary types
 	free( s2 );
     } else {
 	s1[0] = '\0';
@@ -549,34 +586,34 @@ char *uEHM::getCurrentEventName( uFlagT f, char *s1, size_t n ) {
 } // uEHM::getCurrentExceptionName
 
 
-char *uEHM::uStrncpy( char *s1, const char *s2, size_t n ) {
-    strncpy( s1, s2, n );
+char *uEHM::strncpy( char *s1, const char *s2, size_t n ) {
+    ::strncpy( s1, s2, n );
     if ( strlen( s2 ) > n ) {				// name too long ?
 	strcpy( &s1[n], "..." );			// add 4 character ...
     } // if
     return s1;
-} // uEHM::uStrncpy
+} // uEHM::strncpy
 
 
-bool uEHM::uMatch_exception_type( const std::type_info *derived_type, const std::type_info *parent_type ) {
+bool uEHM::match_exception_type( const std::type_info *derived_type, const std::type_info *parent_type ) {
     // return true if derived_type event is derived from parent_type event
     void *dummy;
 #ifdef __DEBUG__
     if ( ! parent_type ) uAbort( "internal error, error in setting up guarded region." );
 #endif // __DEBUG__
     return parent_type->__do_catch( derived_type, &dummy, 0 );
-} // uEHM::uMatch_exception_type
+} // uEHM::match_exception_type
 
 
 bool uEHM::deliverable_exception( const std::type_info *event_type ) {
-    for ( uDeliverAEStack *tmp = uThisCoroutine().uDAEStack; tmp; tmp = tmp->next ) {
+    for ( uDeliverEStack *tmp = uThisCoroutine().DEStack; tmp; tmp = tmp->next ) {
 	if ( tmp->table_size == 0 ) {			// table_size == 0 is a short hand for all exceptions
-	    return tmp->uDeliverFlag;
+	    return tmp->deliverFlag;
 	} // if
 
 	for ( int i = 0; i < tmp->table_size; i += 1 ) {
-	    if ( uMatch_exception_type( event_type, tmp->event_table[i] ) ) {
-		return tmp->uDeliverFlag;
+	    if ( match_exception_type( event_type, tmp->event_table[i] ) ) {
+		return tmp->deliverFlag;
 	    } // if
 	} // for
     } // for
@@ -590,39 +627,39 @@ bool uEHM::deliverable_exception( const std::type_info *event_type ) {
 // the stack. If conseq == true, it means a consequential resumption is being
 // handled, but in order to avoid recursive handling, should not consider
 // earlier resumption handlers. In this case, the virtual top
-// (uHandlerStackVisualTop) of the handler stack is used.
+// (handlerStackVisualTop) of the handler stack is used.
 
-void uEHM::uResumeWorkHorse( const uDualClass &ex, const bool conseq ) {
+void uEHM::resumeWorkHorse( const uDualClass &ex, const bool conseq ) {
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "uEHM::uResumeWorkHorse( ex:0x%p, conseq:%d ) from task %.256s (0x%p)\n",
+    uDebugPrt( "uEHM::resumeWorkHorse( ex:0x%p, conseq:%d ) from task %.256s (0x%p)\n",
 	       &ex, conseq, uThisTask().getName(), &uThisTask() );
 #endif // __U_DEBUG_H__
 
-    const std::type_info *raisedtype = ex.uGetEventType();
-    uResumptionHandlers *tmp = (conseq) ? uThisCoroutine().uHandlerStackVisualTop : uThisCoroutine().uHandlerStackTop;
+    const std::type_info *raisedtype = ex.getEventType();
+    uResumptionHandlers *tmp = (conseq) ? uThisCoroutine().handlerStackVisualTop : uThisCoroutine().handlerStackTop;
 
     while ( tmp ) {
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "uEHM::uResumeWorkHorse tmp:0x%p, raisedtype:0x%p\n", tmp, raisedtype );
+	uDebugPrt( "uEHM::resumeWorkHorse tmp:0x%p, raisedtype:0x%p\n", tmp, raisedtype );
 #endif // __U_DEBUG_H__
 
-	uResumptionHandlers *next = (conseq) ? tmp->uConseqNext : tmp->uNext;
+	uResumptionHandlers *next = (conseq) ? tmp->conseqNext : tmp->next;
 
 	// search all resumption handlers in the same handler clause
 	for ( unsigned int i = 0; i < tmp->size; i += 1 ) {
 	    uHandlerBase *elem = tmp->table[i];		// optimization
 	    const void *bound = ex.getOriginalThrower();
 #ifdef __U_DEBUG_H__
-	    uDebugPrt( "uEHM::uResumeWorkHorse table[%d]:0x%p, originalThrower:0x%p, EventType:0x%p, bound:0x%p\n",
-		       i, elem, elem->originalThrower, elem->EventType, bound );
+	    uDebugPrt( "uEHM::resumeWorkHorse table[%d]:0x%p, originalThrower:0x%p, EventType:0x%p, bound:0x%p\n",
+		       i, elem, elem->getOriginalThrower(), elem->EventType, bound );
 #endif // __U_DEBUG_H__
 	    // if (no binding OR binding match) AND (type match OR resume_any) => handler found
-	    if ( ( elem->originalThrower == 0 || bound == elem->originalThrower ) &&
-		 ( elem->EventType == 0 || uMatch_exception_type( raisedtype, elem->EventType ) ) ) {
+	    if ( ( elem->getMatchBinding() == NULL || bound == elem->getMatchBinding() ) &&
+		 ( elem->getEventType() == NULL || match_exception_type( raisedtype, elem->getEventType() ) ) ) {
 #ifdef __U_DEBUG_H__
-		uDebugPrt( "uEHM::uResumeWorkHorse match\n" );
+		uDebugPrt( "uEHM::resumeWorkHorse match\n" );
 #endif // __U_DEBUG_H__
-		uResumeWorkHorseInit newStackVisualTop( next, (uDualClass &)ex );
+		ResumeWorkHorseInit newStackVisualTop( next, (uDualClass &)ex );
 		elem->uHandler( (uDualClass &)ex );
 		return;					// return after handling the exception
 	    } // if
@@ -631,9 +668,9 @@ void uEHM::uResumeWorkHorse( const uDualClass &ex, const bool conseq ) {
     } // while
 
     // cannot find a handler, use the default handler
-    uResumeWorkHorseInit newStackVisualTop( NULL, (uDualClass &)ex ); // record the current resumption
+    ResumeWorkHorseInit newStackVisualTop( NULL, (uDualClass &)ex ); // record the current resumption
     ex.defaultResume();					// default handler can change the exception
-} // uEHM::uResumeWorkHorse
+} // uEHM::resumeWorkHorse
 
 
 // Local Variables: //
