@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uHeapLmmm.cc -- Lean Mean Malloc Machine - a runtime configurable replacement
 //                 for malloc.
@@ -8,8 +8,8 @@
 // Author           : Peter A. Buhr
 // Created On       : Sat Nov 11 16:07:20 1988
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Jun 27 19:19:49 2005
-// Update Count     : 684
+// Last Modified On : Sat Jul 15 19:38:35 2006
+// Update Count     : 704
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -47,9 +47,9 @@ static bool uHeapBoot = false;				// detect recursion during boot
 #endif // __U_DEBUG__
 static char uHeapStorage[sizeof(uHeapManager)] __attribute__(( aligned (16) )) = {0};
 
-uHeapManager *uHeapManager::uHeapManagerInstance = NULL;
-ptrdiff_t uHeapManager::PreAlloc = 0;
-bool uHeapManager::uTraceAlloc = false;
+uHeapManager *uHeapManager::heapManagerInstance = NULL;
+ptrdiff_t uHeapManager::preAlloc = 0;
+bool uHeapManager::traceAlloc = false;
 
 
 static const unsigned char msbpostab[256] = {
@@ -81,43 +81,43 @@ static size_t ceillog2( size_t i ) {
 
 
 bool uTraceHeapOn() {
-    bool temp = uHeapManager::uTraceAlloc;
-    uHeapManager::uTraceAlloc = true;
+    bool temp = uHeapManager::traceAlloc;
+    uHeapManager::traceAlloc = true;
     return temp;
 } // uTraceHeapOn
 
 
 bool uTraceHeapOff() {
-    bool temp = uHeapManager::uTraceAlloc;
-    uHeapManager::uTraceAlloc = false;
+    bool temp = uHeapManager::traceAlloc;
+    uHeapManager::traceAlloc = false;
     return temp;
 } // uTraceHeapOff
 
 
-void uHeapManager::uNoMemory() {
+void uHeapManager::noMemory() {
     uAbort( "Heap memory exhausted at %lu bytes.\n"
 	    "Possible cause is very large memory allocation and/or large amount of unfreed storage allocated by the program or system/library routines.",
-	     (unsigned long int)((char *)(sbrk( 0 )) - (char *)(uHeapManager::uHeapManagerInstance->uHeapBegin)) );
-} // uHeapManager::uNoMemory
+	     (unsigned long int)((char *)(sbrk( 0 )) - (char *)(uHeapManager::heapManagerInstance->heapBegin)) );
+} // uHeapManager::noMemory
 
 
-inline void uHeapManager::uHeaders( char *name, void *addr, uStorage *&block, uFreeHeader *&freeElem, size_t &alignment ) {
+inline void uHeapManager::headers( char *name, void *addr, uStorage *&block, uFreeHeader *&freeElem, size_t &alignment ) {
 #ifdef __U_DEBUG__
-    if ( addr < uHeapBegin || uHeapEnd <= addr ) {
+    if ( addr < heapBegin || heapEnd <= addr ) {
 	uAbort( "Attempt to %s storage 0x%p outside the current heap range:0x%p to 0x%p.\n"
 		"Possible cause is invalid pointer.",
-		name, addr, uHeapBegin, uHeapEnd );
+		name, addr, heapBegin, heapEnd );
     } // if
 #endif // __U_DEBUG__
 
     block = (uStorage *)( (char *)addr - sizeof(uStorage::uHeader) );
-    freeElem = block->uHdr.uVar.home;
+    freeElem = block->header.kind.home;
     // see memalign for explanation
-    if ( uHeapBegin <= freeElem && freeElem < uHeapEnd ) { // free header within the heap ?
+    if ( heapBegin <= freeElem && freeElem < heapEnd ) { // free header within the heap ?
 	block = (uStorage *)freeElem;
 	// SKULLDUGGERY: see memalign
-	alignment = (size_t)block->uHdr.uProfileMallocEntry;
-	freeElem = block->uHdr.uVar.home;
+	alignment = (size_t)block->header.profileMallocEntry;
+	freeElem = block->header.kind.home;
     } // if
 
 #ifdef __U_DEBUG__
@@ -127,16 +127,16 @@ inline void uHeapManager::uHeaders( char *name, void *addr, uStorage *&block, uF
 		name, addr );
     } // if
 #endif // __U_DEBUG__
-} // uHeapManager::uHeaders
+} // uHeapManager::headers
 
 
-void *uHeapManager::uExtend( size_t size ) {
+void *uHeapManager::extend( size_t size ) {
     extlock.acquire();
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uHeap &)0x%p.uExtend( %u ), uHeapBegin:0x%p, uHeapEnd:0x%p, uHeapRemaining:0x%x, sbrk:0x%p\n",
-               this, size, uHeapBegin, uHeapEnd, uHeapRemaining, sbrk(0) );
+    uDebugPrt( "(uHeap &)0x%p.extend( %u ), heapBegin:0x%p, heapEnd:0x%p, heapRemaining:0x%x, sbrk:0x%p\n",
+               this, size, heapBegin, heapEnd, heapRemaining, sbrk(0) );
 #endif // __U_DEBUG_H__
-    ptrdiff_t rem = uHeapRemaining - size;
+    ptrdiff_t rem = heapRemaining - size;
     if ( rem < 0 ) {
 	// If the size requested is bigger than the current remaining storage,
 	// increase the size of the heap.
@@ -145,34 +145,34 @@ void *uHeapManager::uExtend( size_t size ) {
 	size_t uAmount = uCeiling( size > uDefault ? size : uDefault, uAlign() );
 	if ( sbrk( uAmount ) == (void *)-1 ) {
 #ifdef __U_DEBUG_H__
-	    uDebugPrt( "0x%x = (uHeap &)0x%p.uExtend( %u ), uHeapBegin:0x%p, uHeapEnd:0x%p, uHeapRemaining:0x%x, sbrk:0x%p\n",
-		       NULL, this, size, uHeapBegin, uHeapEnd, uHeapRemaining, sbrk(0) );
+	    uDebugPrt( "0x%x = (uHeap &)0x%p.extend( %u ), heapBegin:0x%p, heapEnd:0x%p, heapRemaining:0x%x, sbrk:0x%p\n",
+		       NULL, this, size, heapBegin, heapEnd, heapRemaining, sbrk(0) );
 #endif // __U_DEBUG_H__
 	    extlock.release();
 	    return NULL;
 	} // if
 #ifdef __U_DEBUG__
 	// Set new memory to garbage so subsequent uninitialized usages might fail.
-	memset( (char *)uHeapEnd + uHeapRemaining, '\377', uAmount );
+	memset( (char *)heapEnd + heapRemaining, '\377', uAmount );
 #endif // __U_DEBUG__
-	rem = uHeapRemaining + uAmount - size;
+	rem = heapRemaining + uAmount - size;
     } // if
 
-    uStorage *block = (uStorage *)uHeapEnd;
-    uHeapRemaining = rem;
-    uHeapEnd = (char *)uHeapEnd + size;
+    uStorage *block = (uStorage *)heapEnd;
+    heapRemaining = rem;
+    heapEnd = (char *)heapEnd + size;
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "0x%p = (uHeap &)0x%p.uExtend( %u ), uHeapBegin:0x%p, uHeapEnd:0x%p, uHeapRemaining:0x%x, sbrk:0x%p\n",
-               block, this, size, uHeapBegin, uHeapEnd, uHeapRemaining, sbrk(0) );
+    uDebugPrt( "0x%p = (uHeap &)0x%p.extend( %u ), heapBegin:0x%p, heapEnd:0x%p, heapRemaining:0x%x, sbrk:0x%p\n",
+               block, this, size, heapBegin, heapEnd, heapRemaining, sbrk(0) );
 #endif // __U_DEBUG_H__
     extlock.release();
     return block;
-} // uHeapManager::uExtend
+} // uHeapManager::extend
 
 
-void *uHeapManager::uDoMalloc( size_t size ) {
+void *uHeapManager::doMalloc( size_t size ) {
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uHeap &)0x%p.uDoMalloc( %u )\n", this, size );
+    uDebugPrt( "(uHeap &)0x%p.doMalloc( %u )\n", this, size );
 #endif // __U_DEBUG_H__
 
     uStorage *block;
@@ -186,7 +186,7 @@ void *uHeapManager::uDoMalloc( size_t size ) {
     size_t tsize = freeElem.blockSize;			// total space needed for request
 
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uHeap &)0x%p.uDoMalloc, size after lookup:%u\n", this, tsize );
+    uDebugPrt( "(uHeap &)0x%p.doMalloc, size after lookup:%u\n", this, tsize );
 #endif // __U_DEBUG_H__
     
     // Spin until the lock is acquired for this particular size of block.
@@ -194,7 +194,7 @@ void *uHeapManager::uDoMalloc( size_t size ) {
     freeElem.lock.acquire();
     if ( freeElem.freeList != NULL ) {
 	block = freeElem.freeList;
-	freeElem.freeList = block->uHdr.uVar.next;
+	freeElem.freeList = block->header.kind.next;
 	freeElem.lock.release();
     } else {
 	freeElem.lock.release();
@@ -202,49 +202,49 @@ void *uHeapManager::uDoMalloc( size_t size ) {
 	// Freelist for that size was empty, so carve it out of the heap if
 	// there's enough left, or get some more and then carve it off.
 
-	block = (uStorage *)uExtend( tsize );		// mutual exclusion on call
+	block = (uStorage *)extend( tsize );		// mutual exclusion on call
 	if ( block == NULL ) return NULL;
     } // if
 
-    block->uHdr.uVar.home = &freeElem;			// pointer back to free list of apropriate size
-    block->uHdr.uProfileMallocEntry = NULL;		// profiler
+    block->header.kind.home = &freeElem;		// pointer back to free list of apropriate size
+    block->header.profileMallocEntry = NULL;		// profiler
     void *area = &(block->uData);			// adjust off header to user bytes
 #ifdef __U_DEBUG__
-    if ( uTraceAlloc ) {
+    if ( traceAlloc ) {
 	uDebugPrt( "0x%p = Malloc( %u ) (allocated %u)\n", area, size, tsize );
-	uThisTask().uPrintCallStack();
+	uThisTask().printCallStack();
     } // if
 #endif // __U_DEBUG__
 
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "0x%p = (uHeap &)0x%p.uDoMalloc\n", area, this );
+    uDebugPrt( "0x%p = (uHeap &)0x%p.doMalloc\n", area, this );
 #endif // __U_DEBUG_H__
     return area;
-} // uHeapManager::uDoMalloc
+} // uHeapManager::doMalloc
 
 
-void uHeapManager::uDoFree( void *addr ) {
+void uHeapManager::doFree( void *addr ) {
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uHeap &)0x%p.uDoFree( 0x%p )\n", this, addr );
+    uDebugPrt( "(uHeap &)0x%p.doFree( 0x%p )\n", this, addr );
 #endif // __U_DEBUG_H__
 
   if ( addr == NULL ) {
-      if ( uThisTask().uProfileActive && uProfiler::uProfiler_RegisterMemoryDeallocate ) {
-	  (*uProfiler::uProfiler_RegisterMemoryDeallocate)( uProfiler::uProfilerInstance, addr, 0, 0 ); 
+      if ( uThisTask().profileActive && uProfiler::uProfiler_registerMemoryDeallocate ) {
+	  (*uProfiler::uProfiler_registerMemoryDeallocate)( uProfiler::profilerInstance, addr, 0, 0 ); 
       } // if
 
 #ifdef __U_DEBUG__
-      if ( uTraceAlloc ) {
+      if ( traceAlloc ) {
 	  uDebugPrt( "Free( 0x%p ) size:0\n", addr );
-	  uThisTask().uPrintCallStack();
+	  uThisTask().printCallStack();
       } // if
 #endif // __U_DEBUG__
       return;
     } // exit
 
 #ifdef __U_DEBUG__
-    if ( uHeapManager::uHeapManagerInstance == NULL ) {
-	fprintf( stderr, "uDoFree( 0x%p ) called before heap is initialized.\n", addr );
+    if ( uHeapManager::heapManagerInstance == NULL ) {
+	fprintf( stderr, "doFree( 0x%p ) called before heap is initialized.\n", addr );
 	_exit( -1 );
     } // if
 #endif // __U_DEBUG__
@@ -252,16 +252,16 @@ void uHeapManager::uDoFree( void *addr ) {
     uStorage *block;
     uFreeHeader *freeElem;
     size_t alignment;					// not used (see realloc)
-    uHeaders( "free", addr, block, freeElem, alignment );
+    headers( "free", addr, block, freeElem, alignment );
 
-    if ( uThisTask().uProfileActive && uProfiler::uProfiler_RegisterMemoryDeallocate ) {
-	(*uProfiler::uProfiler_RegisterMemoryDeallocate)( uProfiler::uProfilerInstance, addr, freeElem->blockSize, block->uHdr.uProfileMallocEntry ); 
+    if ( uThisTask().profileActive && uProfiler::uProfiler_registerMemoryDeallocate ) {
+	(*uProfiler::uProfiler_registerMemoryDeallocate)( uProfiler::profilerInstance, addr, freeElem->blockSize, block->header.profileMallocEntry ); 
     } // if
 
 #ifdef __U_DEBUG__
-    if ( uTraceAlloc ) {
+    if ( traceAlloc ) {
 	uDebugPrt( "Free( 0x%p ) size:%u\n", addr, freeElem->blockSize );
-	uThisTask().uPrintCallStack();
+	uThisTask().printCallStack();
     } // if
 #endif // __U_DEBUG__
 
@@ -271,30 +271,30 @@ void uHeapManager::uDoFree( void *addr ) {
 #endif // __U_DEBUG__
 
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uHeap &)0x%p.uDoFree( 0x%p ) block:0x%p freeElem:0x%p\n", this, addr, &block, &freeElem );
+    uDebugPrt( "(uHeap &)0x%p.doFree( 0x%p ) block:0x%p freeElem:0x%p\n", this, addr, &block, &freeElem );
 #endif // __U_DEBUG_H__
 
     freeElem->lock.acquire();				// acquire spin lock
-    block->uHdr.uVar.next = freeElem->freeList;		// remove node from chain
+    block->header.kind.next = freeElem->freeList;	// remove node from chain
     freeElem->freeList = block;
     freeElem->lock.release();				// release spin lock
 
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uHeap &)0x%p.uDoFree( 0x%p ) returning free block in list 0x%x\n", this, addr, freeElem->blockSize );
+    uDebugPrt( "(uHeap &)0x%p.doFree( 0x%p ) returning free block in list 0x%x\n", this, addr, freeElem->blockSize );
 #endif // __U_DEBUG_H__
-} // uHeapManager::uDoFree
+} // uHeapManager::doFree
 
 
-size_t uHeapManager::uCheckFree() {
+size_t uHeapManager::checkFree() {
     size_t total = 0;
     for ( int i = 0; i < 32; i += 1 ) {
 	size_t size = freeLists[i].blockSize;
-	for ( uStorage *p = freeLists[i].freeList; p; p = p->uHdr.uVar.next ) {
+	for ( uStorage *p = freeLists[i].freeList; p; p = p->header.kind.next ) {
 	    total += size;
 	} // for
     } // for
-    return (char *)uHeapEnd - (char *)uHeapBegin - total;
-} // uHeapManager::uCheckFree
+    return (char *)heapEnd - (char *)heapBegin - total;
+} // uHeapManager::checkFree
 
 
 uHeapManager::uHeapManager() {
@@ -308,19 +308,19 @@ uHeapManager::uHeapManager() {
 
     char *end = (char *)sbrk( 0 );
     sbrk( (char *)uCeiling( (long unsigned int)end, uAlign() ) - end ); // move start of heap to multiple of alignment
-    uHeapBegin = uHeapEnd = sbrk( 0 );			// get new start point
+    heapBegin = heapEnd = sbrk( 0 );			// get new start point
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uHeap &)0x%p.uHeap() uHeapBegin:0x%p, uHeapEnd:0x%p\n", this, uHeapBegin, uHeapEnd );
+    uDebugPrt( "(uHeap &)0x%p.uHeap() heapBegin:0x%p, heapEnd:0x%p\n", this, heapBegin, heapEnd );
 #endif // __U_DEBUG_H__
-    uHeapRemaining = 0;					// don't pre-allocate storage that might not get used
+    heapRemaining = 0;					// don't pre-allocate storage that might not get used
 
-    std::set_new_handler( uNoMemory );			// don't throw exception as the default
+    std::set_new_handler( noMemory );			// don't throw exception as the default
 } // uHeapManager::uHeapManager
 
 
 uHeapManager::~uHeapManager() {
 #ifdef __U_DEBUG__
-    size_t underby = uCheckFree() - uHeapManager::PreAlloc;
+    size_t underby = checkFree() - uHeapManager::preAlloc;
     if ( underby != 0 ) {
 	// DO NOT USE STREAMS AS THEY MAY BE UNAVAILABLE AT THIS POINT.
 	fprintf( stderr, "uC++ Runtime warning (UNIX pid:%ld) : program terminating with %ld(0x%lx) bytes of storage allocated but not freed.\n"
@@ -332,7 +332,7 @@ uHeapManager::~uHeapManager() {
 
 
 void uHeapManager::boot() {
-    if ( ! uKernelModule::uKernelModuleInitialized ) {
+    if ( ! uKernelModule::kernelModuleInitialized ) {
 	uKernelModule::startup();
     } // if
 #ifdef __U_DEBUG__
@@ -347,9 +347,9 @@ void uHeapManager::boot() {
     // SKULLDUGGERY: This ensures that calls to uThisCoroutine work before the
     // kernel is initialized.
 
-    ((uBaseTask *)&uKernelModule::uTaskBootStorage)->currCoroutine = (uBaseTask *)&uKernelModule::uTaskBootStorage;
-    ((uBaseTask *)&uKernelModule::uTaskBootStorage)->uInheritTask = (uBaseTask *)&uKernelModule::uTaskBootStorage;
-    uHeapManager::uHeapManagerInstance = new((void *)&uHeapStorage) uHeapManager;
+    ((uBaseTask *)&uKernelModule::bootTaskStorage)->currCoroutine = (uBaseTask *)&uKernelModule::bootTaskStorage;
+    ((uBaseTask *)&uKernelModule::bootTaskStorage)->inheritTask = (uBaseTask *)&uKernelModule::bootTaskStorage;
+    uHeapManager::heapManagerInstance = new((void *)&uHeapStorage) uHeapManager;
 } // uHeapManager::boot
 
 
@@ -368,15 +368,15 @@ void *uHeapManager::operator new( size_t size ) {
 
 extern "C" {
 void *malloc( size_t size ) __THROW {
-    if ( uHeapManager::uHeapManagerInstance == NULL ) {
+    if ( uHeapManager::heapManagerInstance == NULL ) {
 	uHeapManager::boot();
     } // if
 
-    void *area = uHeapManager::uHeapManagerInstance->uDoMalloc( size );
+    void *area = uHeapManager::heapManagerInstance->doMalloc( size );
 
-    if ( uThisTask().uProfileActive && uProfiler::uProfiler_RegisterMemoryAllocate ) {
+    if ( uThisTask().profileActive && uProfiler::uProfiler_registerMemoryAllocate ) {
 	uHeapManager::uStorage *block = (uHeapManager::uStorage *)( (char *)area - sizeof(uHeapManager::uStorage::uHeader) );
-	block->uHdr.uProfileMallocEntry = (*uProfiler::uProfiler_RegisterMemoryAllocate)( uProfiler::uProfilerInstance, area, size, block->uHdr.uVar.home->blockSize );
+	block->header.profileMallocEntry = (*uProfiler::uProfiler_registerMemoryAllocate)( uProfiler::profilerInstance, area, size, block->header.kind.home->blockSize );
     } // if
 #ifdef __U_DEBUG_H__
     uDebugPrt( "0x%p = malloc( %u )\n", area, size );
@@ -397,7 +397,7 @@ void *calloc( size_t noOfElems, size_t elemSize ) __THROW {
 
 
 void *realloc( void *addr, size_t size ) __THROW {
-    if ( uHeapManager::uHeapManagerInstance == NULL ) {
+    if ( uHeapManager::heapManagerInstance == NULL ) {
 	uHeapManager::boot();
     } // if
 
@@ -410,7 +410,7 @@ void *realloc( void *addr, size_t size ) __THROW {
     uHeapManager::uStorage *block;
     uHeapManager::uFreeHeader *freeElem;
     size_t alignment = 0;
-    uHeapManager::uHeapManagerInstance->uHeaders( "realloc", addr, block, freeElem, alignment );
+    uHeapManager::heapManagerInstance->headers( "realloc", addr, block, freeElem, alignment );
 
     // Subtract off storage before user location (handles memalign)
     size_t s = (char *)block + freeElem->blockSize - (char *)addr;
@@ -438,7 +438,7 @@ void *realloc( void *addr, size_t size ) __THROW {
 
 
 void *memalign( size_t alignment, size_t size ) __THROW {
-    if ( uHeapManager::uHeapManagerInstance == NULL ) {
+    if ( uHeapManager::heapManagerInstance == NULL ) {
 	uHeapManager::boot();
     } // if
 
@@ -464,7 +464,7 @@ void *memalign( size_t alignment, size_t size ) __THROW {
     // boundary, and sufficient space after it for the storage size. This
     // happens automatically because the request is rounded up to the next
     // power of 2.
-    char *area = (char *)uHeapManager::uHeapManagerInstance->uDoMalloc( size + alignment );
+    char *area = (char *)uHeapManager::heapManagerInstance->doMalloc( size + alignment );
   if ( area == NULL ) return NULL;
     // Calculate address in the block of the "next" alignment address. Adding 1
     // ensures the user area does not start at "area" if it happens to be a
@@ -479,12 +479,12 @@ void *memalign( size_t alignment, size_t size ) __THROW {
     // SKULLDUGGERY: Store alignment value as it is needed in realloc.  This
     // field is not used by the profiler; the profiler uses the field in the
     // fake header.
-    block->uHdr.uProfileMallocEntry = (uMemoryInfoEntry *)alignment;
-    fake->uHdr.uVar.home = (uHeapManager::uFreeHeader *)block;
+    block->header.profileMallocEntry = (MMInfoEntry *)alignment;
+    fake->header.kind.home = (uHeapManager::uFreeHeader *)block;
 
-    if ( uThisTask().uProfileActive && uProfiler::uProfiler_RegisterMemoryAllocate ) {
+    if ( uThisTask().profileActive && uProfiler::uProfiler_registerMemoryAllocate ) {
 	uHeapManager::uStorage *block = (uHeapManager::uStorage *)( (char *)area - sizeof(uHeapManager::uStorage::uHeader) );
-	block->uHdr.uProfileMallocEntry = (*uProfiler::uProfiler_RegisterMemoryAllocate)( uProfiler::uProfilerInstance, area, size, block->uHdr.uVar.home->blockSize );
+	block->header.profileMallocEntry = (*uProfiler::uProfiler_registerMemoryAllocate)( uProfiler::profilerInstance, area, size, block->header.kind.home->blockSize );
     } // if
 #ifdef __U_DEBUG_H__
     uDebugPrt( "0x%p = memalign( %u, %u )\n", user, alignment, size );
@@ -499,7 +499,7 @@ void *valloc( size_t size ) __THROW {
 
 
 void free( void *addr ) __THROW {
-    uHeapManager::uHeapManagerInstance->uDoFree( addr );
+    uHeapManager::heapManagerInstance->doFree( addr );
 #ifdef __U_DEBUG_H__
     uDebugPrt( "free( 0x%p )\n", addr );
 #endif // __U_DEBUG_H__
