@@ -1,25 +1,23 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Richard Bilson and Ashif Harji 2003
+// uC++ Version 5.4.0, Copyright (C) Richard Bilson and Ashif Harji 2003
 // 
 // uKernelThreads.h -- 
 // 
 // Author           : Richard Bilson and Ashif Harji
 // Created On       : Wed Jul 16 16:44:10 2003
-// Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Jun 22 12:10:22 2005
-// Update Count     : 24
+// Last Modified By : Richard C. Bilson
+// Last Modified On : Wed Aug 23 15:08:21 2006
+// Update Count     : 27
 // 
 
 /* Most of this code is borrowed from the gnu glibc library machine dependent
    pthread functions.  This code has been modified from the original source
    around May 2003.  <include GPL> */
 
-struct uKernelModule;					// forward declaration
-
 #if defined(__U_MULTI__)
 
-#if defined( __linux__ )
+#if defined( __linux__ ) || defined( __freebsd__ )
 
 #if defined( __i386__ )
 #include <cstddef>					// size_t
@@ -32,7 +30,7 @@ extern int __modify_ldt (int, struct modify_ldt_ldt_s *, size_t);
 /* Read member of the thread descriptor directly.  */
 #define THREAD_GETMEM(member) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value;				\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value;		\
   /* There should not be any value with a size other than 1, 4 or 8.  */	\
   _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
 		   sizeof(__value) == 8 );					\
@@ -40,20 +38,20 @@ extern int __modify_ldt (int, struct modify_ldt_ldt_s *, size_t);
     __asm__ __volatile__ ("movb %%gs:_ZN13uKernelModule17uKernelModuleBootE@ntpoff+%P2,%b0" \
 			  : "=q" (__value)					\
 			  : "0" (0),						\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 4)						\
     __asm__ __volatile__ ("movl %%gs:_ZN13uKernelModule17uKernelModuleBootE@ntpoff+%P1,%0" \
 			  : "=r" (__value)					\
-			  : "i" (offsetof (struct uKernelModule,		\
+			  : "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 8)						\
     __asm__ __volatile__ ("movl %%gs:_ZN13uKernelModule17uKernelModuleBootE@ntpoff+%P1,%%eax\n\t" \
 			  "movl %%gs:_ZN13uKernelModule17uKernelModuleBootE@ntpoff+%P2,%%edx" \
 			  : "=A" (__value)					\
-			  : "i" (offsetof (struct uKernelModule,		\
+			  : "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)),				\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member) + 4));			\
   __value;									\
 })
@@ -61,27 +59,27 @@ extern int __modify_ldt (int, struct modify_ldt_ldt_s *, size_t);
 /* Set member of the thread descriptor directly.  */
 #define THREAD_SETMEM(member, value) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value = (value);			\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value = (value); \
   /* There should not be any value with a size other than 1, 4 or 8.  */	\
   _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
 		   sizeof(__value) == 8 );					\
   if (sizeof(__value) == 1)							\
     __asm__ __volatile__ ("movb %0,%%gs:_ZN13uKernelModule17uKernelModuleBootE@ntpoff+%P1" : \
 			  : "q" (__value),					\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 4)						\
     __asm__ __volatile__ ("movl %0,%%gs:_ZN13uKernelModule17uKernelModuleBootE@ntpoff+%P1" : \
 			  : "r" (__value),					\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 8)						\
     __asm__ __volatile__ ("movl %%eax,%%gs:_ZN13uKernelModule17uKernelModuleBootE@ntpoff+%P1\n\n" \
 			  "movl %%edx,%%gs:_ZN13uKernelModule17uKernelModuleBootE@ntpoff+%P2" : \
 			  : "A" (__value),					\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)),				\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member) + 4));			\
 })
 
@@ -90,7 +88,7 @@ extern int __modify_ldt (int, struct modify_ldt_ldt_s *, size_t);
 /* Read member of the thread descriptor directly.  */
 #define THREAD_GETMEM(member) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value;				\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value;		\
   /* There should not be any value with a size other than 1, 4 or 8.  */	\
   _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
 		   sizeof(__value) == 8 );					\
@@ -98,20 +96,20 @@ extern int __modify_ldt (int, struct modify_ldt_ldt_s *, size_t);
     __asm__ __volatile__ ("movb %%gs:%P2,%b0"					\
 			  : "=q" (__value)					\
 			  : "0" (0),						\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 4)						\
     __asm__ __volatile__ ("movl %%gs:%P1,%0"					\
 			  : "=r" (__value)					\
-			  : "i" (offsetof (struct uKernelModule,		\
+			  : "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 8)						\
     __asm__ __volatile__ ("movl %%gs:%P1,%%eax\n\t"				\
 			  "movl %%gs:%P2,%%edx"					\
 			  : "=A" (__value)					\
-			  : "i" (offsetof (struct uKernelModule,		\
+			  : "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)),				\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member) + 4));			\
   __value;									\
 })
@@ -119,27 +117,27 @@ extern int __modify_ldt (int, struct modify_ldt_ldt_s *, size_t);
 /* Set member of the thread descriptor directly.  */
 #define THREAD_SETMEM(member, value) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value = (value);			\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value = (value); \
   /* There should not be any value with a size other than 1, 4 or 8.  */	\
   _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
 		   sizeof(__value) == 8 );					\
   if (sizeof(__value) == 1)							\
     __asm__ __volatile__ ("movb %0,%%gs:%P1" :					\
 			  : "q" (__value),					\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 4)						\
     __asm__ __volatile__ ("movl %0,%%gs:%P1" :					\
 			  : "r" (__value),					\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 8)						\
     __asm__ __volatile__ ("movl %%eax,%%gs:%P1\n\n"				\
 			  "movl %%edx,%%gs:%P2" :				\
 			  : "A" (__value),					\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)),				\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member) + 4));			\
 })
 
@@ -150,7 +148,7 @@ extern int __modify_ldt (int, struct modify_ldt_ldt_s *, size_t);
 /* Read member of the thread descriptor directly.  */
 #define THREAD_GETMEM(member) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value;				\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value;		\
   /* There should not be any value with a size other than 1, 4 or 8.  */	\
   _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
 		   sizeof(__value) == 8 );					\
@@ -158,17 +156,17 @@ extern int __modify_ldt (int, struct modify_ldt_ldt_s *, size_t);
     __asm__ __volatile__ ("movb %%fs:_ZN13uKernelModule17uKernelModuleBootE@tpoff+%P2,%b0" \
 			  : "=q" (__value)					\
 			  : "0" (0),						\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 4)						\
     __asm__ __volatile__ ("movl %%fs:_ZN13uKernelModule17uKernelModuleBootE@tpoff+%P1,%0" \
 			  : "=r" (__value)					\
-			  : "i" (offsetof (struct uKernelModule,		\
+			  : "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 8)						\
     __asm__ __volatile__ ("movq %%fs:_ZN13uKernelModule17uKernelModuleBootE@tpoff+%P1,%0" \
 			  : "=r" (__value)					\
-			  : "i" (offsetof (struct uKernelModule,		\
+			  : "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   __value;									\
 })
@@ -176,24 +174,24 @@ extern int __modify_ldt (int, struct modify_ldt_ldt_s *, size_t);
 /* Set member of the thread descriptor directly.  */
 #define THREAD_SETMEM(member, value) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value = (value);			\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value = (value); \
   /* There should not be any value with a size other than 1, 4 or 8.  */	\
   _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
 		   sizeof(__value) == 8 );					\
   if (sizeof(__value) == 1)							\
     __asm__ __volatile__ ("movb %0,%%fs:_ZN13uKernelModule17uKernelModuleBootE@tpoff+%P1" : \
 			  : "q" (__value),					\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 4)						\
     __asm__ __volatile__ ("movl %0,%%fs:_ZN13uKernelModule17uKernelModuleBootE@tpoff+%P1" : \
 			  : "r" (__value),					\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 8)						\
     __asm__ __volatile__ ("movq %0,%%fs:_ZN13uKernelModule17uKernelModuleBootE@tpoff+%P1" : \
 			  : "r" (__value),					\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
 })
 
@@ -210,27 +208,27 @@ extern "C" void thread_setmem_8( size_t off, long value );
 
 #define THREAD_GETMEM( member ) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value;				\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value;		\
   /* There should not be any value with a size other than 1, 4 or 8.  */	\
   if (sizeof(__value) == 1)							\
-    __value = (typeof(__value))thread_getmem_1( offsetof( struct uKernelModule, member ) ); \
+    __value = (typeof(__value))thread_getmem_1( offsetof( uKernelModule::uKernelModuleData, member ) ); \
   else if (sizeof(__value) == 4)							\
-    __value = (typeof(__value))thread_getmem_4( offsetof( struct uKernelModule, member ) ); \
+    __value = (typeof(__value))thread_getmem_4( offsetof( uKernelModule::uKernelModuleData, member ) ); \
   else if (sizeof(__value) == 8)						\
-    __value = (typeof(__value))thread_getmem_8( offsetof( struct uKernelModule, member ) ); \
+    __value = (typeof(__value))thread_getmem_8( offsetof( uKernelModule::uKernelModuleData, member ) ); \
   __value;									\
 })
 
 #define THREAD_SETMEM( member, value ) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value = (value);			\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value = (value); \
   /* There should not be any value with a size other than 1, 4 or 8.  */	\
   if (sizeof(__value) == 1)							\
-    thread_setmem_1( offsetof( struct uKernelModule, member ), (char)(__value) ); \
+    thread_setmem_1( offsetof( uKernelModule::uKernelModuleData, member ), (char)(__value) ); \
   else if (sizeof(__value) == 4)						\
-    thread_setmem_4( offsetof( struct uKernelModule, member ), (int)(__value) ); \
+    thread_setmem_4( offsetof( uKernelModule::uKernelModuleData, member ), (int)(__value) ); \
   else if (sizeof(__value) == 8)						\
-    thread_setmem_8( offsetof( struct uKernelModule, member ), (long)(__value) ); \
+    thread_setmem_8( offsetof( uKernelModule::uKernelModuleData, member ), (long)(__value) ); \
 })
 
 #else // ! __INTEL_COMPILER
@@ -334,13 +332,13 @@ extern "C" void thread_setmem_8( size_t off, long value );
                           ENABLE						\
                           HANDLE						\
 			  : "=r" (__value)			      		\
-			  : "ir" (offsetof (uKernelModule, member) -		\
-				 sizeof (uKernelModule) + 16)			\
+			  : "ir" (offsetof (uKernelModule::uKernelModuleData, member) -	\
+				 sizeof (uKernelModule::uKernelModuleData) + 16) \
 			  : "r14", "r15", "p7", HANDLE_CLOBBERS )
 
 #define THREAD_GETMEM(member) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value;				\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value;		\
   /* There should not be any value with a size other than 1, 4 or 8. */		\
   _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
 		   sizeof(__value) == 8 );					\
@@ -368,7 +366,7 @@ extern "C" void thread_setmem_8( size_t off, long value );
 /* Set member of the thread descriptor directly.  */
 #define THREAD_SETMEM(member, value) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value = (value);			\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value = (value); \
   /* There should not be any value with a size other than 1, 4 or 8. */		\
   _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
 		   sizeof(__value) == 8 );					\
@@ -382,14 +380,14 @@ extern "C" void thread_setmem_8( size_t off, long value );
 
 #else
 /*
-   Magic numbers: 1041 == __NR_getpid (<asm/unistd.h>)
+   Magic numbers: 1105 == __NR_gettid (<asm/unistd.h>)
                   1229 == __NR_tkill (<asm/unistd.h>)
                   10 == SIGUSR1 (<bits/signum.h>)
 */
 
 #define HANDLE \
         "(p7) br.cond.sptk.many 0f;;\n" \
-        "mov r15 = 1041\n"              \
+        "mov r15 = 1105\n"              \
         "break 0x100000;;\n"            \
         "mov r15 = 1229\n"              \
         "mov out0 = r8\n"               \
@@ -401,7 +399,7 @@ extern "C" void thread_setmem_8( size_t off, long value );
 
 #define __LOAD_OFFSET \
         ";;mf\ncmp.eq p7, p0 = r0, r0\n"       \
-        "mov r14 = @tprel(_ZN13uKernelModule17uKernelModuleBootE#)+%1\n"				\
+        "mov r14 = @tprel(_ZN13uKernelModule17uKernelModuleBootE#)+%1\n"	\
 	"fetchadd8.acq r15 = [r13], 1;;\n"
 
 #define __ENABLE \
@@ -414,12 +412,12 @@ extern "C" void thread_setmem_8( size_t off, long value );
                           __ENABLE						\
                           HANDLE						\
 			  : "=r" (__value)			      		\
-			  : "i" (offsetof (uKernelModule, member))		\
+			  : "i" (offsetof (uKernelModule::uKernelModuleData, member)) \
 			  : "r14", "r15", "p7", HANDLE_CLOBBERS )
 
 #define THREAD_GETMEM(member) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value;				\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value;		\
   /* There should not be any value with a size other than 1, 4 or 8. */		\
   _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
 		   sizeof(__value) == 8 );					\
@@ -440,13 +438,13 @@ extern "C" void thread_setmem_8( size_t off, long value );
                           HANDLE						\
 			  :					     		\
 			  : "r" (__value),			        	\
-			    "i" (offsetof (uKernelModule, member))		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData, member)) \
 			  : "r14", "r15", "p7", HANDLE_CLOBBERS )
 
 /* Set member of the thread descriptor directly.  */
 #define THREAD_SETMEM(member, value) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value = (value);			\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value = (value); \
   /* There should not be any value with a size other than 1, 4 or 8. */		\
   _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
 		   sizeof(__value) == 8 );					\
@@ -476,24 +474,24 @@ register unsigned long sparc_tp __asm__( "%g7" );
 /* Read member of the thread descriptor directly.  */
 #define THREAD_GETMEM(member) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value;				\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value;		\
   /* There should not be any value with a size other than 1, 4 or 8.  */	\
   _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
 		   sizeof(__value) == 8 );					\
   if (sizeof(__value) == 1)							\
     __asm__ __volatile__ ("ldub [%%g7+%1], %0"					\
 			  : "=r" (__value)					\
-			  : "i" (offsetof (struct uKernelModule,		\
+			  : "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 4)						\
     __asm__ __volatile__ ("lduw [%%g7+%1], %0"					\
 			  : "=r" (__value)					\
-			  : "i" (offsetof (struct uKernelModule,		\
+			  : "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 8)						\
     __asm__ __volatile__ ("ldx [%%g7+%1], %0"					\
 			  : "=r" (__value)					\
-			  : "i" (offsetof (struct uKernelModule,		\
+			  : "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   __value;									\
 })
@@ -501,24 +499,24 @@ register unsigned long sparc_tp __asm__( "%g7" );
 /* Set member of the thread descriptor directly.  */
 #define THREAD_SETMEM(member, value) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value = (value);			\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value = (value); \
   /* There should not be any value with a size other than 1, 4 or 8.  */	\
   _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
 		   sizeof(__value) == 8 );					\
   if (sizeof(__value) == 1)							\
     __asm__ __volatile__ ("stb %0, [%%g7+%1]" :					\
 			  : "r" (__value),					\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 4)						\
     __asm__ __volatile__ ("stw %0, [%%g7+%1]" :					\
 			  : "r" (__value),					\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
   else if (sizeof(__value) == 8)						\
     __asm__ __volatile__ ("stx %0, [%%g7+%1]" :					\
 			  : "r" (__value),					\
-			    "i" (offsetof (struct uKernelModule,		\
+			    "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member)));				\
 })
 
@@ -526,7 +524,7 @@ register unsigned long sparc_tp __asm__( "%g7" );
 
 #define THREAD_GETMEM(member) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value;				\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value;		\
   /* There should not be any value with a size other than 1, 4 or 8.  */	\
   _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
 		   sizeof(__value) == 8 );					\
@@ -536,7 +534,7 @@ register unsigned long sparc_tp __asm__( "%g7" );
 			  "add %%g1, %1, %%g1\n\t"				\
 			  "ldub [%%g7+%%g1], %0"				\
 			  : "=r" (__value)					\
-			  : "i" (offsetof (struct uKernelModule,		\
+			  : "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member))				\
 			  : "%g1" );						\
   else if (sizeof(__value) == 4)						\
@@ -545,7 +543,7 @@ register unsigned long sparc_tp __asm__( "%g7" );
 			  "add %%g1, %1, %%g1\n\t"				\
 			  "lduw [%%g7+%%g1], %0"				\
 			  : "=r" (__value)					\
-			  : "i" (offsetof (struct uKernelModule,		\
+			  : "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member))				\
 			  : "%g1" );						\
   else if (sizeof(__value) == 8)						\
@@ -554,7 +552,7 @@ register unsigned long sparc_tp __asm__( "%g7" );
 			  "add %%g1, %1, %%g1\n\t"				\
 			  "ldx [%%g7+%%g1], %0"					\
 			  : "=r" (__value)					\
-			  : "i" (offsetof (struct uKernelModule,		\
+			  : "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member))				\
 			  : "%g1" );						\
   __value;									\
@@ -563,7 +561,7 @@ register unsigned long sparc_tp __asm__( "%g7" );
 /* Set member of the thread descriptor directly.  */
 #define THREAD_SETMEM(member, value) \
 ({										\
-  __typeof__ (((uKernelModule *)0)->member) __value = (value);			\
+  __typeof__ (((uKernelModule::uKernelModuleData *)0)->member) __value = (value); \
   /* There should not be any value with a size other than 1, 4 or 8.  */	\
   _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
 		   sizeof(__value) == 8 );					\
@@ -573,7 +571,7 @@ register unsigned long sparc_tp __asm__( "%g7" );
 			  "add %%g1, %1, %%g1\n\t"				\
 			  "stb %0, [%%g7+%%g1]"					\
 			  :: "r" (__value),					\
-			     "i" (offsetof (struct uKernelModule,		\
+			     "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member))				\
 			  : "%g1" );						\
   else if (sizeof(__value) == 4)						\
@@ -582,7 +580,7 @@ register unsigned long sparc_tp __asm__( "%g7" );
 			  "add %%g1, %1, %%g1\n\t"				\
 			  "stw %0, [%%g7+%%g1]"					\
 			  :: "r" (__value),					\
-			     "i" (offsetof (struct uKernelModule,		\
+			     "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member))				\
 			  : "%g1" );						\
   else if (sizeof(__value) == 8)						\
@@ -591,7 +589,7 @@ register unsigned long sparc_tp __asm__( "%g7" );
 			  "add %%g1, %1, %%g1\n\t"				\
 			  "stx %0, [%%g7+%%g1]"					\
 			  :: "r" (__value),					\
-			     "i" (offsetof (struct uKernelModule,		\
+			     "i" (offsetof (uKernelModule::uKernelModuleData,	\
 					   member))				\
 			  : "%g1" );						\
 })
@@ -603,8 +601,8 @@ register unsigned long sparc_tp __asm__( "%g7" );
 #include <sys/types.h>					// types for access to PRDA
 #include <sys/prctl.h>					// access PRDA
 
-#define THREAD_GETMEM(member)  ((volatile uKernelModule *)&(PRDA->usr_prda))->member
-#define THREAD_SETMEM(member, value) ((volatile uKernelModule *)&(PRDA->usr_prda))->member = (value)
+#define THREAD_GETMEM(member)  ((volatile uKernelModule::uKernelModuleData *)&(PRDA->usr_prda))->member
+#define THREAD_SETMEM(member, value) ((volatile uKernelModule::uKernelModuleData *)&(PRDA->usr_prda))->member = (value)
 
 #else
     #error uC++ : internal error, unsupported architecture
