@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uMachContext.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Fri Feb 25 15:46:42 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 10:55:48 2005
-// Update Count     : 517
+// Last Modified On : Sat Sep 23 23:19:38 2006
+// Update Count     : 561
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -53,15 +53,15 @@ extern "C" void uInvokeStub( uMachContext * );
 extern "C" void _pthread_deletespecific( void * );	// see pthread simulation
 
 
-void uMachContext::uInvokeCoroutine( uBaseCoroutine &This ) { // magically invoke the "main" of the most derived class
+void uMachContext::invokeCoroutine( uBaseCoroutine &This ) { // magically invoke the "main" of the most derived class
     // Called from the kernel when starting a coroutine or task so must switch
     // back to user mode.
 
     This.setState( uBaseCoroutine::Active );		// set state of next coroutine to active
-    THREAD_GETMEM( uSelf )->enableInterrupts();
+    THREAD_GETMEM( This )->enableInterrupts();
 
-    if ( uThisTask().uProfileActive && uProfiler::uProfiler_PostallocateMetricMemory ) {
-	(*uProfiler::uProfiler_PostallocateMetricMemory)( uProfiler::uProfilerInstance, uThisTask() );
+    if ( uThisTask().profileActive && uProfiler::uProfiler_postallocateMetricMemory ) {
+	(*uProfiler::uProfiler_postallocateMetricMemory)( uProfiler::profilerInstance, uThisTask() );
     } // if
 
     // At this point, execution is on the stack of the new coroutine or task
@@ -69,39 +69,44 @@ void uMachContext::uInvokeCoroutine( uBaseCoroutine &This ) { // magically invok
     // legitimately occur now.
 
     try {
-	This.uCoStarter();				// moved from uCoroutineMain to allow recursion on "main"
+	This.corStarter();				// moved from uCoroutineMain to allow recursion on "main"
+	uEHM::poll();					// cancellation checkpoint
 	This.main();					// start coroutine's "main" routine
+    } catch ( uBaseCoroutine::UnwindStack &u ) {
+	u.exec_dtor = false;				// defuse the bomb or otherwise unwinding will continue
+	This.notHalted = false;				// terminate coroutine
     } catch( uBaseCoroutine::UnHandledException &ex ) {
 	ex.multiple = true;				// set multiple exceptions
 	_Resume ex _At This.resumer();                    
 	This.notHalted = false;				// terminate coroutine
-	This.suspend();					// restart last resumer, which should immediately propagate the nonlocal exception
     } catch( ... ) {					// unhandled exception ?
 	char msg[uEHMMaxMsg], name[uEHMMaxName + sizeof("...")]; // room for "...\0"
 	strcat( strcpy( msg, "an unhandled exception of type " ), uEHM::getCurrentEventName( uEHM::uThrowF, name, uEHMMaxName ) );
 	_Resume uBaseCoroutine::UnHandledException( msg ) _At This.resumer();
 	This.notHalted = false;				// terminate coroutine
-	This.suspend();					// restart last resumer, which should immediately propagate the nonlocal exception
     } // try
-    This.uCoFinish();
-} // uMachContext::uInvokeCoroutine
+    if ( ! This.notHalted ) {				// exceptional ending ? check outside handler so exception is freed before suspending
+	This.suspend();					// restart last resumer, which should immediately propagate the nonlocal exception
+    } // if
+    This.corFinish();
+} // uMachContext::invokeCoroutine
 
 
-void uMachContext::uInvokeTask( uBaseTask &This ) {	// magically invoke the "main" of the most derived class
+void uMachContext::invokeTask( uBaseTask &This ) {	// magically invoke the "main" of the most derived class
     // Called from the kernel when starting a coroutine or task so must switch
     // back to user mode.
 
 #if defined(__U_MULTI__)
-    THREAD_SETMEM( uActiveTask, ((uBaseTask *)&This) );
+    THREAD_SETMEM( activeTask, ((uBaseTask *)&This) );
 #endif
 
     errno = 0;						// reset errno for each task
     This.currCoroutine->setState( uBaseCoroutine::Active ); // set state of next coroutine to active
     This.setState( uBaseTask::Running );
-    THREAD_GETMEM( uSelf )->enableInterrupts();
+    THREAD_GETMEM( This )->enableInterrupts();
 
-    if ( uThisTask().uProfileActive && uProfiler::uProfiler_PostallocateMetricMemory ) {
-	(*uProfiler::uProfiler_PostallocateMetricMemory)( uProfiler::uProfilerInstance, uThisTask() );
+    if ( uThisTask().profileActive && uProfiler::uProfiler_postallocateMetricMemory ) {
+	(*uProfiler::uProfiler_postallocateMetricMemory)( uProfiler::profilerInstance, uThisTask() );
     } // if
 
     // At this point, execution is on the stack of the new coroutine or task
@@ -109,21 +114,10 @@ void uMachContext::uInvokeTask( uBaseTask &This ) {	// magically invoke the "mai
     // legitimately occur now.
 
     try {
+	uEHM::poll();					// cancellation checkpoint
 	This.main();					// start task's "main" routine
-	_Disable {					// task has terminated so ignore concurrent exceptions
-	    This.notHalted = false;
-	    This.setState( uBaseTask::Terminate );
-
-	    // Clean up storage associated with the task for pthread
-	    // thread-specific data, e.g., exception handling associates
-	    // thread-specific data with any task.
-
-	    if ( This.pthreadData != NULL ) {
-		_pthread_deletespecific( This.pthreadData );
-	    } // if
-	    This.getSerial().uLeave2();
-	    uAbort( "(uMachContext::uInvokeTask() : internal error, CONTROL NEVER REACHES HERE!" );
-	} // _Disable
+    } catch( uBaseCoroutine::UnwindStack &evt) {
+	evt.exec_dtor = false;				// defuse the unwinder	
     } catch( uEHM::uDualClass &evt ) {
 	evt.defaultTerminate();
 	cleanup( This );				// preserve current exception
@@ -133,8 +127,23 @@ void uMachContext::uInvokeTask( uBaseTask &This ) {	// magically invoke the "mai
     } catch( ... ) {
 	cleanup( This );				// preserve current exception
     } // try
+
+    This.notHalted = false;
+    This.setState( uBaseTask::Terminate );
+
+    // Clean up storage associated with the task for pthread thread-specific
+    // data, e.g., exception handling associates thread-specific data with any
+    // task.
+
+    if ( This.pthreadData != NULL ) {
+	_pthread_deletespecific( This.pthreadData );
+    } // if
+    This.getSerial().leave2();
     // CONTROL NEVER REACHES HERE!
-} // uMachContext::uInvokeTask
+#ifdef __U_DEBUG__
+    assert( false );
+#endif // __U_DEBUG__
+} // uMachContext::invokeTask
 
 
 void uMachContext::cleanup( uBaseTask &This ) {
@@ -147,11 +156,11 @@ void uMachContext::cleanup( uBaseTask &This ) {
 	_pthread_deletespecific( This.pthreadData );
     } // if
 
-    uEHM::uTerminate();					// call abort terminate routine
+    uEHM::terminate();					// call abort terminate routine
 } // uMachContext::cleanup
 
 
-void *uMachContext::uRtnAdr( void (*rtn)() ) {
+void *uMachContext::rtnAdr( void (*rtn)() ) {
 #if defined( __linux__ ) && defined( __ia64__ )
     if ( ! rtn ) return NULL;
 
@@ -164,11 +173,11 @@ void *uMachContext::uRtnAdr( void (*rtn)() ) {
 #else
     return (void *)rtn;
 #endif
-} // uMachContext::uRtnAdr
+} // uMachContext::rtnAdr
 
 
 #if defined( __linux__ ) && defined( __ia64__ )
-void *uMachContext::uGpAdr( void (*rtn)() ) {
+void *uMachContext::gpAdr( void (*rtn)() ) {
     if ( ! rtn ) return NULL;
 
     struct TOC {
@@ -177,38 +186,38 @@ void *uMachContext::uGpAdr( void (*rtn)() ) {
     };
 
     return ((TOC *)rtn)->toc;
-} // uMachContext::uGpAdr
+} // uMachContext::gpAdr
 #endif
 
 
-unsigned int uMachContext::uMagic() {
+unsigned int uMachContext::magic() {
     return 0x12345678;
-} // uMachContext::uMagic
+} // uMachContext::magic
 
 
-void uMachContext::uStartHere( void (*uInvoke)( uMachContext & ) ) {
+void uMachContext::startHere( void (*uInvoke)( uMachContext & ) ) {
 
 /*******************************************************
   magic number (16 bytes)
-  ,-----------------. \ <--- uBase (stack grows down)
+  ,-----------------. \ <--- base (stack grows down)
   |                 | |
-  |    task stack   | } uSize
+  |    task stack   | } size
   |                 | |
-  `-----------------' / <--- uLimit
+  `-----------------' / <--- limit
   magic number (16 bytes)
   ,-----------------.
   |                 |
   | __U_CONTEXT_T__ |
   |                 |
-0 `-----------------' <--- uStorage
+0 `-----------------' <--- storage
 *******************************************************/
 
 #if defined( __i386__ )
 
     // set base and limits of stack
 
-    uLimit = (char *)uStorage + uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + 16;
-    uBase = (char *)uLimit + uSize;
+    limit = (char *)storage + uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + 16;
+    base = (char *)limit + size;
 
 #if ! defined( __U_SWAPCONTEXT__ )
     struct uFakeStack {
@@ -218,28 +227,28 @@ void uMachContext::uStartHere( void (*uInvoke)( uMachContext & ) ) {
 	void *uArgument;
     };
 
-    ((uContext_t *)uStorage)->uSP = (char *)uBase - sizeof( uFakeStack );
-    ((uContext_t *)uStorage)->uFP = NULL;		// terminate stack with NULL fp
+    ((uContext_t *)storage)->SP = (char *)base - sizeof( uFakeStack );
+    ((uContext_t *)storage)->FP = NULL;		// terminate stack with NULL fp
 
-    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->uArgument = this; // argument to uInvoke
-    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->uReturn = uRtnAdr( (void (*)())uInvoke );
+    ((uFakeStack *)(((uContext_t *)storage)->SP))->uArgument = this; // argument to uInvoke
+    ((uFakeStack *)(((uContext_t *)storage)->SP))->uReturn = rtnAdr( (void (*)())uInvoke );
 #else
     // set base and limits of stack
 
-    uLimit = (char *)uStorage + sizeof(ucontext_t) + 16;
-    uBase = (char *)uLimit + uSize;
+    limit = (char *)storage + sizeof(ucontext_t) + 16;
+    base = (char *)limit + size;
 
-    if ( ::getcontext( (ucontext *)uStorage ) == -1 ) {	// initialize ucontext area
+    if ( ::getcontext( (ucontext *)storage ) == -1 ) {	// initialize ucontext area
 	uAbort( "internal error, getcontext failed" );
     } // if
-    ((ucontext *)uStorage)->uc_stack.ss_sp = (char *)uLimit;
-    ((ucontext *)uStorage)->uc_stack.ss_size = uSize; 
-    ((ucontext *)uStorage)->uc_stack.ss_flags = 0;
-    ::makecontext( (ucontext *)uStorage, (void (*)())uInvoke, 2, this );
+    ((ucontext *)storage)->uc_stack.ss_sp = (char *)limit;
+    ((ucontext *)storage)->uc_stack.ss_size = size; 
+    ((ucontext *)storage)->uc_stack.ss_flags = 0;
+    ::makecontext( (ucontext *)storage, (void (*)())uInvoke, 2, this );
     // TEMPORARY: stack is incorrectly initialized to allow stack walking
-    ((ucontext *)uStorage)->uc_mcontext.gregs[ REG_EBP ] = 0; // terminate stack with NULL fp
+    ((ucontext *)storage)->uc_mcontext.gregs[ REG_EBP ] = 0; // terminate stack with NULL fp
 #if defined( __U_MULTI__ ) && defined( __U_ONETIMER__ )
-    sigaddset( (sigset_t*)&((ucontext *)uStorage)->uc_sigmask, SIGALRM );
+    sigaddset( (sigset_t*)&((ucontext *)storage)->uc_sigmask, SIGALRM );
 #endif // __U_MULTI__ && __U_ONETIMER__
 #endif
 
@@ -247,8 +256,8 @@ void uMachContext::uStartHere( void (*uInvoke)( uMachContext & ) ) {
 
     // set base and limits of stack
 
-    uLimit = (char *)uStorage + uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + 16;
-    uBase = (char *)uLimit + uSize;
+    limit = (char *)storage + uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + 16;
+    base = (char *)limit + size;
 
 #if ! defined( __U_SWAPCONTEXT__ )
     struct uFakeStack {
@@ -256,12 +265,12 @@ void uMachContext::uStartHere( void (*uInvoke)( uMachContext & ) ) {
 	void *uReturn;
     };
 
-    ((uContext_t *)uStorage)->uSP = (char *)uBase - sizeof( uFakeStack );
-    ((uContext_t *)uStorage)->uFP = NULL;		// terminate stack with NULL fp
+    ((uContext_t *)storage)->SP = (char *)base - sizeof( uFakeStack );
+    ((uContext_t *)storage)->FP = NULL;		// terminate stack with NULL fp
 
-    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->uReturn = uRtnAdr( (void (*)())uInvokeStub );
-    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->uFixedRegisters[0] = this;
-    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->uFixedRegisters[1] = uRtnAdr( (void (*)())uInvoke );
+    ((uFakeStack *)(((uContext_t *)storage)->SP))->uReturn = rtnAdr( (void (*)())uInvokeStub );
+    ((uFakeStack *)(((uContext_t *)storage)->SP))->uFixedRegisters[0] = this;
+    ((uFakeStack *)(((uContext_t *)storage)->SP))->uFixedRegisters[1] = rtnAdr( (void (*)())uInvoke );
 #else
     // makecontext is difficult to support.  See http://sources.redhat.com/bugzilla/show_bug.cgi?id=404
     #error uC++ : internal error, swapcontext cannot be used on the x86_64 architecture
@@ -273,8 +282,8 @@ void uMachContext::uStartHere( void (*uInvoke)( uMachContext & ) ) {
 
     // set base and limits of stack
 
-    uLimit = (char *)uStorage + uCeiling( sizeof(__U_CONTEXT_T__), 16 );
-    uBase = (char *)uLimit + uSize;
+    limit = (char *)storage + uCeiling( sizeof(__U_CONTEXT_T__), 16 );
+    base = (char *)limit + size;
 
     struct uFakeStack {
 	void *scratch1[2];				// abi-mandated scratch area
@@ -301,43 +310,43 @@ void uMachContext::uStartHere( void (*uInvoke)( uMachContext & ) ) {
 	void *scratch2[2];				// abi-mandated scratch area
     };
 
-    ((uContext_t *)uStorage)->uSP = (char *)uBase - sizeof( uFakeStack );
-    ((uContext_t *)uStorage)->uBSP = (char*)uLimit + 16;
-    sigemptyset( &((uContext_t *)uStorage)->uSigmask );
+    ((uContext_t *)storage)->SP = (char *)base - sizeof( uFakeStack );
+    ((uContext_t *)storage)->BSP = (char*)limit + 16;
+    sigemptyset( &((uContext_t *)storage)->sigMask );
 #ifdef __U_MULTI__
-    sigaddset( &((uContext_t *)uStorage)->uSigmask, SIGALRM );
+    sigaddset( &((uContext_t *)storage)->sigMask, SIGALRM );
 #endif // __U_MULTI__
-    memset( ((uContext_t *)uStorage)->uSP, 0, sizeof( uFakeStack ) );
-    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->preserved.b0 = uRtnAdr( (void (*)())uInvokeStub );
-    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->preserved.r1 = uGpAdr( (void (*)())uInvokeStub );
+    memset( ((uContext_t *)storage)->SP, 0, sizeof( uFakeStack ) );
+    ((uFakeStack *)(((uContext_t *)storage)->SP))->preserved.b0 = rtnAdr( (void (*)())uInvokeStub );
+    ((uFakeStack *)(((uContext_t *)storage)->SP))->preserved.r1 = gpAdr( (void (*)())uInvokeStub );
 #if defined( __INTEL_COMPILER )
-    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->preserved.fpsr = (void*)__getReg( _IA64_REG_AR_FPSR );
+    ((uFakeStack *)(((uContext_t *)storage)->SP))->preserved.fpsr = (void*)__getReg( _IA64_REG_AR_FPSR );
 #else
-    asm ( "mov.m %0 = ar.fpsr" : "=r" (((uFakeStack *)(((uContext_t *)uStorage)->uSP))->preserved.fpsr) );
+    asm ( "mov.m %0 = ar.fpsr" : "=r" (((uFakeStack *)(((uContext_t *)storage)->SP))->preserved.fpsr) );
 #endif // __INTEL_COMPILER
-    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->preserved.r4 = this;
-    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->preserved.b1 = uRtnAdr( (void (*)())uInvoke );
-    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->preserved.b2 = NULL; // null terminate for stack walking
+    ((uFakeStack *)(((uContext_t *)storage)->SP))->preserved.r4 = this;
+    ((uFakeStack *)(((uContext_t *)storage)->SP))->preserved.b1 = rtnAdr( (void (*)())uInvoke );
+    ((uFakeStack *)(((uContext_t *)storage)->SP))->preserved.b2 = NULL; // null terminate for stack walking
 #else
     // set base and limits of stack
 
-    uLimit = (char *)uStorage + sizeof(ucontext_t) + 16;
-    uBase = (char *)uLimit + uSize;
+    limit = (char *)storage + sizeof(ucontext_t) + 16;
+    base = (char *)limit + size;
 
-    if ( ::getcontext( (ucontext *)uStorage ) == -1 ) {	// initialize ucontext area
+    if ( ::getcontext( (ucontext *)storage ) == -1 ) {	// initialize ucontext area
 	uAbort( "internal error, getcontext failed" );
     } // if
-    ((ucontext *)uStorage)->uc_stack.ss_sp = (char *)uLimit;
-    ((ucontext *)uStorage)->uc_stack.ss_size = uSize;
-    ((ucontext *)uStorage)->uc_stack.ss_flags = 0;
-    ::makecontext( (ucontext *)uStorage, (void (*)())uInvoke, 2, this );
+    ((ucontext *)storage)->uc_stack.ss_sp = (char *)limit;
+    ((ucontext *)storage)->uc_stack.ss_size = size;
+    ((ucontext *)storage)->uc_stack.ss_flags = 0;
+    ::makecontext( (ucontext *)storage, (void (*)())uInvoke, 2, this );
 
     // TEMPORARY: getcontext doesn't get the signal mask properly
-    if ( sigprocmask( SIG_BLOCK, NULL, (sigset_t*)&(((ucontext *)uStorage)->uc_sigmask) ) == -1 ) {
+    if ( sigprocmask( SIG_BLOCK, NULL, (sigset_t*)&(((ucontext *)storage)->uc_sigmask) ) == -1 ) {
         uAbort( "internal error, sigprocmask" );
     } // if
 #if defined( __U_MULTI__ ) && defined( __U_ONETIMER__ )
-    sigaddset( (sigset_t*)&((ucontext *)uStorage)->uc_sigmask, SIGALRM );
+    sigaddset( (sigset_t*)&((ucontext *)storage)->uc_sigmask, SIGALRM );
 #endif // __U_MULTI__ && __U_ONETIMER__
 #endif
 
@@ -345,8 +354,8 @@ void uMachContext::uStartHere( void (*uInvoke)( uMachContext & ) ) {
 
     // set base and limits of stack
 
-    uLimit = (char *)uStorage + uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + 16;
-    uBase = (char *)uLimit + uSize;
+    limit = (char *)storage + uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + 16;
+    base = (char *)limit + size;
 
 #if ! defined( __U_SWAPCONTEXT__ )
     struct uFakeStack {
@@ -358,25 +367,25 @@ void uMachContext::uStartHere( void (*uInvoke)( uMachContext & ) ) {
 	void *uCalleeRegArgs[6];
     };
 
-    ((uContext_t *)uStorage)->uFP = (char *)(SA( (unsigned long)uBase - STACK_ALIGN + 1 ) - SA( MINFRAME ) - STACK_BIAS );
-    ((uContext_t *)uStorage)->uSP = (char *)((uContext_t *)uStorage)->uFP - SA( MINFRAME );
-    ((uContext_t *)uStorage)->uPC = (char *)uRtnAdr( (void (*)())uInvokeStub ) - 8;
+    ((uContext_t *)storage)->FP = (char *)(SA( (unsigned long)base - STACK_ALIGN + 1 ) - SA( MINFRAME ) - STACK_BIAS );
+    ((uContext_t *)storage)->SP = (char *)((uContext_t *)storage)->FP - SA( MINFRAME );
+    ((uContext_t *)storage)->PC = (char *)rtnAdr( (void (*)())uInvokeStub ) - 8;
 
-    ((uFakeStack *)((char *)((uContext_t *)uStorage)->uFP + STACK_BIAS))->uInRegs[0] = this; // argument to uInvoke
-    ((uFakeStack *)((char *)((uContext_t *)uStorage)->uFP + STACK_BIAS))->uInRegs[1] = (void *)uInvoke; // uInvoke routine
-    ((uFakeStack *)((char *)((uContext_t *)uStorage)->uFP + STACK_BIAS))->uInRegs[6] = NULL; // terminate stack with NULL fp
+    ((uFakeStack *)((char *)((uContext_t *)storage)->FP + STACK_BIAS))->uInRegs[0] = this; // argument to uInvoke
+    ((uFakeStack *)((char *)((uContext_t *)storage)->FP + STACK_BIAS))->uInRegs[1] = (void *)uInvoke; // uInvoke routine
+    ((uFakeStack *)((char *)((uContext_t *)storage)->FP + STACK_BIAS))->uInRegs[6] = NULL; // terminate stack with NULL fp
 #else
-    if ( ::getcontext( (ucontext *)uStorage ) == -1 ) {	// initialize ucontext area
+    if ( ::getcontext( (ucontext *)storage ) == -1 ) {	// initialize ucontext area
 	uAbort( " : internal error, getcontext failed" );
     } // if
-    ((ucontext *)uStorage)->uc_stack.ss_sp = (char *)uBase - 8;	// TEMPORARY: -8 for bug in Solaris (fixed in Solaris 4.10)
-    ((ucontext *)uStorage)->uc_stack.ss_size = uSize; 
-    ((ucontext *)uStorage)->uc_stack.ss_flags = 0;
-    ::makecontext( (ucontext *)uStorage, (void (*)(...))uInvoke, 2, this );
+    ((ucontext *)storage)->uc_stack.ss_sp = (char *)base - 8;	// TEMPORARY: -8 for bug in Solaris (fixed in Solaris 4.10)
+    ((ucontext *)storage)->uc_stack.ss_size = size; 
+    ((ucontext *)storage)->uc_stack.ss_flags = 0;
+    ::makecontext( (ucontext *)storage, (void (*)(...))uInvoke, 2, this );
     // TEMPORARY: stack is incorrectly initialized to allow stack walking
-    *((int *)uBase - 8) = 0;				// terminate stack with NULL fp
+    *((int *)base - 8) = 0;				// terminate stack with NULL fp
 #if defined( __U_MULTI__ ) && defined( __U_ONETIMER__ )
-    sigaddset( (sigset_t*)&((ucontext *)uStorage)->uc_sigmask, SIGALRM );
+    sigaddset( (sigset_t*)&((ucontext *)storage)->uc_sigmask, SIGALRM );
 #endif // __U_MULTI__ && __U_ONETIMER__
 #endif
 
@@ -388,31 +397,31 @@ void uMachContext::uStartHere( void (*uInvoke)( uMachContext & ) ) {
 	void *uDummyAlign[1];				// make multiple of 16
     };
 
-    uLimit = (char *)uStorage + uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + 16;
-    uBase = (char *)uStorage + uSize;
+    limit = (char *)storage + uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + 16;
+    base = (char *)storage + size;
 
-    ((uContext_t *)uStorage)->uSP = (char *)uBase - sizeof( uFakeStack );
+    ((uContext_t *)storage)->SP = (char *)base - sizeof( uFakeStack );
 
-    ((uFakeStack *)((uContext_t *)uStorage)->uSP)->uFixedRegisters[0] = reinterpret_cast<unsigned long long>( this ); // argument to uInvoke (r16)
-    ((uFakeStack *)((uContext_t *)uStorage)->uSP)->uFixedRegisters[1] = reinterpret_cast<unsigned long long>( uRtnAdr( (void (*)())uInvoke ) );	// uInvoke routine (r17)
-    ((uFakeStack *)((uContext_t *)uStorage)->uSP)->uFixedRegisters[8] = 0; // terminate stack with NULL fp (r30)
-    ((uFakeStack *)((uContext_t *)uStorage)->uSP)->uFixedRegisters[9] = reinterpret_cast<unsigned long long>( uRtnAdr( (void (*)())uInvokeStub ) ); // (r31)
+    ((uFakeStack *)((uContext_t *)storage)->SP)->uFixedRegisters[0] = reinterpret_cast<unsigned long long>( this ); // argument to uInvoke (r16)
+    ((uFakeStack *)((uContext_t *)storage)->SP)->uFixedRegisters[1] = reinterpret_cast<unsigned long long>( rtnAdr( (void (*)())uInvoke ) );	// uInvoke routine (r17)
+    ((uFakeStack *)((uContext_t *)storage)->SP)->uFixedRegisters[8] = 0; // terminate stack with NULL fp (r30)
+    ((uFakeStack *)((uContext_t *)storage)->SP)->uFixedRegisters[9] = reinterpret_cast<unsigned long long>( rtnAdr( (void (*)())uInvokeStub ) ); // (r31)
 
 #else
     // set base and limits of stack
 
-    uLimit = (char *)uStorage + sizeof(ucontext_t) + 16;
-    uBase = (char *)uLimit + uSize;
+    limit = (char *)storage + sizeof(ucontext_t) + 16;
+    base = (char *)limit + size;
 
-    if ( ::getcontext( (ucontext *)uStorage ) == -1 ) {	// initialize ucontext area
+    if ( ::getcontext( (ucontext *)storage ) == -1 ) {	// initialize ucontext area
 	uAbort( "internal error, getcontext failed" );
     } // if
-    ((ucontext *)uStorage)->uc_stack.ss_sp = (char *)uBase - 8;	// TEMPORARY: -8 for bug in Solaris (fixed in Solaris 4.10)
-    ((ucontext *)uStorage)->uc_stack.ss_size = uSize; 
-    ((ucontext *)uStorage)->uc_stack.ss_flags = 0;
-    ::makecontext( (ucontext *)uStorage, (void (*)())uInvoke, 2, this );
+    ((ucontext *)storage)->uc_stack.ss_sp = (char *)base - 8;	// TEMPORARY: -8 for bug in Solaris (fixed in Solaris 4.10)
+    ((ucontext *)storage)->uc_stack.ss_size = size; 
+    ((ucontext *)storage)->uc_stack.ss_flags = 0;
+    ::makecontext( (ucontext *)storage, (void (*)())uInvoke, 2, this );
 #if defined( __U_MULTI__ ) && defined( __U_ONETIMER__ )
-    sigaddset( (sigset_t*)&((ucontext *)uStorage)->uc_sigmask, SIGALRM );
+    sigaddset( (sigset_t*)&((ucontext *)storage)->uc_sigmask, SIGALRM );
 #endif // __U_MULTI__ && __U_ONETIMER__
 #endif
 
@@ -422,31 +431,31 @@ void uMachContext::uStartHere( void (*uInvoke)( uMachContext & ) ) {
 
     // set magic words on stack
 
-    *(unsigned int *)((char *)uLimit - 16) = uMagic();
-    *(unsigned int *)uBase = uMagic();
-} // uMachContext::uStartHere
+    *(unsigned int *)((char *)limit - 16) = magic();
+    *(unsigned int *)base = magic();
+} // uMachContext::startHere
 
 
-void uMachContext::uCreateContext( unsigned int stacksize ) { // used by all constructors
-    uSize = uCeiling( stacksize, 16 );
-    uLimit = uBase = NULL;
+void uMachContext::createContext( unsigned int stacksize ) { // used by all constructors
+    size = uCeiling( stacksize, 16 );
+    limit = base = NULL;
     uErrno = 0;
-    uExtras.uAllExtras = 0;
-} // uMachContext::uCreateContext
+    extras.allExtras = 0;
+} // uMachContext::createContext
 
 
 uMachContext::uMachContext( unsigned int stacksize ) {
-    uCreateContext( stacksize );
+    createContext( stacksize );
     // use malloc because "new" handles the overflow
-    uStorage = malloc( uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + uSize + 32 );
-    if ( uStorage == NULL ) {				// allocate stack from heap
+    storage = malloc( uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + size + 32 );
+    if ( storage == NULL ) {				// allocate stack from heap
 	uAbort( "Attempt to allocate %d bytes of storage for coroutine or task execution-state but insufficient memory available.", stacksize );
     } // if
 } // uMachContext::uMachContext
 
 
 uMachContext::~uMachContext() {
-    free( uStorage );
+    free( storage );
 } // uMachContext::~uMachContext
 
 
@@ -480,9 +489,15 @@ void *uMachContext::stackPointer() const {
 	return sp;
     } else {						// accessing another coroutine
 #if defined( __U_SWAPCONTEXT__ )
-	return (void *)(((ucontext_t *)uStorage)->uc_mcontext.
-#if defined( __linux__ ) && defined( __i386__ )
+	return (void *)(((ucontext_t *)storage)->uc_mcontext.
+#if defined( __i386__ )
+#if defined( __linux__ )
 	    gregs[REG_ESP]);
+#elif defined( __freebsd__ )
+	    mc_esp;
+#else
+	    #error uC++ : internal error, unsupported architecture
+#endif // __linux__
 #elif defined( __linux__ ) && defined( __x86_64__ )
 	    gregs[REG_RSP]);
 #elif defined( __linux__ ) && defined( __ia64__ )
@@ -496,9 +511,9 @@ void *uMachContext::stackPointer() const {
 #endif
 #else
 #if defined( __sparc__ )
-	return (void*)((char*)((uContext_t *)uStorage)->uSP + STACK_BIAS);
+	return (void*)((char*)((uContext_t *)storage)->SP + STACK_BIAS);
 #else
-	return ((uContext_t *)uStorage)->uSP;
+	return ((uContext_t *)storage)->SP;
 #endif // __sparc__
 #endif
     } // if
@@ -517,47 +532,47 @@ void *uMachContext::registerStackPointer() const {
 	return bsp;
 #endif // __INTEL_COMPILER
     } else {						// accessing another coroutine
-	return (void *)(((ucontext_t *)uStorage)->uc_mcontext.sc_ar_bsp);
+	return (void *)(((ucontext_t *)storage)->uc_mcontext.sc_ar_bsp);
     } // if
 #else
-    return ((uContext_t *)uStorage)->uBSP;
+    return ((uContext_t *)storage)->BSP;
 #endif
 } // uMachContext::registerStackPointer
 #endif // __ia64__
 
 
 unsigned int uMachContext::stackSize() const {
-    return uSize;
+    return size;
 } // uMachContext::stackSize
 
 
 ptrdiff_t uMachContext::stackFree() const {
-    return (char *)stackPointer() - (char *)uLimit;
+    return (char *)stackPointer() - (char *)limit;
 } // uMachContext::stackFree
 
 
 ptrdiff_t uMachContext::stackUsed() const {
-    ptrdiff_t amt = (char *)uBase - (char *)stackPointer();
+    ptrdiff_t amt = (char *)base - (char *)stackPointer();
     return amt < 0 ? -amt : amt;			// abs, for stacks growing up
 } // uMachContext::stackUsed
 
 
 void uMachContext::verify() {
     // Ignore the boot task as it uses the UNIX stack.
-    if ( uStorage == ((uBaseTask *)uKernelModule::uTaskBoot)->uStorage ) return;
+    if ( storage == ((uBaseTask *)uKernelModule::bootTask)->storage ) return;
 
-    if ( stackPointer() < uLimit ) {
+    if ( stackPointer() < limit ) {
 	uAbort( "Stack overflow detected: stack pointer 0x%p below limit 0x%p.\n"
 		"Possible cause is allocation of large stack frame(s) and/or deep call stack.",
-		stackPointer(), uLimit );
-    } else if ( (char *)stackPointer() + 4 * 1024 < uLimit ) {
+		stackPointer(), limit );
+    } else if ( (char *)stackPointer() + 4 * 1024 < limit ) {
 	fprintf( stderr, "WARNING within 4K of stack limit: stack pointer 0x%p and limit 0x%p.\n"
 		 "Possible cause is allocation of large stack frame(s) and/or deep call stack.\n",
-		 stackPointer(), uLimit );
-    } else if ( stackPointer() > uBase ) {
+		 stackPointer(), limit );
+    } else if ( stackPointer() > base ) {
 	uAbort( "Stack underflow detected.\n"
 		"Possible cause is corrupted stack frame via overwriting memory." );
-    } else if ( ( *(unsigned int *)uBase != uMagic() ) || ( *(unsigned int *)((char *)uLimit - 16) != uMagic() ) ) {
+    } else if ( ( *(unsigned int *)base != magic() ) || ( *(unsigned int *)((char *)limit - 16) != magic() ) ) {
 	uAbort( "Stack corruption detected.\n"
 		"Possible cause is corrupted stack frame via overwriting memory." );
 #if defined( __ia64__ )
@@ -571,24 +586,24 @@ void uMachContext::verify() {
 } // uMachContext::verify
 
 
-void uMachContext::uExtraSave() {
+void uMachContext::extraSave() {
     // Don't need to test extras bit, it is sufficent to check context list
 
     uContext *context;
-    for ( uSeqIter<uContext> iter(uAdditionalContexts); iter >> context; ) {
+    for ( uSeqIter<uContext> iter(additionalContexts); iter >> context; ) {
 	context->save();
     } // for
-} // uMachContext::uExtraSave
+} // uMachContext::extraSave
 
 
-void uMachContext::uExtraRestore() {
+void uMachContext::extraRestore() {
     // Don't need to test extras bit, it is sufficent to check context list
 
     uContext *context;
-    for ( uSeqIter<uContext> iter(uAdditionalContexts); iter >> context; ) {
+    for ( uSeqIter<uContext> iter(additionalContexts); iter >> context; ) {
 	context->restore();
     } // for
-} // uMachContext::uExtraRestore
+} // uMachContext::extraRestore
 
 
 // Local Variables: //
