@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uNBIO.cc -- non-blocking IO
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Mar  7 13:56:53 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Dec  3 08:27:31 2005
-// Update Count     : 510
+// Last Modified On : Thu Sep 21 18:02:23 2006
+// Update Count     : 537
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -24,19 +24,24 @@
 // along  with this library.
 // 
 
+// ***************************************************************************
+// WARNING: The poller task uses uYieldNoPoll so that nonlocal exceptions and
+// cancellation cannot occur while it is conceptually blocked on an I/O
+// operation.
+// ***************************************************************************
+
 
 #define __U_KERNEL__
 
 
 #include <uC++.h>
-#include <uAssert.h>
 //#include <uDebug.h>
 
 
 #include <cstring>					// strerror
 #include <cerrno>
 #include <sys/socket.h>
-#if defined( __linux__ )
+#if defined( __linux__ ) || defined( __freebsd__ )
 #include <sys/param.h>					// howmany
 #endif
 
@@ -62,13 +67,13 @@ static inline int uCountBits( unsigned long int x ) {
 //######################### uNBIO #########################
 
 
-void uNBIO::uCheckIO( uDuration delay ) {
+void uNBIO::checkIO( uDuration delay ) {
     int i;
     struct timeval timeout = delay;			// convert to timeval for select
     int tmasks = howmany( maxFD + 1, NFDBITS );		// total number of masks in fd set
 
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uNBIO &)0x%p.uCheckIO: timeout:%ld,%ld\n", this, timeout.tv_sec, timeout.tv_usec );
+    uDebugPrt( "(uNBIO &)0x%p.checkIO: timeout:%ld,%ld\n", this, timeout.tv_sec, timeout.tv_usec );
 #endif // __U_DEBUG_H__
 
     // Make a local copy of the fd sets because the select operation destroys
@@ -89,29 +94,29 @@ void uNBIO::uCheckIO( uDuration delay ) {
     // "select". In such a case, the SIGALRM is treated as spurious.
     // Therefore, it is necessary to poll.
 
-    THREAD_GETMEM( uSelf )->disableInterrupts();
+    THREAD_GETMEM( This )->disableInterrupts();
 
     int uPrevTime = uThisProcessor().getPreemption();	// remember previous preemption time
     if ( uPrevTime != 0 ) {				// optimize out UNIX call if possible
-	uThisProcessor().uSetContextSwitchEvent( 0 );	// turn off preemption or it keeps waking the UNIX processor
+	uThisProcessor().setContextSwitchEvent( 0 );	// turn off preemption or it keeps waking the UNIX processor
     } // if
 
-    uThisCluster().uMakeProcessorIdle( uThisProcessor() );
+    uThisCluster().makeProcessorIdle( uThisProcessor() );
 
 #ifdef __U_DEBUG_H__
 #if 1
     uDebugAcquire();
-    uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, lrfds:", this );
+    uDebugPrt2( "(uNBIO &)0x%p.checkIO, lrfds:", this );
     for ( i = 0; i < tmasks; i += 1 ) {
 	uDebugPrt2( "%lx ", lrfds.fds_bits[i] );
     } // for
     uDebugPrt2( "\n" );
-    uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, lwfds:", this );
+    uDebugPrt2( "        (uNBIO &)0x%p.checkIO, lwfds:", this );
     for ( i = 0; i < tmasks; i += 1 ) {
 	uDebugPrt2( "%lx ", lwfds.fds_bits[i] );
     } // for
     uDebugPrt2( "\n" );
-    uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, lefds:", this );
+    uDebugPrt2( "        (uNBIO &)0x%p.checkIO, lefds:", this );
     for ( i = 0; i < tmasks; i += 1 ) {
 	uDebugPrt2( "%lx ", lefds.fds_bits[i] );
     } // for
@@ -122,36 +127,36 @@ void uNBIO::uCheckIO( uDuration delay ) {
 
     // Check for IO pending on any descriptors.
 
-    uFound = ::select( maxFD + 1, &lrfds, &lwfds, &lefds, &timeout );
+    descriptors = ::select( maxFD + 1, &lrfds, &lwfds, &lefds, &timeout );
 
-    uThisCluster().uMakeProcessorActive( uThisProcessor() );
+    uThisCluster().makeProcessorActive( uThisProcessor() );
 
     if ( uPrevTime != 0 ) {				// optimize out UNIX call if possible
-	uThisProcessor().uSetContextSwitchEvent( uPrevTime ); // reset processor preemption time
+	uThisProcessor().setContextSwitchEvent( uPrevTime ); // reset processor preemption time
     } // if
 
-    THREAD_GETMEM( uSelf )->enableInterrupts();		// does necessary roll forward
+    THREAD_GETMEM( This )->enableInterrupts();		// does necessary roll forward
 
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uNBIO &)0x%p.uCheckIO: select returns: found %d, timeout:%ld,%ld\n", this, uFound, timeout.tv_sec, timeout.tv_usec );
+    uDebugPrt( "(uNBIO &)0x%p.checkIO: select returns: found %d, timeout:%ld,%ld\n", this, descriptors, timeout.tv_sec, timeout.tv_usec );
 #endif // __U_DEBUG_H__
 
-    if ( uFound > 0 ) {					// I/O has occurred ?
+    if ( descriptors > 0 ) {				// I/O has occurred ?
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "(uNBIO &)0x%p.uCheckIO: found %d pending IO operations\n", this, uFound );
+	uDebugPrt( "(uNBIO &)0x%p.checkIO: found %d pending IO operations\n", this, descriptors );
 #if 1
 	uDebugAcquire();
-	uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, lrfds:", this );
+	uDebugPrt2( "(uNBIO &)0x%p.checkIO, lrfds:", this );
 	for ( i = 0; i < tmasks; i += 1 ) {
 	    uDebugPrt2( "%lx ", lrfds.fds_bits[i] );
 	} // for
 	uDebugPrt2( "\n" );
-	uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, lwfds:", this );
+	uDebugPrt2( "        (uNBIO &)0x%p.checkIO, lwfds:", this );
 	for ( i = 0; i < tmasks; i += 1 ) {
 	    uDebugPrt2( "%lx ", lwfds.fds_bits[i] );
 	} // for
 	uDebugPrt2( "\n" );
-	uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, lefds:", this );
+	uDebugPrt2( "        (uNBIO &)0x%p.checkIO, lefds:", this );
 	for ( i = 0; i < tmasks; i += 1 ) {
 	    uDebugPrt2( "%lx ", lefds.fds_bits[i] );
 	} // for
@@ -178,26 +183,26 @@ void uNBIO::uCheckIO( uDuration delay ) {
 	// Check to see which tasks are waiting for ready I/O operations and
 	// wake them.
 
-	uNBIOnode *p;
+	NBIOnode *p;
 	int cnt;
-	for ( uSeqIter<uNBIOnode> iter(uPendingIO); iter >> p; ) {
+	for ( uSeqIter<NBIOnode> iter(pendingIO); iter >> p; ) {
 	    cnt = 0;
-	    if ( p->fdType == uNBIOnode::singleFd ) {	// single fd
+	    if ( p->fdType == NBIOnode::singleFd ) {	// single fd
 #ifdef __U_DEBUG_H__
-		uDebugPrt( "(uNBIO &)0x%p.uCheckIO: found task %.256s (0x%p) waiting on single fd %d with mask 0x%x\n",
-			   this, p->uPendingTask->getName(), p->uPendingTask, p->smfd.sfd.fd, *p->smfd.sfd.uRWE );
+		uDebugPrt( "(uNBIO &)0x%p.checkIO: found task %.256s (0x%p) waiting on single fd %d with mask 0x%x\n",
+			   this, p->pendingTask->getName(), p->pendingTask, p->smfd.sfd.fd, *p->smfd.sfd.uRWE );
 #endif // __U_DEBUG_H__
 		int temp = 0;
-		if ( (*p->smfd.sfd.uRWE & uCluster::uReadSelect) && FD_ISSET( p->smfd.sfd.fd, &lrfds ) ) {
-		    temp |= uCluster::uReadSelect;
+		if ( (*p->smfd.sfd.uRWE & uCluster::readSelect) && FD_ISSET( p->smfd.sfd.fd, &lrfds ) ) {
+		    temp |= uCluster::readSelect;
 		    cnt += 1;
 		} // if
-		if ( (*p->smfd.sfd.uRWE & uCluster::uWriteSelect ) && FD_ISSET( p->smfd.sfd.fd, &lwfds ) ) {
-		    temp |= uCluster::uWriteSelect;
+		if ( (*p->smfd.sfd.uRWE & uCluster::writeSelect ) && FD_ISSET( p->smfd.sfd.fd, &lwfds ) ) {
+		    temp |= uCluster::writeSelect;
 		    cnt += 1;
 		} // if
-		if ( (*p->smfd.sfd.uRWE & uCluster::uExceptSelect) && FD_ISSET( p->smfd.sfd.fd, &lefds ) ) {
-		    temp |= uCluster::uExceptSelect;
+		if ( (*p->smfd.sfd.uRWE & uCluster::exceptSelect) && FD_ISSET( p->smfd.sfd.fd, &lefds ) ) {
+		    temp |= uCluster::exceptSelect;
 		    cnt += 1;
 		} // if
 		if ( cnt != 0 ) {			// reset user mask only if I/O available
@@ -205,8 +210,8 @@ void uNBIO::uCheckIO( uDuration delay ) {
 		} // if
 	    } else {					// multiple fds
 #ifdef __U_DEBUG_H__
-		uDebugPrt( "(uNBIO &)0x%p.uCheckIO: found task %.256s (0x%p) waiting for multiple fd, nfd:%ld\n",
-			   this, p->uPendingTask->getName(), p->uPendingTask, p->smfd.mfd.uNFDs );
+		uDebugPrt( "(uNBIO &)0x%p.checkIO: found task %.256s (0x%p) waiting for multiple fd, nfd:%ld\n",
+			   this, p->pendingTask->getName(), p->pendingTask, p->smfd.mfd.uNFDs );
 #endif // __U_DEBUG_H__
 		fd_set tfds;				// temporary masks to construct result mask
 		int nmasks = howmany( p->smfd.mfd.uNFDs, NFDBITS );
@@ -224,7 +229,7 @@ void uNBIO::uCheckIO( uDuration delay ) {
 #ifdef __U_DEBUG_H__
 #if 1
 		uDebugAcquire();
-		uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, tfds:", this );
+		uDebugPrt2( "(uNBIO &)0x%p.checkIO, tfds:", this );
 		for ( i = 0; i < nmasks; i += 1 ) {
 		    uDebugPrt2( "%lx ", tfds.fds_bits[i] );
 		} // for
@@ -236,21 +241,21 @@ void uNBIO::uCheckIO( uDuration delay ) {
 #if 1
 		uDebugAcquire();
 		if ( p->smfd.mfd.uRFDs != NULL ) {
-		    uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, uRFDs:", this );
+		    uDebugPrt2( "(uNBIO &)0x%p.checkIO, uRFDs:", this );
 		    for ( i = 0; i < tmasks; i += 1 ) {
 			uDebugPrt2( "%lx ", p->smfd.mfd.uRFDs->fds_bits[i] );
 		    } // for
 		    uDebugPrt2( "\n" );
 		} // if
 		if ( p->smfd.mfd.uWFDs != NULL ) {
-		    uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, uWFDs:", this );
+		    uDebugPrt2( "        (uNBIO &)0x%p.checkIO, uWFDs:", this );
 		    for ( i = 0; i < tmasks; i += 1 ) {
 			uDebugPrt2( "%lx ", p->smfd.mfd.uWFDs->fds_bits[i] );
 		    } // for
 		    uDebugPrt2( "\n" );
 		} // if
 		if ( p->smfd.mfd.uEFDs != NULL ) {
-		    uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, uEFDs:", this );
+		    uDebugPrt2( "        (uNBIO &)0x%p.checkIO, uEFDs:", this );
 		    for ( i = 0; i < tmasks; i += 1 ) {
 			uDebugPrt2( "%lx ", p->smfd.mfd.uEFDs->fds_bits[i] );
 		    } // for
@@ -282,24 +287,24 @@ void uNBIO::uCheckIO( uDuration delay ) {
 		} // if
 #ifdef __U_DEBUG_H__
 #if 1
-		uDebugPrt( "(uNBIO &)0x%p.uCheckIO, cnt:%d\n", this, cnt );
+		uDebugPrt( "(uNBIO &)0x%p.checkIO, cnt:%d\n", this, cnt );
 		uDebugAcquire();
 		if ( p->smfd.mfd.uRFDs != NULL ) {
-		    uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, uRFDs:", this );
+		    uDebugPrt2( "(uNBIO &)0x%p.checkIO, uRFDs:", this );
 		    for ( i = 0; i < tmasks; i += 1 ) {
 			uDebugPrt2( "%lx ", p->smfd.mfd.uRFDs->fds_bits[i] );
 		    } // for
 		    uDebugPrt2( "\n" );
 		} // if
 		if ( p->smfd.mfd.uWFDs != NULL ) {
-		    uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, uWFDs:", this );
+		    uDebugPrt2( "        (uNBIO &)0x%p.checkIO, uWFDs:", this );
 		    for ( i = 0; i < tmasks; i += 1 ) {
 			uDebugPrt2( "%lx ", p->smfd.mfd.uWFDs->fds_bits[i] );
 		    } // for
 		    uDebugPrt2( "\n" );
 		} // if
 		if ( p->smfd.mfd.uEFDs != NULL ) {
-		    uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, uEFDs:", this );
+		    uDebugPrt2( "        (uNBIO &)0x%p.checkIO, uEFDs:", this );
 		    for ( i = 0; i < tmasks; i += 1 ) {
 			uDebugPrt2( "%lx ", p->smfd.mfd.uEFDs->fds_bits[i] );
 		    } // for
@@ -309,30 +314,30 @@ void uNBIO::uCheckIO( uDuration delay ) {
 #endif
 #endif // __U_DEBUG_H__
 	    } // if
-	    if ( cnt != 0 || p->uTimedout ) {		// I/O completed for this task or timed out ?
+	    if ( cnt != 0 || p->timedout ) {		// I/O completed for this task or timed out ?
 #ifdef __U_DEBUG_H__
-		uDebugPrt( "(uNBIO &)0x%p.uCheckIO: removing node 0x%p, cnt:%d, uTimedout:%d\n", this, p, cnt, p->uTimedout );
+		uDebugPrt( "(uNBIO &)0x%p.checkIO: removing node 0x%p, cnt:%d, timedout:%d\n", this, p, cnt, p->timedout );
 #endif // __U_DEBUG_H__
-		uPendingIO.remove( p );			// remove node from list of waiting tasks
+		pendingIO.remove( p );			// remove node from list of waiting tasks
 		p->nfds = cnt;				// set return value
-		p->uPending.signal();			// wake up waiting task (empty for IOPoller)
+		p->pending.signal();			// wake up waiting task (empty for IOPoller)
 	    } // if
 	} // for
-    } else if ( uFound == 0 ) {				// time limit expired, no IO is ready
+    } else if ( descriptors == 0 ) {			// time limit expired, no IO is ready
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "(uNBIO &)0x%p.uCheckIO: time limit expired, errno:%d\n", this, errno );
+	uDebugPrt( "(uNBIO &)0x%p.checkIO: time limit expired, errno:%d\n", this, errno );
 #endif // __U_DEBUG_H__
 	// Check for timed out IO
 
-	uNBIOnode *p;
-	for ( uSeqIter<uNBIOnode> iter(uPendingIO); iter >> p; ) {
-	    if ( p->uTimedout ) {			// timed out waiting for I/O for this task ?
+	NBIOnode *p;
+	for ( uSeqIter<NBIOnode> iter(pendingIO); iter >> p; ) {
+	    if ( p->timedout ) {			// timed out waiting for I/O for this task ?
 #ifdef __U_DEBUG_H__
-		uDebugPrt( "(uNBIO &)0x%p.uCheckIO: removing node 0x%p\n", this, p );
+		uDebugPrt( "(uNBIO &)0x%p.checkIO: removing node 0x%p\n", this, p );
 #endif // __U_DEBUG_H__
-		uPendingIO.remove( p );			// remove node from list of waiting tasks
+		pendingIO.remove( p );			// remove node from list of waiting tasks
 		p->nfds = 0;				// set return value
-		p->uPending.signal();			// wake up waiting task (empty for IOPoller)
+		p->pending.signal();			// wake up waiting task (empty for IOPoller)
 	    } // if
 	} // for
     } else {
@@ -351,48 +356,48 @@ void uNBIO::uCheckIO( uDuration delay ) {
 	    // that were waiting for IO, allow them to retry their IO call and
 	    // hope they catch the error this time.
 
-	    uNBIOnode *p;
-	    for ( uSeqIter<uNBIOnode> iter(uPendingIO); iter >> p; ) {
-		uPendingIO.remove( p );			// remove node from list of waiting tasks
+	    NBIOnode *p;
+	    for ( uSeqIter<NBIOnode> iter(pendingIO); iter >> p; ) {
+		pendingIO.remove( p );			// remove node from list of waiting tasks
 		p->nfds = -1;				// mark the fact that something is wrong
-		p->uPending.signal();			// wake up waiting task (empty for IOPoller)
+		p->pending.signal();			// wake up waiting task (empty for IOPoller)
 	    } // for
 	} else {
-	    uAbort( "(uNBIO &)0x%p.uCheckIO() : internal error, error(%d) %s.", this, errno, strerror( errno ) );
+	    uAbort( "(uNBIO &)0x%p.checkIO() : internal error, error(%d) %s.", this, errno, strerror( errno ) );
 	} // if
     } // if
-} // uNBIO::uCheckIO
+} // uNBIO::checkIO
 
 
-bool uNBIO::uCheckPoller( uNBIOnode &uNode ) {
-    uPendingIO.addTail( &uNode );			// node is removed by IOPoller
+bool uNBIO::checkPoller( NBIOnode &node ) {
+    pendingIO.addTail( &node );				// node is removed by IOPoller
 
     // If this is the first task to register interest, this task is nominated
     // as the IO poller task.
 
-    if ( uIOPoller == NULL ) {
-	uIOPoller = &uThisTask();			// make this task the poller
+    if ( IOPoller == NULL ) {
+	IOPoller = &uThisTask();			// make this task the poller
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "(uNBIO &)0x%p.uCheckPoller, set poller task %.256s (0x%p)\n", this, uIOPoller->getName(), uIOPoller );
+	uDebugPrt( "(uNBIO &)0x%p.checkPoller, set poller task %.256s (0x%p)\n", this, IOPoller->getName(), IOPoller );
 #endif // __U_DEBUG_H__
 	return true;
     } else {
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "(uNBIO &)0x%p.uCheckPoller, blocking non-poller I/O task %.256s (0x%p))\n", this, uThisTask().getName(), &uThisTask() );
+	uDebugPrt( "(uNBIO &)0x%p.checkPoller, blocking non-poller I/O task %.256s (0x%p))\n", this, uThisTask().getName(), &uThisTask() );
 #endif // __U_DEBUG_H__
 	// This is not the poller task so add it to the list of tasks waiting
 	// for IO events.  It is woken when an IO event is ready or nominated
 	// as the poller.
 
-	uNode.uPending.wait();
-	if ( uNode.listed() ) {			// poller ?
-	    uAssert( uIOPoller == &uThisTask() );
+	node.pending.wait();
+	if ( node.listed() ) {				// poller ?
+	    assert( IOPoller == &uThisTask() );
 	    return true;
 	} else {
 	    return false;
 	} // if
     } // if
-} // uNBIO::uCheckPoller
+} // uNBIO::checkPoller
 
  
 void uNBIO::setMaxFD(){
@@ -441,7 +446,7 @@ void uNBIO::setMaxFD(){
 } // uNBIO::setMaxFD
 
 
-void uNBIO::uCloseFD( int fd ) {
+void uNBIO::closeFD( int fd ) {
     FD_CLR( fd, &uRFDs );
     FD_CLR( fd, &uWFDs );
     FD_CLR( fd, &uEFDs );
@@ -449,10 +454,10 @@ void uNBIO::uCloseFD( int fd ) {
     if ( fd == maxFD ) {				// increase maxFD if necessary
 	setMaxFD();
     } // if
-} // uNBIO::uCloseFD
+} // uNBIO::closeFD
 
 
-bool uNBIO::uPollIO( uNBIOnode &uNode ) {
+bool uNBIO::pollIO( NBIOnode &node ) {
     // If there are other tasks on the ready queue of this cluster that can
     // still execute, do a nonblocking select call, otherwise do a blocking
     // select call so that the application does not waste cpu cycles.  In
@@ -464,16 +469,16 @@ bool uNBIO::uPollIO( uNBIOnode &uNode ) {
     // IO events.
 
 #ifdef __U_MULTI__
-    if ( uThisCluster().uReadyTasksEmpty() ) {
+    if ( uThisCluster().readyTasksEmpty() ) {
 #else
-    // uOkToSelect is set in the uniprocessor kernel when *all* clusters have
+    // okToSelect is set in the uniprocessor kernel when *all* clusters have
     // empty ready queues.
-    if ( uOkToSelect ) {
+    if ( okToSelect ) {
 #endif // __U_MULTI__
 	uTime nexttime;
 	uDuration timeout;
 
-	nexttime = uEventList::uNextAlarm();		// find first non-context-switch event
+	nexttime = uEventList::nextAlarm();		// find first non-context-switch event
 	timeout = nexttime - uThisProcessor().getClock().getTime(); // time to sleep
 
 	// The minimum wake up time is always uSelectTimeOut to deal with the
@@ -481,78 +486,78 @@ bool uNBIO::uPollIO( uNBIOnode &uNode ) {
 	// "select".
 
 	if ( 0 < timeout && timeout < uSelectTimeOut ) {
-	    uCheckIO( timeout );
+	    checkIO( timeout );
 	} else {
-	    uCheckIO( uSelectTimeOut );
+	    checkIO( uSelectTimeOut );
 	} // if
 
-	uOkToSelect = false;				// reset select flag
+	okToSelect = false;				// reset select flag
     } else {
-	uCheckIO( 0 );
+	checkIO( 0 );
     } // if
 
     // If the IOPoller's I/O completed, attempt to nominate another waiting
     // task to be the IOPoller.
 
-    if ( ! uNode.listed() ) {				// IOPoller's node removed ?
-	if ( ! uPendingIO.empty() ) {			// any other tasks waiting for IO?
+    if ( ! node.listed() ) {				// IOPoller's node removed ?
+	if ( ! pendingIO.empty() ) {			// any other tasks waiting for IO?
 	    // For the uniprocessor kernel, the new poller will appear to have
-	    // found some IO because uFound is not cleared until the new poller
-	    // makes a call to check for IO.
+	    // found some IO because descriptors is not cleared until the new
+	    // poller makes a call to check for IO.
 
-	    uNBIOnode *p = uPendingIO.head();		// node from list of waiting tasks
-	    uIOPoller = p->uPendingTask;		// next poller task
+	    NBIOnode *p = pendingIO.head();		// node from list of waiting tasks
+	    IOPoller = p->pendingTask;			// next poller task
 #ifdef __U_DEBUG_H__
-	    uDebugPrt( "(uNBIO &)0x%p.uPollIO, poller %.256s (0x%p) nominating task %.256s (0x%p) to be next poller\n",
-		       this, uThisTask().getName(), &uThisTask(), uIOPoller->getName(), uIOPoller );
+	    uDebugPrt( "(uNBIO &)0x%p.pollIO, poller %.256s (0x%p) nominating task %.256s (0x%p) to be next poller\n",
+		       this, uThisTask().getName(), &uThisTask(), IOPoller->getName(), IOPoller );
 #endif // __U_DEBUG_H__
-	    p->uPending.signal();			// wake up waiting task
+	    p->pending.signal();			// wake up waiting task
 	} else {
-	    uIOPoller = NULL;
+	    IOPoller = NULL;
 	} // if
 	return false;
     } else {
 	return true;
     } // if
-} // uNBIO::uPollIO
+} // uNBIO::pollIO
 
 
-bool uNBIO::uInitSfd( uNBIOnode &uNode ) {
-    if ( uNode.smfd.sfd.fd > maxFD ) {			// increase maxFD if necessary
-	maxFD = uNode.smfd.sfd.fd;
+bool uNBIO::initSfd( NBIOnode &node ) {
+    if ( node.smfd.sfd.fd > maxFD ) {			// increase maxFD if necessary
+	maxFD = node.smfd.sfd.fd;
     } // if
 
     // set the appropriate fd bit in the master fd mask
-    if ( *uNode.smfd.sfd.uRWE & uCluster::uReadSelect ) FD_SET( uNode.smfd.sfd.fd, &uRFDs );
-    if ( *uNode.smfd.sfd.uRWE & uCluster::uWriteSelect ) FD_SET( uNode.smfd.sfd.fd, &uWFDs );
-    if ( *uNode.smfd.sfd.uRWE & uCluster::uExceptSelect ) FD_SET( uNode.smfd.sfd.fd, &uEFDs );
+    if ( *node.smfd.sfd.uRWE & uCluster::readSelect ) FD_SET( node.smfd.sfd.fd, &uRFDs );
+    if ( *node.smfd.sfd.uRWE & uCluster::writeSelect ) FD_SET( node.smfd.sfd.fd, &uWFDs );
+    if ( *node.smfd.sfd.uRWE & uCluster::exceptSelect ) FD_SET( node.smfd.sfd.fd, &uEFDs );
 
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uNBIO &)0x%p.uInitSfd, adding node 0x%p\n", this, &uNode );
+    uDebugPrt( "(uNBIO &)0x%p.initSfd, adding node 0x%p\n", this, &node );
 #endif // __U_DEBUG_H__
 
-    return uCheckPoller( uNode );
-} // uNBIO::uInitSfd
+    return checkPoller( node );
+} // uNBIO::initSfd
 
 
-bool uNBIO::uInitSfd( uNBIOnode &uNode, uEventNode &uTimeoutEvent ) {
-    if ( uNode.smfd.sfd.fd > maxFD ) {			// increase maxFD if necessary
-	maxFD = uNode.smfd.sfd.fd;
+bool uNBIO::initSfd( NBIOnode &node, uEventNode &uTimeoutEvent ) {
+    if ( node.smfd.sfd.fd > maxFD ) {			// increase maxFD if necessary
+	maxFD = node.smfd.sfd.fd;
     } // if
 
     // set the appropriate fd bit in the master fd mask
-    if ( *uNode.smfd.sfd.uRWE & uCluster::uReadSelect ) FD_SET( uNode.smfd.sfd.fd, &uRFDs );
-    if ( *uNode.smfd.sfd.uRWE & uCluster::uWriteSelect ) FD_SET( uNode.smfd.sfd.fd, &uWFDs );
-    if ( *uNode.smfd.sfd.uRWE & uCluster::uExceptSelect ) FD_SET( uNode.smfd.sfd.fd, &uEFDs );
+    if ( *node.smfd.sfd.uRWE & uCluster::readSelect ) FD_SET( node.smfd.sfd.fd, &uRFDs );
+    if ( *node.smfd.sfd.uRWE & uCluster::writeSelect ) FD_SET( node.smfd.sfd.fd, &uWFDs );
+    if ( *node.smfd.sfd.uRWE & uCluster::exceptSelect ) FD_SET( node.smfd.sfd.fd, &uEFDs );
 
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uNBIO &)0x%p.uInitSfd, adding node 0x%p\n", this, &uNode );
+    uDebugPrt( "(uNBIO &)0x%p.initSfd, adding node 0x%p\n", this, &node );
 #endif // __U_DEBUG_H__
 
     uTimeoutEvent.add();
 
-    return uCheckPoller( uNode );
-} // uNBIO::uInitSfd
+    return checkPoller( node );
+} // uNBIO::initSfd
 
 
 uNBIO::uNBIO() {
@@ -563,8 +568,8 @@ uNBIO::uNBIO() {
     FD_ZERO( &uWFDs );					// clear the write set
     FD_ZERO( &uEFDs );					// clear the exceptional set
     maxFD = 0;						// all masks are clear
-    uIOPoller = NULL;					// no task is first yet
-    uOkToSelect = false;
+    IOPoller = NULL;					// no task is first yet
+    okToSelect = false;
 } // uNBIO::uNBIO
 
 
@@ -572,11 +577,11 @@ uNBIO::~uNBIO() {
 } // uNBIO::~uNBIO
 
 
-int uNBIO::uSelect( int fd, int &rwe, timeval *timeout ) {
+int uNBIO::select( int fd, int &rwe, timeval *timeout ) {
 #ifdef __U_DEBUG_H__
 #if 1
     uDebugAcquire();
-    uDebugPrt2( "(uNBIO &)0x%p.uSelect1, fd:%d, rwe:%x", this, fd, rwe );
+    uDebugPrt2( "(uNBIO &)0x%p.select1, fd:%d, rwe:%x", this, fd, rwe );
     if ( timeout != NULL ) {
 	uDebugPrt2( ", timeout:%ld.%ld\n", timeout->tv_sec, timeout->tv_usec );
     } else {
@@ -588,57 +593,57 @@ int uNBIO::uSelect( int fd, int &rwe, timeval *timeout ) {
 
 #ifdef __U_DEBUG__
     if ( fd < 0 || FD_SETSIZE <= fd ) {
-	uAbort( "Attempt to select on file descriptor %d, which exceeds range 0-%d.",
+	uAbort( "Attempt to select on file descriptor %d that exceeds range 0-%d.",
 		fd, FD_SETSIZE - 1 );
     } // if
 #endif // __U_DEBUG__
 
-    uNBIOnode uNode;
-    uNode.nfds = 0;
-    uNode.uPendingTask = &uThisTask();
-    uNode.fdType = uNBIOnode::singleFd;
-    uNode.uTimedout = false;
-    uNode.smfd.sfd.fd = fd;
-    uNode.smfd.sfd.uRWE = &rwe;
+    NBIOnode node;
+    node.nfds = 0;
+    node.pendingTask = &uThisTask();
+    node.fdType = NBIOnode::singleFd;
+    node.timedout = false;
+    node.smfd.sfd.fd = fd;
+    node.smfd.sfd.uRWE = &rwe;
 
     if ( timeout != NULL ) {				// timeout ?
 	if ( timeout->tv_sec == 0 && timeout->tv_usec == 0 ) { // optimization
 	    // It is unnecessary to create a timeout event for this trivial
 	    // case. Just mark the timeout as having already occurred.
 
-	    uNode.uTimedout = true;
-	    if ( uInitSfd( uNode ) ) {			// poller task ?
-		while ( uPollIO( uNode ) ) uThisTask().yield(); // busy wait
+	    node.timedout = true;
+	    if ( initSfd( node ) ) {			// poller task ?
+		while ( pollIO( node ) ) uThisTask().uYieldNoPoll(); // busy wait
 	    } // if
 	} else {
 	    uDuration delay( timeout->tv_sec, timeout->tv_usec * 1000 );
-	    uTime time = uActiveProcessorKernel->uKernelClock.getTime() + delay;
-	    uSelectTimeoutHndlr handler( uThisTask(), uNode );
+	    uTime time = activeProcessorKernel->kernelClock.getTime() + delay;
+	    uSelectTimeoutHndlr handler( uThisTask(), node );
 
 	    uEventNode uTimeoutEvent( uThisTask(), handler, time ); // event node for event list
-	    uTimeoutEvent.uExecuteLocked = true;
+	    uTimeoutEvent.executeLocked = true;
 
-	    if ( uInitSfd( uNode, uTimeoutEvent ) ) {	// poller task ?
-		while ( uPollIO( uNode ) ) uThisTask().yield(); // busy wait
+	    if ( initSfd( node, uTimeoutEvent ) ) {	// poller task ?
+		while ( pollIO( node ) ) uThisTask().uYieldNoPoll(); // busy wait
 	    } // if
 
 	    // always doing remove guarantees the node is not deallocated prematurely
 	    uTimeoutEvent.remove();
 	} // if
     } else {
-	if ( uInitSfd( uNode ) ) {			// poller task ?
-	    while ( uPollIO( uNode ) ) uThisTask().yield(); // busy wait
+	if ( initSfd( node ) ) {			// poller task ?
+	    while ( pollIO( node ) ) uThisTask().uYieldNoPoll(); // busy wait
 	} // if
     } // if
 
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uNBIO &)0x%p.uSelect1, exits, cnt:%d\n", this, uNode.nfds );
+    uDebugPrt( "(uNBIO &)0x%p.select1, exits, cnt:%d\n", this, node.nfds );
 #endif // __U_DEBUG_H__
-    return uNode.nfds;
-} // uNBIO::uSelect
+    return node.nfds;
+} // uNBIO::select
 
 
-bool uNBIO::uInitMfds( fd_mask nfds, uNBIOnode &uNode ) {
+bool uNBIO::initMfds( fd_mask nfds, NBIOnode &node ) {
     if ( nfds > maxFD ) {				// increase maxFD if necessary
 	maxFD = nfds - 1;
     } // if
@@ -646,20 +651,20 @@ bool uNBIO::uInitMfds( fd_mask nfds, uNBIOnode &uNode ) {
     // set the appropriate fd bits in the master fd mask
     for ( unsigned int i = 0; i < howmany( nfds, NFDBITS ); i += 1 ) {
 	// mask pointers can be NULL => nothing in that mask
-    	if ( uNode.smfd.mfd.uRFDs ) uRFDs.fds_bits[i] |= uNode.smfd.mfd.uRFDs->fds_bits[i];
-    	if ( uNode.smfd.mfd.uWFDs ) uWFDs.fds_bits[i] |= uNode.smfd.mfd.uWFDs->fds_bits[i];
-    	if ( uNode.smfd.mfd.uEFDs ) uEFDs.fds_bits[i] |= uNode.smfd.mfd.uEFDs->fds_bits[i];
+    	if ( node.smfd.mfd.uRFDs ) uRFDs.fds_bits[i] |= node.smfd.mfd.uRFDs->fds_bits[i];
+    	if ( node.smfd.mfd.uWFDs ) uWFDs.fds_bits[i] |= node.smfd.mfd.uWFDs->fds_bits[i];
+    	if ( node.smfd.mfd.uEFDs ) uEFDs.fds_bits[i] |= node.smfd.mfd.uEFDs->fds_bits[i];
     } // for
 
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uNBIO &)0x%p.uInitMfds, adding node 0x%p\n", this, &uNode );
+    uDebugPrt( "(uNBIO &)0x%p.initMfds, adding node 0x%p\n", this, &node );
 #endif // __U_DEBUG_H__
 
-    return uCheckPoller( uNode );
-} // uNBIO::uInitMfds
+    return checkPoller( node );
+} // uNBIO::initMfds
 
      
-bool uNBIO::uInitMfds( fd_mask nfds, uNBIOnode &uNode, uEventNode &uTimeoutEvent ) {
+bool uNBIO::initMfds( fd_mask nfds, NBIOnode &node, uEventNode &uTimeoutEvent ) {
     if ( nfds > maxFD ) {				// increase maxFD if necessary
 	maxFD = nfds - 1;
     } // if
@@ -667,51 +672,51 @@ bool uNBIO::uInitMfds( fd_mask nfds, uNBIOnode &uNode, uEventNode &uTimeoutEvent
     // set the appropriate fd bits in the master fd mask
     for ( unsigned int i = 0; i < howmany( nfds, NFDBITS ); i += 1 ) {
 	// mask pointers can be NULL => nothing in that mask
-    	if ( uNode.smfd.mfd.uRFDs ) uRFDs.fds_bits[i] |= uNode.smfd.mfd.uRFDs->fds_bits[i];
-    	if ( uNode.smfd.mfd.uWFDs ) uWFDs.fds_bits[i] |= uNode.smfd.mfd.uWFDs->fds_bits[i];
-    	if ( uNode.smfd.mfd.uEFDs ) uEFDs.fds_bits[i] |= uNode.smfd.mfd.uEFDs->fds_bits[i];
+    	if ( node.smfd.mfd.uRFDs ) uRFDs.fds_bits[i] |= node.smfd.mfd.uRFDs->fds_bits[i];
+    	if ( node.smfd.mfd.uWFDs ) uWFDs.fds_bits[i] |= node.smfd.mfd.uWFDs->fds_bits[i];
+    	if ( node.smfd.mfd.uEFDs ) uEFDs.fds_bits[i] |= node.smfd.mfd.uEFDs->fds_bits[i];
     } // for
 
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uNBIO &)0x%p.uInitMfds, adding node 0x%p\n", this, &uNode );
+    uDebugPrt( "(uNBIO &)0x%p.initMfds, adding node 0x%p\n", this, &node );
 #endif // __U_DEBUG_H__
 
     uTimeoutEvent.add();
 
-    return uCheckPoller( uNode );
-} // uNBIO::uInitMfds
+    return checkPoller( node );
+} // uNBIO::initMfds
 
 
-int uNBIO::uSelect( fd_mask nfds, fd_set *rfds, fd_set *wfds, fd_set *efds, timeval *timeout ) {
+int uNBIO::select( fd_mask nfds, fd_set *rfds, fd_set *wfds, fd_set *efds, timeval *timeout ) {
 #ifdef __U_DEBUG_H__
 #if 1
     int i;
     int tmasks = howmany( FD_SETSIZE, NFDBITS );	// total number of masks in fd set
-    uDebugPrt( "(uNBIO &)0x%p.uSelect2, nfds:%ld\n", this, nfds );
+    uDebugPrt( "(uNBIO &)0x%p.select2, nfds:%ld\n", this, nfds );
     uDebugAcquire();
     if ( rfds != NULL ) {
-	uDebugPrt2( "(uNBIO &)0x%p.uSelect2, rfds:", this );
+	uDebugPrt2( "(uNBIO &)0x%p.select2, rfds:", this );
 	for ( i = 0; i < tmasks; i += 1 ) {
 	    uDebugPrt2( "%lx ", rfds->fds_bits[i] );
 	} // for
 	uDebugPrt2( "\n" );
     } // if
     if ( wfds != NULL ) {
-	uDebugPrt2( "        (uNBIO &)0x%p.uSelect2, wfds:", this );
+	uDebugPrt2( "        (uNBIO &)0x%p.select2, wfds:", this );
 	for ( i = 0; i < tmasks; i += 1 ) {
 	    uDebugPrt2( "%lx ", wfds->fds_bits[i] );
 	} // for
 	uDebugPrt2( "\n" );
     } // if
     if ( efds != NULL ) {
-	uDebugPrt2( "        (uNBIO &)0x%p.uSelect2, efds:", this );
+	uDebugPrt2( "        (uNBIO &)0x%p.select2, efds:", this );
 	for ( i = 0; i < tmasks; i += 1 ) {
 	    uDebugPrt2( "%lx ", efds->fds_bits[i] );
 	} // for
 	uDebugPrt2( "\n" );
     } // if
     if ( timeout != NULL ) {
-	uDebugPrt2( "        (uNBIO &)0x%p.uSelect2, timeout:%ld.%ld\n", this, timeout->tv_sec, timeout->tv_usec );
+	uDebugPrt2( "        (uNBIO &)0x%p.select2, timeout:%ld.%ld\n", this, timeout->tv_sec, timeout->tv_usec );
     } // if
     uDebugRelease();
 #endif
@@ -719,56 +724,56 @@ int uNBIO::uSelect( fd_mask nfds, fd_set *rfds, fd_set *wfds, fd_set *efds, time
 
 #ifdef __U_DEBUG__
     if ( nfds < 1 || FD_SETSIZE < nfds ) {
-	uAbort( "Attempt to select with a file descriptor set size of %ld, which exceeds range 0-%d.",
+	uAbort( "Attempt to select with a file descriptor set size of %ld that exceeds range 0-%d.",
 		(long int)nfds, FD_SETSIZE );
     } // if
 #endif // __U_DEBUG__
 
-    uNBIOnode uNode;
-    uNode.nfds = 0;
-    uNode.uPendingTask = &uThisTask();
-    uNode.fdType = uNBIOnode::multipleFds;
-    uNode.uTimedout = false;
-    uNode.smfd.mfd.uNFDs = nfds;
-    uNode.smfd.mfd.uRFDs = rfds;
-    uNode.smfd.mfd.uWFDs = wfds;
-    uNode.smfd.mfd.uEFDs = efds;
+    NBIOnode node;
+    node.nfds = 0;
+    node.pendingTask = &uThisTask();
+    node.fdType = NBIOnode::multipleFds;
+    node.timedout = false;
+    node.smfd.mfd.uNFDs = nfds;
+    node.smfd.mfd.uRFDs = rfds;
+    node.smfd.mfd.uWFDs = wfds;
+    node.smfd.mfd.uEFDs = efds;
 
     if ( timeout != NULL ) {				// timeout ?
 	if ( timeout->tv_sec == 0 && timeout->tv_usec == 0 ) { // optimization
 	    // It is unnecessary to create a timeout event for this trivial
 	    // case. Just mark the timeout as having already occurred.
 
-	    uNode.uTimedout = true;
-	    if ( uInitMfds( nfds, uNode ) ) {		// poller task ?
-		while ( uPollIO( uNode ) ) uThisTask().yield(); // busy wait
+	    node.timedout = true;
+	    if ( initMfds( nfds, node ) ) {		// poller task ?
+		while ( pollIO( node ) ) uThisTask().uYieldNoPoll(); // busy wait
 	    } // if
 	} else {
 	    uDuration delay( timeout->tv_sec, timeout->tv_usec * 1000 );
-	    uTime time = uActiveProcessorKernel->uKernelClock.getTime() + delay;
-	    uSelectTimeoutHndlr handler( uThisTask(), uNode );
+	    uTime time = activeProcessorKernel->kernelClock.getTime() + delay;
+	    uSelectTimeoutHndlr handler( uThisTask(), node );
 
 	    uEventNode uTimeoutEvent( uThisTask(), handler, time ); // event node for event list
-	    uTimeoutEvent.uExecuteLocked = true;
+	    uTimeoutEvent.executeLocked = true;
 
-	    if ( uInitMfds( nfds, uNode, uTimeoutEvent ) ) { // poller task ?
-		while ( uPollIO( uNode ) ) uThisTask().yield(); // busy wait
+	    if ( initMfds( nfds, node, uTimeoutEvent ) ) { // poller task ?
+		while ( pollIO( node ) ) uThisTask().uYieldNoPoll(); // busy wait
 	    } // if
 
 	    // always doing remove guarantees the node is not deallocated prematurely
 	    uTimeoutEvent.remove();
 	} // if
     } else {
-	if ( uInitMfds( nfds, uNode ) ) {		// poller task ?
-	    while ( uPollIO( uNode ) ) uThisTask().yield(); // busy wait
+	if ( initMfds( nfds, node ) ) {			// poller task ?
+	    while ( pollIO( node ) ) uThisTask().uYieldNoPoll(); // busy wait
 	} // if
     } // if
 
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uNBIO &)0x%p.uSelect2, exits, cnt:%d\n", this, uNode.nfds );
+    uDebugPrt( "(uNBIO &)0x%p.select2, exits, cnt:%d\n", this, node.nfds );
 #endif // __U_DEBUG_H__
-    return uNode.nfds;
-} // uNBIO::uSelect
+    return node.nfds;
+} // uNBIO::select
 
  
 // Local Variables: //
