@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uProcessor.h -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Thu May 26 09:36:12 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Jun 13 15:34:38 2005
-// Update Count     : 36
+// Last Modified On : Wed Jan 25 08:59:43 2006
+// Update Count     : 47
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -33,26 +33,26 @@
 
 
 _Task uProcessorTask {
-    friend class uProcessor;				// access: uSetPreemption
+    friend class uProcessor;				// access: setPreemption
 
-    uProcessor &uProc;					// associated processor
-    uCondition uResult;
+    uProcessor &processor;				// associated processor
+    uCondition result;
 
 
-    int uPreemption;					// communication: uSetPreemption
-    uCluster *uClus;					// communication: uSetCluster
-    uProcessor *uCreateProc;				// communication: uProcCreate
-    uPid_t uPid;					// communication: uProcWait
-    int uRetCode;					// communication: uProcExit
+    unsigned int preemption;				// communication: setPreemption
+    uCluster *cluster;					// communication: setCluster
+    uProcessor *createProc;				// communication: procCreate
+    uPid_t pid;						// communication: procWait
+    int retCode;					// communication: procExit
 
     void main();
     _Mutex void setPreemption( unsigned int ms );
-    _Mutex void setCluster( uCluster &clus );
-    _Mutex pid_t uProcCreate( uProcessor *np );
-    _Mutex void uProcWait( uPid_t pid );
-    _Mutex void uProcExit( int retcode ) __attribute__(( noreturn ));
+    _Mutex void setCluster( uCluster &cluster );
+    _Mutex pid_t procCreate( uProcessor *processor );
+    _Mutex void procWait( uPid_t pid );
+    _Mutex void procExit( int retcode ) __attribute__(( noreturn ));
 
-    uProcessorTask( uCluster &uClus, uProcessor &uProc );
+    uProcessorTask( uCluster &cluster, uProcessor &processor );
     ~uProcessorTask();
   public:
 }; // uProcessorTask
