@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uSignal.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Sun Dec 19 16:32:13 1993
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Jun 25 21:28:07 2005
-// Update Count     : 639
+// Last Modified On : Tue Sep 12 08:07:09 2006
+// Update Count     : 656
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -40,7 +40,7 @@
 // Binding of signal numbers to meaning is not unique on UNIX systems. A
 // meaningful description is generated for the most common signals.
 // (Designators would allow the descriptions to be in an array.)
-static const char *uSignalDescription( int sig ) {
+static const char *signalDescription( int sig ) {
     switch ( sig ) {
       case SIGHUP:
 	return "hangup";
@@ -79,12 +79,12 @@ static const char *uSignalDescription( int sig ) {
       default:
 	return "";
     } // switch
-}; // uSignalDescription
+}; // signalDescription
 
 
-void uSigHandlerModule::uSSignal( int sig, void (*handler)(__U_SIGPARMS__), int flags ) { // name clash with uSignal statement
+void uSigHandlerModule::signal( int sig, void (*handler)(__U_SIGPARMS__), int flags ) { // name clash with uSignal statement
     struct sigaction act;
-    *(void (**)(__U_SIGPARMS__))(&act.sa_sigaction) = handler; // cast because handler type is inconsistent
+    act.sa_sigaction = (void (*)(int, siginfo_t*, void*))handler;
     sigemptyset( &act.sa_mask );
     sigaddset( &act.sa_mask, SIGALRM );			// disable during signal handler
     sigaddset( &act.sa_mask, SIGVTALRM );
@@ -93,16 +93,22 @@ void uSigHandlerModule::uSSignal( int sig, void (*handler)(__U_SIGPARMS__), int
 
     if ( sigaction( sig, &act, NULL ) == -1 ) {
 	// THE KERNEL IS NOT STARTED SO CALL NO uC++ ROUTINES!
-	fprintf( stderr, " uSigHandlerModule::uSSignal( sig:%d, handler:0x%p, flags:%d ), problem installing signal handler, error(%d) %s.\n",
+	fprintf( stderr, " uSigHandlerModule::signal( sig:%d, handler:0x%p, flags:%d ), problem installing signal handler, error(%d) %s.\n",
 		 sig, handler, flags, errno, strerror( errno ) );
 	_exit( -1 );
     } // if
-} // uSigHandlerModule::uSSignal
+} // uSigHandlerModule::signal
 
 
-void *uSigHandlerModule::uSignalContextPC( __U_SIGCXT__ cxt ) {
+void *uSigHandlerModule::signalContextPC( __U_SIGCXT__ cxt ) {
 #if defined( __i386__ )
+#if defined( __linux__ )
     return (void *)(cxt->uc_mcontext.gregs[REG_EIP]);
+#elif defined( __freebsd__ )
+    return (void *)(cxt->uc_mcontext.mc_eip);
+#else
+    #error uC++ : internal error, unsupported architecture
+#endif // __linux__
 #elif defined( __x86_64__ )
     return (void *)(cxt->uc_mcontext.gregs[REG_RIP]);
 #elif defined( __ia64__ )
@@ -114,30 +120,30 @@ void *uSigHandlerModule::uSignalContextPC( __U_SIGCXT__ cxt ) {
 #else
     #error uC++ : internal error, unsupported architecture
 #endif
-} // uSigHandlerModule::uSignalContextPC
+} // uSigHandlerModule::signalContextPC
 
 
-void uSigHandlerModule::uSigChldHandler( __U_SIGPARMS__ ) {
+void uSigHandlerModule::sigChldHandler( __U_SIGPARMS__ ) {
     // The SIGCHLD signal is delivered as the result of a child process
     // terminating.  If the child process terminates because of some error, the
     // application is terminated.
 
-  if ( uKernelModule::uGlobalAbort ) return;		// close down in progress, ignore signal
+  if ( uKernelModule::globalAbort ) return;		// close down in progress, ignore signal
 
     pid_t pid;
     int status = 0;
 
     // SIGALRM is masked so no EINTR looping.
     pid = ::waitpid( -1, &status, WNOHANG );		// grab the pid of any child and its exit status
-    // uProcWait and uSigChldHandler race to wait on the pid for normal
+    // procWait and sigChldHandler race to wait on the pid for normal
     // termination so the loser ignores the ECHILD.
     if ( pid == -1 && errno != ECHILD ) {
-	uAbort( "uSigHandlerModule::uSigChldHandler : internal error, error(%d) %s.", errno, strerror( errno ) );
+	uAbort( "uSigHandlerModule::sigChldHandler : internal error, error(%d) %s.", errno, strerror( errno ) );
     } // if
 
 #ifdef __U_DEBUG_H__
     char buffer[256];
-    uDebugPrtBuf( buffer, "uSigChldHandler, pid:%ld, status:0x%x, uThisTask:%.256s (0x%p), uThisCoroutine:0x%p\n",
+    uDebugPrtBuf( buffer, "sigChldHandler, pid:%ld, status:0x%x, uThisTask:%.256s (0x%p), uThisCoroutine:0x%p\n",
 		  (long int)pid, status, uThisTask().getName(), &uThisTask(), &uThisCoroutine() );
 #endif // __U_DEBUG_H__
 
@@ -146,16 +152,16 @@ void uSigHandlerModule::uSigChldHandler( __U_SIGPARMS__ ) {
     // well, the uProcWait may have already reaped the process sending the
     // sigchld but there are still running child processes.
 
-    if ( pid > 0 && WIFSIGNALED( status ) ) {		// process died as the result of some signal ?
+    if ( pid > 0 && WIFSIGNALED( status ) && ! uKernelModule::inExit ) { // process died as the result of some signal ?
 	// Terminate the application with an appropriate error message.
 
-	uKernelModule::uCoreDumped = true;		// assume the child dumped core
-	uAbort( "Child process %ld died with signal %d %s.", (long int)pid, WTERMSIG( status ), uSignalDescription( WTERMSIG( status ) ) );
+	uKernelModule::coreDumped = true;		// assume the child dumped core
+	uAbort( "Child process %ld died with signal %d %s.", (long int)pid, WTERMSIG( status ), signalDescription( WTERMSIG( status ) ) );
     } // if
-} // uSigHandlerModule::uSigChldHandler
+} // uSigHandlerModule::sigChldHandler
 
 
-void uSigHandlerModule::uSigTermHandler( __U_SIGTYPE__ ) {
+void uSigHandlerModule::sigTermHandler( __U_SIGTYPE__ ) {
     // This routine handles a SIGHUP, SIGINT, or a SIGTERM signal.  The signal
     // is delivered to the root process as the result of some action on the
     // part of the user attempting to terminate the application.  It must be
@@ -163,17 +169,17 @@ void uSigHandlerModule::uSigTermHandler( __U_SIGTYPE__ ) {
 
 #ifdef __U_DEBUG_H__
     char buffer[256];
-    uDebugPrtBuf( buffer, "uSigTermHandler, cluster:%.256s (0x%p), processor:0x%p\n",
+    uDebugPrtBuf( buffer, "sigTermHandler, cluster:%.256s (0x%p), processor:0x%p\n",
 		  uThisCluster().getName(), &uThisCluster(), &uThisProcessor() );
 #endif // __U_DEBUG_H__
 
-  if ( uKernelModule::uGlobalAbort ) return;		// close down in progress, ignore signal
+  if ( uKernelModule::globalAbort ) return;		// close down in progress, ignore signal
 
     uAbort( "Application interrupted by a termination signal." );
-} // uSigHandlerModule::uSigTermHandler
+} // uSigHandlerModule::sigTermHandler
 
 
-void uSigHandlerModule::uSigAlrmHandler( __U_SIGPARMS__ ) {
+void uSigHandlerModule::sigAlrmHandler( __U_SIGPARMS__ ) {
 #ifdef __U_DEBUG_H__
     char buffer[256];
 #endif // __U_DEBUG_H__
@@ -193,50 +199,50 @@ void uSigHandlerModule::uSigAlrmHandler( __U_SIGPARMS__ ) {
     // a thread.  This handler attempts to yield the currently executing thread
     // so that another thread may be scheduled by this processor.
 
-  if ( uKernelModule::uGlobalAbort ) return;		// close down in progress, ignore signal
-  if ( THREAD_GETMEM( InKernelRF ) ) {			// roll-forward flag on ? spurious alarm
+  if ( uKernelModule::globalAbort ) return;		// close down in progress, ignore signal
+  if ( THREAD_GETMEM( inKernelRF ) ) {			// roll-forward flag on ? spurious alarm
       // set roll forward to 2 to detect alarms during roll forward
-      THREAD_SETMEM( InKernelRF, 2 );
+      THREAD_SETMEM( inKernelRF, 2 );
       return;
   } // if
 
     int terrno = errno;
 
-    if ( THREAD_GETMEM( uDisableInt ) || THREAD_GETMEM( uDisableIntSpin ) ) { // inside the kernel or spinlock acquired
+    if ( THREAD_GETMEM( disableInt ) || THREAD_GETMEM( disableIntSpin ) ) { // inside the kernel or spinlock acquired
 #ifdef __U_DEBUG_H__
-	    uDebugPrtBuf( buffer, "uSigAlrmHandler1, task:0x%p, stack:0x%p, address:0x%p, uDisableInt:%d, uDisableIntCnt:%d\n",
+	    uDebugPrtBuf( buffer, "sigAlrmHandler1, task:0x%p, stack:0x%p, address:0x%p, disableInt:%d, disableIntCnt:%d\n",
 #if defined( __solaris__ ) || defined( __irix__ )
-			  &uThisTask(), uThisTask().stackPointer(), uSignalContextPC( cxt ),
-			  THREAD_GETMEM( uDisableInt ), THREAD_GETMEM( uDisableIntCnt ) );
+			  &uThisTask(), uThisTask().stackPointer(), signalContextPC( cxt ),
+			  THREAD_GETMEM( disableInt ), THREAD_GETMEM( disableIntCnt ) );
 #elif defined( __ia64__ )
-	                  &uThisTask(), cxt->uc_stack.ss_sp, uSignalContextPC( cxt ),
-		          THREAD_GETMEM( uDisableInt ), THREAD_GETMEM( uDisableIntCnt ) );
+	                  &uThisTask(), cxt->uc_stack.ss_sp, signalContextPC( cxt ),
+		          THREAD_GETMEM( disableInt ), THREAD_GETMEM( disableIntCnt ) );
 #else
-	    		  &uThisTask(), cxt->sc_sp, uSignalContextPC( cxt ),
-	    		  THREAD_GETMEM( uDisableInt ), THREAD_GETMEM( uDisableIntCnt ) );
+	    		  &uThisTask(), cxt->sc_sp, signalContextPC( cxt ),
+	    		  THREAD_GETMEM( disableInt ), THREAD_GETMEM( disableIntCnt ) );
 #endif
 #endif // __U_DEBUG_H__
-            int newRF = THREAD_GETMEM( InKernelRF ) + 1;
-	    THREAD_SETMEM( InKernelRF, newRF );
+            int newRF = THREAD_GETMEM( inKernelRF ) + 1;
+	    THREAD_SETMEM( inKernelRF, newRF );
     } else {		// and not in kernel or spinlock ?
-	THREAD_SETMEM( InKernelRF, 1 );                    // detect if subsequent interrupts occur
+	THREAD_SETMEM( inKernelRF, 1 );                    // detect if subsequent interrupts occur
 
 	if ( sigprocmask( SIG_SETMASK, (sigset_t *)&(cxt->uc_sigmask), NULL ) == -1 ) { // clear the blocked SIGALRM signal so more can arrive
 	    uAbort( "internal error, sigprocmask" );
 	} // if
-	uAssert( ! sigismember( (sigset_t *)&(cxt->uc_sigmask), SIGUSR1 ) );
+	assert( ! sigismember( (sigset_t *)&(cxt->uc_sigmask), SIGUSR1 ) );
 
 #ifdef __U_DEBUG_H__
-	    uDebugPrtBuf( buffer, "uSigAlrmHandler2, task:0x%p, stack:0x%p, address:0x%p, uDisableInt:%d, uDisableIntCnt:%d\n",
+	    uDebugPrtBuf( buffer, "sigAlrmHandler2, task:0x%p, stack:0x%p, address:0x%p, disableInt:%d, disableIntCnt:%d\n",
 #if defined( __solaris__ ) || defined( __irix__ )
-			  &uThisTask(), uThisTask().stackPointer(), uSignalContextPC( cxt ),
-			  THREAD_GETMEM( uDisableInt ), THREAD_GETMEM( uDisableIntCnt ) );
+			  &uThisTask(), uThisTask().stackPointer(), signalContextPC( cxt ),
+			  THREAD_GETMEM( disableInt ), THREAD_GETMEM( disableIntCnt ) );
 #elif defined( __ia64__ )
-	                  &uThisTask(), cxt->uc_stack.ss_sp, uSignalContextPC( cxt ),
-		          THREAD_GETMEM( uDisableInt ), THREAD_GETMEM( uDisableIntCnt ) );
+	                  &uThisTask(), cxt->uc_stack.ss_sp, signalContextPC( cxt ),
+		          THREAD_GETMEM( disableInt ), THREAD_GETMEM( disableIntCnt ) );
 #else
-	    		  &uThisTask(), cxt->sc_sp, uSignalContextPC( cxt ),
-	    		  THREAD_GETMEM( uDisableInt ), THREAD_GETMEM( uDisableIntCnt ) );
+	    		  &uThisTask(), cxt->sc_sp, signalContextPC( cxt ),
+	    		  THREAD_GETMEM( disableInt ), THREAD_GETMEM( disableIntCnt ) );
 #endif
 #endif // __U_DEBUG_H__
 
@@ -245,16 +251,16 @@ void uSigHandlerModule::uSigAlrmHandler( __U_SIGPARMS__ ) {
 	// debugger to check if the task was time sliced at a breakpoint
 	// location.
 
-	uThisTask().DebugPCandSRR = uSignalContextPC( cxt );
+	uThisTask().debugPCandSRR = signalContextPC( cxt );
 #endif // __U_DEBUG__
 
-	THREAD_GETMEM( uSelf )->rollForward();
+	uKernelModule::rollForward();
 
 #ifdef __U_DEBUG__
 	// Reset this field before task is started, to denote that this task is
 	// not blocked.
 
-	uThisTask().DebugPCandSRR = NULL;
+	uThisTask().debugPCandSRR = NULL;
 #endif // __U_DEBUG__
 
 #if 0							// TEMPORARY: unnecessary code ?
@@ -276,15 +282,17 @@ void uSigHandlerModule::uSigAlrmHandler( __U_SIGPARMS__ ) {
     } // if
 
 #ifdef __U_MULTI__
-#if defined( __i386__ ) && ! defined( __U_PTHREAD__ )
+#if defined( __linux__ ) && defined( __i386__ ) && ! defined( __U_PTHREAD__ )
     ((ucontext_t *)cxt)->uc_mcontext.gregs[REG_GS] = THREAD_GETMEM( ldtValue );
 #elif defined( __ia64__ )
     ((ucontext_t *)cxt)->uc_mcontext.sc_gr[13] = (unsigned long)THREAD_GETMEM( threadPointer );
 #elif defined( __sparc__ )
-    ((ucontext_t *)cxt)->uc_mcontext.gregs[REG_G7] = (greg_t)THREAD_GETMEM( uSelf );
+    ((ucontext_t *)cxt)->uc_mcontext.gregs[REG_G7] = (greg_t)THREAD_GETMEM( This );
+#elif defined( __freebsd__ ) && defined( __i386__ )
+    ((ucontext_t *)cxt)->uc_mcontext.mc_gs = THREAD_GETMEM( ldtValue );
 #endif
 #ifdef __U_ONETIMER__
-    if ( &uThisProcessor() == uKernelModule::uSystemProcessor ) {
+    if ( &uThisProcessor() == uKernelModule::systemProcessor ) {
 	sigdelset( (sigset_t *)&(cxt->uc_sigmask), SIGALRM );
     } else {
 	sigaddset( (sigset_t *)&(cxt->uc_sigmask), SIGALRM );
@@ -293,27 +301,30 @@ void uSigHandlerModule::uSigAlrmHandler( __U_SIGPARMS__ ) {
 #endif // __U_MULTI__
 
     errno = terrno;
-} // uSigHandlerModule::uSigAlrmHandler
+} // uSigHandlerModule::sigAlrmHandler
 
 
-void uSigHandlerModule::uSigSegvBusHandler( __U_SIGPARMS__ ) {
+void uSigHandlerModule::sigSegvBusHandler( __U_SIGPARMS__ ) {
+  if ( uKernelModule::globalAbort ) return;		// close down in progress, ignore signal
     uAbort( "Attempt to address location 0x%p.\n"
             "Possible cause is reading outside the address space or writing to a protected area within the address space with an invalid pointer or subscript.",
 	    sfp->si_addr );
-} // uSigHandlerModule::uSigSegvBusHandler
+} // uSigHandlerModule::sigSegvBusHandler
 
 
-void uSigHandlerModule::uSigIllHandler( __U_SIGPARMS__ ) {
+void uSigHandlerModule::sigIllHandler( __U_SIGPARMS__ ) {
+  if ( uKernelModule::globalAbort ) return;		// close down in progress, ignore signal
     uAbort( "Attempt to execute code at location 0x%p.\n"
             "Possible cause is stack corruption.",
 	    sfp->si_addr );
-} // uSigHandlerModule::uSigIllHandler
+} // uSigHandlerModule::sigIllHandler
 
 
-void uSigHandlerModule::uSigFpeHandler( __U_SIGPARMS__ ) {
+void uSigHandlerModule::sigFpeHandler( __U_SIGPARMS__ ) {
+  if ( uKernelModule::globalAbort ) return;		// close down in progress, ignore signal
     uAbort( "Floating point error.\n"
             "Possible cause is division by zero." );
-} // uSigHandlerModule::uSigFpeHandler
+} // uSigHandlerModule::sigFpeHandler
 
 
 uSigHandlerModule::uSigHandlerModule() {
@@ -321,21 +332,21 @@ uSigHandlerModule::uSigHandlerModule() {
     // interested in.  These handlers are inherited by all unix processes that
     // are subsequently created so they need not be installed again.
 
-    uSSignal( SIGCHLD, uSigChldHandler, SA_SIGINFO );
-    uSSignal( SIGHUP,  uSigTermHandler, SA_SIGINFO );
-    uSSignal( SIGINT,  uSigTermHandler, SA_SIGINFO );
-    uSSignal( SIGTERM, uSigTermHandler, SA_SIGINFO );
-    uSSignal( SIGSEGV, uSigSegvBusHandler, SA_SIGINFO );
-    uSSignal( SIGBUS,  uSigSegvBusHandler, SA_SIGINFO );
-    uSSignal( SIGILL,  uSigIllHandler, SA_SIGINFO );
-    uSSignal( SIGFPE,  uSigFpeHandler, SA_SIGINFO );
+    signal( SIGCHLD, sigChldHandler, SA_SIGINFO );
+    signal( SIGHUP,  sigTermHandler, SA_SIGINFO );
+    signal( SIGINT,  sigTermHandler, SA_SIGINFO );
+    signal( SIGTERM, sigTermHandler, SA_SIGINFO );
+    signal( SIGSEGV, sigSegvBusHandler, SA_SIGINFO );
+    signal( SIGBUS,  sigSegvBusHandler, SA_SIGINFO );
+    signal( SIGILL,  sigIllHandler, SA_SIGINFO );
+    signal( SIGFPE,  sigFpeHandler, SA_SIGINFO );
 
     // Do NOT specify SA_RESTART for SIGALRM because "select" does not wake up
     // when sent a SIGALRM from another UNIX process, which means non-blocking
     // I/O does not work correctly in multiprocessor mode.
 
-    uSSignal( SIGALRM, uSigAlrmHandler, SA_SIGINFO );
-    uSSignal( SIGUSR1, uSigAlrmHandler, SA_SIGINFO );
+    signal( SIGALRM, sigAlrmHandler, SA_SIGINFO );
+    signal( SIGUSR1, sigAlrmHandler, SA_SIGINFO );
 } // uSigHandlerModule::uSigHandlerModule
 
 
