@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1998
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1998
 // 
 // uSystemTask.h -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Jun 22 15:23:25 1998
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Jun 13 15:34:46 2005
-// Update Count     : 17
+// Last Modified On : Thu Aug 10 17:08:41 2006
+// Update Count     : 19
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -30,19 +30,12 @@
 
 
 _Task uSystemTask {
-    friend _Task uMain;				// access: pthreadDetach, pthreadCheck
-    friend _Task uPThread;				// access: pthreadDetachStart, pthreadDetachEnd
+    friend _Task Pthread;				// access: pthreadDetachEnd
 
     uBaseTask *victim;					// communication
 
     // pthread
 
-    static volatile bool pthreadDetach;			// optimization: prevent uMain calling pthreadCheck if no detached pthreads
-    unsigned int pthreadDetachCnt;
-    uCondition detached;
-
-    _Mutex void pthreadCheck();
-    _Mutex void pthreadDetachStart();
     _Mutex void pthreadDetachEnd( uBaseTask &victim );
 
     void main();
