@@ -1,16 +1,17 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 2002
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 2002
 // 
 // Unix.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Dec  2 22:46:18 2002
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Aug 12 17:24:57 2005
-// Update Count     : 19
+// Last Modified On : Fri Sep  1 15:46:16 2006
+// Update Count     : 20
 // 
 
+#define __U_KERNEL__
 #include <uC++.h>
 //#include <uDebug.h>
 
