@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 2002
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 2002
 // 
 // semaphore.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Sun Jan 20 20:34:08 2002
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Dec 21 11:22:56 2005
-// Update Count     : 53
+// Last Modified On : Fri Sep  1 15:42:18 2006
+// Update Count     : 55
 // 
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -24,6 +24,7 @@
 // along  with this library.
 
 
+#define __U_KERNEL__
 #include <uC++.h>
 #include <uSemaphore.h>
 #include <semaphore.h>
@@ -46,6 +47,8 @@ extern "C" {
 	return 0;
     } // sem_wait
 
+// sem_timedwait()         XOPEN extension
+
     int sem_trywait( sem_t *sem ) __THROW {
 	if ( ! ((uSemaphore *)sem)->TryP() ) {
 	    errno = EAGAIN;
