@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uFile.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Tue Mar 29 16:42:36 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Jun 24 14:48:32 2005
-// Update Count     : 293
+// Last Modified On : Tue Jan 24 18:17:55 2006
+// Update Count     : 305
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -50,8 +50,8 @@ void uFile::unaccess() {
 
 
 void uFile::uCreateFile( const char *name ) {
-    uName = new char[strlen( name ) + 1];
-    strcpy( uName, name );
+    uFile::name = new char[strlen( name ) + 1];
+    strcpy( uFile::name, name );
     accessCnt = 0;
 } // uFile::uCreateFile
 
@@ -63,7 +63,7 @@ uFile::uFile( const char *name ) {
 
 uFile::~uFile() {
     TerminateFailure temp( *this, accessCnt, "terminating access with outstanding accessor(s)" );
-    if ( uName != 0 ) delete uName;			// safe to delete name as the name is copied in the exception object
+    if ( name != 0 ) delete name;			// safe to delete name as the name is copied in the exception object
     if ( accessCnt != 0 ) {
 	if ( ! std::uncaught_exception() ) _Throw temp;
     } // if
@@ -73,9 +73,9 @@ uFile::~uFile() {
 const char *uFile::getName() const {
     return
 #ifdef __U_DEBUG__
-	( uName == NULL || uName == (const char *)-1 ) ? "*unknown*" : // storage might be scrubbed
+	( name == NULL || name == (const char *)-1 ) ? "*unknown*" : // storage might be scrubbed
 #endif // __U_DEBUG__
-	uName;
+	name;
 } // uFile::getName
 
 
@@ -83,7 +83,7 @@ void uFile::status( struct stat &buf ) {
     int code;
 
     for ( ;; ) {
-	code = ::stat( uName, &buf );
+	code = ::stat( name, &buf );
       if ( code != -1 ) break;
       if ( errno != EINTR ) break;			// timer interrupt ?
     } // for
@@ -105,52 +105,52 @@ uFileIO::~uFileIO() {
 
 
 int uFileIO::_read( char *buf, int len ) {
-    if ( access.poll.uGetStatus() == uPoll::uPollOnDemand ) access.poll.uSetPollFlag( access.fd );
+    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.setPollFlag( access.fd );
     int rlen = ::read( access.fd, buf, len );
     int terrno = errno;					// preserve errno across calls
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uFileIO &)0x%p._read attempting read to fd:%d, rlen:%d, errno:%d\n", this, access.fd, rlen, errno );
 #endif // __U_DEBUG_H__
-    if ( access.poll.uGetStatus() == uPoll::uPollOnDemand ) access.poll.uClearPollFlag( access.fd );
+    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.clearPollFlag( access.fd );
     errno = terrno;
     return rlen;
 } // uFileIO::_read
 
 
 int uFileIO::_readv( const struct iovec *iov, int iovcnt ) {
-    if ( access.poll.uGetStatus() == uPoll::uPollOnDemand ) access.poll.uSetPollFlag( access.fd );
+    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.setPollFlag( access.fd );
     int rlen = ::readv( access.fd, iov, iovcnt );
     int terrno = errno;					// preserve errno across calls
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uFileIO &)0x%p._readv attempting readv to fd:%d, rlen:%d, errno:%d\n", this, access.fd, rlen, errno );
 #endif // __U_DEBUG_H__
-    if ( access.poll.uGetStatus() == uPoll::uPollOnDemand ) access.poll.uClearPollFlag( access.fd );
+    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.clearPollFlag( access.fd );
     errno = terrno;
     return rlen;
 } // uFileIO::_readv
 
 
 int uFileIO::_write( char *buf, int len ) {
-    if ( access.poll.uGetStatus() == uPoll::uPollOnDemand ) access.poll.uSetPollFlag( access.fd );
+    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.setPollFlag( access.fd );
     int wlen = ::write( access.fd, buf, len );
     int terrno = errno;					// preserve errno across calls
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uFileIO &)0x%p._write attempting write to fd:%d, wlen:%d, errno:%d\n", this, access.fd, wlen, errno );
 #endif // __U_DEBUG_H__
-    if ( access.poll.uGetStatus() == uPoll::uPollOnDemand ) access.poll.uClearPollFlag( access.fd );
+    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.clearPollFlag( access.fd );
     errno = terrno;
     return wlen;
 } // uFileIO::_write
 
 
 int uFileIO::_writev( const struct iovec *iov, int iovcnt ) {
-    if ( access.poll.uGetStatus() == uPoll::uPollOnDemand ) access.poll.uSetPollFlag( access.fd );
+    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.setPollFlag( access.fd );
     int wlen = ::writev( access.fd, iov, iovcnt );
     int terrno = errno;					// preserve errno across calls
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uFileIO &)0x%p._writev attempting writev to fd:%d, wlen:%d, errno:%d\n", this, access.fd, wlen, errno );
 #endif // __U_DEBUG_H__
-    if ( access.poll.uGetStatus() == uPoll::uPollOnDemand ) access.poll.uClearPollFlag( access.fd );
+    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.clearPollFlag( access.fd );
     errno = terrno;
     return wlen;
 } // uFileIO::_writev
@@ -168,12 +168,12 @@ int uFileIO::read( char *buf, int len, uDuration *timeout ) {
       if ( rlen != -1 ) break;
       if ( ! ( errno == EINTR || errno == U_EWOULDBLOCK ) ) break;
 	if ( errno == U_EWOULDBLOCK ) {
-	    int mask = uCluster::uReadSelect;
+	    int mask = uCluster::readSelect;
 	    if ( timeout == NULL ) {
-		uThisCluster().uSelect( access.fd, mask );
+		uThisCluster().select( access.fd, mask );
 	    } else {
 		timeval t = *timeout;			// convert to timeval for select
-		if ( uThisCluster().uSelect( access.fd, mask, &t ) == 0 ) { // timeout ?
+		if ( uThisCluster().select( access.fd, mask, &t ) == 0 ) { // timeout ?
 		    readTimeout( buf, len, timeout, "read" );
 		} // if
 	    } // if
@@ -203,12 +203,12 @@ int uFileIO::readv( const struct iovec *iov, int iovcnt, uDuration *timeout ) {
       if ( rlen != -1 ) break;
       if ( ! ( errno == EINTR || errno == U_EWOULDBLOCK ) ) break;
 	if ( errno == U_EWOULDBLOCK ) {
-	    int mask = uCluster::uReadSelect;
+	    int mask = uCluster::readSelect;
 	    if ( timeout == NULL ) {
-		uThisCluster().uSelect( access.fd, mask );
+		uThisCluster().select( access.fd, mask );
 	    } else {
 		timeval t = *timeout;			// convert to timeval for select
-		if ( uThisCluster().uSelect( access.fd, mask, &t ) == 0 ) { // timeout ?
+		if ( uThisCluster().select( access.fd, mask, &t ) == 0 ) { // timeout ?
 		    readTimeout( (const char *)iov, iovcnt, timeout, "readv" );
 		} // if
 	    } // if
@@ -238,12 +238,12 @@ int uFileIO::write( char *buf, int len, uDuration *timeout ) {
 	  if ( wlen != -1 ) break;
 	  if ( ! ( errno == EINTR || errno == U_EWOULDBLOCK ) ) break;
 	    if ( errno == U_EWOULDBLOCK ) {
-		int mask = uCluster::uWriteSelect;
+		int mask = uCluster::writeSelect;
 		if ( timeout == NULL ) {
-		    uThisCluster().uSelect( access.fd, mask );
+		    uThisCluster().select( access.fd, mask );
 		} else {
 		    timeval t = *timeout;		// convert to timeval for select
-		    if ( uThisCluster().uSelect( access.fd, mask, &t ) == 0 ) { // timeout ?
+		    if ( uThisCluster().select( access.fd, mask, &t ) == 0 ) { // timeout ?
 			writeTimeout( buf, len, timeout, "write" );
 		    } // if
 		} // if
@@ -281,12 +281,12 @@ int uFileIO::writev( const struct iovec *iov, int iovcnt, uDuration *timeout ) {
       if ( wlen != -1 ) break;
       if ( ! ( errno == EINTR || errno == U_EWOULDBLOCK ) ) break;
 	if ( errno == U_EWOULDBLOCK ) {
-	    int mask = uCluster::uWriteSelect;
+	    int mask = uCluster::writeSelect;
 	    if ( timeout == NULL ) {
-		uThisCluster().uSelect( access.fd, mask );
+		uThisCluster().select( access.fd, mask );
 	    } else {
 		timeval t = *timeout;		// convert to timeval for select
-		if ( uThisCluster().uSelect( access.fd, mask, &t ) == 0 ) { // timeout ?
+		if ( uThisCluster().select( access.fd, mask, &t ) == 0 ) { // timeout ?
 		    writeTimeout( (const char *)iov, iovcnt, timeout, "writev" );
 		} // if
 	    } // if
@@ -346,33 +346,33 @@ void uFileAccess::writeTimeout( const char *buf, const int len, const uDuration
 
 uFileAccess::uFileAccess( int fd, uFile &f ) : uFileIO( access ), ufile( f ) {
     access.fd = fd;
-    access.poll.uSetStatus( uPoll::uPollOnDemand );
+    access.poll.setStatus( uPoll::PollOnDemand );
     ufile.access();
 } // uFileAccess::uFileAccess
 
 
 uFileAccess::uFileAccess( uFile &f, int flags, int mode ) : uFileIO( access ), ufile( f ) {
     for ( ;; ) {
-	access.fd = ::open( ufile.uName, flags, mode );
+	access.fd = ::open( ufile.name, flags, mode );
       if ( access.fd != -1 ) break;
       if ( errno != EINTR ) break;			// timer interrupt ?
     } // for
     if ( access.fd == -1 ) {
         _Throw uFileAccess::OpenFailure( *this, flags, mode, "unable to access file" );
     } // if
-    access.poll.uComputeStatus( access.fd );
-    if ( access.poll.uGetStatus() == uPoll::uAlwaysPoll ) access.poll.uSetPollFlag( access.fd );
+    access.poll.computeStatus( access.fd );
+    if ( access.poll.getStatus() == uPoll::AlwaysPoll ) access.poll.setPollFlag( access.fd );
     ufile.access();
 } // uFileAccess::uFileAccess
 
 
 uFileAccess::~uFileAccess() {
     ufile.unaccess();
-    if ( access.poll.uGetStatus() == uPoll::uAlwaysPoll ) access.poll.uClearPollFlag( access.fd );
+    if ( access.poll.getStatus() == uPoll::AlwaysPoll ) access.poll.clearPollFlag( access.fd );
     if ( access.fd >= 3 ) {				// don't close the standard file descriptors
 	int code;
 
-	uThisCluster().uCloseFD( access.fd );
+	uThisCluster().closeFD( access.fd );
 	for ( ;; ) {
 	    code = ::close( access.fd );
 	  if ( code != -1 ) break;
@@ -420,14 +420,14 @@ int uFileAccess::fsync() {
 
 uFile::Failure::Failure( const uFile &f, const char *const msg ) : uIOFailure( msg ), f( f ) {
     // file name is copied because its storage can be freed and scrubbed before handler starts
-    uEHM::uStrncpy( uName, f.getName(), uEHMMaxName );
+    uEHM::strncpy( name, f.getName(), uEHMMaxName );
 } // uFile::Failure::Failure
 
 uFile::Failure::~Failure() {}
 
 const uFile &uFile::Failure::file() const { return f; }
 
-const char *uFile::Failure::getName() const { return uName; }
+const char *uFile::Failure::getName() const { return name; }
 
 void uFile::Failure::defaultTerminate() const {
     uAbort( "(uFile &)0x%p, %.256s \"%.256s\".", &file(), message(), getName() );
