@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uPoll.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Tue Mar 29 17:02:07 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Aug 11 12:18:18 2004
-// Update Count     : 30
+// Last Modified On : Tue Jan 24 18:15:32 2006
+// Update Count     : 39
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -34,7 +34,7 @@
 #include <fcntl.h>
 
 
-void uPoll::uSetPollFlag( int fd ) {
+void uPoll::setPollFlag( int fd ) {
     int flags;
 
     for ( ;; ) {
@@ -43,7 +43,7 @@ void uPoll::uSetPollFlag( int fd ) {
       if ( errno != EINTR ) break;			// timer interrupt ?
     } // for
     if ( flags == -1 ) {
-	uStatus = uNeverPoll;
+	uStatus = NeverPoll;
     } else {
 	for ( ;; ) {
 	    flags = ::fcntl( fd, F_SETFL, flags | U_FNDELAY );
@@ -51,16 +51,16 @@ void uPoll::uSetPollFlag( int fd ) {
 	  if ( errno != EINTR ) break;			// timer interrupt ?
 	} // for
 	if ( flags == -1 ) {
-	    uStatus = uNeverPoll;
+	    uStatus = NeverPoll;
 	} // if
     } // if
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uPoll &)0x%p.uSetPollFlag( %d ), uStatus:%d\n", this, fd, uStatus );
+    uDebugPrt( "(uPoll &)0x%p.setPollFlag( %d ), uStatus:%d\n", this, fd, uStatus );
 #endif // __U_DEBUG_H__
-} // uPoll::uSetPollFlag
+} // uPoll::setPollFlag
 
 
-void uPoll::uClearPollFlag( int fd ) {
+void uPoll::clearPollFlag( int fd ) {
     int flags;
 
     for ( ;; ) {
@@ -69,7 +69,7 @@ void uPoll::uClearPollFlag( int fd ) {
       if ( errno != EINTR ) break;			// timer interrupt ?
     } // for
     if ( flags == -1 ) {
-	uStatus = uNeverPoll;
+	uStatus = NeverPoll;
     } else {
 	for ( ;; ) {
 	    flags = ::fcntl( fd, F_SETFL, flags & ~ U_FNDELAY );
@@ -77,13 +77,13 @@ void uPoll::uClearPollFlag( int fd ) {
 	  if ( errno != EINTR ) break;			// timer interrupt ?
 	} // for
 	if ( flags == -1 ) {
-	    uStatus = uNeverPoll;
+	    uStatus = NeverPoll;
 	} // if
     } // if
-} // uPoll::uClearPollFlag
+} // uPoll::clearPollFlag
 
 
-void uPoll::uComputeStatus( int fd ) {
+void uPoll::computeStatus( int fd ) {
     struct stat buf;
     int flags;
 
@@ -93,35 +93,35 @@ void uPoll::uComputeStatus( int fd ) {
       if ( errno != EINTR ) break;			// timer interrupt ?
     } // for
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uPoll &)0x%p.uComputeStatus( %d ), flags:%d, st_mode:0x%p\n", this, fd, flags, buf.st_mode );
+    uDebugPrt( "(uPoll &)0x%p.computeStatus( %d ), flags:%d, st_mode:0x%x\n", this, fd, flags, buf.st_mode );
 #endif // __U_DEBUG_H__
     if ( flags ) {
-	uStatus = uNeverPoll;				// if the file cannot be stat'ed, never poll
+	uStatus = NeverPoll;				// if the file cannot be stat'ed, never poll
     } else if ( S_ISCHR(buf.st_mode) ) {
-	uStatus = uPollOnDemand;			// if a tty, poll on demand
+	uStatus = PollOnDemand;				// if a tty, poll on demand
 #ifdef S_IFIFO
     } else if ( S_ISFIFO(buf.st_mode) ) {
-	uStatus = uAlwaysPoll;				// if a pipe, always poll
+	uStatus = AlwaysPoll;				// if a pipe, always poll
 #endif
     } else if ( S_ISSOCK(buf.st_mode) ) {
-	uStatus = uAlwaysPoll;				// if a socket, always poll
+	uStatus = AlwaysPoll;				// if a socket, always poll
     } else {
-	uStatus = uNeverPoll;				// otherwise, never
+	uStatus = NeverPoll;				// otherwise, never
     } // if
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uPoll &)0x%p.uComputeStatus( %d ), uStatus:%d\n", this, fd, uStatus );
+    uDebugPrt( "(uPoll &)0x%p.computeStatus( %d ), uStatus:%d\n", this, fd, uStatus );
 #endif // __U_DEBUG_H__
-} // uPoll::uComputeStatus
+} // uPoll::computeStatus
 
 
-void uPoll::uSetStatus( uPollStatus s ) {
+void uPoll::setStatus( PollStatus s ) {
     uStatus = s;
-} // uPoll::uSetStatus
+} // uPoll::setStatus
 
 
-uPoll::uPollStatus uPoll::uGetStatus() {
+uPoll::PollStatus uPoll::getStatus() {
     return uStatus;
-} // uPoll::uGetStatus
+} // uPoll::getStatus
 
 
 // Local Variables: //
