@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uPoll.h -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Tue Mar 29 17:01:20 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jul 24 22:14:03 2003
-// Update Count     : 24
+// Last Modified On : Tue Jan 24 18:14:00 2006
+// Update Count     : 26
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -53,15 +53,15 @@
 
 class uPoll {
   public:
-    enum uPollStatus { uNeverPoll, uPollOnDemand, uAlwaysPoll };
+    enum PollStatus { NeverPoll, PollOnDemand, AlwaysPoll };
   private:
-    uPollStatus uStatus;
+    PollStatus uStatus;
   public:
-    uPollStatus uGetStatus();
-    void uComputeStatus( int fd );
-    void uSetStatus( uPollStatus status );
-    void uSetPollFlag( int fd );
-    void uClearPollFlag( int fd );
+    PollStatus getStatus();
+    void computeStatus( int fd );
+    void setStatus( PollStatus status );
+    void setPollFlag( int fd );
+    void clearPollFlag( int fd );
 };
 
 
