@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 2003
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 2003
 // 
 // uSemaphore.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Thu Nov 20 17:17:52 2003
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 11:17:19 2005
-// Update Count     : 24
+// Last Modified On : Fri Sep  1 15:42:48 2006
+// Update Count     : 31
 // 
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
@@ -26,6 +26,7 @@
 // 
 
 
+#define __U_KERNEL__
 #include <uC++.h>
 #include <uSemaphore.h>
 
@@ -38,10 +39,10 @@ void uSemaphore::P() {					// wait on a semaphore
     spin.acquire();
     count -= 1;
     if ( count < 0 ) {
-	waiting.addTail( &(uThisTask().uEntryRef) );	// block current task
-	THREAD_GETMEM( uSelf)->disableInterrupts();
-	uActiveProcessorKernel->uSchedule( &spin );	// atomically release spin lock and block
-	THREAD_GETMEM( uSelf)->enableInterrupts();
+	waiting.addTail( &(uThisTask().entryRef) );	// block current task
+	THREAD_GETMEM( This)->disableInterrupts();
+	activeProcessorKernel->schedule( &spin );	// atomically release spin lock and block
+	THREAD_GETMEM( This)->enableInterrupts();
     } else {
 	spin.release();
     } // if
@@ -52,7 +53,7 @@ void uSemaphore::P( uSemaphore &s ) {			// wait on a semaphore and release anoth
     spin.acquire();
     if ( &s == this ) {					// perform operation on self ?
 	if ( count < 0 ) {				// V my semaphore
-	    waiting.dropHead()->uGet().uWake();	// remove task at head of waiting list
+	    waiting.dropHead()->task().wake();		// remove task at head of waiting list
 	} // if
 	count += 1;
     } else {
@@ -61,10 +62,10 @@ void uSemaphore::P( uSemaphore &s ) {			// wait on a semaphore and release anoth
 
     count -= 1;						// now P my semaphore
     if ( count < 0 ) {
-	waiting.addTail( &(uThisTask().uEntryRef) );	// block current task
-	THREAD_GETMEM( uSelf)->disableInterrupts();
-	uActiveProcessorKernel->uSchedule( &spin );	// atomically release spin lock and block
-	THREAD_GETMEM( uSelf)->enableInterrupts();
+	waiting.addTail( &(uThisTask().entryRef) );	// block current task
+	THREAD_GETMEM( This)->disableInterrupts();
+	activeProcessorKernel->schedule( &spin );	// atomically release spin lock and block
+	THREAD_GETMEM( This)->enableInterrupts();
     } else {
 	spin.release();
     } // if
@@ -73,13 +74,13 @@ void uSemaphore::P( uSemaphore &s ) {			// wait on a semaphore and release anoth
 
 bool uSemaphore::TryP() {				// conditionally wait on a semaphore
     spin.acquire();
-  if ( count <= 0 ) {
+    if ( count > 0 ) {
+	count -= 1;
 	spin.release();
-	return false;
+	return true;
     } // if
-    count -= 1;
     spin.release();
-    return true;
+    return false;
 } // uSemaphore::TryP
 
 
@@ -91,7 +92,7 @@ void uSemaphore::V( unsigned int times ) {		// signal a semaphore
 	    break;
 	} // if
 	count += 1;
-	waiting.dropHead()->uGet().uWake();		// remove task at head of waiting list and make new owner
+	waiting.dropHead()->task().wake();		// remove task at head of waiting list and make new owner
     } // for
     spin.release();
 } // uSemaphore::V
@@ -120,4 +121,3 @@ void *uSemaphore::operator new( size_t size ) {
 // Local Variables: //
 // compile-command: "gmake install" //
 // End: //
-
