@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uSocket.h -- Nonblocking UNIX Socket I/O
 // 
 // Author           : Peter Buhr
 // Created On       : Tue Mar 29 17:04:36 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Nov 30 08:39:14 2005
-// Update Count     : 307
+// Last Modified On : Wed Feb  8 12:46:54 2006
+// Update Count     : 310
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -40,6 +40,11 @@
 #include <netdb.h>					// MAXHOSTNAMELEN on Solaris
 #include <sys/param.h>					// MAXHOSTNAMELEN on BSD
 
+#if defined( __freebsd__ )
+#include <netinet/in.h>					// struct sockaddr_in
+#include <sys/socket.h>					// SOCK_STREAM
+#endif // __freebsd__
+
 
 //######################### uSocket #########################
 
@@ -144,8 +149,8 @@ _Monitor uSocketServer : public uSocketIO {
     uSocketServer( unsigned short *port, int type = SOCK_STREAM, int protocol = 0, int backlog = 10 );
     virtual ~uSocketServer();
 
-    void uSetClient( struct sockaddr *addr, socklen_t len );
-    void uGetClient( struct sockaddr *addr, socklen_t *len );
+    void setClient( struct sockaddr *addr, socklen_t len );
+    void getClient( struct sockaddr *addr, socklen_t *len );
 
     _DualEvent Failure;
     friend _DualEvent Failure;				// access: socket
@@ -235,8 +240,8 @@ _Monitor uSocketClient : public uSocketIO {
     uSocketClient( unsigned short port, const char *name, uDuration *timeout, int type = SOCK_STREAM, int protocol = 0 );
     virtual ~uSocketClient();
 
-    void uSetServer( struct sockaddr *addr, socklen_t len );
-    void uGetServer( struct sockaddr *addr, socklen_t *len );
+    void setServer( struct sockaddr *addr, socklen_t len );
+    void getServer( struct sockaddr *addr, socklen_t *len );
 
     _DualEvent Failure;
     friend _DualEvent Failure;
