@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 2004
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr 2004
 // 
 // ulocks.cc -- IRIX semaphore operations
 // 
 // Author           : Richard C. Bilson
 // Created On       : Mon Mar 22 14:09:50 2004
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Jun 26 19:19:40 2004
-// Update Count     : 21
+// Last Modified On : Tue Sep 12 08:08:29 2006
+// Update Count     : 24
 // 
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -49,7 +49,7 @@ extern "C" {
 
     usema_t *_usnewsema( usptr_t *handle, int val ) {
 	// handle ignored -- separate arenas is unsupported
-	uAssert( val == 1 );
+	assert( val == 1 );
 	uOwnerLock *lock = new uOwnerLock();
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "usnewsema( 0x%p , %d ) -> 0x%p\n", handle, val, lock );
@@ -57,8 +57,8 @@ extern "C" {
 	return (usema_t *)lock;
     } // _usnewsema
 
-    int _usinitsema(usema_t *sem, int val) {
-	uAssert( val == 1 );
+    int _usinitsema( usema_t *sem, int val ) {
+	assert( val == 1 );
 	new(sem) uOwnerLock();
 	return 0;
     } // _usnewsema
@@ -82,7 +82,7 @@ extern "C" {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "usvsema( 0x%p )\n", sem );
 #endif
-	uAssert( ((uOwnerLock *)sem)->times() > 0 );
+	assert( ((uOwnerLock *)sem)->times() > 0 );
 	((uOwnerLock *)sem)->release();
 	return 0;
     } // _usvsema
@@ -92,7 +92,7 @@ extern "C" {
 	    return 0;
 	} else {
 	    return 10;
-	}
+	} // if
     } // _ustestsema
 
     void _usfreesema( usema_t *sem, usptr_t *handle ) {
@@ -107,9 +107,9 @@ extern "C" {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "usctlsema( 0x%p , %d )\n", sem, cmd );
 #endif
-	if( cmd != CS_RECURSIVEON ) {
+	if ( cmd != CS_RECURSIVEON ) {
 	    uAbort( "invalid semaphore control command %d", cmd );
-	}
+	} // if
 	return 0;
     } // usnewpollsema
 
