@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Philipp E. Lim 1996
+// uC++ Version 5.4.0, Copyright (C) Philipp E. Lim 1996
 // 
 // uDeadlineMonotonic.h -- 
 // 
 // Author           : Philipp E. Lim and Ashif S. Harji
 // Created On       : Fri Jul 19 23:20:17 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 11:11:47 2005
-// Update Count     : 130
+// Last Modified On : Sat Jan 21 10:27:38 2006
+// Update Count     : 132
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -35,11 +35,11 @@
 
 
 class uDeadlineMonotonic : public uPriorityScheduleSeq<uBaseTaskSeq, uBaseTaskDL> {
-    int compare( uBaseTask &t1, uBaseTask &t2 );
+    int compare( uBaseTask &task1, uBaseTask &task2 );
   public:
-    void addInitialize( uSequence<uBaseTaskDL> &TaskList );
+    void addInitialize( uSequence<uBaseTaskDL> &taskList );
     void removeInitialize( uSequence<uBaseTaskDL> & );
-    void uRescheduleTask( uBaseTaskDL *TaskNode, uBaseTaskSeq &TaskList );
+    void rescheduleTask( uBaseTaskDL *taskNode, uBaseTaskSeq &taskList );
 }; // uDeadlineMonotonic
 
 
