@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Philipp E. Lim 1996
+// uC++ Version 5.4.0, Copyright (C) Philipp E. Lim 1996
 // 
 // uDeadlineMonotonic1.cc -- 
 // 
 // Author           : Philipp E. Lim and Ashif S. Harji
 // Created On       : Fri Oct 27 08:25:33 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 11:13:26 2005
-// Update Count     : 20
+// Last Modified On : Tue Sep 12 08:12:59 2006
+// Update Count     : 32
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -28,76 +28,74 @@
 #include <uC++.h>
 #include <uDeadlineMonotonic1.h>
 
-
-#include <uAssert.h>
 //#include <uDebug.h>
 
 
-void uDeadlineMonotonic1::addInitialize( uSequence<uBaseTaskDL> &TaskList ) {
+void uDeadlineMonotonic1::addInitialize( uSequence<uBaseTaskDL> &taskList ) {
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uDeadlineMonotonic1 &)0x%p.addInitialize: enter\n" );
+    uDebugPrt( "(uDeadlineMonotonic1 &)0x%p.addInitialize: enter\n", this );
 #endif // __U_DEBUG_H__
 
-    uBaseTask &t = TaskList.tail()->uGet();
+    uBaseTask &task = taskList.tail()->task();
 
-    uPIHeap *PIHptr = dynamic_cast<uPIHeap *>(t.uPIQ);
+    uPIHeap *PIHptr = dynamic_cast<uPIHeap *>(task.uPIQ);
     if ( PIHptr == NULL ) {
-	uAbort("(uDeadlineMonotonic1 &)0x%p.addInitialize : Task 0x%p has incorrect uPIQ type.", this, &t );
+	uAbort("(uDeadlineMonotonic1 &)0x%p.addInitialize : Task 0x%p has incorrect uPIQ type.", this, &task );
     } // if
 
     int queueNum = PIHptr->head();
-    int priority = PIHptr->uGetHighestPriority();
-    uRealTimeBaseTask *rbt;
-    uPeriodicBaseTask *pbt;
-    uSporadicBaseTask *sbt;
+    int priority = PIHptr->getHighestPriority();
+    uRealTimeBaseTask *rbtask;
+    uPeriodicBaseTask *pbtask;
+    uSporadicBaseTask *sbtask;
 
-    if ( ( rbt = dynamic_cast<uRealTimeBaseTask *>(&t) ) == NULL ) { 
+    if ( ( rbtask = dynamic_cast<uRealTimeBaseTask *>(&task) ) == NULL ) { 
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "(uDeadlineMonotonic1 &)0x%p.addInitialize: exit1\n" );
+	uDebugPrt( "(uDeadlineMonotonic1 &)0x%p.addInitialize: exit1\n", this );
 #endif // __U_DEBUG_H__
-	uSetBasePriority( t, INT_MAX );			// set to a large number
+	setBasePriority( task, INT_MAX );		// set to a large number
 
 	if ( queueNum == -1 ) {
-	    uSetActivePriority( t, t );
+	    setActivePriority( task, task );
 	} else {
-	    uSetActivePriority( t, priority );
+	    setActivePriority( task, priority );
 	} // if
-    } else if ( ( pbt = dynamic_cast<uPeriodicBaseTask *>(&t) ) != NULL ) {
-	uSetBasePriority( t, (int)(pbt->uGetPeriod().nanoseconds() / 1000000) );
+    } else if ( ( pbtask = dynamic_cast<uPeriodicBaseTask *>(&task) ) != NULL ) {
+	setBasePriority( task, (int)(pbtask->getPeriod().nanoseconds() / 1000000) );
 	if ( queueNum == -1 ) {
-	    uSetActivePriority( *pbt, t );
+	    setActivePriority( *pbtask, task );
 	} else {
-	    uSetActivePriority( *pbt, priority );
+	    setActivePriority( *pbtask, priority );
 	} // if
-    } else if ( ( sbt = dynamic_cast<uSporadicBaseTask *>(&t) ) != NULL ) {
-	uSetBasePriority( t, (int)(sbt->uGetFrame().nanoseconds() / 1000000) );
+    } else if ( ( sbtask = dynamic_cast<uSporadicBaseTask *>(&task) ) != NULL ) {
+	setBasePriority( task, (int)(sbtask->getFrame().nanoseconds() / 1000000) );
 	if ( queueNum == -1 ) {
-	    uSetActivePriority( *sbt, t );
+	    setActivePriority( *sbtask, task );
 	} else {
-	    uSetActivePriority( *sbt, priority );
+	    setActivePriority( *sbtask, priority );
 	} // if
     } else {						// only uRealtime
-	uSetBasePriority( t, (int)(rbt->uGetDeadline().nanoseconds() / 1000000) );
+	setBasePriority( task, (int)(rbtask->getDeadline().nanoseconds() / 1000000) );
 	if ( queueNum == -1 ) {
-	    uSetActivePriority( (uRealTimeBaseTask &)t, t );
+	    setActivePriority( (uRealTimeBaseTask &)task, task );
 	} else {
-	    uSetActivePriority( (uRealTimeBaseTask &)t, priority );
+	    setActivePriority( (uRealTimeBaseTask &)task, priority );
 	} // if
     } // if
 
     // must assign a queue if none already assigned increment count.  do linear
     // search checking priority values.
-    int tpri = uGetBasePriority( t );
+    int tpri = getBasePriority( task );
     bool flag = false;
 
     for ( int i = 0; i < num_priorities; i += 1 ) {
-	if ( tpri == uObjects[i].priority ) {
+	if ( tpri == objects[i].priority ) {
 	    flag = true;
-	    uSetBaseQueue( t, i);
+	    setBaseQueue( task, i);
 	    if ( queueNum == -1 ) {
-		uSetActiveQueue( t, i );		// should have at least t's serial on queue by now
+		setActiveQueue( task, i );		// should have at least t's serial on queue by now
 	    } else {
-		uSetActiveQueue( t, queueNum );		// should have at least t's serial on queue by now
+		setActiveQueue( task, queueNum );	// should have at least t's serial on queue by now
 	    } // if
 	    break;
 	} // if
@@ -106,12 +104,12 @@ void uDeadlineMonotonic1::addInitialize( uSequence<uBaseTaskDL> &TaskList ) {
     if ( ! flag ) {
 	num_priorities += 1;
 	if ( num_priorities <= __U_MAX_NUMBER_PRIORITIES__ ) {
-	    uObjects[num_priorities - 1].priority = tpri;
-	    uSetBaseQueue( t, num_priorities - 1 );
+	    objects[num_priorities - 1].priority = tpri;
+	    setBaseQueue( task, num_priorities - 1 );
 	    if ( queueNum == -1 ) {
-		uSetActiveQueue( t, num_priorities - 1 ); // should have at least t's serial on queue by now
+		setActiveQueue( task, num_priorities - 1 ); // should have at least t's serial on queue by now
 	    } else {
-		uSetActiveQueue( t, queueNum );
+		setActiveQueue( task, queueNum );
 	    } // if
 	} else {
 	    uAbort( "(uDeadlineMonotonic1 &)0x%p.addInitialize : Cannot schedule task as more priorities are needed than current limit of %d.",
@@ -126,16 +124,16 @@ void uDeadlineMonotonic1::removeInitialize( uSequence<uBaseTaskDL> & ) {
     // should not affect the ability to schedule the task or the order the
     // tasks execute. Therefore, no rescheduling is performed.
     
-//	addInitialize( TaskList );
+//	addInitialize( taskList );
 } // uDeadlineMonotonic1::removeInitialize
 
 
-void uDeadlineMonotonic1::uRescheduleTask( uBaseTaskDL *TaskNode, uBaseTaskSeq &TaskList ) {
+void uDeadlineMonotonic1::rescheduleTask( uBaseTaskDL *taskNode, uBaseTaskSeq &taskList ) {
     //verCount += 1;
-    TaskList.remove( TaskNode );
-    TaskList.addTail( TaskNode );
-    addInitialize( TaskList );
-} // uDeadlineMonotonic1::uRescheduleTask
+    taskList.remove( taskNode );
+    taskList.addTail( taskNode );
+    addInitialize( taskList );
+} // uDeadlineMonotonic1::rescheduleTask
 
 
 // Local Variables: //
