@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Philipp E. Lim 1996
+// uC++ Version 5.4.0, Copyright (C) Philipp E. Lim 1996
 // 
 // uDeadlineMonotonic.h -- 
 // 
 // Author           : Philipp E. Lim and Ashif S. Harji
 // Created On       : Fri Jul 19 23:20:17 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 11:11:54 2005
-// Update Count     : 241
+// Last Modified On : Sat Jan 21 10:28:06 2006
+// Update Count     : 243
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -37,9 +37,9 @@
 
 class uDeadlineMonotonic1 : public uPriorityScheduleQSeq<uBaseTaskSeq, uBaseTaskDL> {
   public:
-    void addInitialize( uSequence<uBaseTaskDL> &TaskList );
+    void addInitialize( uSequence<uBaseTaskDL> &taskList );
     void removeInitialize( uSequence<uBaseTaskDL> & );
-    void uRescheduleTask( uBaseTaskDL *TaskNode, uBaseTaskSeq &TaskList );
+    void rescheduleTask( uBaseTaskDL *taskNode, uBaseTaskSeq &taskList );
 }; // uDeadlineMonotonic1
 
 
