@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.4.0, Copyright (C) Ashif S. Harji 2000
 // 
 // uDeadlineMonotonicStatic.cc -- 
 // 
 // Author           : Ashif S. Harji
 // Created On       : Fri Oct 27 16:09:42 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 11:31:17 2005
-// Update Count     : 24
+// Last Modified On : Tue Sep 12 08:12:44 2006
+// Update Count     : 36
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -28,8 +28,6 @@
 #include <uC++.h>
 #include <uDeadlineMonotonicStatic.h>
 
-
-#include <uAssert.h>
 //#include <uDebug.h>
 
 
@@ -40,7 +38,7 @@
 // all real-time tasks.  This compare function acts in the same way as strcmp
 // in terms of return value.
 
-int uDeadlineMonotonicStatic::compare( uBaseTask &t1, uBaseTask &t2 ) {
+int uDeadlineMonotonicStatic::compare( uBaseTask &task1, uBaseTask &task2 ) {
     uDuration temp;
     enum Codes { PS_PS, PS_NPS, NPS_PS, R_R, R_NR, NR_R, NR_NR }; // T1_T2
     Codes taskCodes[][4] = { { NR_NR,	NR_R,	NPS_PS,	NPS_PS	},
@@ -48,46 +46,46 @@ int uDeadlineMonotonicStatic::compare( uBaseTask &t1, uBaseTask &t2 ) {
 			     { PS_NPS,  	PS_NPS, PS_PS,	PS_PS	},
 			     { PS_NPS,  	PS_NPS, PS_PS,	PS_PS	} };
 
-    uAssert( &t1 != NULL && &t2 != NULL );
+    assert( &task1 != NULL && &task2 != NULL );
 
-    uRealTimeBaseTask *rbt1, *rbt2;
-    uPeriodicBaseTask *pbt1, *pbt2;
-    uSporadicBaseTask *sbt1 = NULL, *sbt2 = NULL;
+    uRealTimeBaseTask *rbtask1, *rbtask2;
+    uPeriodicBaseTask *pbtask1, *pbtask2;
+    uSporadicBaseTask *sbtask1 = NULL, *sbtask2 = NULL;
     int index1, index2;
 
-    rbt1 = dynamic_cast<uRealTimeBaseTask *>(&t1);
-    if ( rbt1 == NULL ) {
+    rbtask1 = dynamic_cast<uRealTimeBaseTask *>(&task1);
+    if ( rbtask1 == NULL ) {
 	index1 = 0;
-	pbt1 = NULL;
-	sbt1 = NULL;
+	pbtask1 = NULL;
+	sbtask1 = NULL;
     } else {
 	index1 = 1;
 
-	if ( ( pbt1 = dynamic_cast<uPeriodicBaseTask *>(&t1) ) != NULL ) {
+	if ( ( pbtask1 = dynamic_cast<uPeriodicBaseTask *>(&task1) ) != NULL ) {
 	    index1 = 2;
-	} else if ( ( sbt1 = dynamic_cast<uSporadicBaseTask *>(&t1) ) != NULL ) {
+	} else if ( ( sbtask1 = dynamic_cast<uSporadicBaseTask *>(&task1) ) != NULL ) {
 	    index1 = 3;
 	} // if
     } // if
 
-    rbt2 = dynamic_cast<uRealTimeBaseTask *>(&t2);
-    if ( rbt2 == NULL ) {
+    rbtask2 = dynamic_cast<uRealTimeBaseTask *>(&task2);
+    if ( rbtask2 == NULL ) {
 	index2 = 0;
-	pbt2 = NULL;
-	sbt2 = NULL;
+	pbtask2 = NULL;
+	sbtask2 = NULL;
     } else {
 	index2 = 1;
 
-	if ( ( pbt2 = dynamic_cast<uPeriodicBaseTask *>(&t2) ) != NULL ) {
+	if ( ( pbtask2 = dynamic_cast<uPeriodicBaseTask *>(&task2) ) != NULL ) {
 	    index2 = 2;
-	} else if ( ( sbt2 = dynamic_cast<uSporadicBaseTask *>(&t2) ) != NULL ) {
+	} else if ( ( sbtask2 = dynamic_cast<uSporadicBaseTask *>(&task2) ) != NULL ) {
 	    index2 = 3;
 	} // if
     } // if
 
     switch ( taskCodes[index1][index2] ){
-      case PS_PS:					// both t1 and t2 periodic or sporadic
-	temp = rbt1->uGetDeadline() - rbt2->uGetDeadline();
+      case PS_PS:					// both task1 and task2 periodic or sporadic
+	temp = rbtask1->getDeadline() - rbtask2->getDeadline();
 	if ( temp > 0 ) {
 	    return 1;
 	} else if ( temp < 0 ) {
@@ -95,18 +93,18 @@ int uDeadlineMonotonicStatic::compare( uBaseTask &t1, uBaseTask &t2 ) {
 	} else {					// real-time tasks have equal deadlines => check their periods or frames
 	    uDuration period1, period2;
 
-	    if ( pbt1 != NULL ) {			// periodic ?
-		period1 = pbt1->uGetPeriod();
-	    } else if ( sbt1  != NULL ) {		// sporadic ?
-		period1 = sbt1->uGetFrame();
+	    if ( pbtask1 != NULL ) {			// periodic ?
+		period1 = pbtask1->getPeriod();
+	    } else if ( sbtask1  != NULL ) {		// sporadic ?
+		period1 = sbtask1->getFrame();
 	    } else {
 		uAbort( "(uDeadlineMonotonicStatic *)0x%p.compare : internal error.", this );
 	    } // if
 
-	    if ( pbt2 != NULL ) {			// periodic ?
-		period2 = pbt2->uGetPeriod();
-	    } else if ( sbt2  != NULL ) {		// sporadic ?
-		period2 = sbt2->uGetFrame();
+	    if ( pbtask2 != NULL ) {			// periodic ?
+		period2 = pbtask2->getPeriod();
+	    } else if ( sbtask2  != NULL ) {		// sporadic ?
+		period2 = sbtask2->getFrame();
 	    } else {
 		uAbort( "(uDeadlineMonotonicStatic *)0x%p.compare : internal error.", this );
 	    } // if
@@ -116,28 +114,28 @@ int uDeadlineMonotonicStatic::compare( uBaseTask &t1, uBaseTask &t2 ) {
 	} // if
 	break;
 
-      case PS_NPS:					// t1 periodic or sporadic and t2 is not ?
+      case PS_NPS:					// task1 periodic or sporadic and task2 is not ?
 	return -1;
 	break;
 
-      case NPS_PS:					// t1 is not and t2 periodic or sporadic ?
+      case NPS_PS:					// task1 is not and task2 periodic or sporadic ?
 	return 1;
 	break;
 
-      case R_R:						// both t1 and t2 aperiodic
-	temp = rbt1->uGetDeadline() - rbt2->uGetDeadline();
+      case R_R:						// both task1 and task2 aperiodic
+	temp = rbtask1->getDeadline() - rbtask2->getDeadline();
 	return (temp > 0) ? 1 : (temp < 0) ? -1 : 0;
 	break;
 
-      case R_NR:					// t1 aperiodic and t2 is not ?
+      case R_NR:					// task1 aperiodic and task2 is not ?
 	return -1;
 	break;
 
-      case NR_R:					// t1 is not and t2 is aperiodic ?
+      case NR_R:					// task1 is not and task2 is aperiodic ?
 	return 1;
 	break;
 
-      case NR_NR:					// both t1 and t1 are non-real-time
+      case NR_NR:					// both task1 and task1 are non-real-time
 	return 0;
 	break;
 
@@ -148,9 +146,9 @@ int uDeadlineMonotonicStatic::compare( uBaseTask &t1, uBaseTask &t2 ) {
 } // uDeadlineMonotonicStatic::compare
 
 
-void uDeadlineMonotonicStatic::addInitialize( uSequence<uBaseTaskDL> &TaskList ) {
+void uDeadlineMonotonicStatic::addInitialize( uSequence<uBaseTaskDL> &taskList ) {
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uDeadlineMonotonicStatic &)0x%p.addInitialize: enter\n" );
+    uDebugPrt( "(uDeadlineMonotonicStatic &)0x%p.addInitialize: enter\n", this );
 #endif // __U_DEBUG_H__
     uSeqIter<uBaseTaskDL> iter;
     uBaseTaskDL *ref = NULL, *prev = NULL, *node = NULL;
@@ -161,36 +159,36 @@ void uDeadlineMonotonicStatic::addInitialize( uSequence<uBaseTaskDL> &TaskList )
     // cluster list with initializing newly scheduled tasks so only one call is
     // made in uTaskAdd.)
 
-    uRealTimeBaseTask *rtb = dynamic_cast<uRealTimeBaseTask *>(&(TaskList.tail()->uGet()));
+    uRealTimeBaseTask *rtb = dynamic_cast<uRealTimeBaseTask *>(&(taskList.tail()->task()));
 
     if ( rtb == NULL ) {
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "(uDeadlineMonotonicStatic &)0x%p.addInitialize: exit1\n" );
+	uDebugPrt( "(uDeadlineMonotonicStatic &)0x%p.addInitialize: exit1\n", this );
 #endif // __U_DEBUG_H__
 	return;
     } // exit
 
-    ref = TaskList.dropTail();
+    ref = taskList.dropTail();
 
     if ( ref == NULL ) {				// necessary if addInitialize is called from removeInitialize
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "(uDeadlineMonotonicStatic &)0x%p.addInitialize: exit2\n" );
+	uDebugPrt( "(uDeadlineMonotonicStatic &)0x%p.addInitialize: exit2\n", this );
 #endif // __U_DEBUG_H__
 	return;
     } // exit
 
-    for ( iter.over(TaskList), prev = NULL; iter >> node ; prev = node ) { // find place in the list to insert
-	if ( compare( ref->uGet(), node->uGet() ) < 0 ) break;
+    for ( iter.over(taskList), prev = NULL; iter >> node ; prev = node ) { // find place in the list to insert
+	if ( compare( ref->task(), node->task() ) < 0 ) break;
     } // for
-    TaskList.insertBef( ref, node );
+    taskList.insertBef( ref, node );
 
     // Find out if task was ever on cluster, if so compare verCount with
     // verCount for cluster.  If different or first visit recalculate
     // otherwise, stop after putting task back into task list
 
-    if ( verCount == (unsigned int)rtb->uGetVersion( rtb->getCluster() ) ) {
+    if ( verCount == (unsigned int)rtb->getVersion( rtb->getCluster() ) ) {
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "(uDeadlineMonotonicStatic &)0x%p.addInitialize: exit3\n" );
+	uDebugPrt( "(uDeadlineMonotonicStatic &)0x%p.addInitialize: exit3\n", this );
 #endif // __U_DEBUG_H__
 	return;
     } // exit
@@ -198,54 +196,54 @@ void uDeadlineMonotonicStatic::addInitialize( uSequence<uBaseTaskDL> &TaskList )
     // either new task or verCounts differ, increment verCount and continue
     verCount += 1;
 
-    uBaseTask &t = ref->uGet();
-    uRealTimeBaseTask *rt = dynamic_cast<uRealTimeBaseTask *>(&t);
-    if ( rt != NULL ) {
+    uBaseTask &task = ref->task();
+    uRealTimeBaseTask *rtask = dynamic_cast<uRealTimeBaseTask *>(&task);
+    if ( rtask != NULL ) {
 	int pval;
 	int diff;
 	int firstIndex = 0;
 	int lastIndex = __U_MAX_NUMBER_PRIORITIES__;
 
 	if ( prev != NULL ) {
-	    firstIndex = uGetBasePriority( prev->uGet() );
+	    firstIndex = getBasePriority( prev->task() );
 	} // if
 
 	if ( node != NULL ) {
-	    lastIndex = uGetBasePriority( node->uGet());
+	    lastIndex = getBasePriority( node->task());
 	} // if
 
 	// Scheduling is static, so no dynamic reassignment of priorities
 	// occurs.  A unique priority is assigned in between the priorities of
 	// the task's neighbours.
 	diff = (lastIndex - firstIndex) / 2 ;
-	if ( diff == 0 ) uAbort( "(uDeadlineMonotonicStatic *)0x%p.addInitialize : Cannot assign priority to task 0x%p between existing priorities", this, &t );
+	if ( diff == 0 ) uAbort( "(uDeadlineMonotonicStatic *)0x%p.addInitialize : Cannot assign priority to task 0x%p between existing priorities", this, &task );
 	pval = firstIndex + diff;
 
-	uSetBasePriority( *rt, pval );
-	rt->uSetVersion( rt->getCluster(), verCount );
-	uSetActivePriority( *rt, pval );
+	setBasePriority( *rtask, pval );
+	rtask->setVersion( rtask->getCluster(), verCount );
+	setActivePriority( *rtask, pval );
     } else {
-	if ( uGetBasePriority( t ) == 0 ) {		// if first time, intialize priority for nonreal-time task
-	    uSetBasePriority( t, __U_MAX_NUMBER_PRIORITIES__ - 1);
+	if ( getBasePriority( task ) == 0 ) {		// if first time, intialize priority for nonreal-time task
+	    setBasePriority( task, __U_MAX_NUMBER_PRIORITIES__ - 1);
 	} // if
-	uSetActivePriority( t, __U_MAX_NUMBER_PRIORITIES__ - 1 );
+	setActivePriority( task, __U_MAX_NUMBER_PRIORITIES__ - 1 );
     } // if 
 
-    for ( iter.over( TaskList ); iter >> node; ) { 
-	uRealTimeBaseTask *rt1 = dynamic_cast<uRealTimeBaseTask *>(&node->uGet());
-	if ( rt1 != NULL ) {
-	    rt1->uSetVersion( rt1->getCluster(), verCount );
+    for ( iter.over( taskList ); iter >> node; ) { 
+	uRealTimeBaseTask *rtask1 = dynamic_cast<uRealTimeBaseTask *>(&node->task());
+	if ( rtask1 != NULL ) {
+	    rtask1->setVersion( rtask1->getCluster(), verCount );
 	} // if
     } // for
 
 #ifdef __U_DEBUG_H__
 // 	uSeqIter<uBaseTaskDL> j;
 //	uBaseTaskDL *ptr = NULL;
-//      for (j.over(TaskList); j >> ptr; ) {
-//          fprintf(stderr, "0x%p Task with priority %d\n", &(ptr->uGet()), ptr->uGet().uGetActivePriority());
+//      for (j.over(taskList); j >> ptr; ) {
+//          fprintf(stderr, "0x%p Task with priority %d\n", &(ptr->task()), ptr->task().getActivePriority());
 //      }
 //      fprintf(stderr, "Leaving uInitialize! \n");
-	uDebugPrt( "(uDeadlineMonotonicStatic &)0x%p.addInitialize: exit4\n" );
+	uDebugPrt( "(uDeadlineMonotonicStatic &)0x%p.addInitialize: exit4\n", this );
 #endif // __U_DEBUG_H__
 } // uDeadlineMonotonicStatic::addInitialize
 
@@ -255,16 +253,16 @@ void uDeadlineMonotonicStatic::removeInitialize( uSequence<uBaseTaskDL> & ) {
     // should not affect the ability to schedule the task or the order the
     // tasks execute. Therefore, no rescheduling is performed.
 
-//	addInitialize( TaskList );
+//	addInitialize( taskList );
 } // uDeadlineMonotonicStatic::removeInitialize
 
 
-void uDeadlineMonotonicStatic::uRescheduleTask( uBaseTaskDL *TaskNode, uBaseTaskSeq &TaskList ) {
+void uDeadlineMonotonicStatic::rescheduleTask( uBaseTaskDL *taskNode, uBaseTaskSeq &taskList ) {
     verCount += 1;
-    TaskList.remove(TaskNode);
-    TaskList.addTail(TaskNode);
-    addInitialize(TaskList);
-} // uDeadlineMonotonicStatic::uRescheduleTask
+    taskList.remove(taskNode);
+    taskList.addTail(taskNode);
+    addInitialize(taskList);
+} // uDeadlineMonotonicStatic::rescheduleTask
 
 
 // Local Variables: //
