@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.4.0, Copyright (C) Ashif S. Harji 2000
 // 
 // uDeadlineMonotonic.h -- 
 // 
 // Author           : Ashif S. Harji
 // Created On       : Fri Oct 27 16:09:42 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 11:12:01 2005
-// Update Count     : 151
+// Last Modified On : Sat Jan 21 10:28:34 2006
+// Update Count     : 153
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -36,11 +36,11 @@
 
 
 class uDeadlineMonotonicStatic : public uStaticPriorityScheduleSeq<uBaseTaskSeq, uBaseTaskDL> {
-    int compare( uBaseTask &t1, uBaseTask &t2 );
+    int compare( uBaseTask &task1, uBaseTask &task2 );
   public:
-    void addInitialize( uSequence<uBaseTaskDL> &TaskList );
+    void addInitialize( uSequence<uBaseTaskDL> &taskList );
     void removeInitialize( uSequence<uBaseTaskDL> & );
-    void uRescheduleTask( uBaseTaskDL *TaskNode, uBaseTaskSeq &TaskList );
+    void rescheduleTask( uBaseTaskDL *taskNode, uBaseTaskSeq &taskList );
 }; // uDeadlineMonotonicStatic
 
 
