@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.4.0, Copyright (C) Ashif S. Harji 2000
 // 
 // uHeapQ.cc -- 
 // 
 // Author           : Ashif S. Harji
 // Created On       : Fri Feb  4 10:57:13 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 11:12:15 2005
-// Update Count     : 40
+// Last Modified On : Wed Jan 25 12:55:18 2006
+// Update Count     : 53
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -60,16 +60,16 @@ void uPriorityQ::exchange( uHeapable<int, uHeapBaseSeq *> &x, uHeapable<int, uHe
 
 uPriorityQ::uPriorityQ() : heap( &compare, &exchange ) {
     //for ( int i = 0; i < __U_MAX_NUMBER_PRIORITIES__ ; i += 1 ) {
-    //    heap.A[i + 1].data = &(uObjects[i]);
+    //    heap.A[i + 1].data = &(objects[i]);
     //} // for
     //num_priorities = 1; // first is always non-real-time tasks
-    // uObjects[0].priority = 2147483647;  // use a large number, syn which addInitialize
+    // objects[0].priority = 2147483647;  // use a large number, syn which addInitialize
     // uPriorityValue = -1;
     // uInheritTask = NULL;
     // uQueueNum = -1;
-    uExecuteHooks = true;
-    uCurrPriority = -1;
-    uCurrQueueNum = -1;
+    executeHooks = true;
+    currPriority = -1;
+    currQueueNum = -1;
 } // uPriorityQ::uPriorityQ
 
 
@@ -89,39 +89,39 @@ uBaseTaskDL *uPriorityQ::head() const {
 } // uPriorityQ::head
 
 
-int uPriorityQ::add( uBaseTaskDL *node, uBaseTask *uOwner ) {
+int uPriorityQ::add( uBaseTaskDL *node, uBaseTask *owner ) {
     // Dynamic check to verify that the task being added to entry queue is
     // compliant with PIHeap type.
-    uPIHeap *PIHptr = dynamic_cast<uPIHeap *>(node->uGet().uPIQ);
+    uPIHeap *PIHptr = dynamic_cast<uPIHeap *>(node->task().uPIQ);
     if ( PIHptr == NULL ) {
-	uAbort("(uPriorityQ &)0x%p.add : Task 0x%p has incorrect uPIQ type for mutex object.", this, &node->uGet());
+	uAbort("(uPriorityQ &)0x%p.add : Task 0x%p has incorrect uPIQ type for mutex object.", this, &node->task());
     } //if
 
     // check if your priority needs to be updated
-    if ( PIHptr->uGetHighestPriority() < uGetActivePriorityValue( node->uGet() )  ) {
-	uThisCluster().uTaskSetPriority( node->uGet(), node->uGet() );
+    if ( PIHptr->getHighestPriority() < getActivePriorityValue( node->task() )  ) {
+	uThisCluster().taskSetPriority( node->task(), node->task() );
     } // if
 
     // As uCurrentSerial is updated, the calling task's priority can no longer
     // change because the tasks uPIQ is fixed as the entry lock is acquired.
     // So subsequent updates will only reaffirm the task's current priority.
 
-    int priority = uGetActivePriorityValue( node->uGet() );
-    int queueNum = uGetActiveQueueValue( node->uGet() ); // use the node for you active priority
+    int priority = getActivePriorityValue( node->task() );
+    int queueNum = getActiveQueueValue( node->task() ); // use the node for you active priority
 
     // if empty then must add to heap, otherwise just insert node
-    if ( uObjects[queueNum].queue.empty() ) {
-	uObjects[queueNum].queue.add(node);
+    if ( objects[queueNum].queue.empty() ) {
+	objects[queueNum].queue.add(node);
 	// the index must be set before inserting because the index can change as part of the insert
-	uObjects[queueNum].index = heap.size() + 1;
- 	heap.insert( priority, &(uObjects[queueNum]) );
+	objects[queueNum].index = heap.size() + 1;
+ 	heap.insert( priority, &(objects[queueNum]) );
     } else {
-	uObjects[queueNum].queue.add(node);
+	objects[queueNum].queue.add(node);
     } // if
     
     // only perform inheritance for entry list
-    if ( uIsEntryBlocked( node->uGet() ) && uCheckHookConditions( *uOwner, node->uGet() ) ) {	// TEMP: entry queue??
-	return( uAfterEntry( uOwner ) );		// perform any priority inheritance
+    if ( isEntryBlocked( node->task() ) && checkHookConditions( *owner, node->task() ) ) { // TEMP: entry queue??
+	return( afterEntry( owner ) );			// perform any priority inheritance
     } else {
 	return uLockAcquired;
     } // if
@@ -147,109 +147,109 @@ uBaseTaskDL *uPriorityQ::drop() {
 void uPriorityQ::remove( uBaseTaskDL *node ) {
     // use stored queue value because this task has entry lock, so its uPIQ may
     // be updated, but not its position on the entry queue.
-    int queueNum = uGetActiveQueueValue( node->uGet() );// use the node for you active priority
+    int queueNum = getActiveQueueValue( node->task() );	// use the node for you active priority
     
     // do remove
-    uObjects[queueNum].queue.remove(node);
+    objects[queueNum].queue.remove(node);
 
     // if empty then must remove from heap
-    if ( uObjects[queueNum].queue.empty() ) {
-	heap.deletenode( heap.A[uObjects[queueNum].index] );
+    if ( objects[queueNum].queue.empty() ) {
+	heap.deletenode( heap.A[objects[queueNum].index] );
     } // if
 } // uPriorityQ::remove
 
 
-int uPriorityQ::uAfterEntry(uBaseTask *uOwner ) {	// use pointer to owner as it could be Null
-    // static_cast to PIHeap are valid here as add and uOnAcquire already
+int uPriorityQ::afterEntry(uBaseTask *owner ) {	// use pointer to owner as it could be Null
+    // static_cast to PIHeap are valid here as add and onAcquire already
     // verify that the associated tasks use type uPIHeap.
 
     // assume entry lock acquired
     int uRelPrevLock = uLockAcquired;
 
     // if entry queue empty (called by owner) or no owner, then no inheritance
-    if ( empty() || uOwner == NULL /* || uCurrPriority == -1 */ ) {
+    if ( empty() || owner == NULL /* || currPriority == -1 */ ) {
 	return uRelPrevLock;
     } // if
 
-    uBaseTask &uCalling = head()->uGet();		// can't be NULL as not empty 
+    uBaseTask &uCalling = head()->task();		// can't be NULL as not empty 
 
     // does node need to be updated?
-    if ( uCalling.getActivePriorityValue() < uCurrPriority ) { 
+    if ( uCalling.getActivePriorityValue() < currPriority ) { 
         // only task with entry lock can be modifying this mutex's node
 	// remove node
-	(static_cast<uPIHeap *>(uOwner->uPIQ))->remove( uCurrPriority, uCurrQueueNum );
+	(static_cast<uPIHeap *>(owner->uPIQ))->remove( currPriority, currQueueNum );
 	
 	// reset priority value for monitor
-	uCurrPriority = uCalling.getActivePriorityValue();
-	uCurrQueueNum = uCalling.getActiveQueueValue();
+	currPriority = uCalling.getActivePriorityValue();
+	currQueueNum = uCalling.getActiveQueueValue();
 
         // update mutex owner's uPIQ for new priority
-	(static_cast<uPIHeap *>(uOwner->uPIQ))->add( uCurrPriority, uCurrQueueNum ) ;  
+	(static_cast<uPIHeap *>(owner->uPIQ))->add( currPriority, currQueueNum ) ;  
     
 	// does inheritance occur ?
-	if ( uCurrPriority < uOwner->getActivePriorityValue() ) {
+	if ( currPriority < owner->getActivePriorityValue() ) {
 	    
-	    uRepositionEntry rep(*uOwner, uCalling);
+	    uRepositionEntry rep(*owner, uCalling);
             // if task is blocked on entry list, adjust and perform transitivity
-	    if ( uIsEntryBlocked( *uOwner ) ) {
+	    if ( isEntryBlocked( *owner ) ) {
 		uRelPrevLock = rep.uReposition(true);
 	    } else {
                 // call cluster routine to adjust ready queue and active
                 // priority Note: can only raise priority to at most uCalling,
-                // otherwise updating uOwner's priority can conflit with the
-                // uOwner blocking on an entry queue at a particular priority
+                // otherwise updating owner's priority can conflit with the
+                // owner blocking on an entry queue at a particular priority
                 // level.  Furthermore, uCalling's priority is fixed while the
                 // entry lock of where it is blocked (s->lock) is acquired, but
                 // uThisTask()'s priority can change as entry lock's are
                 // released along inheritance chain.
-		uThisCluster().uTaskSetPriority( *uOwner, uCalling );
+		uThisCluster().taskSetPriority( *owner, uCalling );
 	    } // if
 	} // if
     } // if
 
     return uRelPrevLock;
-} // uPriorityQ::uAfterEntry
+} // uPriorityQ::afterEntry
 
 
-void uPriorityQ::uOnAcquire(uBaseTask &uOwner ) {
+void uPriorityQ::onAcquire(uBaseTask &owner ) {
     // Dynamic check to verify that the task acquiring the serial is compliant
     // with PIHeap type.
-    uPIHeap *PIHptr = dynamic_cast<uPIHeap *>(uOwner.uPIQ);
+    uPIHeap *PIHptr = dynamic_cast<uPIHeap *>(owner.uPIQ);
     if ( PIHptr == NULL ) {
-	uAbort("(uPriorityQ &)0x%p.uOnAcquire : Task 0x%p has incorrect uPIQ type for mutex object.", this, &uOwner);
+	uAbort("(uPriorityQ &)0x%p.onAcquire : Task 0x%p has incorrect uPIQ type for mutex object.", this, &owner);
     } //if
 
     // check if mutex owner's priority needs to be updated
-    if ( PIHptr->uGetHighestPriority() < uGetActivePriorityValue( uOwner ) ) {
-	uThisCluster().uTaskSetPriority( uOwner, uOwner );
+    if ( PIHptr->getHighestPriority() < getActivePriorityValue( owner ) ) {
+	uThisCluster().taskSetPriority( owner, owner );
     } // if
 
     // remember current priority value, update task's uPIQ
-    uCurrPriority = uOwner.getBasePriority();
-    uCurrQueueNum = uOwner.getBaseQueue();
-    PIHptr->add( uCurrPriority, uCurrQueueNum );
+    currPriority = owner.getBasePriority();
+    currQueueNum = owner.getBaseQueue();
+    PIHptr->add( currPriority, currQueueNum );
 
     // perform priority inheritance
-    uAfterEntry( &uOwner );
-} // uPriorityQ::uOnAcquire
+    afterEntry( &owner );
+} // uPriorityQ::onAcquire
 
 
-void uPriorityQ::uOnRelease(uBaseTask &uOldOwner ) {
-    // static_cast to PIHeap are valid here as add and uOnAcquire already
+void uPriorityQ::onRelease(uBaseTask &uOldOwner ) {
+    // static_cast to PIHeap are valid here as add and onAcquire already
     // verify that the associated tasks use type uPIHeap.
 
     // update task's uPIQ, reset stored values
-    (static_cast<uPIHeap *>(uOldOwner.uPIQ))->remove( uCurrPriority, uCurrQueueNum ); 
-    uCurrPriority = -1;
-    uCurrQueueNum = -1;
+    (static_cast<uPIHeap *>(uOldOwner.uPIQ))->remove( currPriority, currQueueNum ); 
+    currPriority  = -1;
+    currQueueNum = -1;
 
     // reset active priority if necessary
     // only case where priority can decrease
     if ( (static_cast<uPIHeap *>(uOldOwner.uPIQ))->empty() ||
-	 (static_cast<uPIHeap *>(uOldOwner.uPIQ))->uGetHighestPriority() > uGetActivePriorityValue( uOldOwner ) ) {
-	uThisCluster().uTaskSetPriority( uOldOwner, uOldOwner );
+	 (static_cast<uPIHeap *>(uOldOwner.uPIQ))->getHighestPriority() > getActivePriorityValue( uOldOwner ) ) {
+	uThisCluster().taskSetPriority( uOldOwner, uOldOwner );
     } // if
-} // uPriorityQ::uOnRelease
+} // uPriorityQ::onRelease
 
 // Local Variables: //
 // compile-command: "gmake install" //
