@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.4.0, Copyright (C) Ashif S. Harji 2000
 // 
 // uHeapQ.h -- 
 // 
 // Author           : Ashif S. Harji
 // Created On       : Fri Jan 14 17:59:34 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 11:12:28 2005
-// Update Count     : 42
+// Last Modified On : Wed Jan 25 12:59:41 2006
+// Update Count     : 54
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -44,34 +44,29 @@
 
 class uPriorityQ : public uBasePrioritySeq {
     struct uHeapBaseSeq {
-	// int priority;
 	int index;
 	uBaseTaskSeq queue;
     };
 
-    uHeapBaseSeq uObjects[__U_MAX_NUMBER_PRIORITIES__ ]; 
+    uHeapBaseSeq objects[__U_MAX_NUMBER_PRIORITIES__ ]; 
     uHeap<int, uHeapBaseSeq *, __U_MAX_NUMBER_PRIORITIES__> heap;
-    //int num_priorities;
-    // int uPriorityValue;
-    // int uQueueNum;
-    // uBaseTask *uInheritTask;
     
-    int uCurrPriority;
-    int uCurrQueueNum;
+    int currPriority;
+    int currQueueNum;
 
     static int compare(int k1, int k2);
     static void exchange( uHeapable<int, uHeapBaseSeq *> &x, uHeapable<int, uHeapBaseSeq *> &y );
   public:
-    uPriorityQ ();
+    uPriorityQ();
     virtual bool empty() const;
     virtual uBaseTaskDL *head() const;
-    virtual int add( uBaseTaskDL *node, uBaseTask *uOwner );
+    virtual int add( uBaseTaskDL *node, uBaseTask *owner );
     virtual uBaseTaskDL *drop();
     virtual void remove( uBaseTaskDL *node ); 
-    virtual void uOnAcquire(uBaseTask &uOwner );
-    virtual void uOnRelease(uBaseTask &uOwner );
+    virtual void onAcquire(uBaseTask &uOwner );
+    virtual void onRelease(uBaseTask &uOwner );
 
-    int uAfterEntry( uBaseTask *uOwner );
+    int afterEntry( uBaseTask *owner );
 }; // PriorityQ
 
 
@@ -83,7 +78,7 @@ template<class List, class Node> class uPriorityScheduleQ : public uBaseSchedule
     };
 
     // compare for Heapify property, ie parent(i) <= i
-    static int compare(int k1, int k2) {
+    static int compare( int k1, int k2 ) {
 	if ( k1 < k2 ) {
 	    return 1;
 	} else if ( k1 == k2 ){
@@ -105,7 +100,7 @@ template<class List, class Node> class uPriorityScheduleQ : public uBaseSchedule
 #endif
     } // exchange
   protected:
-    uHeapScheduleSeq uObjects[ __U_MAX_NUMBER_PRIORITIES__ ];
+    uHeapScheduleSeq objects[ __U_MAX_NUMBER_PRIORITIES__ ];
     uHeap<int, uHeapScheduleSeq *, __U_MAX_NUMBER_PRIORITIES__> heap;
     unsigned int verCount;
     int num_priorities;
@@ -113,7 +108,7 @@ template<class List, class Node> class uPriorityScheduleQ : public uBaseSchedule
     uPriorityScheduleQ() : heap( &compare, &exchange ) {
 	verCount = 0;
 	num_priorities = 1;				// first is always non-real-time tasks
-	uObjects[0].priority = INT_MAX;			// use a large number, syn which addInitialize
+	objects[0].priority = INT_MAX;			// use a large number, syn which addInitialize
     } // uPriorityScheduleQ::uPriorityScheduleQ
 
     virtual bool empty() const {
@@ -131,16 +126,16 @@ template<class List, class Node> class uPriorityScheduleQ : public uBaseSchedule
     } // uPriorityScheduleQ::head
 
     virtual void add( Node *node ) {
-	int queueNum = uGetActiveQueueValue( node->uGet() );  // use the node for you active priority
+	int queueNum = getActiveQueueValue( node->task() );  // use the node for you active priority
 	    
 	// if empty then must add to heap, otherwise just insert node
-	if ( uObjects[queueNum].queue.empty() ) {
-	    uObjects[queueNum].queue.add(node);
+	if ( objects[queueNum].queue.empty() ) {
+	    objects[queueNum].queue.add(node);
 	    // the index must be set before inserting because the index can change as part of the insert
-	    uObjects[queueNum].index = heap.size() + 1;
-	    heap.insert( uObjects[queueNum].priority, &(uObjects[queueNum]) );
+	    objects[queueNum].index = heap.size() + 1;
+	    heap.insert( objects[queueNum].priority, &(objects[queueNum]) );
 	} else {
-	    uObjects[queueNum].queue.add(node);
+	    objects[queueNum].queue.add(node);
 	} // if
     } // uPriorityScheduleQ::add
 
@@ -159,12 +154,12 @@ template<class List, class Node> class uPriorityScheduleQ : public uBaseSchedule
 	} // if
     } // uPriorityScheduleQ::drop
 
-    virtual bool uCheckPriority( Node &, Node & ) {
+    virtual bool checkPriority( Node &, Node & ) {
 	return false;
-    } // uPriorityScheduleQ::uCheckPriority
+    } // uPriorityScheduleQ::checkPriority
 
-    virtual void uResetPriority( Node &, Node & ) {
-    } // uPriorityScheduleQ::uResetPriority
+    virtual void resetPriority( Node &, Node & ) {
+    } // uPriorityScheduleQ::resetPriority
 
     virtual void addInitialize( uBaseTaskSeq & ) {
     } // uPriorityScheduleQ::addInitialize
@@ -172,26 +167,26 @@ template<class List, class Node> class uPriorityScheduleQ : public uBaseSchedule
     virtual void removeInitialize( uBaseTaskSeq & ) {
     } // uPriorityScheduleQ::removeInitialize
 
-    virtual void uRescheduleTask( uBaseTaskDL *, uBaseTaskSeq & ) {
-    } // uPriorityScheduleQ::uRescheduleTask
+    virtual void rescheduleTask( uBaseTaskDL *, uBaseTaskSeq & ) {
+    } // uPriorityScheduleQ::rescheduleTask
 }; // uPriorityScheduleQ
 
 
 template<class List, class Node> class uPriorityScheduleQSeq : public uPriorityScheduleQ<List, Node> {
   protected:
-    using uPriorityScheduleQ<List, Node>::uObjects;
-    using uPriorityScheduleQ<List, Node>::uSetActivePriority;
-    using uPriorityScheduleQ<List, Node>::uSetActiveQueue;
+    using uPriorityScheduleQ<List, Node>::objects;
+    using uPriorityScheduleQ<List, Node>::setActivePriority;
+    using uPriorityScheduleQ<List, Node>::setActiveQueue;
     using uPriorityScheduleQ<List, Node>::heap;
   public:
-    virtual bool uCheckPriority( Node &owner, Node &calling ) {
-	return uGetActivePriorityValue( owner.uGet() ) > uGetActivePriorityValue( calling.uGet() );
-    } // uPriorityScheduleQSeq::uCheckPriority
+    virtual bool checkPriority( Node &owner, Node &calling ) {
+	return getActivePriorityValue( owner.task() ) > getActivePriorityValue( calling.task() );
+    } // uPriorityScheduleQSeq::checkPriority
 
-    virtual void uResetPriority( Node &owner, Node &calling ) {
+    virtual void resetPriority( Node &owner, Node &calling ) {
 	int queueNum;
-	uBaseTask &uOwner = owner.uGet();
-	uBaseTask &uCalling = calling.uGet();
+	uBaseTask &uOwner = owner.task();
+	uBaseTask &uCalling = calling.task();
 	// if same, update owner based on uPIQ
 	if ( &uOwner == &uCalling ) {
 	    queueNum = (static_cast<uPIHeap *>(uOwner.uPIQ))->head(); // TODO: dynamic needed???
@@ -206,23 +201,23 @@ template<class List, class Node> class uPriorityScheduleQSeq : public uPriorityS
 		
 	if ( owner.listed() ) {
 	    remove( &owner );
-	    uSetActivePriority( uOwner, uObjects[queueNum].priority );
-	    uSetActiveQueue( uOwner, queueNum );
+	    setActivePriority( uOwner, objects[queueNum].priority );
+	    setActiveQueue( uOwner, queueNum );
 	    add( &owner );
 	} else {
-	    uSetActivePriority( uOwner, uObjects[queueNum].priority );
-	    uSetActiveQueue( uOwner, queueNum );
+	    setActivePriority( uOwner, objects[queueNum].priority );
+	    setActiveQueue( uOwner, queueNum );
 	} // if
-    } // uPriorityScheduleQSeq::uResetPriority
+    } // uPriorityScheduleQSeq::resetPriority
 
     virtual void remove( Node *node ) {
-	int queueNum = uGetActiveQueueValue( node->uGet() ); // use the node for you active priority
+	int queueNum = getActiveQueueValue( node->task() ); // use the node for you active priority
 
 	// do remove
-	uObjects[queueNum].queue.remove(node);
+	objects[queueNum].queue.remove(node);
 	// if empty then must remove from heap
-	if ( uObjects[queueNum].queue.empty() ) {
-	    heap.deletenode( heap.A[uObjects[queueNum].index] );
+	if ( objects[queueNum].queue.empty() ) {
+	    heap.deletenode( heap.A[objects[queueNum].index] );
 	}
     } // uPriorityScheduleQSeq::remove
 }; // uPriorityScheduleQSeq
