@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Jiongxiong Chen and Ashif S. Harji 2003
+// uC++ Version 5.4.0, Copyright (C) Jiongxiong Chen and Ashif S. Harji 2003
 // 
 // uLifoScheduler.h -- 
 // 
 // Author           : Jiongxiong Chen and Ashif S. Harji
 // Created On       : Fri Feb 14 14:26:49 2003
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 11:18:18 2005
-// Update Count     : 143
+// Last Modified On : Wed Jan 25 07:45:59 2006
+// Update Count     : 146
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -44,15 +44,15 @@ uBaseTaskDL *uLifoScheduler::drop() {
     return temp;
 } // uLifoScheduler::drop
 
-bool uLifoScheduler::uCheckPriority( uBaseTaskDL &, uBaseTaskDL & ) { return false; }
+bool uLifoScheduler::checkPriority( uBaseTaskDL &, uBaseTaskDL & ) { return false; }
 
-void uLifoScheduler::uResetPriority( uBaseTaskDL &, uBaseTaskDL & ) {}
+void uLifoScheduler::resetPriority( uBaseTaskDL &, uBaseTaskDL & ) {}
 
 void uLifoScheduler::addInitialize( uBaseTaskSeq & ) {};
 
 void uLifoScheduler::removeInitialize( uBaseTaskSeq & ) {};
 
-void uLifoScheduler::uRescheduleTask( uBaseTaskDL *, uBaseTaskSeq & ) {};
+void uLifoScheduler::rescheduleTask( uBaseTaskDL *, uBaseTaskSeq & ) {};
 
 
 // Local Variables: //
