@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Jiongxiong Chen and Ashif S. Harji 2003
+// uC++ Version 5.4.0, Copyright (C) Jiongxiong Chen and Ashif S. Harji 2003
 // 
 // uLifoScheduler.h -- 
 // 
 // Author           : Jiongxiong Chen and Ashif S. Harji
 // Created On       : Fri Feb 14 14:26:49 2003
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 11:13:50 2005
-// Update Count     : 136
+// Last Modified On : Wed Jan 25 07:45:52 2006
+// Update Count     : 140
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -38,11 +38,11 @@ class uLifoScheduler : public uBaseSchedule<uBaseTaskDL> {
     bool empty() const;
     void add( uBaseTaskDL *node );
     uBaseTaskDL *drop();
-    bool uCheckPriority( uBaseTaskDL &owner, uBaseTaskDL &calling );
-    void uResetPriority( uBaseTaskDL &owner, uBaseTaskDL &calling );
-    void addInitialize( uBaseTaskSeq &TaskList );
-    void removeInitialize( uBaseTaskSeq &TaskList );
-    void uRescheduleTask( uBaseTaskDL *TaskNode, uBaseTaskSeq &TaskList );
+    bool checkPriority( uBaseTaskDL &owner, uBaseTaskDL &calling );
+    void resetPriority( uBaseTaskDL &owner, uBaseTaskDL &calling );
+    void addInitialize( uBaseTaskSeq &taskList );
+    void removeInitialize( uBaseTaskSeq &taskList );
+    void rescheduleTask( uBaseTaskDL *taskNode, uBaseTaskSeq &taskList );
 }; // uLifoScheduler
 
 #pragma __U_USER_CODE__
