@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.4.0, Copyright (C) Ashif S. Harji 2000
 // 
 // uPIHeap.cc -- 
 // 
 // Author           : Ashif S. Harji
 // Created On       : Fri Feb  4 11:10:44 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 11:12:35 2005
-// Update Count     : 24
+// Last Modified On : Wed Jan 25 08:28:41 2006
+// Update Count     : 27
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -58,11 +58,11 @@ void uPIHeap::exchange( uHeapable<int, uHeapBaseSeq *> &x, uHeapable<int, uHeapB
 
 uPIHeap::uPIHeap() : heap( &compare, &exchange ) {
     for ( int i = 0; i < __U_MAX_NUMBER_PRIORITIES__ ; i += 1 ) {
-	uObjects[i].count = 0;
+	objects[i].count = 0;
     } // for
     //num_priorities = 1; // first is always non-real-time tasks
-    //uObjects[0].priority = 2147483647;  // use a large number, syn which addInitialize
-    //uObjects[0].count = 0;
+    //objects[0].priority = 2147483647;  // use a large number, syn which addInitialize
+    //objects[0].count = 0;
 } // uPIHeap::uPIHeap
 
 
@@ -82,7 +82,7 @@ int uPIHeap::head() const {
 } // uPIHeap::head
 
 
-int uPIHeap::uGetHighestPriority() {			
+int uPIHeap::getHighestPriority() {			
     if ( ! empty() ) {
 	uHeapable<int,uHeapBaseSeq *> rqueue;
 	heap.getRoot( rqueue );
@@ -90,7 +90,7 @@ int uPIHeap::uGetHighestPriority() {
     } else {
 	return -1;
     } // if
-} // uPIHeap::uGetHighestPriority
+} // uPIHeap::getHighestPriority
 
 
 void uPIHeap::add( int priority, int queueNum ) {	
@@ -99,25 +99,25 @@ void uPIHeap::add( int priority, int queueNum ) {
 
     // as the entry lock is acquired, no other task can be manipulating this node,
     // so lock does not need to be aquired yet.
-    //if ( uOwner == &(node->uGet()) ) {
-    //priority = uGetBasePriority( node->uGet() );
-    //queueNum = uGetBaseQueue( node->uGet() );  // use the node for your base priority
+    //if ( uOwner == &(node->task()) ) {
+    //priority = getBasePriority( node->task() );
+    //queueNum = getBaseQueue( node->task() );  // use the node for your base priority
     //} else {
-    //priority = uGetActivePriority( node->uGet() );
-    //queueNum = uGetActiveQueue( uGetInheritTask( node->uGet() ) ); // use the node for your active priority
+    //priority = getActivePriority( node->task() );
+    //queueNum = getActiveQueue( getInheritTask( node->task() ) ); // use the node for your active priority
     //} // if
 
     lock.acquire();
 
     // if empty then must add to heap, otherwise just insert node
-    if ( uObjects[queueNum].count == 0 ) {
+    if ( objects[queueNum].count == 0 ) {
 	// the index must be set before inserting because the index can change as part of the insert
-	uObjects[queueNum].index = heap.size() + 1;
-	heap.insert( priority, &(uObjects[queueNum]) );
+	objects[queueNum].index = heap.size() + 1;
+	heap.insert( priority, &(objects[queueNum]) );
     } // if
-    //uObjects[queueNum].queue.add(node);
-    uObjects[queueNum].count += 1;
-    uObjects[queueNum].queueNum = queueNum;
+    //objects[queueNum].queue.add(node);
+    objects[queueNum].count += 1;
+    objects[queueNum].queueNum = queueNum;
     lock.release();
 } // uPriorityScheduleQueue::add
 
@@ -148,20 +148,20 @@ void uPIHeap::remove( int priority, int queueNum ) {
     // as the entry lock is acquired, no other task can be manipulating this node,
     // so lock does not need to be aquired yet.
 
-    //if ( uOwner == &(node->uGet()) ) {
-    //queueNum = uGetBaseQueue( node->uGet() );	// use the node for your base priority
+    //if ( uOwner == &(node->task()) ) {
+    //queueNum = getBaseQueue( node->task() );	// use the node for your base priority
     //} else {
-    //queueNum = uGetActiveQueue( uGetInheritTask(node->uGet() ) ); // use the node for your active priority
+    //queueNum = getActiveQueue( getInheritTask(node->task() ) ); // use the node for your active priority
     //} // if
 
     lock.acquire();
 
     // do remove
-    uObjects[queueNum].count -= 1;
+    objects[queueNum].count -= 1;
 
     // if empty then must remove from heap
-    if ( uObjects[queueNum].count == 0 ) {
-	heap.deletenode( heap.A[uObjects[queueNum].index] );
+    if ( objects[queueNum].count == 0 ) {
+	heap.deletenode( heap.A[objects[queueNum].index] );
     } // if
 
     lock.release();
