@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.4.0, Copyright (C) Ashif S. Harji 2000
 // 
 // uPIHeap.h -- 
 // 
 // Author           : Ashif S. Harji
 // Created On       : Fri Jan 14 17:53:22 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 10:29:05 2005
-// Update Count     : 20
+// Last Modified On : Wed Jan 25 07:48:31 2006
+// Update Count     : 22
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -47,7 +47,7 @@ class uPIHeap : public uBasePIQ {
 	//uBaseTaskSeq queue;
     };
 
-    uHeapBaseSeq uObjects[ __U_MAX_NUMBER_PRIORITIES__ ]; 
+    uHeapBaseSeq objects[ __U_MAX_NUMBER_PRIORITIES__ ]; 
     uHeap<int, uHeapBaseSeq *, __U_MAX_NUMBER_PRIORITIES__> heap;
     uSpinLock lock;
     
@@ -57,7 +57,7 @@ class uPIHeap : public uBasePIQ {
     uPIHeap();
     virtual bool empty() const;
     virtual int head() const;
-    virtual int uGetHighestPriority();
+    virtual int getHighestPriority();
     virtual void add( int priority, int queueNum );
     virtual int drop();
     virtual void remove( int priority, int queueNum ); 
