@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Philipp E. Lim 1996
+// uC++ Version 5.4.0, Copyright (C) Philipp E. Lim 1996
 // 
 // uRealTime.h -- 
 // 
 // Author           : Philipp E. Lim
 // Created On       : Fri Jul 19 16:34:59 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 11:12:43 2005
-// Update Count     : 86
+// Last Modified On : Tue Sep 12 08:12:08 2006
+// Update Count     : 113
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -42,7 +42,6 @@
 class uEvent {
   public:
     uEvent() {};
-    //     uEvent(int x) {};
 };
 
 
@@ -54,23 +53,23 @@ class uEvent {
 
 template<class List, class Node> class uPriorityScheduleQueue : public uBaseSchedule<Node> {
   protected:
-    List uObjects[__U_MAX_NUMBER_PRIORITIES__];
-    unsigned int uMask;					// allow access to all queue flags
+    List objects[__U_MAX_NUMBER_PRIORITIES__];
+    unsigned int mask;					// allow access to all queue flags
     unsigned int verCount;
   public:
     uPriorityScheduleQueue() {
-	verCount = uMask = 0;
+	verCount = mask = 0;
     } // uPriorityScheduleQueue::uPriorityScheduleQueue
 
     virtual bool empty() const {
-	return uMask == 0;
+	return mask == 0;
     } // uPriorityScheduleQueue::empty
 
     virtual Node *head() const {
-	int highestPriority = ffs( uMask ) - 1;
+	int highestPriority = ffs( mask ) - 1;
 
 	if ( highestPriority >= 0 ) {
-	    Node *node = uObjects[highestPriority].head();
+	    Node *node = objects[highestPriority].head();
 	    return node;
 	} else {
 	    return NULL;
@@ -78,29 +77,29 @@ template<class List, class Node> class uPriorityScheduleQueue : public uBaseSche
     } // uPriorityScheduleQueue::head
 
     virtual void add( Node *node ) {
-	int priority = uGetActivePriority( node->uGet() );
+	int priority = getActivePriority( node->task() );
 #ifdef __U_DEBUG__
-	uAssert( 0 <= priority && priority <= __U_MAX_NUMBER_PRIORITIES__ - 1 );
+	assert( 0 <= priority && priority <= __U_MAX_NUMBER_PRIORITIES__ - 1 );
 #endif // __U_DEBUG__
-	uObjects[priority].add( node );
-	uMask |= 1ul << priority;
+	objects[priority].add( node );
+	mask |= 1ul << priority;
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "(uPriorityScheduleQueue &)0x%p.add( 0x%p ) task %.256s (0x%p) adding   task %.256s (0x%p) with priority %d on cluster 0x%p\n",
-		   this, node, uThisTask().getName(), &uThisTask(), node->uGet().getName(), &node->uGet(), priority, &uThisCluster() );
+		   this, node, uThisTask().getName(), &uThisTask(), node->task().getName(), &node->task(), priority, &uThisCluster() );
 #endif // __U_DEBUG_H__
     } // uPriorityScheduleQueue::add
 
     virtual Node *drop() {
-	int highestPriority = ffs( uMask ) - 1;
+	int highestPriority = ffs( mask ) - 1;
 
 	if ( highestPriority >= 0 ) {
-	    Node *node = uObjects[highestPriority].drop();
-	    if ( uObjects[highestPriority].empty() ) {
-		uMask &= ~ ( 1ul << highestPriority );
+	    Node *node = objects[highestPriority].drop();
+	    if ( objects[highestPriority].empty() ) {
+		mask &= ~ ( 1ul << highestPriority );
 	    } // if
 #ifdef __U_DEBUG_H__
 	    uDebugPrt( "(uPriorityScheduleQueue &)0x%p.drop( 0x%p ) task %.256s (0x%p) removing task %.256s (0x%p) with priority %d on cluster 0x%p\n",
-		       this, node, uThisTask().getName(), &uThisTask(), node->uGet().getName(), &node->uGet(), highestPriority, &uThisCluster() );
+		       this, node, uThisTask().getName(), &uThisTask(), node->task().getName(), &node->task(), highestPriority, &uThisCluster() );
 #endif // __U_DEBUG_H__
 	    return node;
 	} else {
@@ -108,12 +107,12 @@ template<class List, class Node> class uPriorityScheduleQueue : public uBaseSche
 	} // if
     } // uPriorityScheduleQueue::drop
 
-    virtual bool uCheckPriority( Node &, Node & ) {
+    virtual bool checkPriority( Node &, Node & ) {
 	return false;
-    } // uPriorityScheduleQueue::uCheckPriority
+    } // uPriorityScheduleQueue::checkPriority
 
-    virtual void uResetPriority( Node &, Node & ) {
-    } // uPriorityScheduleQueue::uResetPriority
+    virtual void resetPriority( Node &, Node & ) {
+    } // uPriorityScheduleQueue::resetPriority
 
     virtual void addInitialize( uBaseTaskSeq & ) {
     } // uPriorityScheduleQueue::addInitialize
@@ -121,52 +120,52 @@ template<class List, class Node> class uPriorityScheduleQueue : public uBaseSche
     virtual void removeInitialize( uBaseTaskSeq & ) {
     } // uPriorityScheduleQueue::removeInitialize
 
-    virtual void uRescheduleTask( uBaseTaskDL *, uBaseTaskSeq & ) {
-    } // uPriorityScheduleQueue::uRescheduleTask
+    virtual void rescheduleTask( uBaseTaskDL *, uBaseTaskSeq & ) {
+    } // uPriorityScheduleQueue::rescheduleTask
 }; // uPriorityScheduleQueue
 
 
 class uPrioritySeq : public uBasePrioritySeq {
   protected:
-    uBaseTaskSeq uObjects[__U_MAX_NUMBER_PRIORITIES__];
-    unsigned int uMask;					// allow access to all queue flags
-    uBaseTask *uOldInheritTask;
-    int uAfterEntry( uBaseTask *uOwner );
+    uBaseTaskSeq objects[__U_MAX_NUMBER_PRIORITIES__];
+    unsigned int mask;					// allow access to all queue flags
+    uBaseTask *oldInheritTask;
+    int afterEntry( uBaseTask *owner );
   public:
     uPrioritySeq();
     virtual bool empty() const;
     virtual uBaseTaskDL *head() const;
-    virtual int add( uBaseTaskDL *node, uBaseTask *uOwner );
+    virtual int add( uBaseTaskDL *node, uBaseTask *owner );
     virtual uBaseTaskDL *drop();
     virtual void remove( uBaseTaskDL *node );
-    virtual void uOnAcquire(uBaseTask &uOldOwner );
-    virtual void uOnRelease( uBaseTask &uOwner );
+    virtual void onAcquire( uBaseTask &oldOwner );
+    virtual void onRelease( uBaseTask &owner );
 }; // uPrioritySeq
 
 
 template<class List, class Node> class uPriorityScheduleSeq : public uPriorityScheduleQueue<List, Node> {
-    using uPriorityScheduleQueue<List, Node>::uObjects;
-    using uPriorityScheduleQueue<List, Node>::uMask;
+    using uPriorityScheduleQueue<List, Node>::objects;
+    using uPriorityScheduleQueue<List, Node>::mask;
   public:
-    virtual bool uCheckPriority( Node &owner, Node &calling ) {
-	return uGetActivePriority( owner.uGet() ) > uGetActivePriority( calling.uGet() );
-    } // uPriorityScheduleSeq::uCheckPriority
+    virtual bool checkPriority( Node &owner, Node &calling ) {
+	return getActivePriority( owner.task() ) > getActivePriority( calling.task() );
+    } // uPriorityScheduleSeq::checkPriority
 
-    virtual void uResetPriority( Node &owner, Node &calling ) {
+    virtual void resetPriority( Node &owner, Node &calling ) {
 	if ( owner.listed() ) {
 	    remove( &owner );
-	    uSetActivePriority( owner.uGet(), calling.uGet() );
+	    setActivePriority( owner.task(), calling.task() );
 	    add( &owner );
 	} else {
-	    uSetActivePriority( owner.uGet(), calling.uGet() );
+	    setActivePriority( owner.task(), calling.task() );
 	} // if
-    } // uPriorityScheduleSeq::uResetPriority
+    } // uPriorityScheduleSeq::resetPriority
 
     virtual void remove( Node *node ) {
-	int priority = uGetActivePriority( node->uGet() );
-	uObjects[priority].remove( node );
-	if ( uObjects[priority].empty() ) {
-	    uMask &= ~ ( 1ul << priority );
+	int priority = getActivePriority( node->task() );
+	objects[priority].remove( node );
+	if ( objects[priority].empty() ) {
+	    mask &= ~ ( 1ul << priority );
 	} // if
     } // uPriorityScheduleSeq::remove
 }; // uPriorityScheduleSeq
@@ -176,32 +175,32 @@ template<class List, class Node> class uPriorityScheduleSeq : public uPrioritySc
 
 
 class uRealTimeBaseTask : public uBaseTask {
-    class uVerCount : public uSeqable {
+    class VerCount : public uSeqable {
       public:
 	int version;
 	uCluster *cluster;
-    }; // uVerCount
+    }; // VerCount
 
-    uDuration uDeadline;
-    uSequence<uVerCount> uVerCountSeq;                  // list of scheduler version counts with associated cluster 
+    uDuration deadline;
+    uSequence<VerCount> verCountSeq;			// list of scheduler version counts with associated cluster 
   protected: 
-    uTime uFirstActivateTime;
-    uEvent uFirstActivateEvent;
-    uTime uEndTime;
+    uTime firstActivateTime;
+    uEvent firstActivateEvent;
+    uTime endTime;
   public:
     uRealTimeBaseTask( uCluster &cluster = uThisCluster() );
-    uRealTimeBaseTask( uTime FirstActivateT, uTime EndTime, uDuration Deadline, uCluster &cluster = uThisCluster() );
-    uRealTimeBaseTask( uEvent FirstActivateE, uTime EndTime, uDuration Deadline, uCluster &cluster = uThisCluster() );
-    uRealTimeBaseTask( uTime FirstActivateT, uEvent FirstActivateE, uTime EndTime, uDuration Deadline, uCluster &cluster = uThisCluster() );
+    uRealTimeBaseTask( uTime _firstActivateTask, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
+    uRealTimeBaseTask( uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
+    uRealTimeBaseTask( uTime _firstActivateTask, uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
     ~uRealTimeBaseTask();
-    virtual uDuration uGetDeadline() const;
-    virtual uDuration uSetDeadline( uDuration Deadline );
+    virtual uDuration getDeadline() const;
+    virtual uDuration setDeadline( uDuration _deadline );
 
     // These members should be private but cannot be because they are
     // referenced from user code.
 
-    virtual int uGetVersion( uCluster &cluster );
-    virtual int uSetVersion( uCluster &cluster, int version );
+    virtual int getVersion( uCluster &cluster );
+    virtual int setVersion( uCluster &cluster, int version );
 }; // uRealTimeBaseTask
 
 
@@ -210,14 +209,14 @@ class uRealTimeBaseTask : public uBaseTask {
 
 class uPeriodicBaseTask : public uRealTimeBaseTask {
   protected:
-    uDuration uPeriod;
+    uDuration period;
   public:
-    uPeriodicBaseTask( uDuration Period, uCluster &cluster = uThisCluster() );
-    uPeriodicBaseTask( uDuration Period, uTime FirstActivateT, uTime EndTime, uDuration Deadline, uCluster &cluster = uThisCluster() );
-    uPeriodicBaseTask( uDuration Period, uEvent FirstActivateE, uTime EndTime, uDuration Deadline, uCluster &cluster = uThisCluster() );
-    uPeriodicBaseTask( uDuration Period, uTime FirstActivateT, uEvent FirstActivateE, uTime EndTime, uDuration Deadline, uCluster &cluster = uThisCluster() );
-    uDuration uGetPeriod() const;
-    uDuration uSetPeriod( uDuration period );
+    uPeriodicBaseTask( uDuration _period, uCluster &cluster = uThisCluster() );
+    uPeriodicBaseTask( uDuration _period, uTime _firstActivateTask, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
+    uPeriodicBaseTask( uDuration _period, uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
+    uPeriodicBaseTask( uDuration _period, uTime _firstActivateTask, uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
+    uDuration getPeriod() const;
+    uDuration setPeriod( uDuration _period );
 }; // uPeriodicBaseTask
 
 
@@ -226,14 +225,14 @@ class uPeriodicBaseTask : public uRealTimeBaseTask {
 
 class uSporadicBaseTask : public uRealTimeBaseTask {
   protected:
-    uDuration uFrame;
+    uDuration frame;
   public:
-    uSporadicBaseTask( uDuration Frame, uCluster &cluster = uThisCluster() );
-    uSporadicBaseTask( uDuration Frame, uTime FirstActivateT, uTime EndTime, uDuration Deadline, uCluster &cluster = uThisCluster() );
-    uSporadicBaseTask( uDuration Frame, uEvent FirstActivateE, uTime EndTime, uDuration Deadline, uCluster &cluster = uThisCluster() );
-    uSporadicBaseTask( uDuration Frame, uTime FirstActivateT, uEvent FirstActivateE, uTime EndTime, uDuration Deadline, uCluster &cluster = uThisCluster() );
-    uDuration uGetFrame() const;
-    uDuration uSetFrame( uDuration frame );
+    uSporadicBaseTask( uDuration _frame, uCluster &cluster = uThisCluster() );
+    uSporadicBaseTask( uDuration _frame, uTime _firstActivateTask, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
+    uSporadicBaseTask( uDuration _frame, uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
+    uSporadicBaseTask( uDuration _frame, uTime _firstActivateTask, uEvent _firstActivateEvent, uTime _endTime, uDuration _deadline, uCluster &cluster = uThisCluster() );
+    uDuration getFrame() const;
+    uDuration setFrame( uDuration _frame );
 }; // uSporadicBaseTask
 
 
