@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.4.0, Copyright (C) Ashif S. Harji 2000
 // 
 // uPIHeap.cc -- 
 // 
 // Author           : Ashif S. Harji
 // Created On       : Fri Feb  4 11:10:44 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 10:29:31 2005
-// Update Count     : 43
+// Last Modified On : Tue Sep 12 08:12:15 2006
+// Update Count     : 48
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -35,18 +35,18 @@
 
 uStaticPIQ::uStaticPIQ() {
     for ( int i = 0; i < __U_MAX_NUMBER_PRIORITIES__ ; i += 1 ) {
-	uObjects[i] = 0;
+	objects[i] = 0;
     } // for
-    uMask = 0;
+    mask = 0;
 
 } // uStaticPIQ::uStaticPIQ
 
 bool uStaticPIQ::empty() const {
-    return uMask == 0;
+    return mask == 0;
 } // uStaticPIQ::empty
 
 //int uStaticPIQ::head() {			
-//	int highestPriority = ffs( uMask ) - 1;
+//	int highestPriority = ffs( mask ) - 1;
 //
 //	if ( highestPriority >= 0 ) {
 //	    return highestPriority;
@@ -56,22 +56,22 @@ bool uStaticPIQ::empty() const {
 //
 //} // uStaticPIQ::head
 
-int uStaticPIQ::uGetHighestPriority() {			
-	int highestPriority = ffs( uMask ) - 1;
+int uStaticPIQ::getHighestPriority() {			
+    int highestPriority = ffs( mask ) - 1;
 
-	if ( highestPriority >= 0 ) {
-	    return highestPriority;
-	} else {
-	    return -1;
-	} // if
-} // uStaticPIQ::uGetHighestPriority
+    if ( highestPriority >= 0 ) {
+	return highestPriority;
+    } else {
+	return -1;
+    } // if
+} // uStaticPIQ::getHighestPriority
 
 void uStaticPIQ::add( int priority ) {	
     lock.acquire();
 
-    uAssert( 0 <= priority && priority <= __U_MAX_NUMBER_PRIORITIES__ - 1 );
-    uObjects[priority] += 1;
-    uMask |= 1ul << priority;
+    assert( 0 <= priority && priority <= __U_MAX_NUMBER_PRIORITIES__ - 1 );
+    objects[priority] += 1;
+    mask |= 1ul << priority;
 
     lock.release();
 } // uPriorityScheduleQueue::add
@@ -79,13 +79,13 @@ void uStaticPIQ::add( int priority ) {
 int uStaticPIQ::drop() {				
     lock.acquire();
     
-    int highestPriority = ffs( uMask ) - 1;
+    int highestPriority = ffs( mask ) - 1;
 	
     if ( highestPriority >= 0 ) {
-	uObjects[highestPriority] -= 1;
+	objects[highestPriority] -= 1;
 
-	if ( uObjects[highestPriority] == 0 ) {
-	    uMask &= ~ ( 1ul << highestPriority );
+	if ( objects[highestPriority] == 0 ) {
+	    mask &= ~ ( 1ul << highestPriority );
 	} // if
 	
     } // if
@@ -97,10 +97,10 @@ int uStaticPIQ::drop() {
 void uStaticPIQ::remove( int priority ) {		
     lock.acquire();
 
-    uAssert( 0 <= priority && priority <= __U_MAX_NUMBER_PRIORITIES__ - 1 );
-    uObjects[priority] -= 1;
-    if ( uObjects[priority] == 0 ) {
-	uMask &= ~ ( 1ul << priority );
+    assert( 0 <= priority && priority <= __U_MAX_NUMBER_PRIORITIES__ - 1 );
+    objects[priority] -= 1;
+    if ( objects[priority] == 0 ) {
+	mask &= ~ ( 1ul << priority );
     } // if
 
     lock.release();
