@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.4.0, Copyright (C) Ashif S. Harji 2000
 // 
 // uStaticPIQ.h -- 
 // 
 // Author           : Ashif S. Harji
 // Created On       : Fri Jan 14 17:53:22 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 10:29:38 2005
-// Update Count     : 30
+// Last Modified On : Thu Jan 26 17:57:24 2006
+// Update Count     : 34
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -41,16 +41,16 @@
 
 
 class uStaticPIQ : public uBasePIQ {
-    int uObjects[ __U_MAX_NUMBER_PRIORITIES__ ];
+    int objects[ __U_MAX_NUMBER_PRIORITIES__ ];
     uSpinLock lock;
-    unsigned int uMask;
+    unsigned int mask;
     
-    static int compare(int k1, int k2);
+    static int compare( int k1, int k2 );
   public:
     uStaticPIQ();
     virtual bool empty() const;
     //virtual int head();
-    virtual int uGetHighestPriority();
+    virtual int getHighestPriority();
     virtual void add( int priority );
     virtual int drop();
     virtual void remove( int priority ); 
