@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.4.0, Copyright (C) Ashif S. Harji 2000
 // 
 // uStaticPriorityQ.cc -- 
 // 
 // Author           : Ashif S. Harji
 // Created On       : Mon Feb  1 15:06:12 1999
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 10:29:47 2005
-// Update Count     : 139
+// Last Modified On : Tue Sep 12 08:12:21 2006
+// Update Count     : 153
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -35,53 +35,53 @@
 
 
 uStaticPriorityQ::uStaticPriorityQ() {				
-    uMask = 0;
-    uExecuteHooks = true;
-    uCurrPriority = -1;
+    mask = 0;
+    executeHooks = true;
+    currPriority = -1;
 } // uStaticPriorityQ::uStaticPriorityQ
 
 bool uStaticPriorityQ::empty() const {			
-    return uMask == 0;
+    return mask == 0;
 } // uStaticPriorityQ::empty
 
 uBaseTaskDL *uStaticPriorityQ::head() const {			
-    int highestPriority = ffs( uMask ) - 1;
+    int highestPriority = ffs( mask ) - 1;
 
     if ( highestPriority >= 0 ) {
-	uBaseTaskDL *node = uObjects[highestPriority].head();
+	uBaseTaskDL *node = objects[highestPriority].head();
 	return node;
     } else {
 	return NULL;
     } // if
 } // uStaticPriorityQ::head
 
-int uStaticPriorityQ::add( uBaseTaskDL *node, uBaseTask *uOwner ) {
+int uStaticPriorityQ::add( uBaseTaskDL *node, uBaseTask *owner ) {
     // Dynamic check to verify that the task being added to entry queue is
     // compliant with PIHeap type.
-    uStaticPIQ *PIQptr = dynamic_cast<uStaticPIQ *>(node->uGet().uPIQ);
+    uStaticPIQ *PIQptr = dynamic_cast<uStaticPIQ *>(node->task().uPIQ);
     if ( PIQptr == NULL ) {
     //return uLockAcquired; // TEMPORARY
-	uAbort("(uStaticPriorityQ &)0x%p.add : Task 0x%p has incorrect uPIQ type for mutex object.", this, &node->uGet());
+	uAbort("(uStaticPriorityQ &)0x%p.add : Task 0x%p has incorrect uPIQ type for mutex object.", this, &node->task());
     } //if
     
     // check if your priority needs to be updated
-    if ( PIQptr->uGetHighestPriority() < uGetActivePriorityValue( node->uGet() )  ) {
-	uThisCluster().uTaskSetPriority( node->uGet(), node->uGet() );
+    if ( PIQptr->getHighestPriority() < getActivePriorityValue( node->task() )  ) {
+	uThisCluster().taskSetPriority( node->task(), node->task() );
     } // if
 
     // As uCurrentSerial is updated, the calling task's priority can no longer
     // change because the tasks uPIQ is fixed as the entry lock is acquired.
     // So subsequent updates will only reaffirm the task's current priority.
 
-    int priority = uGetActivePriorityValue( node->uGet() );
+    int priority = getActivePriorityValue( node->task() );
 
-    uAssert( 0 <= priority && priority <= __U_MAX_NUMBER_PRIORITIES__ - 1 );
-    uObjects[priority].add( node );
-    uMask |= 1ul << priority;
+    assert( 0 <= priority && priority <= __U_MAX_NUMBER_PRIORITIES__ - 1 );
+    objects[priority].add( node );
+    mask |= 1ul << priority;
 
     // only perform inheritance for entry list
-    if ( /* this == &(s->uEntryList) */ uIsEntryBlocked( node->uGet() ) && uCheckHookConditions( *uOwner, node->uGet() ) ) {	// TEMP: entry queue??
-	return( uAfterEntry( uOwner ) );		// perform any priority inheritance
+    if ( /* this == &(s->uEntryList) */ isEntryBlocked( node->task() ) && checkHookConditions( *owner, node->task() ) ) { // TEMP: entry queue??
+	return( afterEntry( owner ) );		// perform any priority inheritance
     } else {
 	return uLockAcquired;
     } // if
@@ -89,12 +89,12 @@ int uStaticPriorityQ::add( uBaseTaskDL *node, uBaseTask *uOwner ) {
 } // uStaticPriorityQ::add
 
 uBaseTaskDL *uStaticPriorityQ::drop() {				
-    int highestPriority = ffs( uMask ) - 1;
+    int highestPriority = ffs( mask ) - 1;
 
     if ( highestPriority >= 0 ) {
-	uBaseTaskDL *node = uObjects[highestPriority].drop();
-	if ( uObjects[highestPriority].empty() ) {
-	    uMask &= ~ ( 1ul << highestPriority );
+	uBaseTaskDL *node = objects[highestPriority].drop();
+	if ( objects[highestPriority].empty() ) {
+	    mask &= ~ ( 1ul << highestPriority );
 	} // if
 	return node;
     } else {
@@ -105,58 +105,58 @@ uBaseTaskDL *uStaticPriorityQ::drop() {
 void uStaticPriorityQ::remove( uBaseTaskDL *node ) {		
     // use stored priority value because this task has entry lock, so its uPIQ may
     // be updated, but not its position on the entry queue.
-    int priority = uGetActivePriorityValue( node->uGet() );
+    int priority = getActivePriorityValue( node->task() );
 
-    uObjects[priority].remove( node );
-    if ( uObjects[priority].empty() ) {
-	uMask &= ~ ( 1ul << priority );
+    objects[priority].remove( node );
+    if ( objects[priority].empty() ) {
+	mask &= ~ ( 1ul << priority );
     } // if
 } // uStaticPriorityQ::remove
 
 
-int uStaticPriorityQ::uAfterEntry(uBaseTask *uOwner ) { // use pointer to owner as it could be Null
-    // static_cast to uStaticPIQ are valid here as add and uOnAcquire already
+int uStaticPriorityQ::afterEntry( uBaseTask *owner ) { // use pointer to owner as it could be Null
+    // static_cast to uStaticPIQ are valid here as add and onAcquire already
     // verify that the associated tasks use type uStaticPIQ.
 
     // assume entry lock acquired
     int uRelPrevLock = uLockAcquired;
 
     // if entry queue empty (called by owner) or no owner, then no inheritance
-    if ( empty() || uOwner == NULL /* || uCurrPriority == -1 */ ) {
+    if ( empty() || owner == NULL /* || currPriority == -1 */ ) {
 	return uRelPrevLock;
     } // if
 
-    uBaseTask &uCalling = head()->uGet();		// can't be NULL as not empty 
+    uBaseTask &uCalling = head()->task();		// can't be NULL as not empty 
 
     // does node need to be updated?
-    if ( uCalling.getActivePriorityValue() < uCurrPriority ) { 
+    if ( uCalling.getActivePriorityValue() < currPriority ) { 
         // only task with entry lock can be modifying this mutex's node
 	// remove node
-	(static_cast<uStaticPIQ *>(uOwner->uPIQ))->remove( uCurrPriority );
+	(static_cast<uStaticPIQ *>(owner->uPIQ))->remove( currPriority );
 	
 	// reset priority value for monitor
-	uCurrPriority = uCalling.getActivePriorityValue();
+	currPriority = uCalling.getActivePriorityValue();
 
         // update mutex owner's uPIQ for new priority
-	(static_cast<uStaticPIQ *>(uOwner->uPIQ))->add( uCurrPriority ) ;  
+	(static_cast<uStaticPIQ *>(owner->uPIQ))->add( currPriority ) ;  
     
 	// does inheritance occur ?
-	if ( uCurrPriority < uOwner->getActivePriorityValue() ) {
+	if ( currPriority < owner->getActivePriorityValue() ) {
 	    
-	    uRepositionEntry rep(*uOwner, uCalling);
-	    //uSerial *uRememberSerial = &(uOwner->uGetSerial());
+	    uRepositionEntry rep(*owner, uCalling);
+	    //uSerial *uRememberSerial = &(owner->getSerial());
             // if task is blocked on entry list, adjust and perform transitivity
-	    if ( uIsEntryBlocked( *uOwner ) ) {
+	    if ( isEntryBlocked( *owner ) ) {
 
 		uRelPrevLock = rep.uReposition(true);
-		//uRepositionWrapper( uOwner, uRememberSerial, s );
+		//uRepositionWrapper( owner, uRememberSerial, s );
 		//uRememberSerial->lock.acquire();
 		
 		// if owner's current mutex object changes, then owner fixes
 		// its own active priority. Recheck if inheritance is necessary
 		// as only owner can lower its priority => updated
-		//if ( uRememberSerial != &(uOwner->uGetSerial()) || ! uIsEntryBlocked( *uOwner ) ||
-		//    (static_cast<uStaticPIQ *>(uOwner->uPIQ))->uGetHighestPriority() >= uOwner->uGetActivePriorityValue() ) {
+		//if ( uRememberSerial != &(owner->getSerial()) || ! isEntryBlocked( *owner ) ||
+		//    (static_cast<uStaticPIQ *>(owner->uPIQ))->getHighestPriority() >= owner->getActivePriorityValue() ) {
 		// As owner restarted, the end of the blocking chain has been reached.
 		//uRememberSerial->lock.release();
 		//return uRelPrevLock;
@@ -165,28 +165,28 @@ int uStaticPriorityQ::uAfterEntry(uBaseTask *uOwner ) { // use pointer to owner
 		//s->lock.release();  // release the old lock as correct current lock is acquired
 		//uRelPrevLock = uLockReleased;
 		
-		//if ( uReposition( uOwner, uRememberSerial ) == uLockAcquired ) {
+		//if ( uReposition( owner, uRememberSerial ) == uLockAcquired ) {
 		// only last call does not release lock, so reacquire first entry lock
-		//uThisTask().uGetSerial().lock.acquire();
+		//uThisTask().getSerial().lock.acquire();
 		//uRememberSerial->lock.release();
 		//} // if
 		
                 // proceed with transitivity
 		// remove from entry queue
-		//uRememberSerial->uEntryList.remove( &(uOwner->uEntryRef) ); 
+		//uRememberSerial->uEntryList.remove( &(owner->uEntryRef) ); 
 		// remove from mutex queue
-		//uOwner->uCalledEntryMem->remove( &(uOwner->uMutexRef) );
+		//owner->uCalledEntryMem->remove( &(owner->uMutexRef) );
 		
 		// call cluster routine to adjust ready queue and active
 		// priority as owner is not on entry queue, it can be updated
 		// based on its uPIQ
-		//uThisCluster().uTaskSetPriority( *uOwner, *uOwner );
+		//uThisCluster().taskSetPriority( *owner, *owner );
 		
 		// add to mutex queue
-		//uOwner->uCalledEntryMem->add( &(uOwner->uMutexRef), uRememberSerial->uMutexOwner, uRememberSerial );
+		//owner->uCalledEntryMem->add( &(owner->uMutexRef), uRememberSerial->uMutexOwner, uRememberSerial );
 		
 		// add to entry queue, automatically does transitivity
-		//if ( uRememberSerial->uEntryList.add( &(uOwner->uEntryRef), uRememberSerial->uMutexOwner, uRememberSerial ) == uLockAcquired ) {
+		//if ( uRememberSerial->uEntryList.add( &(owner->uEntryRef), uRememberSerial->uMutexOwner, uRememberSerial ) == uLockAcquired ) {
                     // only last call does not release lock, so reacquire first entry lock
 		//uThisTask().uCurrentSerial->lock.acquire();
 		//uRememberSerial->lock.release();
@@ -195,58 +195,58 @@ int uStaticPriorityQ::uAfterEntry(uBaseTask *uOwner ) { // use pointer to owner
 	    } else {
                 // call cluster routine to adjust ready queue and active
                 // priority Note: can only raise priority to at most uCalling,
-                // otherwise updating uOwner's priority can conflit with the
-                // uOwner blocking on an entry queue at a particular priority
+                // otherwise updating owner's priority can conflit with the
+                // owner blocking on an entry queue at a particular priority
                 // level.  Furthermore, uCalling's priority is fixed while the
                 // entry lock of where it is blocked (s->lock) is acquired, but
                 // uThisTask()'s priority can change as entry lock's are
                 // released along inheritance chain.
-		uThisCluster().uTaskSetPriority( *uOwner, uCalling );
+		uThisCluster().taskSetPriority( *owner, uCalling );
 	    } // if
 	} // if
     } // if
 
     return uRelPrevLock;
-} // uStaticPriorityQ::uAfterEntry
+} // uStaticPriorityQ::afterEntry
 
 
-void uStaticPriorityQ::uOnAcquire(uBaseTask &uOwner ) {
+void uStaticPriorityQ::onAcquire( uBaseTask &owner ) {
     // Dynamic check to verify that the task acquiring the serial is compliant
     // with PIHeap type.
-    uStaticPIQ *PIQptr = dynamic_cast<uStaticPIQ *>(uOwner.uPIQ);
+    uStaticPIQ *PIQptr = dynamic_cast<uStaticPIQ *>(owner.uPIQ);
     if ( PIQptr == NULL ) {
-	uAbort("(uStaticPriorityQ &)0x%p.uOnAcquire : Task 0x%p has incorrect uPIQ type for mutex object.", this, &uOwner);
+	uAbort("(uStaticPriorityQ &)0x%p.onAcquire : Task 0x%p has incorrect uPIQ type for mutex object.", this, &owner);
     } //if
 
     // check if mutex owner's priority needs to be updated
-    if ( PIQptr->uGetHighestPriority() < uGetActivePriorityValue( uOwner ) ) {
-	uThisCluster().uTaskSetPriority( uOwner, uOwner );
+    if ( PIQptr->getHighestPriority() < getActivePriorityValue( owner ) ) {
+	uThisCluster().taskSetPriority( owner, owner );
     } // if
 
     // remember current priority value, update task's uPIQ
-    uCurrPriority = uOwner.getBasePriority();
+    currPriority = owner.getBasePriority();
 
-    PIQptr->add( uCurrPriority );
+    PIQptr->add( currPriority );
 
     // perform priority inheritance
-    uAfterEntry( &uOwner );
-} // uStaticPriorityQ::uOnAcquire
+    afterEntry( &owner );
+} // uStaticPriorityQ::onAcquire
 
 
-void uStaticPriorityQ::uOnRelease(uBaseTask &uOldOwner ) {
-    // static_cast to PIHeap are valid here as add and uOnAcquire already
+void uStaticPriorityQ::onRelease( uBaseTask &oldOwner ) {
+    // static_cast to PIHeap are valid here as add and onAcquire already
     // verify that the associated tasks use type uStaticPIQ.
 
     // update task's uPIQ, reset stored values
-    (static_cast<uStaticPIQ *>(uOldOwner.uPIQ))->remove( uCurrPriority ); 
-    uCurrPriority = -1;
+    (static_cast<uStaticPIQ *>(oldOwner.uPIQ))->remove( currPriority ); 
+    currPriority = -1;
 
     // reset active priority if necessary
     // only case where priority can decrease
-    if ( (static_cast<uStaticPIQ *>(uOldOwner.uPIQ))->empty() || (static_cast<uStaticPIQ *>(uOldOwner.uPIQ))->uGetHighestPriority() > uGetActivePriorityValue( uOldOwner ) ) {
-	uThisCluster().uTaskSetPriority( uOldOwner, uOldOwner );
+    if ( (static_cast<uStaticPIQ *>(oldOwner.uPIQ))->empty() || (static_cast<uStaticPIQ *>(oldOwner.uPIQ))->getHighestPriority() > getActivePriorityValue( oldOwner ) ) {
+	uThisCluster().taskSetPriority( oldOwner, oldOwner );
     } // if
-} // uStaticPriorityQ::uOnRelease
+} // uStaticPriorityQ::onRelease
 
 // Local Variables: //
 // compile-command: "gmake install" //
