@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
+// uC++ Version 5.4.0, Copyright (C) Ashif S. Harji 2000
 // 
 // uStaticPriorityQ.h -- 
 // 
 // Author           : Ashif S. Harji
 // Created On       : Fri Jan 14 17:59:34 2000
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Oct 10 11:12:50 2005
-// Update Count     : 75
+// Last Modified On : Tue Sep 12 08:12:27 2006
+// Update Count     : 89
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -44,43 +44,43 @@
 
 class uStaticPriorityQ : public uBasePrioritySeq {
   protected:
-    uBaseTaskSeq uObjects[__U_MAX_NUMBER_PRIORITIES__];
-    unsigned int uMask;					// allow access to all queue flags
+    uBaseTaskSeq objects[__U_MAX_NUMBER_PRIORITIES__];
+    unsigned int mask;					// allow access to all queue flags
 
-    int uCurrPriority;
+    int currPriority;
   public:
     uStaticPriorityQ();
     virtual bool empty() const;
     virtual uBaseTaskDL *head() const;
-    virtual int add( uBaseTaskDL *node, uBaseTask *uOwner );
+    virtual int add( uBaseTaskDL *node, uBaseTask *owner );
     virtual uBaseTaskDL *drop();
     virtual void remove( uBaseTaskDL *node );
-    virtual void uOnAcquire(uBaseTask &uOldOwner);
-    virtual void uOnRelease( uBaseTask &uOwner );
+    virtual void onAcquire( uBaseTask &oldOwner );
+    virtual void onRelease( uBaseTask &owner );
 
-    int uAfterEntry( uBaseTask *uOwner );
+    int afterEntry( uBaseTask *owner );
 }; // StaticPriorityQ
 
 
 template<class List, class Node> class uStaticPriorityScheduleQ : public uBaseSchedule<Node> {
   protected:
-    List uObjects[__U_MAX_NUMBER_PRIORITIES__];
-    unsigned int uMask;					// allow access to all queue flags
+    List objects[__U_MAX_NUMBER_PRIORITIES__];
+    unsigned int mask;					// allow access to all queue flags
     unsigned int verCount;
   public:
     uStaticPriorityScheduleQ() {
-	verCount = uMask = 0;
+	verCount = mask = 0;
     } // uStaticPriorityScheduleQ::uStaticPriorityScheduleQ
 
     virtual bool empty() const {
-	return uMask == 0;
+	return mask == 0;
     } // uStaticPriorityScheduleQ::empty
 
     virtual Node *head() const {
-	int highestPriority = ffs( uMask ) - 1;
+	int highestPriority = ffs( mask ) - 1;
 
 	if ( highestPriority >= 0 ) {
-	    Node *node = uObjects[highestPriority].head();
+	    Node *node = objects[highestPriority].head();
 	    return node;
 	} else {
 	    return NULL;
@@ -88,29 +88,29 @@ template<class List, class Node> class uStaticPriorityScheduleQ : public uBaseSc
     } // uStaticPriorityScheduleQ::head
 
     virtual void add( Node *node ) {
-	int priority = uGetActivePriorityValue( node->uGet() );
+	int priority = getActivePriorityValue( node->task() );
 #ifdef __U_DEBUG__
-	uAssert( 0 <= priority && priority <= __U_MAX_NUMBER_PRIORITIES__ - 1 );
+	assert( 0 <= priority && priority <= __U_MAX_NUMBER_PRIORITIES__ - 1 );
 #endif // __U_DEBUG__
-	uObjects[priority].add( node );
-	uMask |= 1ul << priority;
+	objects[priority].add( node );
+	mask |= 1ul << priority;
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "(uStaticPriorityScheduleQ &)0x%p.add( 0x%p ) task %.256s (0x%p) adding task %.256s (0x%p) with priority %d on cluster 0x%p\n",
-		   this, node, uThisTask().getName(), &uThisTask(), node->uGet().getName(), &node->uGet(), priority, &uThisCluster() );
+		   this, node, uThisTask().getName(), &uThisTask(), node->task().getName(), &node->task(), priority, &uThisCluster() );
 #endif // __U_DEBUG_H__
     } // uStaticPriorityScheduleQ::add
 
     virtual Node *drop() {
-	int highestPriority = ffs( uMask ) - 1;
+	int highestPriority = ffs( mask ) - 1;
 
 	if ( highestPriority >= 0 ) {
-	    Node *node = uObjects[highestPriority].drop();
-	    if ( uObjects[highestPriority].empty() ) {
-		uMask &= ~ ( 1ul << highestPriority );
+	    Node *node = objects[highestPriority].drop();
+	    if ( objects[highestPriority].empty() ) {
+		mask &= ~ ( 1ul << highestPriority );
 	    } // if
 #ifdef __U_DEBUG_H__
 	    uDebugPrt( "(uStaticPriorityScheduleQ &)0x%p.drop( 0x%p ) task %.256s (0x%p) removing task %.256s (0x%p) with priority %d on cluster 0x%p\n",
-		       this, node, uThisTask().getName(), &uThisTask(), node->uGet().getName(), &node->uGet(), highestPriority, &uThisCluster() );
+		       this, node, uThisTask().getName(), &uThisTask(), node->task().getName(), &node->task(), highestPriority, &uThisCluster() );
 #endif // __U_DEBUG_H__
 	    return node;
 	} else {
@@ -118,12 +118,12 @@ template<class List, class Node> class uStaticPriorityScheduleQ : public uBaseSc
 	} // if
     } // uStaticPriorityScheduleQ::drop
 
-    virtual bool uCheckPriority( Node &, Node & ) {
+    virtual bool checkPriority( Node &, Node & ) {
 	return false;
-    } // uStaticPriorityScheduleQ::uCheckPriority
+    } // uStaticPriorityScheduleQ::checkPriority
 
-    virtual void uResetPriority( Node &, Node & ) {
-    } // uStaticPriorityScheduleQ::uResetPriority
+    virtual void resetPriority( Node &, Node & ) {
+    } // uStaticPriorityScheduleQ::resetPriority
 
     virtual void addInitialize( uBaseTaskSeq & ) {
     } // uStaticPriorityScheduleQ::addInitialize
@@ -131,51 +131,51 @@ template<class List, class Node> class uStaticPriorityScheduleQ : public uBaseSc
     virtual void removeInitialize( uBaseTaskSeq & ) {
     } // uStaticPriorityScheduleQ::removeInitialize
 
-    virtual void uRescheduleTask( uBaseTaskDL *, uBaseTaskSeq & ) {
-    } // uStaticPriorityScheduleQ::uRescheduleTask
+    virtual void rescheduleTask( uBaseTaskDL *, uBaseTaskSeq & ) {
+    } // uStaticPriorityScheduleQ::rescheduleTask
 }; // uStaticPriorityScheduleQ
 
 
 template<class List, class Node> class uStaticPriorityScheduleSeq : public uStaticPriorityScheduleQ<List, Node> {
   protected:
-    using uStaticPriorityScheduleQ<List, Node>::uObjects;
-    using uStaticPriorityScheduleQ<List, Node>::uMask;
-    using uStaticPriorityScheduleQ<List, Node>::uSetActivePriority;
+    using uStaticPriorityScheduleQ<List, Node>::objects;
+    using uStaticPriorityScheduleQ<List, Node>::mask;
+    using uStaticPriorityScheduleQ<List, Node>::setActivePriority;
   public:
-    virtual bool uCheckPriority( Node &owner, Node &calling ) {
-	return uGetActivePriorityValue( owner.uGet() ) > uGetActivePriorityValue( calling.uGet() );
-    } // uPriorityScheduleSeq::uCheckPriority
+    virtual bool checkPriority( Node &owner, Node &calling ) {
+	return getActivePriorityValue( owner.task() ) > getActivePriorityValue( calling.task() );
+    } // uPriorityScheduleSeq::checkPriority
 
-    virtual void uResetPriority( Node &owner, Node &calling ) {
+    virtual void resetPriority( Node &owner, Node &calling ) {
 	int priority;
-	uBaseTask &uOwner = owner.uGet();
-	uBaseTask &uCalling = calling.uGet();
+	uBaseTask &ownerTask = owner.task();
+	uBaseTask &callingTask = calling.task();
 	// if same, update owner based on uPIQ
-	if ( &uOwner == &uCalling ) {
-	    priority = (static_cast<uStaticPIQ *>(uOwner.uPIQ))->uGetHighestPriority(); // TODO: dynamic needed???
+	if ( &ownerTask == &callingTask ) {
+	    priority = (static_cast<uStaticPIQ *>(ownerTask.uPIQ))->getHighestPriority(); // TODO: dynamic needed???
 	    // if no inheritance priority use base priority
 	    if ( priority == -1 ) {
-		priority = uOwner.getBasePriority();
+		priority = ownerTask.getBasePriority();
 	    } // if
 	} else {  // otherwise, update to atmost calling task's priority
-	    if ( uCalling.getActivePriorityValue() > uOwner.getActivePriorityValue() ) return;
-	    priority = uCalling.getActivePriorityValue();
+	    if ( callingTask.getActivePriorityValue() > ownerTask.getActivePriorityValue() ) return;
+	    priority = callingTask.getActivePriorityValue();
 	} // if
 		
 	if ( owner.listed() ) {
 	    remove( &owner );
-	    uSetActivePriority( uOwner, priority );
+	    setActivePriority( ownerTask, priority );
 	    add( &owner );
 	} else {
-	    uSetActivePriority( uOwner, priority );
+	    setActivePriority( ownerTask, priority );
 	} // if
-    } // uPriorityScheduleSeq::uResetPriority
+    } // uPriorityScheduleSeq::resetPriority
 
     virtual void remove( Node *node ) {
-	int priority = uGetActivePriorityValue( node->uGet() );
-	uObjects[priority].remove( node );
-	if ( uObjects[priority].empty() ) {
-	    uMask &= ~ ( 1ul << priority );
+	int priority = getActivePriorityValue( node->task() );
+	objects[priority].remove( node );
+	if ( objects[priority].empty() ) {
+	    mask &= ~ ( 1ul << priority );
 	} // if
     } // uPriorityScheduleSeq::remove
 }; // uPriorityScheduleSeq
