@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
 // 
 // gen.c -- 
 // 
 // Author           : Richard A. Stroobosscher
 // Created On       : Tue Apr 28 15:00:53 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Dec 12 09:02:41 2005
-// Update Count     : 805
+// Last Modified On : Fri Jan 27 07:49:07 2006
+// Update Count     : 807
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -199,21 +199,21 @@ void gen_main_prefix( token_t *before, symbol_t *symbol ) {
     if ( table->symbol->data->key == TASK ) {
 	if ( table->symbol->data->attribute.rttskkind.kind.PERIODIC ) {
 	    gen_code( before,
-		     "uSleep ( uFirstActivateTime ) ; "
-		     "if ( uEndTime == 0 || uThisProcessor ( ) . getClock ( ) . getTime ( ) < uEndTime ) { "
+		     "uSleep ( firstActivateTime ) ; "
+		     "if ( endTime == 0 || uThisProcessor ( ) . getClock ( ) . getTime ( ) < endTime ) { "
 		     "for ( ; ; ) { "
-		     "uTime uStartTime = uThisProcessor ( ) . getClock ( ) . getTime ( ) + uGetPeriod ( ) ;"
+		     "uTime uStartTime = uThisProcessor ( ) . getClock ( ) . getTime ( ) + getPeriod ( ) ;"
 		     );
 	} else if ( table->symbol->data->attribute.rttskkind.kind.SPORADIC ) {
 	    gen_code( before,
-		     "uSleep ( uFirstActivateTime ) ; "
-		     "if ( uEndTime == 0 || uThisProcessor ( ) . getClock ( ) . getTime ( ) < uEndTime ) { "
+		     "uSleep ( firstActivateTime ) ; "
+		     "if ( endTime == 0 || uThisProcessor ( ) . getClock ( ) . getTime ( ) < endTime ) { "
 		     "for ( ; ; ) { "
-		     "uTime uStartTime = uThisProcessor ( ) . getClock ( ) . getTime ( ) + uGetPeriod ( ) ;"
+		     "uTime uStartTime = uThisProcessor ( ) . getClock ( ) . getTime ( ) + getPeriod ( ) ;"
 		     );
 	} else if ( table->symbol->data->attribute.rttskkind.kind.APERIODIC ) {
 	    gen_code( before,
-		     "uSleep ( uFirstActivateTime ) ; "
+		     "uSleep ( firstActivateTime ) ; "
 		     "for ( ; ; ) {"
 		     );
 	} // if
@@ -231,13 +231,13 @@ void gen_main_suffix( token_t *before, symbol_t *symbol ) {
     if ( table->symbol->data->key == COROUTINE || table->symbol->data->key == TASK ) {
 	if ( table->symbol->data->attribute.rttskkind.kind.PERIODIC ) {
 	    gen_code( before,
-		     "if ( uEndTime != 0 && uEndTime <= uStartTime ) break ; "
+		     "if ( endTime != 0 && endTime <= uStartTime ) break ; "
 		     "uSleep( uStartTime ) ;"
 		     );
 	    gen_code( before, "} }" );
 	} else if ( table->symbol->data->attribute.rttskkind.kind.SPORADIC ) {
 	    gen_code( before,
-		     "if ( uEndTime != 0 && uEndTime <= uStartTime ) break ;"
+		     "if ( endTime != 0 && endTime <= uStartTime ) break ;"
 		     );
 	    gen_code( before, "} }" );
 	} else if ( table->symbol->data->attribute.rttskkind.kind.APERIODIC ) {
