@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr and Nikita Borisov 1995
+// uC++ Version 5.4.0, Copyright (C) Peter A. Buhr and Nikita Borisov 1995
 // 
 // u++.cc -- 
 // 
 // Author           : Nikita Borisov
 // Created On       : Tue Apr 28 15:26:27 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Dec 21 11:23:45 2005
-// Update Count     : 786
+// Last Modified On : Fri Sep 15 20:54:49 2006
+// Update Count     : 797
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -105,6 +105,7 @@ int main( int argc, char *argv[] ) {
     bool verify = false;				// -verify flag
     bool profile = false;				// -profile flag
     bool debugging = false;				// -g flag
+    bool openmp = false;				// -openmp flag
 
     const char *args[argc + 100];			// u++ command line values, plus some space for additional flags
 #if __GNUC__==3 && __GNUC_MINOR__==2
@@ -267,6 +268,10 @@ int main( int argc, char *argv[] ) {
 		// if the user specifies a library, load it after user code
 		libs[nlibs] = argv[i];
 		nlibs += 1;
+	    } else if ( arg == "-openmp" ) {
+		openmp = true;				// openmp mode
+		args[nargs] = argv[i];			// pass the argument along
+		nargs += 1;
 	    } else {
 		// concatenate any other arguments
 		args[nargs] = argv[i];
@@ -399,19 +404,19 @@ int main( int argc, char *argv[] ) {
 	    // link the profiling library before the user code
 	    args[sargs] = "-u";
 	    sargs += 1;
-	    args[sargs] = "__cyg_profile_func_enter";	// force profiler library to be loaded from archive
+	    args[sargs] = "__cyg_profile_func_enter";	// force profiler library to be loaded
 	    sargs += 1;
 	    args[sargs] = "-u";
 	    sargs += 1;
-	    args[sargs] = "U_EXACTPROFILINGSW";		// force profiler start-up widgets to be loaded from archive
+	    args[sargs] = "U_SMEXACTMENUWD";		// force profiler start-up widgets to be loaded
 	    sargs += 1;
 	    args[sargs] = "-u";
 	    sargs += 1;
-	    args[sargs] = "U_STATSPROFILINGSW";		// force profiler start-up widgets to be loaded from archive
+	    args[sargs] = "U_SMSTATSMENUWD";		// force profiler start-up widgets to be loaded
 	    sargs += 1;
 	    args[sargs] = "-u";
 	    sargs += 1;
-	    args[sargs] = "U_OTHERPROFILINGSW";		// force profiler start-up widgets to be loaded from archive
+	    args[sargs] = "U_SMOTHERMENUWD";		// force profiler start-up widgets to be loaded
 	    sargs += 1;
 	    args[sargs] = ( *new string( mvdlibdir + "/uProfile"  + m + d + ".a" ) ).c_str();
 	    sargs += 1;
@@ -434,6 +439,12 @@ int main( int argc, char *argv[] ) {
 	    nargs += 1;
 	} // if
 
+	// override uDefaultProcessors for OpenMP -- must come before uKernel
+	if ( openmp ) {
+	    args[nargs] = ( *new string( installlibdir + "/uDefaultProcessors-OpenMP.o" ) ).c_str();
+	    nargs += 1;
+	} // if
+
 	// link with the correct version of the kernel module
 
 	args[nargs] = ( *new string( installlibdir + "/uKernel" + m + d + ".a" ) ).c_str();
@@ -470,8 +481,9 @@ int main( int argc, char *argv[] ) {
 
 	// any machine specific libraries
 
-	if ( tos != "irix" ) {
+	if ( tos != "irix" && tos != "freebsd" ) {
 	    // unnecessary on irix, and potentially not present in 64-bit
+	    // not on freebsd at all
 	    libs[nlibs] = "-ldl";			// calls to dlsym/dlerror
 	    nlibs += 1;
 	} // if
@@ -637,16 +649,26 @@ int main( int argc, char *argv[] ) {
         heading += " (no profile)";
     } // if
 
+    if ( openmp ) {
+	args[nargs] = "-D__U_OPENMP__";
+	nargs += 1;
+    } // if
+
 #if defined( TLS )					// Thread Local Storage ?
     args[nargs] = "-D__U_TLS__";
     nargs += 1;
 #endif // U_TLS
 
-#if defined( ONETIMER )					// Thread Local Storage ?
+#if defined( ONETIMER )					// Per-process, instead of per-kernel-thread timers
     args[nargs] = "-D__U_ONETIMER__";
     nargs += 1;
 #endif // U_ONETIMER
 
+#if defined( BROKEN_CANCEL )				// TEMPORARY: old glibc has pthread_testcancel as throw()
+    args[nargs] = "-D__U_BROKEN_CANCEL__";
+    nargs += 1;
+#endif // U_ONETIMER
+
     if ( Bprefix.length() == 0 ) {
 	Bprefix = installlibdir;
 	args[nargs] = ( *new string( string("-D__U_GCC_BPREFIX__=") + Bprefix ) ).c_str();
@@ -666,8 +688,7 @@ int main( int argc, char *argv[] ) {
 
     if ( prefix( compiler_name, "g++" ) ) {		// allow suffix on g++ name
 	if ( tcpu == "ia64" ) {
-	    // TEMPORARY: gcc 3 code gen problem on ia64
-	    args[nargs] = "-fno-optimize-sibling-calls"; 
+	    args[nargs] = "-fno-optimize-sibling-calls"; // TEMPORARY: gcc 3 code gen problem on ia64
 	    nargs += 1;
 	} // if
 	args[nargs] = "-no-integrated-cpp"; 
@@ -684,12 +705,13 @@ int main( int argc, char *argv[] ) {
 	// 177 label used but never referenced
 	// 239 floating-point underflow -- necessary for gcc includes
 	// 327 null reference
+	// 654 overloaded virtual function is only partially overridden
 	// 873 no placement delete operator
 	// 1125 virtual function override intended? -- useful, but prone to false positives
 	// 1292 attribute "__nonnull__" ignored -- necessary for gcc includes
 	// 1476 tail padding of base class
 	// 1572 floating-point equality -- necessary for gcc includes
-	args[nargs] = "-wd61,68,161,177,239,327,873,1125,1292,1476,1572";
+	args[nargs] = "-wd61,68,161,177,239,327,654,873,1125,1292,1476,1572";
 	nargs += 1;
     } else {
 	cerr << argv[0] << " error, compiler " << compiler_name << " not supported." << endl;
